@@ -6,8 +6,8 @@
  * Date        : 2004-06-15
  * Description : digiKam album types
  *
- * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * Copyright (C) 2006-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,6 +46,11 @@
 namespace Digikam
 {
 
+/** Album list type definition.
+ */
+class Album;
+typedef QList<Album*> AlbumList;    
+    
 /**
  * \class Album
  * \brief Abstract base class for all album types
@@ -102,7 +107,7 @@ public:
     /**
      * @return a list of all child Albums
      */
-    QList<Album*>  childAlbums(bool recursive = false);
+    AlbumList childAlbums(bool recursive = false);
 
     /**
      * @return a list of all child Albums
@@ -166,7 +171,7 @@ public:
      * @param album Album to check whether it belongs in the child
      * hierarchy
      */
-    bool    isAncestorOf(Album* album) const;
+    bool    isAncestorOf(Album* const album) const;
 
     /**
      * This allows to associate some "extra" data to a Album. As one
@@ -197,7 +202,7 @@ public:
      * @see extraData
      * @see removeExtraData
      */
-    void    setExtraData(const void* key, void* value);
+    void    setExtraData(const void* const key, void* const value);
 
     /**
      * Remove the associated extra data associated with @p key
@@ -206,7 +211,7 @@ public:
      * @see setExtraData
      * @see extraData
      */
-    void    removeExtraData(const void* key);
+    void    removeExtraData(const void* const key);
 
     /**
      * Retrieve the associated extra data associated with @p key
@@ -215,7 +220,7 @@ public:
      * @see setExtraData
      * @see extraData
      */
-    void*   extraData(const void* key) const;
+    void*   extraData(const void* const key) const;
 
 protected:
 
@@ -224,11 +229,6 @@ protected:
      */
     Album(Album::Type type, int id, bool root);
 
-    /**
-     * Constructor
-     */
-    Album(Album::Type type, QString name, bool root);
-
     /**
      * Destructor
      *
@@ -257,7 +257,7 @@ protected:
      *
      * @param parent set the parent album of album to @p parent
      */
-    void setParent(Album* parent);
+    void setParent(Album* const parent);
 
     /**
      * @internal use only
@@ -266,7 +266,7 @@ protected:
      *
      * @param child the Album to add as child
      */
-    void insertChild(Album* child);
+    void insertChild(Album* const child);
 
     /**
      * @internal use only
@@ -275,7 +275,7 @@ protected:
      *
      * @param child the Album to remove
      */
-    void removeChild(Album* child);
+    void removeChild(Album* const child);
 
 private:
 
@@ -318,7 +318,7 @@ class PAlbum : public Album
 public:
 
     /// Constructor for root album
-    PAlbum(const QString& title);
+    explicit PAlbum(const QString& title);
     /// Constructor for album root albums
     PAlbum(int albumRoot, const QString& label);
     /// Constructor for normal albums
@@ -519,7 +519,7 @@ class AlbumIterator
 {
 public:
 
-    AlbumIterator(Album* album);
+    explicit AlbumIterator(Album* const album);
     ~AlbumIterator();
 
     AlbumIterator& operator++();
@@ -528,12 +528,9 @@ public:
 
 private:
 
-    AlbumIterator() {}
-    AlbumIterator(const AlbumIterator&) {}
-    AlbumIterator& operator=(const AlbumIterator&)
-    {
-        return *this;
-    }
+    // disable copying and construction without an album
+    AlbumIterator();
+    Q_DISABLE_COPY(AlbumIterator)
 
 private:
 
