@@ -273,7 +273,7 @@ AlbumPropsEdit::AlbumPropsEdit(PAlbum* const album, bool create)
         d->titleEdit->setText(i18n("New Album"));
         d->datePicker->setDate(QDate::currentDate());
         d->parentCombo->addItem(i18n("Selected Album (Default)"));
-        d->parentCombo->addItem(i18nc("top level folder of album","Root"));
+        d->parentCombo->addItem(i18nc("top level folder of album","Root of current collection"));
     }
     else
     {
