@@ -7,8 +7,8 @@
  * Description : scan pictures interface.
  *
  * Copyright (C) 2005-2006 by Tom Albers <tomalbers@kde.nl>
- * Copyright (C) 2006-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2006-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -55,6 +55,7 @@
 #include "databaseaccess.h"
 #include "collectionmanager.h"
 #include "collectionlocation.h"
+#include "filereadwritelock.h"
 #include "loadingcache.h"
 #include "databasewatch.h"
 #include "databasechangesets.h"
@@ -75,7 +76,8 @@ class SimpleCollectionScannerObserver : public CollectionScannerObserver
 {
 public:
 
-    explicit SimpleCollectionScannerObserver(bool* var) : m_continue(var)
+    explicit SimpleCollectionScannerObserver(bool* const var)
+        : m_continue(var)
     {
         *m_continue = true;
     }
@@ -90,11 +92,11 @@ public:
 
 // ------------------------------------------------------------------------------
 
-class ScanController::ScanControllerPriv
+class ScanController::Private
 {
 public:
 
-    ScanControllerPriv() :
+    Private() :
         running(false),
         needsInitialization(false),
         needsCompleteScan(false),
@@ -110,6 +112,7 @@ public:
         eventLoop(0),
         showTimer(0),
         relaxedTimer(0),
+        hints(CollectionScanner::createHintContainer()),
         progressDialog(0),
         splash(0),
         advice(ScanController::Success),
@@ -151,9 +154,13 @@ public:
     QPixmap                   actionPix;
     QPixmap                   errorPix;
 
+    /* Lists only needed for inter-process / network-wide communication, all DBUS-able
     QList<AlbumCopyMoveHint>  albumHints;
     QList<ItemCopyMoveHint>   itemHints;
     QList<ItemChangeHint>     itemChangeHints;
+    QList<ItemMetadataAdjustmentHint> itemMetadataAdjustmentHints;
+    */
+    CollectionScannerHintContainer* hints;
 
     QDateTime                 lastHintAdded;
 
@@ -220,16 +227,19 @@ public:
 
     void garbageCollectHints(bool setAccessTime)
     {
-        // called with locked mutex
         QDateTime current = QDateTime::currentDateTime();
 
-        if (idle &&
+        if (idle                    &&
             lastHintAdded.isValid() &&
-            lastHintAdded.secsTo(current) > 5*60)
+            lastHintAdded.secsTo(current) > (5*60))
         {
+            /*
             itemHints.clear();
             albumHints.clear();
             itemChangeHints.clear();
+            itemMetadataAdjustmentHints.clear();
+            */
+            hints->clear();
         }
 
         if (setAccessTime)
@@ -270,6 +280,7 @@ public:
 
     ScanController object;
 };
+
 K_GLOBAL_STATIC(ScanControllerCreator, creator)
 
 // ------------------------------------------------------------------------------
@@ -280,7 +291,7 @@ ScanController* ScanController::instance()
 }
 
 ScanController::ScanController()
-    : d(new ScanControllerPriv)
+    : d(new Private)
 {
     // create event loop
     d->eventLoop = new QEventLoop(this);
@@ -326,6 +337,7 @@ ScanController::~ScanController()
     shutDown();
 
     delete d->progressDialog;
+    delete d->hints;
     delete d;
 }
 
@@ -340,6 +352,7 @@ void ScanController::shutDown()
     d->continueInitialization = false;
     d->continueScan           = false;
     d->continuePartialScan    = false;
+
     {
         QMutexLocker lock(&d->mutex);
         d->condVar.wakeAll();
@@ -401,19 +414,21 @@ ScanController::Advice ScanController::databaseInitialization()
     d->advice = Success;
     createProgressDialog();
     setInitializationMessage();
+
     {
         QMutexLocker lock(&d->mutex);
         d->needsInitialization = true;
         d->condVar.wakeAll();
     }
+
     // loop is quit by signal
     d->eventLoop->exec();
 
     // setup file watch service for LoadingCache - now that we are sure we have a DatabaseWatch
     if (!d->fileWatchInstalled)
     {
-        d->fileWatchInstalled = true; // once per application lifetime only
-        LoadingCache* cache   = LoadingCache::cache();
+        d->fileWatchInstalled     = true; // once per application lifetime only
+        LoadingCache* const cache = LoadingCache::cache();
         LoadingCache::CacheLock lock(cache);
         cache->setFileWatch(new ScanControllerLoadingCacheFileWatch);
     }
@@ -424,7 +439,7 @@ ScanController::Advice ScanController::databaseInitialization()
     return d->advice;
 }
 
-void ScanController::completeCollectionScanDeferFiles(SplashScreen* splash)
+void ScanController::completeCollectionScanDeferFiles(SplashScreen* const splash)
 {
     completeCollectionScan(splash, true);
 }
@@ -436,27 +451,40 @@ void ScanController::allowToScanDeferredFiles()
     d->condVar.wakeAll();
 }
 
-void ScanController::completeCollectionScan(SplashScreen* splash, bool defer)
+void ScanController::completeCollectionScan(SplashScreen* const splash, bool defer)
 {
     d->splash = splash;
     createProgressDialog();
+    
     // we only need to count the files in advance
-    //if we show a progress percentage in progress dialog
-    d->needTotalFiles = (!d->splash || !CollectionScanner::databaseInitialScanDone());
+    // if we show a progress percentage in progress dialog
+    completeCollectionScanCore(!d->splash || !CollectionScanner::databaseInitialScanDone(), defer);
 
+    delete d->progressDialog;
+    d->progressDialog = 0;
+    // We do not delete Splashscreen here.
+    d->splash         = 0;
+}
+
+void ScanController::completeCollectionScanInBackground(bool defer)
+{
+    completeCollectionScanCore(true, defer);
+}
+
+void ScanController::completeCollectionScanCore(bool needTotalFiles, bool defer)
+{
+    d->needTotalFiles = needTotalFiles;
+    
     {
         QMutexLocker lock(&d->mutex);
         d->needsCompleteScan = true;
         d->deferFileScanning = defer;
         d->condVar.wakeAll();
     }
+
     // loop is quit by signal
     d->eventLoop->exec();
-
-    delete d->progressDialog;
-    d->progressDialog = 0;
-    // We do not delete Splashscreen here.
-    d->splash         = 0;
+    
     d->needTotalFiles = false;
 }
 
@@ -518,10 +546,10 @@ void ScanController::slotRelaxedScanning()
 ImageInfo ScanController::scannedInfo(const QString& filePath)
 {
     CollectionScanner scanner;
-    scanner.recordHints(d->itemHints);
-    scanner.recordHints(d->itemChangeHints);
+    scanner.setHintContainer(d->hints);
 
     ImageInfo info(filePath);
+
     if (info.isNull())
     {
         qlonglong id = scanner.scanFile(filePath, CollectionScanner::NormalScan);
@@ -537,11 +565,7 @@ ImageInfo ScanController::scannedInfo(const QString& filePath)
 ScanController::FileMetadataWrite::FileMetadataWrite(const ImageInfo& info)
     : m_info(info), m_changed(false)
 {
-    // This class does not implement the optimization which is possible
-    // Idea: Get modification time before and after the operation,
-    // if file was properly scanned at all times (seen from mod times)
-    // use a shortened scan which only updates the hard values,
-    // and also take care to reuse the thumbnail.
+    ScanController::instance()->beginFileMetadataWrite(info);
 }
 
 void ScanController::FileMetadataWrite::changed(bool wasChanged)
@@ -551,10 +575,7 @@ void ScanController::FileMetadataWrite::changed(bool wasChanged)
 
 ScanController::FileMetadataWrite::~FileMetadataWrite()
 {
-    if (m_changed)
-    {
-        ScanController::instance()->scanFileDirectly(m_info.filePath());
-    }
+    ScanController::instance()->finishFileMetadataWrite(m_info, m_changed);
 }
 
 void ScanController::scanFileDirectly(const QString& filePath)
@@ -562,13 +583,19 @@ void ScanController::scanFileDirectly(const QString& filePath)
     suspendCollectionScan();
 
     CollectionScanner scanner;
-    scanner.recordHints(d->itemHints);
-    scanner.recordHints(d->itemChangeHints);
+    scanner.setHintContainer(d->hints);
     scanner.scanFile(filePath);
 
     resumeCollectionScan();
 }
 
+void ScanController::scanFileDirectlyNormal(const ImageInfo& info)
+{
+    CollectionScanner scanner;
+    scanner.setHintContainer(d->hints);
+    scanner.scanFile(info, CollectionScanner::NormalScan);
+}
+
 /*
 
     / **
@@ -721,10 +748,7 @@ void ScanController::run()
 
             scanner.setNeedFileCount(d->needTotalFiles);
             scanner.setDeferredFileScanning(doScanDeferred);
-
-            scanner.recordHints(d->albumHints);
-            scanner.recordHints(d->itemHints);
-            scanner.recordHints(d->itemChangeHints);
+            scanner.setHintContainer(d->hints);
 
             SimpleCollectionScannerObserver observer(&d->continueScan);
             scanner.setObserver(&observer);
@@ -732,6 +756,7 @@ void ScanController::run()
             scanner.completeScan();
 
             emit completeScanDone();
+
             if (doScanDeferred)
             {
                 d->completeScanDeferredAlbums = scanner.deferredAlbumPaths();
@@ -744,6 +769,7 @@ void ScanController::run()
             {
                 continue;
             }
+
             CollectionScanner scanner;
             connectCollectionScanner(&scanner);
 
@@ -751,9 +777,7 @@ void ScanController::run()
             //TODO: reconsider performance
             scanner.setNeedFileCount(true);//d->needTotalFiles);
 
-            scanner.recordHints(d->albumHints);
-            scanner.recordHints(d->itemHints);
-            scanner.recordHints(d->itemChangeHints);
+            scanner.setHintContainer(d->hints);
 
             SimpleCollectionScannerObserver observer(&d->continueScan);
             scanner.setObserver(&observer);
@@ -767,13 +791,12 @@ void ScanController::run()
         else if (doPartialScan)
         {
             CollectionScanner scanner;
-            scanner.recordHints(d->albumHints);
-            scanner.recordHints(d->itemHints);
-            scanner.recordHints(d->itemChangeHints);
+            scanner.setHintContainer(d->hints);
             //connectCollectionScanner(&scanner);
             SimpleCollectionScannerObserver observer(&d->continuePartialScan);
             scanner.setObserver(&observer);
             scanner.partialScan(task);
+            emit partialScanDone(task);
         }
         else if (doUpdateUniqueHash)
         {
@@ -788,7 +811,7 @@ void ScanController::run()
 }
 
 // (also implementing InitializationObserver)
-void ScanController::connectCollectionScanner(CollectionScanner* scanner)
+void ScanController::connectCollectionScanner(CollectionScanner* const scanner)
 {
     scanner->setSignalsEnabled(true);
 
@@ -820,6 +843,7 @@ void ScanController::slotTotalFilesToScan(int count)
     {
         d->progressDialog->incrementMaximum(count);
     }
+
     d->totalFilesToScan = count;
     emit totalFilesToScan(d->totalFilesToScan);
 }
@@ -829,7 +853,7 @@ void ScanController::slotStartCompleteScan()
     d->totalFilesToScan = 0;
     slotTriggerShowProgressDialog();
 
-    QString message = i18n("Preparing collection scan...");
+    QString message     = i18n("Preparing collection scan...");
 
     if (d->splash)
     {
@@ -858,6 +882,7 @@ void ScanController::slotScannedFiles(int scanned)
     {
         d->progressDialog->advance(scanned);
     }
+
     if (d->totalFilesToScan)
     {
         emit filesScanned(scanned);
@@ -995,7 +1020,7 @@ void ScanController::setInitializationMessage()
     }
 }
 
-static AlbumCopyMoveHint hintForAlbum(const PAlbum* album, int dstAlbumRootId, const QString& relativeDstPath,
+static AlbumCopyMoveHint hintForAlbum(const PAlbum* const album, int dstAlbumRootId, const QString& relativeDstPath,
                                       const QString& albumName)
 {
     QString dstAlbumPath;
@@ -1013,7 +1038,7 @@ static AlbumCopyMoveHint hintForAlbum(const PAlbum* album, int dstAlbumRootId, c
                              dstAlbumRootId, dstAlbumPath);
 }
 
-static QList<AlbumCopyMoveHint> hintsForAlbum(const PAlbum* album, int dstAlbumRootId, QString relativeDstPath,
+static QList<AlbumCopyMoveHint> hintsForAlbum(const PAlbum* const album, int dstAlbumRootId, QString relativeDstPath,
                                               const QString& albumName)
 {
     QList<AlbumCopyMoveHint> newHints;
@@ -1028,7 +1053,7 @@ static QList<AlbumCopyMoveHint> hintsForAlbum(const PAlbum* album, int dstAlbumR
 
     for (AlbumIterator it(const_cast<PAlbum*>(album)); *it; ++it)
     {
-        PAlbum* a = (PAlbum*)*it;
+        PAlbum* const a = (PAlbum*)*it;
         QString childAlbumPath = a->albumPath();
         newHints << hintForAlbum(a, dstAlbumRootId, relativeDstPath, albumName + childAlbumPath.mid(parentAlbumPath.length()));
     }
@@ -1036,7 +1061,7 @@ static QList<AlbumCopyMoveHint> hintsForAlbum(const PAlbum* album, int dstAlbumR
     return newHints;
 }
 
-void ScanController::hintAtMoveOrCopyOfAlbum(const PAlbum* album, const QString& dstPath, const QString& newAlbumName)
+void ScanController::hintAtMoveOrCopyOfAlbum(const PAlbum* const album, const QString& dstPath, const QString& newAlbumName)
 {
     // get album root and album from dst path
     CollectionLocation location = CollectionManager::instance()->locationForPath(dstPath);
@@ -1048,66 +1073,90 @@ void ScanController::hintAtMoveOrCopyOfAlbum(const PAlbum* album, const QString&
         return;
     }
 
-    QString relativeDstPath = CollectionManager::instance()->album(location, dstPath);
+    QString relativeDstPath           = CollectionManager::instance()->album(location, dstPath);
 
     QList<AlbumCopyMoveHint> newHints = hintsForAlbum(album, location.id(), relativeDstPath,
                                                       newAlbumName.isNull() ? album->title() : newAlbumName);
 
-    QMutexLocker lock(&d->mutex);
-    d->albumHints << newHints;
+    //QMutexLocker lock(&d->mutex);
+    //d->albumHints << newHints;
+    d->hints->recordHints(newHints);
 }
 
-void ScanController::hintAtMoveOrCopyOfAlbum(const PAlbum* album, const PAlbum* dstAlbum, const QString& newAlbumName)
+void ScanController::hintAtMoveOrCopyOfAlbum(const PAlbum* const album, const PAlbum* const dstAlbum, const QString& newAlbumName)
 {
     QList<AlbumCopyMoveHint> newHints = hintsForAlbum(album, dstAlbum->albumRootId(), dstAlbum->albumPath(),
                                                       newAlbumName.isNull() ? album->title() : newAlbumName);
 
-    QMutexLocker lock(&d->mutex);
-    d->albumHints << newHints;
+    //QMutexLocker lock(&d->mutex);
+    //d->albumHints << newHints;
+    d->hints->recordHints(newHints);
 }
 
-void ScanController::hintAtMoveOrCopyOfItems(const QList<qlonglong> ids, const PAlbum* dstAlbum,
+void ScanController::hintAtMoveOrCopyOfItems(const QList<qlonglong> ids, const PAlbum* const dstAlbum,
                                              const QStringList& itemNames)
 {
     ItemCopyMoveHint hint(ids, dstAlbum->albumRootId(), dstAlbum->id(), itemNames);
 
-    QMutexLocker lock(&d->mutex);
     d->garbageCollectHints(true);
-    d->itemHints << hint;
+    //d->itemHints << hint;
+    d->hints->recordHints(QList<ItemCopyMoveHint>() << hint);
 }
 
-void ScanController::hintAtMoveOrCopyOfItem(qlonglong id, const PAlbum* dstAlbum, const QString& itemName)
+void ScanController::hintAtMoveOrCopyOfItem(qlonglong id, const PAlbum* const dstAlbum, const QString& itemName)
 {
     ItemCopyMoveHint hint(QList<qlonglong>() << id, dstAlbum->albumRootId(), dstAlbum->id(), QStringList() << itemName);
 
-    QMutexLocker lock(&d->mutex);
     d->garbageCollectHints(true);
-    d->itemHints << hint;
+    //d->itemHints << hint;
+    d->hints->recordHints(QList<ItemCopyMoveHint>() << hint);
 }
 
 void ScanController::hintAtModificationOfItems(const QList<qlonglong> ids)
 {
     ItemChangeHint hint(ids, ItemChangeHint::ItemModified);
 
-    QMutexLocker lock(&d->mutex);
     d->garbageCollectHints(true);
-    d->itemChangeHints << hint;
+    //d->itemHints << hint;
+    d->hints->recordHints(QList<ItemChangeHint>() << hint);
 }
 
 void ScanController::hintAtModificationOfItem(qlonglong id)
 {
     ItemChangeHint hint(QList<qlonglong>() << id, ItemChangeHint::ItemModified);
 
-    QMutexLocker lock(&d->mutex);
     d->garbageCollectHints(true);
-    d->itemChangeHints << hint;
+    //d->itemHints << hint;
+    d->hints->recordHints(QList<ItemChangeHint>() << hint);
+}
+
+void ScanController::beginFileMetadataWrite(const ImageInfo& info)
+{
+    {
+        // throw in a lock to synchronize with all parallel writing
+        FileReadLocker locker(info.filePath());
+    }
+    QFileInfo fi(info.filePath());
+    d->hints->recordHint(ItemMetadataAdjustmentHint(info.id(), ItemMetadataAdjustmentHint::AboutToEditMetadata,
+                                                    fi.lastModified(), fi.size()));
+}
+
+void ScanController::finishFileMetadataWrite(const ImageInfo& info, bool changed)
+{
+    QFileInfo fi(info.filePath());
+    d->hints->recordHint(ItemMetadataAdjustmentHint(info.id(),
+                                                    changed ? ItemMetadataAdjustmentHint::MetadataEditingFinished :
+                                                              ItemMetadataAdjustmentHint::MetadataEditingAborted,
+                                                    fi.lastModified(), fi.size()));
+
+    scanFileDirectlyNormal(info);
 }
 
 // --------------------------------------------------------------------------------------------
 
 ScanControllerLoadingCacheFileWatch::ScanControllerLoadingCacheFileWatch()
 {
-    DatabaseWatch* dbwatch = DatabaseAccess::databaseWatch();
+    DatabaseWatch* const dbwatch = DatabaseAccess::databaseWatch();
 
     // we opt for a queued connection to make stuff a bit relaxed
     connect(dbwatch, SIGNAL(imageChange(ImageChangeset)),
@@ -1117,14 +1166,11 @@ ScanControllerLoadingCacheFileWatch::ScanControllerLoadingCacheFileWatch()
 
 void ScanControllerLoadingCacheFileWatch::slotImageChanged(const ImageChangeset& changeset)
 {
-    DatabaseAccess access;
-
     foreach(const qlonglong& imageId, changeset.ids())
     {
         DatabaseFields::Set changes = changeset.changes();
 
-        if (changes & DatabaseFields::ModificationDate
-            || changes & DatabaseFields::Orientation)
+        if (changes & DatabaseFields::ModificationDate || changes & DatabaseFields::Orientation)
         {
             ImageInfo info(imageId);
             //kDebug() << imageId << info.filePath();
