@@ -6,7 +6,7 @@
  * Date        : 2007-01-05
  * Description : Metadata handling
  *
- * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2007-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software you can redistribute it
@@ -50,6 +50,8 @@
 #include "imageattributeswatch.h"
 #include "tagscache.h"
 
+#include "facetagseditor.h"
+
 namespace Digikam
 {
 
@@ -116,6 +118,8 @@ public:
 
     QStringList                       tagList;
 
+    QMap<QString, QVariant>           faceTagsList;
+
     MetadataHub::Status               dateTimeStatus;
     MetadataHub::Status               titlesStatus;
     MetadataHub::Status               commentsStatus;
@@ -166,7 +170,7 @@ void MetadataHub::reset()
 void MetadataHub::load(const ImageInfo& info)
 {
     d->count++;
-
+    //kDebug() << "---------------------------------Load from ImageInfo ----------------";
     CaptionsMap commentMap;
     CaptionsMap titleMap;
     {
@@ -190,12 +194,13 @@ void MetadataHub::load(const ImageInfo& info)
 
     QList<int> tagIds = info.tagIds();
     loadTags(tagIds);
+
+    loadFaceTags(info, info.dimensions());
 }
 
 void MetadataHub::load(const DMetadata& metadata)
 {
     d->count++;
-
     CaptionsMap comments;
     CaptionsMap titles;
     QStringList keywords;
@@ -255,6 +260,7 @@ void MetadataHub::load(const DMetadata& metadata)
 
 bool MetadataHub::load(const QString& filePath, const MetadataSettingsContainer& settings)
 {
+
     DMetadata metadata;
     metadata.setSettings(settings);
     bool success = metadata.load(filePath);
@@ -345,7 +351,7 @@ void MetadataHub::loadTags(const QStringList& loadedTagPaths)
 */
 
 // private common code to load dateTime, comment, color label, pick label, rating
-void MetadataHub::load(const QDateTime& dateTime, 
+void MetadataHub::load(const QDateTime& dateTime,
                        const CaptionsMap& titles, const CaptionsMap& comments,
                        int colorLabel, int pickLabel,
                        int rating, const Template& t)
@@ -593,6 +599,7 @@ bool MetadataHub::write(DMetadata& metadata, WriteMode writeMode, const Metadata
     bool saveColorLabel = (settings.saveColorLabel && d->colorLabelStatus == MetadataAvailable);
     bool saveRating     = (settings.saveRating     && d->ratingStatus     == MetadataAvailable);
     bool saveTemplate   = (settings.saveTemplate   && d->templateStatus   == MetadataAvailable);
+    bool saveFaces      =  settings.saveFaceTags;
     bool saveTags       = false;
 
     if (settings.saveTags)
@@ -688,6 +695,11 @@ bool MetadataHub::write(DMetadata& metadata, WriteMode writeMode, const Metadata
         }
     }
 
+    if(saveFaces)
+        metadata.setImageFacesMap(d->faceTagsList,true);
+    else
+        metadata.setImageFacesMap(d->faceTagsList,false);
+
     if (saveTags && (writeAllFields || d->tagsChanged))
     {
         // Store tag paths as Iptc keywords tags.
@@ -697,7 +709,7 @@ bool MetadataHub::write(DMetadata& metadata, WriteMode writeMode, const Metadata
 
         // create list of keywords to be added and to be removed
         QStringList tagsPathList, oldKeywords, newKeywords;
-        metadata.getImageTagsPath(tagsPathList);
+        //metadata.getImageTagsPath(tagsPathList);
 
         for (QMap<int, TagStatus>::iterator it = d->tags.begin(); it != d->tags.end(); ++it)
         {
@@ -1247,4 +1259,31 @@ void MetadataHubOnTheRoad::slotInvalidate()
     d->invalid = true;
 }
 
+void Digikam::MetadataHub::loadFaceTags(const ImageInfo info, QSize size)
+{
+    FaceTagsEditor editor;
+    //kDebug() << "Image Dimensions ----------------" << info.dimensions();
+
+    QList<DatabaseFace> facesList = editor.confirmedDatabaseFaces(info.id());
+    d->faceTagsList.clear();
+
+    if(!facesList.isEmpty())
+    {
+        foreach(DatabaseFace dface,facesList)
+        {
+            QString faceName = FaceTags::faceNameForTag(dface.tagId());
+            if(faceName.isEmpty())
+                continue;
+
+            QRect   temprect = dface.region().toRect();
+            QRectF  faceRect = TagRegion::absoluteToRelative(temprect,size);
+
+            d->faceTagsList[faceName] = QVariant(faceRect);
+        }
+
+    }
+
+
+}
+
 } // namespace Digikam
