@@ -6,7 +6,7 @@
  * Date        : 2011-02-23
  * Description : a widget to filter album contents by text query
  *
- * Copyright (C) 2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,25 +37,31 @@
 namespace Digikam
 {
 
-class TextFilter::TextFilterPriv
+class TextFilter::Private
 {
 public:
 
-    TextFilterPriv()
+    Private()
     {
-        imageNameAction    = 0;
-        imageCommentAction = 0;
-        tagNameAction      = 0;
-        albumNameAction    = 0;
-        optionsBtn         = 0;
-        optionsMenu        = 0;
-        searchTextBar      = 0;
+        imageNameAction        = 0;
+        imageTitleAction       = 0;
+        imageCommentAction     = 0;
+        tagNameAction          = 0;
+        albumNameAction        = 0;
+        optionsBtn             = 0;
+        optionsMenu            = 0;
+        searchTextBar          = 0;
+        imageAspectRatioAction = 0;
+        imagePixelSizeAction   = 0;
     }
 
     QAction*       imageNameAction;
+    QAction*       imageTitleAction;
     QAction*       imageCommentAction;
     QAction*       tagNameAction;
     QAction*       albumNameAction;
+    QAction*       imageAspectRatioAction;
+    QAction*       imagePixelSizeAction;
 
     QToolButton*   optionsBtn;
 
@@ -64,8 +70,8 @@ public:
     SearchTextBar* searchTextBar;
 };
 
-TextFilter::TextFilter(QWidget* parent)
-    : KHBox(parent), d(new TextFilterPriv)
+TextFilter::TextFilter(QWidget* const parent)
+    : KHBox(parent), d(new Private)
 {
     d->searchTextBar = new SearchTextBar(this, "AlbumIconViewFilterSearchTextBar");
     d->searchTextBar->setTextQueryCompletion(true);
@@ -79,15 +85,21 @@ TextFilter::TextFilter(QWidget* parent)
     d->optionsBtn->setPopupMode(QToolButton::InstantPopup);
     d->optionsBtn->setWhatsThis(i18n("Defines which fields to search for the text in."));
 
-    d->optionsMenu        = new KMenu(d->optionsBtn);
-    d->imageNameAction    = d->optionsMenu->addAction(i18n("Image Name"));
+    d->optionsMenu            = new KMenu(d->optionsBtn);
+    d->imageNameAction        = d->optionsMenu->addAction(i18n("Image Name"));
     d->imageNameAction->setCheckable(true);
-    d->imageCommentAction = d->optionsMenu->addAction(i18n("Image Comment"));
+    d->imageTitleAction       = d->optionsMenu->addAction(i18n("Image Title"));
+    d->imageTitleAction->setCheckable(true);
+    d->imageCommentAction     = d->optionsMenu->addAction(i18n("Image Comment"));
     d->imageCommentAction->setCheckable(true);
-    d->tagNameAction      = d->optionsMenu->addAction(i18n("Tag Name"));
+    d->tagNameAction          = d->optionsMenu->addAction(i18n("Tag Name"));
     d->tagNameAction->setCheckable(true);
-    d->albumNameAction    = d->optionsMenu->addAction(i18n("Album Name"));
+    d->albumNameAction        = d->optionsMenu->addAction(i18n("Album Name"));
     d->albumNameAction->setCheckable(true);
+    d->imageAspectRatioAction = d->optionsMenu->addAction(i18n("Image Aspect Ratio"));
+    d->imageAspectRatioAction->setCheckable(true);
+    d->imagePixelSizeAction   = d->optionsMenu->addAction(i18n("Image Pixel Size"));
+    d->imagePixelSizeAction->setCheckable(true);
     d->optionsBtn->setMenu(d->optionsMenu);
 
     setMargin(0);
@@ -118,6 +130,10 @@ SearchTextFilterSettings::TextFilterFields TextFilter::searchTextFields()
     {
         fields |= SearchTextFilterSettings::ImageName;
     }
+    if (d->imageTitleAction->isChecked())
+    {
+        fields |= SearchTextFilterSettings::ImageTitle;
+    }
     if (d->imageCommentAction->isChecked())
     {
         fields |= SearchTextFilterSettings::ImageComment;
@@ -130,6 +146,14 @@ SearchTextFilterSettings::TextFilterFields TextFilter::searchTextFields()
     {
         fields |= SearchTextFilterSettings::AlbumName;
     }
+    if (d->imageAspectRatioAction->isChecked())
+    {
+        fields |= SearchTextFilterSettings::ImageAspectRatio;
+    }
+    if (d->imagePixelSizeAction->isChecked())
+    {
+        fields |= SearchTextFilterSettings::ImagePixelSize;
+    }
 
     return (SearchTextFilterSettings::TextFilterFields)fields;
 }
@@ -137,9 +161,12 @@ SearchTextFilterSettings::TextFilterFields TextFilter::searchTextFields()
 void TextFilter::setsearchTextFields(SearchTextFilterSettings::TextFilterFields fields)
 {
     d->imageNameAction->setChecked(fields & SearchTextFilterSettings::ImageName);
+    d->imageTitleAction->setChecked(fields & SearchTextFilterSettings::ImageTitle);
     d->imageCommentAction->setChecked(fields & SearchTextFilterSettings::ImageComment);
     d->tagNameAction->setChecked(fields & SearchTextFilterSettings::TagName);
     d->albumNameAction->setChecked(fields & SearchTextFilterSettings::AlbumName);
+    d->imageAspectRatioAction->setChecked(fields & SearchTextFilterSettings::ImageAspectRatio);
+    d->imagePixelSizeAction->setChecked(fields & SearchTextFilterSettings::ImagePixelSize);
 }
 
 void TextFilter::slotSearchFieldsChanged()
