@@ -47,8 +47,8 @@
 #include "albumfiltermodel.h"
 #include "assignnamewidget.h"
 #include "databaseface.h"
-#include "faceiface.h"
 #include "facepipeline.h"
+#include "facetags.h"
 #include "imagedelegate.h"
 #include "imagemodel.h"
 #include "imagecategorizedview.h"
@@ -73,8 +73,6 @@ public:
     CheckableAlbumFilterModel filterModel;
     TagPropertiesFilterModel  filteredModel;
 
-    FaceIface                 faceIface;
-
     AssignNameWidget*         assignNameWidget;
     QPersistentModelIndex     index;
 
