@@ -6,10 +6,10 @@
  * Date        : 2009-04-19
  * Description : Qt item view for images - the delegate
  *
- * Copyright (C) 2002-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2002-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -35,7 +35,7 @@
 
 #include "albumsettings.h"
 #include "databaseface.h"
-#include "faceiface.h"
+#include "faceutils.h"
 #include "imagemodel.h"
 #include "tagregion.h"
 #include "digikamimagedelegatepriv.h"
@@ -91,7 +91,7 @@ QRect DigikamImageFaceDelegate::largerFaceRect(const QModelIndex& index) const
         return rect;
     }
 
-    const int margin = FaceIface::faceRectDisplayMargin();
+    const int margin = FaceUtils::faceRectDisplayMargin();
 
     return rect.adjusted(-margin, -margin, margin, margin);
 }
