@@ -6,7 +6,7 @@
  * Date        : 2009-05-04
  * Description : Various operations on images
  *
- * Copyright (C) 2009-2010 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2009-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -53,13 +53,19 @@ class ImageViewUtilities : public QObject
 
 public:
 
-    ImageViewUtilities(QWidget* parentWidget);
+    enum DeleteMode
+    {
+        DeletePermanently = 1,
+        DeleteUseTrash = 2
+    };
+
+    explicit ImageViewUtilities(QWidget* parentWidget);
 
 public Q_SLOTS:
 
     void createNewAlbumForInfos(const QList<ImageInfo>& infos, Album* currentAlbum);
-    bool deleteImages(const QList<ImageInfo>& infos, bool deletePermanently);
-    void deleteImagesDirectly(const QList<ImageInfo>& infos, bool useTrash);
+    bool deleteImages(const QList<ImageInfo>& infos, const DeleteMode deleteMode);
+    void deleteImagesDirectly(const QList<ImageInfo>& infos, const DeleteMode deleteMode);
 
     void insertToLightTableAuto(const QList<ImageInfo>& all, const QList<ImageInfo>& selected, const ImageInfo& current);
     void insertToLightTable(const QList<ImageInfo>& list, const ImageInfo& current, bool addTo);
@@ -73,19 +79,12 @@ public Q_SLOTS:
     void rename(const KUrl& imageUrl, const QString& newName);
     void setAsAlbumThumbnail(Album* album, const ImageInfo& imageInfo);
 
+    void createGroupByTimeFromInfoList(const ImageInfoList& imageInfoList);
+
 Q_SIGNALS:
 
     void editorCurrentUrlChanged(const KUrl& url);
 
-    void imageRenameSucceeded(const KUrl&);
-    void imageRenameFailed(const KUrl&);
-    void renamingAborted();
-
-protected Q_SLOTS:
-
-    void slotDIOResult(KJob* kjob);
-    void slotRenamed(KIO::Job*, const KUrl&, const KUrl& newURL);
-
 protected:
 
     QWidget* m_widget;
@@ -93,4 +92,6 @@ protected:
 
 } // namespace Digikam
 
+Q_DECLARE_METATYPE(Digikam::ImageViewUtilities::DeleteMode)
+
 #endif /* IMAGEVIEWUTILITIES_H */
