@@ -109,9 +109,6 @@ public:
     void setShowSplashScreen(bool val);
     bool getShowSplashScreen() const;
 
-    void setScanAtStart(bool val);
-    bool getScanAtStart() const;
-
     void setAlbumCategoryNames(const QStringList& list);
     QStringList getAlbumCategoryNames() const;
 
@@ -393,7 +390,7 @@ public:
     void setApplicationStyle(const QString& style);
     QString getApplicationStyle() const;
 
-    KConfigGroup defaultConfigGroup() const;
+    KConfigGroup generalConfigGroup() const;
 
 public Q_SLOTS:
 
