@@ -499,8 +499,8 @@ void ContextMenuHelper::addRemoveTagsMenu(const imageIds &ids)
     d->parent->addMenu(removeTagsPopup);
 
     // Performance: Only check for tags if there are <250 images selected
-    // Also disable the remove Tag popup menu, if there are no tags at all.
-    if (ids.count() > 250 || !DatabaseAccess().db()->hasTags(ids))
+    // Otherwise enable it regardless if there are tags or not
+    if (ids.count() < 250 && !DatabaseAccess().db()->hasTags(ids))
     {
         removeTagsPopup->menuAction()->setEnabled(false);
     }
@@ -870,15 +870,27 @@ void ContextMenuHelper::slotDeselectParents()
     d->albumModel->resetCheckedParentAlbums(d->indexForAlbumFromAction(sender()));
 }
 
-void ContextMenuHelper::addGroupMenu(const imageIds &ids)
+void ContextMenuHelper::addGroupMenu(const imageIds &ids, const QList<QAction*>& extraMenuItems)
 {
     QList<QAction*> actions = groupMenuActions(ids);
 
-    if (actions.isEmpty())
+    if (actions.isEmpty() && extraMenuItems.isEmpty())
     {
         return;
     }
 
+    if (!extraMenuItems.isEmpty())
+    {
+        if (!actions.isEmpty())
+        {
+            QAction* separator = new QAction(this);
+            separator->setSeparator(true);
+            actions << separator;
+        }
+
+        actions << extraMenuItems;
+    }
+
     KMenu* menu = new KMenu(i18n("Group"));
     foreach(QAction* action, actions)
     {
