@@ -158,6 +158,7 @@ public Q_SLOTS:
     void slotNewTag();
     void slotDeleteTag();
     void slotEditTag();
+    void slotAssignTag();
 
     // Search action slots
     void slotNewKeywordSearch();
@@ -206,6 +207,8 @@ public Q_SLOTS:
     void slotLeftSideBarActivateAlbums();
     void slotLeftSideBarActivateTags();
 
+    void slotFocusAndNextImage();
+
 #ifdef USE_PRESENTATION_MODE
     void slotSlideShowQml();
 #endif // USE_PRESENTATION_MODE
