@@ -8,6 +8,7 @@
  *               or the current image preview.
  *
  * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -56,6 +57,7 @@
 #include "mediaplayerview.h"
 #include "thumbbardock.h"
 #include "mapwidgetview.h"
+#include "tableview.h"
 
 namespace Digikam
 {
@@ -78,6 +80,7 @@ public:
         mapWidgetView      = 0;
         needUpdateBar      = false;
         syncingSelection   = false;
+        tableView          = 0;
     }
 
     bool               needUpdateBar;
@@ -93,6 +96,7 @@ public:
     ThumbBarDock*      thumbBarDock;
     WelcomePageView*   welcomePageView;
     MapWidgetView*     mapWidgetView;
+    TableView*         tableView;
 };
 
 StackedView::StackedView(QWidget* parent)
@@ -112,14 +116,21 @@ StackedView::StackedView(QWidget* parent)
     d->mapWidgetView   = new MapWidgetView(d->imageIconView->getSelectionModel(),
                                            d->imageIconView->imageFilterModel(), this);
     d->mapWidgetView->setObjectName("mainwindow_mapwidgetview");
+    d->tableView       = new TableView(
+            d->imageIconView->getSelectionModel(),
+            d->imageIconView->imageFilterModel(),
+            this
+        );
+    d->tableView->setObjectName("mainwindow_tableview");
 
-    insertWidget(PreviewAlbumMode, d->imageIconView);
+    insertWidget(IconViewMode,     d->imageIconView);
     insertWidget(PreviewImageMode, d->imagePreviewView);
     insertWidget(WelcomePageMode,  d->welcomePageView->view());
     insertWidget(MediaPlayerMode,  d->mediaPlayerView);
     insertWidget(MapWidgetMode,    d->mapWidgetView);
+    insertWidget(TableViewMode,    d->tableView);
 
-    setPreviewMode(PreviewAlbumMode);
+    setViewMode(IconViewMode);
     setAttribute(Qt::WA_DeleteOnClose);
 
     readSettings();
@@ -226,7 +237,7 @@ ImageThumbnailBar* StackedView::thumbBar() const
 
 void StackedView::slotEscapePreview()
 {
-    if (previewMode() == MediaPlayerMode)
+    if (viewMode() == MediaPlayerMode)
     {
         d->mediaPlayerView->escapePreview();
     }
@@ -247,6 +258,11 @@ MapWidgetView* StackedView::mapWidgetView() const
     return d->mapWidgetView;
 }
 
+TableView* StackedView::tableView() const
+{
+    return d->tableView;
+}
+
 MediaPlayerView* StackedView::mediaPlayerView() const
 {
     return d->mediaPlayerView;
@@ -259,7 +275,9 @@ bool StackedView::isInSingleFileMode() const
 
 bool StackedView::isInMultipleFileMode() const
 {
-    return currentIndex() == PreviewAlbumMode || currentIndex() == MapWidgetMode;
+    return currentIndex() == IconViewMode
+        || currentIndex() == MapWidgetMode
+        || currentIndex() == TableViewMode;
 }
 
 bool StackedView::isInAbstractMode() const
@@ -271,11 +289,11 @@ void StackedView::setPreviewItem(const ImageInfo& info, const ImageInfo& previou
 {
     if (info.isNull())
     {
-        if (previewMode() == MediaPlayerMode)
+        if (viewMode() == MediaPlayerMode)
         {
             d->mediaPlayerView->setCurrentItem();
         }
-        else if (previewMode() == PreviewImageMode)
+        else if (viewMode() == PreviewImageMode)
         {
             d->imagePreviewView->setImageInfo();
         }
@@ -285,18 +303,18 @@ void StackedView::setPreviewItem(const ImageInfo& info, const ImageInfo& previou
         if (info.category() == DatabaseItem::Audio || info.category() == DatabaseItem::Video)
         {
             // Stop image viewer
-            if (previewMode() == PreviewImageMode)
+            if (viewMode() == PreviewImageMode)
             {
                 d->imagePreviewView->setImageInfo();
             }
 
-            setPreviewMode(MediaPlayerMode);
+            setViewMode(MediaPlayerMode);
             d->mediaPlayerView->setCurrentItem(info.fileUrl(), !previous.isNull(), !next.isNull());
         }
         else
         {
             // Stop media player if running...
-            if (previewMode() == MediaPlayerMode)
+            if (viewMode() == MediaPlayerMode)
             {
                 d->mediaPlayerView->setCurrentItem();
             }
@@ -314,15 +332,14 @@ void StackedView::setPreviewItem(const ImageInfo& info, const ImageInfo& previou
     }
 }
 
-int StackedView::previewMode()
+StackedView::StackedViewMode StackedView::viewMode() const
 {
-    return indexOf(currentWidget());
+    return StackedViewMode(indexOf(currentWidget()));
 }
 
-void StackedView::setPreviewMode(const int mode)
+void StackedView::setViewMode(const StackedViewMode mode)
 {
-    if (mode != PreviewAlbumMode && mode != PreviewImageMode &&
-        mode != WelcomePageMode  && mode != MediaPlayerMode && mode != MapWidgetMode)
+    if ((mode<StackedViewModeFirst)||(mode>StackedViewModeLast))
     {
         return;
     }
@@ -337,7 +354,7 @@ void StackedView::setPreviewMode(const int mode)
         d->thumbBarDock->hide();
     }
 
-    if (mode == PreviewAlbumMode || mode == WelcomePageMode || mode == MapWidgetMode)
+    if (mode == IconViewMode || mode == WelcomePageMode || mode == MapWidgetMode || mode == TableViewMode)
     {
         setPreviewItem();
         setCurrentIndex(mode);
@@ -348,8 +365,9 @@ void StackedView::setPreviewMode(const int mode)
     }
 
     d->mapWidgetView->setActive(mode == MapWidgetMode);
+    d->tableView->slotSetActive(mode == TableViewMode);
 
-    if (mode == PreviewAlbumMode)
+    if (mode == IconViewMode)
     {
         d->imageIconView->setFocus();
     }
@@ -357,6 +375,10 @@ void StackedView::setPreviewMode(const int mode)
     {
         d->mapWidgetView->setFocus();
     }
+    else if (mode == TableViewMode)
+    {
+        d->tableView->setFocus();
+    }
 
     emit signalViewModeChanged();
 }
@@ -401,7 +423,7 @@ void StackedView::slotThumbBarSelectionChanged()
 
 void StackedView::slotIconViewSelectionChanged()
 {
-    if (currentIndex() != PreviewAlbumMode)
+    if (currentIndex() != IconViewMode)
     {
         return;
     }
@@ -421,7 +443,7 @@ void StackedView::previewLoaded()
 
 void StackedView::slotZoomFactorChanged(double z)
 {
-    if (previewMode() == PreviewImageMode)
+    if (viewMode() == PreviewImageMode)
     {
         emit signalZoomFactorChanged(z);
     }
@@ -490,7 +512,7 @@ double StackedView::zoomMax()
 
 void StackedView::slotPreviewLoaded(bool)
 {
-    setPreviewMode(StackedView::PreviewImageMode);
+    setViewMode(StackedView::PreviewImageMode);
     previewLoaded();
 }
 
