@@ -58,8 +58,6 @@ namespace Digikam
 
 TableViewModel::Item::Item()
   : imageId(0),
-    cachedDatabaseFields(),
-    databaseFields(),
     parent(0),
     children()
 {
@@ -605,6 +603,14 @@ void TableViewModel::slotDatabaseImageChanged(const ImageChangeset& imageChanges
 
     /// @todo Decide which changes are relevant here or
     ///       let the TableViewColumn object decide which are relevant
+    /// @todo Re-population of the model is also triggered, thus making this
+    ///       check irrelevant. Needs to be fixed.
+    bool needToResort = false;
+    if ((d->sortColumn>=0)&&(d->sortColumn<=d->columnObjects.count()))
+    {
+        TableViewColumn* const sortColumnObject = d->columnObjects.at(d->sortColumn);
+        needToResort = sortColumnObject->columnAffectedByChangeset(imageChangeset);
+    }
 
     foreach(const qlonglong& id, imageChangeset.ids())
     {
@@ -631,11 +637,6 @@ void TableViewModel::slotDatabaseImageChanged(const ImageChangeset& imageChanges
             continue;
         }
 
-        /// force an update of the database fields on next access
-        item->databaseFields.clear();
-        /// @todo Introduce/find a clear function
-        item->cachedDatabaseFields = DatabaseFields::Set();
-
         // remove cached info and re-insert it
         if (d->cachedImageInfos.contains(item->imageId))
         {
@@ -665,19 +666,25 @@ void TableViewModel::slotDatabaseImageChanged(const ImageChangeset& imageChanges
 
         /// @todo Re-check grouping for this item
 
-        const QModelIndex changedIndexBottomRight = index(
-                changedIndexTopLeft.row(),
-                columnCount(changedIndexTopLeft.parent())-1,
-                changedIndexTopLeft.parent()
-            );
-        if (changedIndexBottomRight.isValid())
+        // only update now if we do not resort later anyway
+        if (!needToResort)
         {
-            emit(dataChanged(changedIndexTopLeft, changedIndexBottomRight));
+            const QModelIndex changedIndexBottomRight = index(
+                    changedIndexTopLeft.row(),
+                    columnCount(changedIndexTopLeft.parent())-1,
+                    changedIndexTopLeft.parent()
+                );
+            if (changedIndexBottomRight.isValid())
+            {
+                emit(dataChanged(changedIndexTopLeft, changedIndexBottomRight));
+            }
         }
     }
 
-    /// @todo React smarter just to the changed items
-    scheduleResort();
+    if (needToResort)
+    {
+        scheduleResort();
+    }
 }
 
 Qt::ItemFlags TableViewModel::flags(const QModelIndex& index) const
@@ -724,7 +731,6 @@ void TableViewModel::slotClearModel(const bool sendNotifications)
 
     d->rootItem = new Item();
     d->cachedImageInfos.clear();
-    d->sortRequired = false;
 
     if (sendNotifications)
     {
@@ -934,39 +940,9 @@ ImageInfo TableViewModel::infoFromItem(Digikam::TableViewModel::Item* const item
 
 TableViewModel::DatabaseFieldsHashRaw TableViewModel::itemDatabaseFieldsRaw(TableViewModel::Item* const item, const DatabaseFields::Set requestedSet)
 {
-    if ((item->cachedDatabaseFields & requestedSet)==0)
-    {
-        // fields are not buffered yet, we have to request them
+    const ImageInfo itemImageInfo = infoFromItem(item);
 
-        if (requestedSet.hasFieldsFromImageMetadata())
-        {
-            const DatabaseFields::ImageMetadata imageMetadataFields = requestedSet;
-            const QVariantList fieldValues = DatabaseAccess().db()->getImageMetadata(item->imageId, imageMetadataFields);
-
-            if (!fieldValues.isEmpty())
-            {
-                int fieldsIndex = 0;
-                for (DatabaseFields::ImageMetadataIterator it; !it.atEnd(); ++it)
-                {
-                    /// @todo The typecasting here is a workaround...
-                    if (imageMetadataFields.testFlag(DatabaseFields::ImageMetadataField(int(*it))))
-                    {
-                        const QVariant fieldValue = fieldValues.at(fieldsIndex);
-                        ++fieldsIndex;
-
-                        /// @todo Re-implement insert?
-                        item->databaseFields.insert(DatabaseFieldsHashRaw::uniqueKey(*it), fieldValue);
-                    }
-                }
-            }
-        }
-
-        // We assume that we found all requested tags here. If they were not found, we now know
-        // that they do not exist. Should they be created, the cache will be cleared.
-        item->cachedDatabaseFields.setFields(requestedSet);
-    }
-
-    return item->databaseFields;
+    return itemImageInfo.getDatabaseFieldsRaw(requestedSet);
 }
 
 QVariant TableViewModel::itemDatabaseFieldRaw(TableViewModel::Item* const item, const DatabaseFields::Set requestedField)
@@ -981,6 +957,14 @@ QVariant TableViewModel::itemDatabaseFieldRaw(TableViewModel::Item* const item,
         return value;
     }
 
+    if (requestedField.hasFieldsFromVideoMetadata())
+    {
+        const DatabaseFields::VideoMetadata requestedFieldFlag = requestedField;
+        const QVariant value = rawHash.value(requestedFieldFlag);
+
+        return value;
+    }
+
     return QVariant();
 }
 
