@@ -76,7 +76,7 @@ WelcomePageView::WelcomePageView(QWidget* const parent)
 
     // ------------------------------------------------------------
 
-    connect(browserExtension(), SIGNAL(openUrlRequest(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)),
+    connect(browserExtension(), SIGNAL(openUrlRequest(KUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)),
             this, SLOT(slotUrlOpen(KUrl)));
 
     connect(ThemeManager::instance(), SIGNAL(signalThemeChanged()),
@@ -97,6 +97,12 @@ void WelcomePageView::slotUrlOpen(const KUrl& url)
 QString WelcomePageView::infoPage() const
 {
     QStringList newFeatures;
+    newFeatures << i18n("New Faces Recognition engine;");
+    newFeatures << i18n("New Table-View view mode dedicated to show album items in a list view;");
+    newFeatures << i18n("New tool to Auto-Crop image based on black hole borders detection;");
+    newFeatures << i18n("New Aspect Ratio information displayed in icon-view and tooltips;");
+    newFeatures << i18n("New filter based on Aspect-Ratio information;");
+    newFeatures << i18n("New search tool to find items based on Aspect-Ratio information;");
     newFeatures << i18n("KIPI actions tool-bar support;");
     newFeatures << i18n("Automatic Noise Reduction tool;");
     newFeatures << i18n("Import tool rewritten using Model/View;");
