@@ -7,7 +7,7 @@
  * Description : a widget to display a welcome page
  *               on root album.
  *
- * Copyright (C) 2006-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -48,7 +48,7 @@ class WelcomePageView : public KHTMLPart
 
 public:
 
-    WelcomePageView(QWidget* parent);
+    explicit WelcomePageView(QWidget* const parent);
     ~WelcomePageView();
 
 private:
