@@ -6,7 +6,7 @@
  * Date        : 2004-12-01
  * Description : image histogram adjust curves.
  *
- * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -61,37 +61,36 @@
 namespace DigikamColorImagePlugin
 {
 
-class AdjustCurvesTool::AdjustCurvesToolPriv
+class AdjustCurvesTool::Private
 {
 public:
 
-    AdjustCurvesToolPriv() :
-        destinationPreviewData(0),
+    Private() :
         settingsView(0),
         previewWidget(0),
         gboxSettings(0)
-    {}
+    {
+    }
 
     static const QString configGroupName;
     static const QString configHistogramChannelEntry;
     static const QString configHistogramScaleEntry;
 
-    uchar*               destinationPreviewData;
-
     CurvesSettings*      settingsView;
     ImageRegionWidget*   previewWidget;
 
     EditorToolSettings*  gboxSettings;
 };
-const QString AdjustCurvesTool::AdjustCurvesToolPriv::configGroupName("adjustcurves Tool");
-const QString AdjustCurvesTool::AdjustCurvesToolPriv::configHistogramChannelEntry("Histogram Channel");
-const QString AdjustCurvesTool::AdjustCurvesToolPriv::configHistogramScaleEntry("Histogram Scale");
+
+const QString AdjustCurvesTool::Private::configGroupName("adjustcurves Tool");
+const QString AdjustCurvesTool::Private::configHistogramChannelEntry("Histogram Channel");
+const QString AdjustCurvesTool::Private::configHistogramScaleEntry("Histogram Scale");
 
 // --------------------------------------------------------
 
-AdjustCurvesTool::AdjustCurvesTool(QObject* parent)
+AdjustCurvesTool::AdjustCurvesTool(QObject* const parent)
     : EditorToolThreaded(parent),
-      d(new AdjustCurvesToolPriv)
+      d(new Private)
 {
     setObjectName("adjustcurves");
     setToolName(i18n("Adjust Curves"));
@@ -119,9 +118,9 @@ AdjustCurvesTool::AdjustCurvesTool(QObject* parent)
 
     // -------------------------------------------------------------
 
-    ImageIface iface(0, 0);
+    ImageIface iface;
     QVBoxLayout* vbox = new QVBoxLayout(d->gboxSettings->plainPage());
-    d->settingsView   = new CurvesSettings(d->gboxSettings->plainPage(), iface.getOriginalImg());
+    d->settingsView   = new CurvesSettings(d->gboxSettings->plainPage(), iface.original());
     d->gboxSettings->histogramBox()->setContentsMargins(d->settingsView->curvesLeftOffset(), 0, 0, 0);
     vbox->addWidget(d->settingsView);
     vbox->addStretch(10);
@@ -129,7 +128,6 @@ AdjustCurvesTool::AdjustCurvesTool(QObject* parent)
     vbox->setSpacing(0);
 
     setToolSettings(d->gboxSettings);
-    init();
 
     // -------------------------------------------------------------
 
@@ -143,7 +141,7 @@ AdjustCurvesTool::AdjustCurvesTool(QObject* parent)
             this, SLOT(slotScaleChanged()));
 
     connect(d->previewWidget, SIGNAL(signalResized()),
-            this, SLOT(slotEffect()));
+            this, SLOT(slotPreview()));
 
     connect(d->previewWidget, SIGNAL(signalCapturedPointFromOriginal(Digikam::DColor,QPoint)),
             d->settingsView, SLOT(slotSpotColorChanged(Digikam::DColor)));
@@ -156,20 +154,14 @@ AdjustCurvesTool::AdjustCurvesTool(QObject* parent)
 
     connect(d->settingsView, SIGNAL(signalPickerChanged(int)),
             this, SLOT(slotPickerColorButtonActived(int)));
-
-    /*
-        connect(d->previewWidget, SIGNAL(spotPositionChangedFromTarget(Digikam::DColor,QPoint)),
-                this, SLOT(slotColorSelectedFromTarget(Digikam::DColor)));
-    */
+/*
+    connect(d->previewWidget, SIGNAL(spotPositionChangedFromTarget(Digikam::DColor,QPoint)),
+            this, SLOT(slotColorSelectedFromTarget(Digikam::DColor)));
+*/
 }
 
 AdjustCurvesTool::~AdjustCurvesTool()
 {
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
     delete d;
 }
 
@@ -186,7 +178,7 @@ void AdjustCurvesTool::slotPickerColorButtonActived(int type)
 void AdjustCurvesTool::slotSpotColorChanged()
 {
     d->previewWidget->setCapturePointMode(false);
-    slotEffect();
+    slotPreview();
 }
 
 void AdjustCurvesTool::slotColorSelectedFromTarget(const DColor& color)
@@ -197,7 +189,7 @@ void AdjustCurvesTool::slotColorSelectedFromTarget(const DColor& color)
 void AdjustCurvesTool::slotResetCurrentChannel()
 {
     d->gboxSettings->histogramBox()->histogram()->reset();
-    slotEffect();
+    slotPreview();
 }
 
 void AdjustCurvesTool::slotChannelChanged()
@@ -226,7 +218,7 @@ void AdjustCurvesTool::readSettings()
     slotScaleChanged();
     slotChannelChanged();
 
-    slotEffect();
+    slotPreview();
 }
 
 void AdjustCurvesTool::writeSettings()
@@ -245,10 +237,10 @@ void AdjustCurvesTool::slotResetSettings()
 {
     d->settingsView->resetToDefault();
     d->gboxSettings->histogramBox()->histogram()->reset();
-    slotEffect();
+    slotPreview();
 }
 
-void AdjustCurvesTool::prepareEffect()
+void AdjustCurvesTool::preparePreview()
 {
     CurvesContainer settings = d->settingsView->settings();
 
@@ -258,36 +250,28 @@ void AdjustCurvesTool::prepareEffect()
     setFilter(new CurvesFilter(&preview, this, settings));
 }
 
-void AdjustCurvesTool::putPreviewData()
+void AdjustCurvesTool::setPreviewImage()
 {
     DImg preview = filter()->getTargetImage();
     d->previewWidget->setPreviewImage(preview);
 
     // Update histogram.
 
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
-    d->destinationPreviewData = preview.copyBits();
-    d->gboxSettings->histogramBox()->histogram()->updateData(d->destinationPreviewData,
-            preview.width(), preview.height(), preview.sixteenBit(),
-            0, 0, 0, false);
+    d->gboxSettings->histogramBox()->histogram()->updateData(preview.copy(), DImg(), false);
 }
 
 void AdjustCurvesTool::prepareFinal()
 {
     CurvesContainer settings = d->settingsView->settings();
 
-    ImageIface iface(0, 0);
-    setFilter(new CurvesFilter(iface.getOriginalImg(), this, settings));
+    ImageIface iface;
+    setFilter(new CurvesFilter(iface.original(), this, settings));
 }
 
-void AdjustCurvesTool::putFinalData()
+void AdjustCurvesTool::setFinalImage()
 {
-    ImageIface iface(0, 0);
-    iface.putOriginalImage(i18n("Adjust Curve"), filter()->filterAction(), filter()->getTargetImage().bits());
+    ImageIface iface;
+    iface.setOriginal(i18n("Adjust Curve"), filter()->filterAction(), filter()->getTargetImage());
 }
 
 void AdjustCurvesTool::slotLoadSettings()
@@ -296,7 +280,7 @@ void AdjustCurvesTool::slotLoadSettings()
 
     // Refresh the current curves config.
     slotChannelChanged();
-    slotEffect();
+    slotPreview();
 }
 
 void AdjustCurvesTool::slotSaveAsSettings()
