@@ -7,8 +7,8 @@
  * Description : digiKam image editor to adjust Brightness,
  *               Contrast, and Gamma of picture.
  *
- * Copyright (C) 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2005-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004      by Renchi Raju <renchi dot raju at gmail dot com>
+ * Copyright (C) 2005-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -60,12 +60,11 @@
 namespace DigikamColorImagePlugin
 {
 
-class BCGTool::BCGToolPriv
+class BCGTool::Private
 {
 public:
 
-    BCGToolPriv() :
-        destinationPreviewData(0),
+    Private() :
         settingsView(0),
         previewWidget(0),
         gboxSettings(0)
@@ -75,21 +74,20 @@ public:
     static const QString configHistogramChannelEntry;
     static const QString configHistogramScaleEntry;
 
-    uchar*               destinationPreviewData;
-
     BCGSettings*         settingsView;
     ImageRegionWidget*   previewWidget;
     EditorToolSettings*  gboxSettings;
 };
-const QString BCGTool::BCGToolPriv::configGroupName("bcgadjust Tool");
-const QString BCGTool::BCGToolPriv::configHistogramChannelEntry("Histogram Channel");
-const QString BCGTool::BCGToolPriv::configHistogramScaleEntry("Histogram Scale");
+
+const QString BCGTool::Private::configGroupName("bcgadjust Tool");
+const QString BCGTool::Private::configHistogramChannelEntry("Histogram Channel");
+const QString BCGTool::Private::configHistogramScaleEntry("Histogram Scale");
 
 // --------------------------------------------------------
 
-BCGTool::BCGTool(QObject* parent)
+BCGTool::BCGTool(QObject* const parent)
     : EditorToolThreaded(parent),
-      d(new BCGToolPriv)
+      d(new Private)
 {
     setObjectName("bcgadjust");
     setToolName(i18n("Brightness / Contrast / Gamma"));
@@ -97,6 +95,7 @@ BCGTool::BCGTool(QObject* parent)
     setToolIcon(SmallIcon("contrast"));
     setToolHelp("bcgadjusttool.anchor");
     setToolCategory(FilterAction::ReproducibleFilter);
+    setInitPreview(true);
 
     d->previewWidget = new ImageRegionWidget;
     setToolView(d->previewWidget);
@@ -110,13 +109,12 @@ BCGTool::BCGTool(QObject* parent)
     d->gboxSettings->setButtons(EditorToolSettings::Default|
                                 EditorToolSettings::Ok|
                                 EditorToolSettings::Cancel);
-    //                                EditorToolSettings::Try);
+//                              EditorToolSettings::Try);
 
     // -------------------------------------------------------------
 
     d->settingsView = new BCGSettings(d->gboxSettings->plainPage());
     setToolSettings(d->gboxSettings);
-    init();
 
     // -------------------------------------------------------------
 
@@ -124,18 +122,11 @@ BCGTool::BCGTool(QObject* parent)
             this, SLOT(slotTimer()));
 
     connect(d->previewWidget, SIGNAL(signalResized()),
-            this, SLOT(slotEffect()));
-
-    slotTimer();
+            this, SLOT(slotPreview()));
 }
 
 BCGTool::~BCGTool()
 {
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
     delete d;
 }
 
@@ -164,10 +155,10 @@ void BCGTool::writeSettings()
 void BCGTool::slotResetSettings()
 {
     d->settingsView->resetToDefault();
-    slotEffect();
+    slotPreview();
 }
 
-void BCGTool::prepareEffect()
+void BCGTool::preparePreview()
 {
     BCGContainer settings = d->settingsView->settings();
 
@@ -177,37 +168,29 @@ void BCGTool::prepareEffect()
     setFilter(new BCGFilter(&preview, this, settings));
 }
 
-void BCGTool::putPreviewData()
+void BCGTool::setPreviewImage()
 {
     DImg preview = filter()->getTargetImage();
     d->previewWidget->setPreviewImage(preview);
 
     // Update histogram.
 
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
-    d->destinationPreviewData = preview.copyBits();
-    d->gboxSettings->histogramBox()->histogram()->updateData(d->destinationPreviewData,
-            preview.width(), preview.height(), preview.sixteenBit(),
-            0, 0, 0, false);
+    d->gboxSettings->histogramBox()->histogram()->updateData(preview.copy(), DImg(), false);
 }
 
 void BCGTool::prepareFinal()
 {
     BCGContainer settings = d->settingsView->settings();
 
-    ImageIface iface(0, 0);
+    ImageIface iface;
 
-    setFilter(new BCGFilter(iface.getOriginalImg(), this, settings));
+    setFilter(new BCGFilter(iface.original(), this, settings));
 }
 
-void BCGTool::putFinalData()
+void BCGTool::setFinalImage()
 {
-    ImageIface iface(0, 0);
-    iface.putOriginalImage(i18n("Brightness / Contrast / Gamma"), filter()->filterAction(), filter()->getTargetImage().bits());
+    ImageIface iface;
+    iface.setOriginal(i18n("Brightness / Contrast / Gamma"), filter()->filterAction(), filter()->getTargetImage());
 }
 
 }  // namespace DigikamColorImagePlugin
