@@ -6,7 +6,7 @@
  * Date        : 2004-07-11
  * Description : digiKam image editor Color Balance tool.
  *
- * Copyright (C) 2004-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -56,12 +56,11 @@ using namespace KDcrawIface;
 namespace DigikamColorImagePlugin
 {
 
-class CBTool::CBToolPriv
+class CBTool::Private
 {
 public:
 
-    CBToolPriv() :
-        destinationPreviewData(0),
+    Private() :
         cbSettings(0),
         previewWidget(0),
         gboxSettings(0)
@@ -71,25 +70,25 @@ public:
     static const QString configHistogramChannelEntry;
     static const QString configHistogramScaleEntry;
 
-    uchar*               destinationPreviewData;
-
     CBSettings*          cbSettings;
     ImageRegionWidget*   previewWidget;
     EditorToolSettings*  gboxSettings;
 };
-const QString CBTool::CBToolPriv::configGroupName("colorbalance Tool");
-const QString CBTool::CBToolPriv::configHistogramChannelEntry("Histogram Channel");
-const QString CBTool::CBToolPriv::configHistogramScaleEntry("Histogram Scale");
+
+const QString CBTool::Private::configGroupName("colorbalance Tool");
+const QString CBTool::Private::configHistogramChannelEntry("Histogram Channel");
+const QString CBTool::Private::configHistogramScaleEntry("Histogram Scale");
 
 // --------------------------------------------------------
 
-CBTool::CBTool(QObject* parent)
+CBTool::CBTool(QObject* const parent)
     : EditorToolThreaded(parent),
-      d(new CBToolPriv)
+      d(new Private)
 {
     setObjectName("colorbalance");
     setToolName(i18n("Color Balance"));
     setToolIcon(SmallIcon("adjustrgb"));
+    setInitPreview(true);
 
     d->previewWidget = new ImageRegionWidget;
     setToolView(d->previewWidget);
@@ -106,7 +105,6 @@ CBTool::CBTool(QObject* parent)
 
     d->cbSettings = new CBSettings(d->gboxSettings->plainPage());
     setToolSettings(d->gboxSettings);
-    init();
 
     // -------------------------------------------------------------
 
@@ -114,18 +112,11 @@ CBTool::CBTool(QObject* parent)
             this, SLOT(slotTimer()));
 
     connect(d->previewWidget, SIGNAL(signalResized()),
-            this, SLOT(slotEffect()));
-
-    slotTimer();
+            this, SLOT(slotPreview()));
 }
 
 CBTool::~CBTool()
 {
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
     delete d;
 }
 
@@ -155,10 +146,10 @@ void CBTool::writeSettings()
 void CBTool::slotResetSettings()
 {
     d->cbSettings->resetToDefault();
-    slotEffect();
+    slotPreview();
 }
 
-void CBTool::prepareEffect()
+void CBTool::preparePreview()
 {
     CBContainer settings = d->cbSettings->settings();
     d->gboxSettings->histogramBox()->histogram()->stopHistogramComputation();
@@ -167,36 +158,28 @@ void CBTool::prepareEffect()
     setFilter(new CBFilter(&preview, this, settings));
 }
 
-void CBTool::putPreviewData()
+void CBTool::setPreviewImage()
 {
     DImg preview = filter()->getTargetImage();
     d->previewWidget->setPreviewImage(preview);
 
     // Update histogram.
 
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
-    d->destinationPreviewData = preview.copyBits();
-    d->gboxSettings->histogramBox()->histogram()->updateData(d->destinationPreviewData,
-            preview.width(), preview.height(), preview.sixteenBit(),
-            0, 0, 0, false);
+    d->gboxSettings->histogramBox()->histogram()->updateData(preview.copy(), DImg(), false);
 }
 
 void CBTool::prepareFinal()
 {
     CBContainer settings = d->cbSettings->settings();
 
-    ImageIface iface(0, 0);
-    setFilter(new CBFilter(iface.getOriginalImg(), this, settings));
+    ImageIface iface;
+    setFilter(new CBFilter(iface.original(), this, settings));
 }
 
-void CBTool::putFinalData()
+void CBTool::setFinalImage()
 {
-    ImageIface iface(0, 0);
-    iface.putOriginalImage(i18n("Color Balance"), filter()->filterAction(), filter()->getTargetImage().bits());
+    ImageIface iface;
+    iface.setOriginal(i18n("Color Balance"), filter()->filterAction(), filter()->getTargetImage());
 }
 
 }  // namespace DigikamColorImagePlugin
