@@ -7,7 +7,7 @@
  * Description : digiKam image editor to adjust Hue, Saturation,
  *               and Lightness of picture.
  *
- * Copyright (C) 2004-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -55,12 +55,11 @@ using namespace KDcrawIface;
 namespace DigikamColorImagePlugin
 {
 
-class HSLTool::HSLToolPriv
+class HSLTool::Private
 {
 public:
 
-    HSLToolPriv() :
-        destinationPreviewData(0),
+    Private() :
         hslSettings(0),
         previewWidget(0),
         gboxSettings(0)
@@ -70,26 +69,26 @@ public:
     static const QString configHistogramChannelEntry;
     static const QString configHistogramScaleEntry;
 
-    uchar*               destinationPreviewData;
-
     HSLSettings*         hslSettings;
     ImageRegionWidget*   previewWidget;
     EditorToolSettings*  gboxSettings;
 };
-const QString HSLTool::HSLToolPriv::configGroupName("hsladjust Tool");
-const QString HSLTool::HSLToolPriv::configHistogramChannelEntry("Histogram Channel");
-const QString HSLTool::HSLToolPriv::configHistogramScaleEntry("Histogram Scale");
+
+const QString HSLTool::Private::configGroupName("hsladjust Tool");
+const QString HSLTool::Private::configHistogramChannelEntry("Histogram Channel");
+const QString HSLTool::Private::configHistogramScaleEntry("Histogram Scale");
 
 // --------------------------------------------------------
 
-HSLTool::HSLTool(QObject* parent)
+HSLTool::HSLTool(QObject* const parent)
     : EditorToolThreaded(parent),
-      d(new HSLToolPriv)
+      d(new Private)
 {
     setObjectName("adjusthsl");
     setToolName(i18n("Hue / Saturation / Lightness"));
     setToolIcon(SmallIcon("adjusthsl"));
     setToolHelp("hsladjusttool.anchor");
+    setInitPreview(true);
 
     d->previewWidget = new ImageRegionWidget;
     setToolView(d->previewWidget);
@@ -108,26 +107,18 @@ HSLTool::HSLTool(QObject* parent)
 
     d->hslSettings = new HSLSettings(d->gboxSettings->plainPage());
     setToolSettings(d->gboxSettings);
-    init();
 
     // -------------------------------------------------------------
 
     connect(d->previewWidget, SIGNAL(signalResized()),
-            this, SLOT(slotEffect()));
+            this, SLOT(slotPreview()));
 
     connect(d->hslSettings, SIGNAL(signalSettingsChanged()),
             this, SLOT(slotTimer()));
-
-    slotTimer();
 }
 
 HSLTool::~HSLTool()
 {
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
     delete d;
 }
 
@@ -156,10 +147,10 @@ void HSLTool::writeSettings()
 void HSLTool::slotResetSettings()
 {
     d->hslSettings->resetToDefault();
-    slotEffect();
+    slotPreview();
 }
 
-void HSLTool::prepareEffect()
+void HSLTool::preparePreview()
 {
     HSLContainer settings = d->hslSettings->settings();
     d->gboxSettings->histogramBox()->histogram()->stopHistogramComputation();
@@ -168,36 +159,28 @@ void HSLTool::prepareEffect()
     setFilter(new HSLFilter(&preview, this, settings));
 }
 
-void HSLTool::putPreviewData()
+void HSLTool::setPreviewImage()
 {
     DImg preview = filter()->getTargetImage();
     d->previewWidget->setPreviewImage(preview);
 
     // Update histogram.
 
-    if (d->destinationPreviewData)
-    {
-        delete [] d->destinationPreviewData;
-    }
-
-    d->destinationPreviewData = preview.copyBits();
-    d->gboxSettings->histogramBox()->histogram()->updateData(d->destinationPreviewData,
-            preview.width(), preview.height(), preview.sixteenBit(),
-            0, 0, 0, false);
+    d->gboxSettings->histogramBox()->histogram()->updateData(preview.copy(), DImg(), false);
 }
 
 void HSLTool::prepareFinal()
 {
     HSLContainer settings = d->hslSettings->settings();
 
-    ImageIface iface(0, 0);
-    setFilter(new HSLFilter(iface.getOriginalImg(), this, settings));
+    ImageIface iface;
+    setFilter(new HSLFilter(iface.original(), this, settings));
 }
 
-void HSLTool::putFinalData()
+void HSLTool::setFinalImage()
 {
-    ImageIface iface(0, 0);
-    iface.putOriginalImage(i18n("HSL Adjustments"), filter()->filterAction(), filter()->getTargetImage().bits());
+    ImageIface iface;
+    iface.setOriginal(i18n("HSL Adjustments"), filter()->filterAction(), filter()->getTargetImage());
 }
 
 }  // namespace DigikamColorImagePlugin
