@@ -6,7 +6,7 @@
  * Date        : 2004-07-09
  * Description : a tool to blur an image
  *
- * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -40,7 +40,7 @@ class BlurTool : public EditorToolThreaded
 
 public:
 
-    BlurTool(QObject* parent);
+    explicit BlurTool(QObject* const parent);
     ~BlurTool();
 
 private Q_SLOTS:
@@ -51,15 +51,15 @@ private:
 
     void readSettings();
     void writeSettings();
-    void prepareEffect();
+    void preparePreview();
     void prepareFinal();
-    void putPreviewData();
-    void putFinalData();
+    void setPreviewImage();
+    void setFinalImage();
 
 private:
 
-    class BlurToolPriv;
-    BlurToolPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace DigikamEnhanceImagePlugin
