@@ -7,8 +7,8 @@
  * Description : a digiKam image editor plugin to emboss
  *               an image.
  *
- * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2004-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -56,11 +56,11 @@ using namespace KDcrawIface;
 namespace DigikamFxFiltersImagePlugin
 {
 
-class EmbossTool::EmbossToolPriv
+class EmbossTool::Private
 {
 public:
 
-    EmbossToolPriv() :
+    Private() :
         depthInput(0),
         previewWidget(0),
         gboxSettings(0)
@@ -73,18 +73,20 @@ public:
     ImageRegionWidget*   previewWidget;
     EditorToolSettings*  gboxSettings;
 };
-const QString EmbossTool::EmbossToolPriv::configGroupName("emboss Tool");
-const QString EmbossTool::EmbossToolPriv::configDepthAdjustmentEntry("DepthAdjustment");
+
+const QString EmbossTool::Private::configGroupName("emboss Tool");
+const QString EmbossTool::Private::configDepthAdjustmentEntry("DepthAdjustment");
 
 // --------------------------------------------------------
 
-EmbossTool::EmbossTool(QObject* parent)
+EmbossTool::EmbossTool(QObject* const parent)
     : EditorToolThreaded(parent),
-      d(new EmbossToolPriv)
+      d(new Private)
 {
     setObjectName("emboss");
     setToolName(i18n("Emboss"));
     setToolIcon(SmallIcon("embosstool"));
+    setInitPreview(true);
 
     // -------------------------------------------------------------
 
@@ -115,19 +117,14 @@ EmbossTool::EmbossTool(QObject* parent)
     setToolSettings(d->gboxSettings);
     setToolView(d->previewWidget);
     setPreviewModeMask(PreviewToolBar::AllPreviewModes);
-    init();
 
     // -------------------------------------------------------------
 
     connect(d->previewWidget, SIGNAL(signalOriginalClipFocusChanged()),
-            this, SLOT(slotEffect()));
+            this, SLOT(slotPreview()));
 
     connect(d->depthInput, SIGNAL(valueChanged(int)),
             this, SLOT(slotTimer()));
-
-    // -------------------------------------------------------------
-
-    slotTimer();
 }
 
 EmbossTool::~EmbossTool()
@@ -160,10 +157,10 @@ void EmbossTool::slotResetSettings()
     d->depthInput->slotReset();
     d->depthInput->blockSignals(false);
 
-    slotEffect();
+    slotPreview();
 }
 
-void EmbossTool::prepareEffect()
+void EmbossTool::preparePreview()
 {
     DImg image = d->previewWidget->getOriginalRegionImage();
     int depth  = d->depthInput->value();
@@ -175,19 +172,19 @@ void EmbossTool::prepareFinal()
 {
     int depth = d->depthInput->value();
 
-    ImageIface iface(0, 0);
-    setFilter(new EmbossFilter(iface.getOriginalImg(), this, depth));
+    ImageIface iface;
+    setFilter(new EmbossFilter(iface.original(), this, depth));
 }
 
-void EmbossTool::putPreviewData()
+void EmbossTool::setPreviewImage()
 {
     d->previewWidget->setPreviewImage(filter()->getTargetImage());
 }
 
-void EmbossTool::putFinalData()
+void EmbossTool::setFinalImage()
 {
-    ImageIface iface(0, 0);
-    iface.putOriginalImage(i18n("Emboss"), filter()->filterAction(), filter()->getTargetImage().bits());
+    ImageIface iface;
+    iface.setOriginal(i18n("Emboss"), filter()->filterAction(), filter()->getTargetImage());
 }
 
 }  // namespace DigikamFxFiltersImagePlugin
