@@ -81,13 +81,13 @@ public:
 /// @brief File stream class
 class CPGFFileStream : public CPGFStream {
 protected:
-	HANDLE m_hFile;
+	HANDLE m_hFile;	///< file handle
 
 public:
 	CPGFFileStream() : m_hFile(0) {}
 	/// Constructor
 	/// @param hFile File handle
-	CPGFFileStream(HANDLE hFile) : m_hFile(hFile) {}
+	explicit CPGFFileStream(HANDLE hFile) : m_hFile(hFile) {}
 	/// @return File handle
 	HANDLE GetHandle() { return m_hFile; }
 
@@ -105,20 +105,22 @@ public:
 /// @brief Memory stream class
 class CPGFMemoryStream : public CPGFStream {
 protected:
-	UINT8 *m_buffer, *m_pos;// buffer start address and current buffer address
-	UINT8 *m_eos;			// end of stream (first address beyond written area)
-	size_t m_size;			// buffer size
-	bool   m_allocated;		// indicates a new allocated buffer
+	UINT8 *m_buffer, *m_pos;///< buffer start address and current buffer address
+	UINT8 *m_eos;			///< end of stream (first address beyond written area)
+	size_t m_size;			///< buffer size
+	bool   m_allocated;		///< indicates a new allocated buffer
 
 public:
 	/// Constructor
 	/// @param size Size of new allocated memory buffer
-	CPGFMemoryStream(size_t size) THROW_;
+	explicit CPGFMemoryStream(size_t size) THROW_;
+	
 	/// Constructor. Use already allocated memory of given size
 	/// @param pBuffer Memory location
 	/// @param size Memory size
 	CPGFMemoryStream(UINT8 *pBuffer, size_t size) THROW_;
-	/// Constructor. Use already allocated memory of given size
+	
+	/// Use already allocated memory of given size
 	/// @param pBuffer Memory location
 	/// @param size Memory size
 	void Reinitialize(UINT8 *pBuffer, size_t size) THROW_;
@@ -156,9 +158,9 @@ public:
 #ifdef _MFC_VER
 class CPGFMemFileStream : public CPGFStream {
 protected:
-	CMemFile *m_memFile;
+	CMemFile *m_memFile;	///< MFC memory file
 public:
-	CPGFMemFileStream(CMemFile *memFile) : m_memFile(memFile) {}
+	explicit CPGFMemFileStream(CMemFile *memFile) : m_memFile(memFile) {}
 	virtual bool	IsValid() const	{ return m_memFile != NULL; }
 	virtual ~CPGFMemFileStream() {}
 	virtual void Write(int *count, void *buffer) THROW_; // throws IOException 
@@ -175,9 +177,9 @@ public:
 #if defined(WIN32) || defined(WINCE)
 class CPGFIStream : public CPGFStream {
 protected:
-	IStream *m_stream;
+	IStream *m_stream;	///< COM+ IStream
 public:
-	CPGFIStream(IStream *stream) : m_stream(stream) {}
+	explicit CPGFIStream(IStream *stream) : m_stream(stream) {}
 	virtual bool IsValid() const	{ return m_stream != 0; }
 	virtual ~CPGFIStream() {}
 	virtual void Write(int *count, void *buffer) THROW_; // throws IOException 
