@@ -6,7 +6,7 @@
  * Date        : 2007-03-21
  * Description : Collection scanning to database.
  *
- * Copyright (C) 2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2005-2006 by Tom Albers <tomalbers@kde.nl>
  * Copyright (C) 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
@@ -35,9 +35,12 @@
 
 #include <QDir>
 #include <QFileInfo>
+#include <QReadWriteLock>
+#include <QReadLocker>
 #include <QStringList>
 #include <QSet>
 #include <QTime>
+#include <QWriteLocker>
 
 // KDE includes
 
@@ -74,15 +77,22 @@ class NewlyAppearedFile
 
 public:
 
-    NewlyAppearedFile() : albumId(0) {}
+    NewlyAppearedFile() : albumId(0)
+    {
+    }
+
     NewlyAppearedFile(int albumId, const QString& fileName)
-        : albumId(albumId), fileName(fileName) {}
+        : albumId(albumId), fileName(fileName)
+    {
+    }
 
     bool operator==(const NewlyAppearedFile& other) const
     {
-        return albumId == other.albumId && fileName == other.fileName;
+        return (albumId == other.albumId) && (fileName == other.fileName);
     }
 
+public:
+    
     int     albumId;
     QString fileName;
 };
@@ -96,14 +106,177 @@ inline uint qHash(const NewlyAppearedFile& file)
 
 // --------------------------------------------------------------------
 
-class CollectionScanner::CollectionScannerPriv
+static bool modificationDateEquals(const QDateTime& a, const QDateTime& b)
+{
+    if (a != b)
+    {
+        // allow a "modify window" of one second.
+        // FAT filesystems store the modify date in 2-second resolution.
+        int diff = a.secsTo(b);
+
+        if (abs(diff) > 1)
+        {
+            return false;
+        }
+    }
+
+    return true;
+}
+
+// --------------------------------------------------------------------
+
+class CollectionScannerHintContainerImplementation : public CollectionScannerHintContainer
+{
+public:
+
+    virtual void recordHints(const QList<AlbumCopyMoveHint>& hints);
+    virtual void recordHints(const QList<ItemCopyMoveHint>& hints);
+    virtual void recordHints(const QList<ItemChangeHint>& hints);
+    virtual void recordHint(const ItemMetadataAdjustmentHint& hint);
+
+    virtual void clear();
+
+    bool hasAnyNormalHint(qlonglong id)
+    {
+        QReadLocker locker(&lock);
+
+        return modifiedItemHints.contains(id)          || 
+               rescanItemHints.contains(id)            ||
+               metadataAboutToAdjustHints.contains(id) || 
+               metadataAdjustedHints.contains(id);
+    }
+
+    bool hasAlbumHints()                            { QReadLocker locker(&lock); return !albumHints.isEmpty();                   }
+    bool hasModificationHint(qlonglong id)          { QReadLocker locker(&lock); return modifiedItemHints.contains(id);          }
+    bool hasRescanHint(qlonglong id)                { QReadLocker locker(&lock); return rescanItemHints.contains(id);            }
+    bool hasMetadataAboutToAdjustHint(qlonglong id) { QReadLocker locker(&lock); return metadataAboutToAdjustHints.contains(id); }
+    bool hasMetadataAdjustedHint(qlonglong id)      { QReadLocker locker(&lock); return metadataAdjustedHints.contains(id);      }
+
+public:
+    
+    QReadWriteLock                                                        lock;
+
+    QHash<CollectionScannerHints::DstPath, CollectionScannerHints::Album> albumHints;
+    QHash<NewlyAppearedFile, qlonglong>                                   itemHints;
+    QSet<qlonglong>                                                       modifiedItemHints;
+    QSet<qlonglong>                                                       rescanItemHints;
+    QHash<qlonglong, QDateTime>                                           metadataAboutToAdjustHints;
+    QHash<qlonglong, QDateTime>                                           metadataAdjustedHints;
+};
+
+void CollectionScannerHintContainerImplementation::recordHints(const QList<AlbumCopyMoveHint>& hints)
+{
+    QWriteLocker locker(&lock);
+
+    foreach(const AlbumCopyMoveHint& hint, hints)
+    {
+        // automagic casting to src and dst
+        albumHints[hint] = hint;
+    }
+}
+
+void CollectionScannerHintContainerImplementation::recordHints(const QList<ItemCopyMoveHint>& hints)
+{
+    QWriteLocker locker(&lock);
+
+    foreach(const ItemCopyMoveHint& hint, hints)
+    {
+        QList<qlonglong> ids = hint.srcIds();
+        QStringList dstNames = hint.dstNames();
+
+        for (int i=0; i<ids.size(); ++i)
+        {
+            itemHints[NewlyAppearedFile(hint.albumIdDst(), dstNames.at(i))] = ids.at(i);
+        }
+    }
+}
+
+void CollectionScannerHintContainerImplementation::recordHints(const QList<ItemChangeHint>& hints)
+{
+    QWriteLocker locker(&lock);
+
+    foreach(const ItemChangeHint& hint, hints)
+    {
+        const QList<qlonglong>& ids = hint.ids();
+
+        for (int i=0; i<ids.size(); ++i)
+        {
+            if (hint.isModified())
+            {
+                modifiedItemHints << ids.at(i);
+            }
+            else
+            {
+                rescanItemHints << ids.at(i);
+            }
+        }
+    }
+}
+
+void CollectionScannerHintContainerImplementation::recordHint(const ItemMetadataAdjustmentHint& hint)
+{
+    if (hint.isAboutToEdit())
+    {
+        ImageInfo info(hint.id());
+        
+        if (!
+            (modificationDateEquals(hint.modificationDate(), info.modDateTime())
+             && hint.fileSize() == info.fileSize())
+           )
+        {
+            // refuse to create a hint as a rescan is required already before any metadata edit
+            // or, in case of multiple edits, there is already a hint with an older date, then all is fine.
+            return;
+        }
+
+        QWriteLocker locker(&lock);
+        metadataAboutToAdjustHints[hint.id()] = hint.modificationDate();
+    }
+    else if (hint.isEditingFinished())
+    {
+        QWriteLocker locker(&lock);
+        QHash<qlonglong, QDateTime>::iterator it = metadataAboutToAdjustHints.find(hint.id());
+
+        if (it == metadataAboutToAdjustHints.end())
+        {
+            return;
+        }
+
+        QDateTime date = it.value();
+        metadataAboutToAdjustHints.erase(it);
+
+        metadataAdjustedHints[hint.id()] = hint.modificationDate();
+    }
+    else // Aborted
+    {
+         QWriteLocker locker(&lock);
+         QDateTime formerDate = metadataAboutToAdjustHints.take(hint.id());
+    }
+}
+
+void CollectionScannerHintContainerImplementation::clear()
+{
+    QWriteLocker locker(&lock);
+
+    albumHints.clear();
+    itemHints.clear();
+    modifiedItemHints.clear();
+    rescanItemHints.clear();
+    metadataAboutToAdjustHints.clear();
+    metadataAdjustedHints.clear();
+}
+
+// --------------------------------------------------------------------
+
+class CollectionScanner::Private
 {
 
 public:
 
-    CollectionScannerPriv() :
+    Private() :
         wantSignals(false),
         needTotalFiles(false),
+        hints(0),
         updatingHashHint(false),
         recordHistoryIds(false),
         deferredFileScanning(false),
@@ -117,6 +290,7 @@ public:
     {
         removedItemsTime = QDateTime();
     }
+
     void removedItems()
     {
         removedItemsTime = QDateTime::currentDateTime();
@@ -139,6 +313,7 @@ public:
             deferredAlbumPaths << info.path();
             return true;
         }
+
         return false;
     }
 
@@ -146,35 +321,48 @@ public:
 
 public:
 
-    QSet<QString>                                                         nameFilters;
-    QSet<QString>                                                         imageFilterSet;
-    QSet<QString>                                                         videoFilterSet;
-    QSet<QString>                                                         audioFilterSet;
-    QList<int>                                                            scannedAlbums;
-    bool                                                                  wantSignals;
-    bool                                                                  needTotalFiles;
+    QSet<QString>                                 nameFilters;
+    QSet<QString>                                 imageFilterSet;
+    QSet<QString>                                 videoFilterSet;
+    QSet<QString>                                 audioFilterSet;
+    QList<int>                                    scannedAlbums;
+    bool                                          wantSignals;
+    bool                                          needTotalFiles;
 
-    QDateTime                                                             removedItemsTime;
+    QDateTime                                     removedItemsTime;
 
-    QHash<CollectionScannerHints::DstPath, CollectionScannerHints::Album> albumHints;
-    QHash<NewlyAppearedFile, qlonglong>                                   itemHints;
-    QHash<int, int>                                                       establishedSourceAlbums;
-    QSet<int>                                                             modifiedItemHints;
-    QSet<int>                                                             rescanItemHints;
-    bool                                                                  updatingHashHint;
+    CollectionScannerHintContainerImplementation* hints;
+    QHash<int, int>                               establishedSourceAlbums;
+    bool                                          updatingHashHint;
 
-    bool                                                                  recordHistoryIds;
-    QSet<qlonglong>                                                       needResolveHistorySet;
-    QSet<qlonglong>                                                       needTaggingHistorySet;
+    bool                                          recordHistoryIds;
+    QSet<qlonglong>                               needResolveHistorySet;
+    QSet<qlonglong>                               needTaggingHistorySet;
 
-    bool                                                                  deferredFileScanning;
-    QSet<QString>                                                         deferredAlbumPaths;
+    bool                                          deferredFileScanning;
+    QSet<QString>                                 deferredAlbumPaths;
 
-    CollectionScannerObserver*                                            observer;
+    CollectionScannerObserver*                    observer;
 };
 
+void CollectionScanner::Private::finishScanner(ImageScanner& scanner)
+{
+    // Perform the actual write operation to the database
+    {
+        DatabaseOperationGroup group;
+        scanner.commit();
+    }
+
+    if (recordHistoryIds && scanner.hasHistoryToResolve())
+    {
+        needResolveHistorySet << scanner.id();
+    }
+}
+
+// --------------------------------------------------------------------------
+
 CollectionScanner::CollectionScanner()
-    : d(new CollectionScannerPriv)
+    : d(new Private)
 {
 }
 
@@ -193,47 +381,15 @@ void CollectionScanner::setNeedFileCount(bool on)
     d->needTotalFiles = on;
 }
 
-void CollectionScanner::recordHints(const QList<AlbumCopyMoveHint>& hints)
+CollectionScannerHintContainer* CollectionScanner::createHintContainer()
 {
-    foreach(const AlbumCopyMoveHint& hint, hints)
-    {
-        // automagic casting to src and dst
-        d->albumHints[hint] = hint;
-    }
+    return new CollectionScannerHintContainerImplementation;
 }
 
-void CollectionScanner::recordHints(const QList<ItemCopyMoveHint>& hints)
+void CollectionScanner::setHintContainer(CollectionScannerHintContainer* const container)
 {
-    foreach(const ItemCopyMoveHint& hint, hints)
-    {
-        QList<qlonglong> ids = hint.srcIds();
-        QStringList dstNames = hint.dstNames();
-
-        for (int i=0; i<ids.size(); ++i)
-        {
-            d->itemHints[NewlyAppearedFile(hint.albumIdDst(), dstNames.at(i))] = ids.at(i);
-        }
-    }
-}
-
-void CollectionScanner::recordHints(const QList<ItemChangeHint>& hints)
-{
-    foreach(const ItemChangeHint& hint, hints)
-    {
-        QList<qlonglong> ids = hint.ids();
-
-        for (int i=0; i<ids.size(); ++i)
-        {
-            if (hint.isModified())
-            {
-                d->modifiedItemHints << ids.at(i);
-            }
-            else
-            {
-                d->rescanItemHints << ids.at(i);
-            }
-        }
-    }
+    // the API specs require the object given here to be created by createContainer, so we can cast.
+    d->hints = static_cast<CollectionScannerHintContainerImplementation*>(container);
 }
 
 void CollectionScanner::setUpdateHashHint(bool hint)
@@ -259,7 +415,7 @@ void CollectionScanner::loadNameFilters()
     d->nameFilters = d->imageFilterSet + d->audioFilterSet + d->videoFilterSet;
 }
 
-void CollectionScanner::setObserver(CollectionScannerObserver* observer)
+void CollectionScanner::setObserver(CollectionScannerObserver* const observer)
 {
     d->observer = observer;
 }
@@ -294,6 +450,7 @@ void CollectionScanner::completeScan()
     {
         // count for progress info
         int count = 0;
+
         foreach(const CollectionLocation& location, allLocations)
         {
             count += countItemsInFolder(location.albumRootPath());
@@ -309,7 +466,7 @@ void CollectionScanner::completeScan()
     }
 
     // if we have no hints to follow, clean up all stale albums
-    if (d->albumHints.isEmpty())
+    if (!d->hints || !d->hints->hasAlbumHints())
     {
         DatabaseAccess().db()->deleteStaleAlbums();
     }
@@ -338,6 +495,7 @@ void CollectionScanner::completeScan()
         emit cancelled();
         return;
     }
+
     if (d->deferredFileScanning)
     {
         kDebug() << "Complete scan (file scanning deferred) took:" << time.elapsed() << "msecs.";
@@ -376,6 +534,7 @@ void CollectionScanner::finishCompleteScan(const QStringList& albumPaths)
     QStringList sortedPaths = albumPaths;
     qSort(sortedPaths);
     QStringList::iterator it, it2;
+
     for (it = sortedPaths.begin(); it != sortedPaths.end(); )
     {
         // remove all following entries as long as they have the same beginning (= are subalbums)
@@ -390,6 +549,7 @@ void CollectionScanner::finishCompleteScan(const QStringList& albumPaths)
     {
         // count for progress info
         int count = 0;
+
         foreach(const QString& path, sortedPaths)
         {
             count += countItemsInFolder(path);
@@ -401,7 +561,8 @@ void CollectionScanner::finishCompleteScan(const QStringList& albumPaths)
     foreach(const QString& path, sortedPaths)
     {
         CollectionLocation location = CollectionManager::instance()->locationForPath(path);
-        QString album = CollectionManager::instance()->album(path);
+        QString album               = CollectionManager::instance()->album(path);
+
         if (album == "/")
         {
             scanAlbumRoot(location);
@@ -452,7 +613,7 @@ void CollectionScanner::completeScanCleanupPart()
 void CollectionScanner::partialScan(const QString& filePath)
 {
     QString albumRoot = CollectionManager::instance()->albumRootPath(filePath);
-    QString album = CollectionManager::instance()->album(filePath);
+    QString album     = CollectionManager::instance()->album(filePath);
     partialScan(albumRoot, album);
 }
 
@@ -488,7 +649,7 @@ void CollectionScanner::partialScan(const QString& albumRoot, const QString& alb
 
     // if we have no hints to follow, clean up all stale albums
     // Hint: Rethink with next major db update
-    if (d->albumHints.isEmpty())
+    if (!d->hints || !d->hints->hasAlbumHints())
     {
         DatabaseAccess().db()->deleteStaleAlbums();
     }
@@ -498,15 +659,21 @@ void CollectionScanner::partialScan(const QString& albumRoot, const QString& alb
     // also scan the second location
     QSet<int> locationIdsToScan;
     locationIdsToScan << location.id();
-    QHash<CollectionScannerHints::DstPath, CollectionScannerHints::Album>::const_iterator it;
 
-    for (it = d->albumHints.constBegin(); it != d->albumHints.constEnd(); ++it)
+    if (d->hints)
     {
-        if (it.key().albumRootId == location.id())
+        QReadLocker locker(&d->hints->lock);
+        QHash<CollectionScannerHints::DstPath, CollectionScannerHints::Album>::const_iterator it;
+
+        for (it = d->hints->albumHints.constBegin(); it != d->hints->albumHints.constEnd(); ++it)
         {
-            locationIdsToScan << it.key().albumRootId;
+            if (it.key().albumRootId == location.id())
+            {
+                locationIdsToScan << it.key().albumRootId;
+            }
         }
     }
+
     scanForStaleAlbums(locationIdsToScan.toList());
 
     if (!d->checkObserver())
@@ -547,6 +714,7 @@ qlonglong CollectionScanner::scanFile(const QString& filePath, FileScanMode mode
     }
 
     QString album = CollectionManager::instance()->album(dirPath);
+
     return scanFile(albumRoot, album, info.fileName(), mode);
 }
 
@@ -668,6 +836,7 @@ void CollectionScanner::scanAlbumRoot(const CollectionLocation& location)
 void CollectionScanner::scanForStaleAlbums(const QList<CollectionLocation>& locations)
 {
     QList<int> locationIdsToScan;
+
     foreach(const CollectionLocation& location, locations)
     {
         locationIdsToScan << location.id();
@@ -723,19 +892,27 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
     // We can still copy over album attributes later, but we cannot identify
     // the former album of removed images.
     // Just renaming the album is also much cheaper than rescanning all files.
-    if (!toBeDeleted.isEmpty() && !d->albumHints.isEmpty())
+    if (!toBeDeleted.isEmpty() && d->hints)
     {
+        // shallow copy for reading without caring for locks
+        QHash<CollectionScannerHints::DstPath, CollectionScannerHints::Album> albumHints;
+        {
+            QReadLocker locker(&d->hints->lock);
+            albumHints = d->hints->albumHints;
+        }
+
         // go through all album copy/move hints
         QHash<CollectionScannerHints::DstPath, CollectionScannerHints::Album>::const_iterator it;
         int toBeDeletedIndex;
 
-        for (it = d->albumHints.constBegin(); it != d->albumHints.constEnd(); ++it)
+        for (it = albumHints.constBegin(); it != albumHints.constEnd(); ++it)
         {
             // if the src entry of a hint is found in toBeDeleted, we have a move/rename, no copy. Handle these here.
             toBeDeletedIndex = toBeDeleted.indexOf(it.value().albumId);
 
             // We must double check that not, for some reason, the target album has already been scanned.
             QList<AlbumShortInfo>::const_iterator it2;
+
             for (it2 = albumList.constBegin(); it2 != albumList.constEnd(); ++it2)
             {
                 if (it2->albumRootId == it.key().albumRootId
@@ -781,6 +958,7 @@ void CollectionScanner::safelyRemoveAlbums(const QList<int>& albumIds)
     // Make album orphan (no album root, keep entries until next application start)
     DatabaseAccess access;
     DatabaseTransaction transaction(&access);
+
     foreach(int albumId, albumIds)
     {
         QList<qlonglong> ids = access.db()->getItemIDsInAlbum(albumId);
@@ -804,13 +982,20 @@ int CollectionScanner::checkAlbum(const CollectionLocation& location, const QStr
         albumID = DatabaseAccess().db()->addAlbum(location.id(), album, QString(), fi.lastModified().date(), QString());
 
         // have album this one was copied from?
-        CollectionScannerHints::Album src = d->albumHints.value(CollectionScannerHints::DstPath(location.id(), album));
-
-        if (!src.isNull())
+        if (d->hints)
         {
-            //kDebug() << "Identified album" << src.albumId << "as source of new album" << fi.filePath();
-            DatabaseAccess().db()->copyAlbumProperties(src.albumId, albumID);
-            d->establishedSourceAlbums[albumID] = src.albumId;
+            CollectionScannerHints::Album src;
+            {
+                QReadLocker locker(&d->hints->lock);
+                src = d->hints->albumHints.value(CollectionScannerHints::DstPath(location.id(), album));
+            }
+
+            if (!src.isNull())
+            {
+                //kDebug() << "Identified album" << src.albumId << "as source of new album" << fi.filePath();
+                DatabaseAccess().db()->copyAlbumProperties(src.albumId, albumID);
+                d->establishedSourceAlbums[albumID] = src.albumId;
+            }
         }
     }
 
@@ -838,8 +1023,7 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
         emit startScanningAlbum(location.albumRootPath(), album);
     }
 
-    int albumID = checkAlbum(location, album);
-
+    int albumID                   = checkAlbum(location, album);
     QList<ItemScanInfo> scanInfos = DatabaseAccess().db()->getItemScanInfos(albumID);
 
     // create a hash filename -> index in list
@@ -952,50 +1136,62 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
     }
 }
 
-static bool modificationDateEquals(const QDateTime& a, const QDateTime& b)
-{
-    if (a != b)
-    {
-        // allow a "modify window" of one second.
-        // FAT filesystems store the modify date in 2-second resolution.
-        int diff = a.secsTo(b);
-
-        if (abs(diff) > 1)
-        {
-            return false;
-        }
-    }
-    return true;
-}
-
 void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo& scanInfo)
 {
+    bool hasAnyHint = d->hints && d->hints->hasAnyNormalHint(scanInfo.id);
+
     // if the date is null, this signals a full rescan
-    if (scanInfo.modificationDate.isNull() || d->rescanItemHints.contains(scanInfo.id))
+    if (scanInfo.modificationDate.isNull() || 
+        (hasAnyHint && d->hints->hasRescanHint(scanInfo.id)) )
     {
-        d->rescanItemHints.remove(scanInfo.id);
+        if (hasAnyHint)
+        {
+            QWriteLocker locker(&d->hints->lock);
+            d->hints->rescanItemHints.remove(scanInfo.id);
+        }
+        
         rescanFile(fi, scanInfo);
+
         return;
     }
-    else if (d->modifiedItemHints.contains(scanInfo.id))
+    else if (hasAnyHint && d->hints->hasModificationHint(scanInfo.id))
     {
-        d->modifiedItemHints.remove(scanInfo.id);
+        {
+            QWriteLocker locker(&d->hints->lock);
+            d->hints->modifiedItemHints.remove(scanInfo.id);
+        }
+        
         scanModifiedFile(fi, scanInfo);
+
         return;
     }
+    else if (hasAnyHint) // metadata adjustment hints
+    {
+        if (d->hints->hasMetadataAboutToAdjustHint(scanInfo.id))
+        {
+            // postpone scan
+            return;
+        }
+        else // hasMetadataAdjustedHint
+        {
+            {
+                QWriteLocker locker(&d->hints->lock);
+                d->hints->metadataAdjustedHints.remove(scanInfo.id);
+            }
+
+            scanFileUpdateHashReuseThumbnail(fi, scanInfo, true);
+
+            return;
+        }
+    }
     else if (d->updatingHashHint)
     {
         // if the file need not be scanned because of modification, update the hash
         if (modificationDateEquals(fi.lastModified(), scanInfo.modificationDate)
             && fi.size() == scanInfo.fileSize)
         {
-            QString oldHash = scanInfo.uniqueHash;
-            QString newHash = scanFileUpdateHash(fi, scanInfo);
-            if (ThumbnailDatabaseAccess::isInitialized())
-            {
-                ThumbnailDatabaseAccess().db()->replaceUniqueHash(oldHash, scanInfo.fileSize,
-                                                                  newHash, scanInfo.fileSize);
-            }
+            scanFileUpdateHashReuseThumbnail(fi, scanInfo, false);
+            
             return;
         }
     }
@@ -1007,20 +1203,6 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
     }
 }
 
-void CollectionScanner::CollectionScannerPriv::finishScanner(ImageScanner& scanner)
-{
-    // Perform the actual write operation to the database
-    {
-        DatabaseOperationGroup group;
-        scanner.commit();
-    }
-
-    if (recordHistoryIds && scanner.hasHistoryToResolve())
-    {
-        needResolveHistorySet << scanner.id();
-    }
-}
-
 qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
 {
     if (d->checkDeferred(info))
@@ -1032,7 +1214,13 @@ qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
     scanner.setCategory(category(info));
 
     // Check copy/move hints for single items
-    qlonglong srcId = d->itemHints.value(NewlyAppearedFile(albumId, info.fileName()));
+    qlonglong srcId = 0;
+
+    if (d->hints)
+    {
+        QReadLocker locker(&d->hints->lock);
+        srcId = d->hints->itemHints.value(NewlyAppearedFile(albumId, info.fileName()));
+    }
 
     if (srcId != 0)
     {
@@ -1061,6 +1249,7 @@ qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
     }
 
     d->finishScanner(scanner);
+
     return scanner.id();
 }
 
@@ -1075,6 +1264,7 @@ qlonglong CollectionScanner::scanNewFileFullScan(const QFileInfo& info, int albu
     scanner.setCategory(category(info));
     scanner.newFileFullScan(albumId);
     d->finishScanner(scanner);
+
     return scanner.id();
 }
 
@@ -1091,14 +1281,43 @@ void CollectionScanner::scanModifiedFile(const QFileInfo& info, const ItemScanIn
     d->finishScanner(scanner);
 }
 
-QString CollectionScanner::scanFileUpdateHash(const QFileInfo& info, const ItemScanInfo& scanInfo)
+void CollectionScanner::scanFileUpdateHashReuseThumbnail(const QFileInfo& info, const ItemScanInfo& scanInfo, bool fileWasEdited)
 {
+    QString oldHash   = scanInfo.uniqueHash;
+    qlonglong oldSize = scanInfo.fileSize;
+
     // same code as scanModifiedFile
     ImageScanner scanner(info, scanInfo);
     scanner.setCategory(category(info));
     scanner.fileModified();
+
+    QString newHash   = scanner.itemScanInfo().uniqueHash;
+    qlonglong newSize = scanner.itemScanInfo().fileSize;
+
+    if (ThumbnailDatabaseAccess::isInitialized())
+    {
+        if (fileWasEdited)
+        {
+            // The file was edited in such a way that we know that the pixel content did not change, so we can reuse the thumbnail.
+            // We need to add a link the the thumbnail data with the new hash/file size _and_ adjust
+            // the file modification date in the data table.
+            DatabaseThumbnailInfo thumbDbInfo = ThumbnailDatabaseAccess().db()->findByHash(oldHash, oldSize);
+
+            if (thumbDbInfo.id != -1)
+            {
+                ThumbnailDatabaseAccess().db()->insertUniqueHash(newHash, newSize, thumbDbInfo.id);
+                ThumbnailDatabaseAccess().db()->updateModificationDate(thumbDbInfo.id, scanner.itemScanInfo().modificationDate);
+                // TODO: also update details thumbnails (by file path and URL scheme)
+            }
+        }
+        else
+        {
+            ThumbnailDatabaseAccess().db()->replaceUniqueHash(oldHash, oldSize,
+                                                              newHash, newSize);
+        }
+    }
+
     d->finishScanner(scanner);
-    return scanner.itemScanInfo().uniqueHash;
 }
 
 void CollectionScanner::rescanFile(const QFileInfo& info, const ItemScanInfo& scanInfo)
@@ -1120,18 +1339,19 @@ void CollectionScanner::copyFileProperties(const ImageInfo& source, const ImageI
     {
         return;
     }
-    ImageInfo dest(d);
 
+    ImageInfo dest(d);
     DatabaseOperationGroup group;
 
     kDebug() << "Copying properties from" << source.id() << "to" << dest.id();
 
     // Rating, creation dates
-    DatabaseFields::ImageInformation imageInfoFields =
-        DatabaseFields::Rating |
-        DatabaseFields::CreationDate |
-        DatabaseFields::DigitizationDate;
+    DatabaseFields::ImageInformation imageInfoFields = DatabaseFields::Rating       |
+                                                       DatabaseFields::CreationDate |
+                                                       DatabaseFields::DigitizationDate;
+
     QVariantList imageInfos = DatabaseAccess().db()->getImageInformation(source.id(), imageInfoFields);
+
     if (!imageInfos.isEmpty())
     {
         DatabaseAccess().db()->changeImageInformation(dest.id(), imageInfos, imageInfoFields);
@@ -1142,6 +1362,7 @@ void CollectionScanner::copyFileProperties(const ImageInfo& source, const ImageI
     {
         dest.setTag(tagId);
     }
+
     // Copy color and pick label
     dest.setPickLabel(source.pickLabel());
     dest.setColorLabel(source.colorLabel());
@@ -1149,6 +1370,7 @@ void CollectionScanner::copyFileProperties(const ImageInfo& source, const ImageI
 
     // GPS data
     QVariantList positionData = DatabaseAccess().db()->getImagePosition(source.id(), DatabaseFields::ImagePositionsAll);
+
     if (!positionData.isEmpty())
     {
         DatabaseAccess().db()->addImagePosition(dest.id(), positionData, DatabaseFields::ImagePositionsAll);
@@ -1204,7 +1426,7 @@ void CollectionScanner::completeHistoryScanning()
     QList<qlonglong> ids = DatabaseAccess().db()->getItemIDsInTag(needResolvingTag);
     historyScanningStage2(ids);
 
-    ids = DatabaseAccess().db()->getItemIDsInTag(needTaggingTag);
+    ids                  = DatabaseAccess().db()->getItemIDsInTag(needTaggingTag);
     kDebug() << "items to tag" << ids;
     historyScanningStage3(ids);
 }
@@ -1246,6 +1468,7 @@ void CollectionScanner::historyScanningStage2(const QList<qlonglong>& ids)
         {
             QList<qlonglong> needTaggingIds;
             ImageScanner::resolveImageHistory(id, &needTaggingIds);
+
             foreach(qlonglong needTag, needTaggingIds)
             {
                 d->needTaggingHistorySet << needTag;
@@ -1291,7 +1514,7 @@ int CollectionScanner::countItemsInFolder(const QString& directory)
 
     for (fi = list.constBegin(); fi != list.constEnd(); ++fi)
     {
-        if ( fi->isDir() &&
+        if ( fi->isDir()           &&
              fi->fileName() != "." &&
              fi->fileName() != "..")
         {
