@@ -26,6 +26,7 @@
 
 // Qt includes
 
+#include <QDateTime>
 #include <QList>
 #include <QStringList>
 #include <QDBusArgument>
@@ -44,13 +45,16 @@ namespace CollectionScannerHints
 class DIGIKAM_DATABASE_EXPORT Album
 {
 public:
+
     Album();
     Album(int albumRootId, int albumId);
 
-    bool isNull() const;
-    uint qHash() const;
+    bool isNull()                       const;
+    uint qHash()                        const;
     bool operator==(const Album& other) const;
 
+public:
+
     int albumRootId;
     int albumId;
 };
@@ -60,14 +64,17 @@ public:
 class DIGIKAM_DATABASE_EXPORT DstPath
 {
 public:
+
     DstPath();
     DstPath(int albumRootId, const QString& relativePath);
 
-    bool isNull() const;
-    uint qHash() const;
+    bool isNull()                         const;
+    uint qHash()                          const;
     bool operator==(const DstPath& other) const;
 
-    int albumRootId;
+public:
+
+    int     albumRootId;
     QString relativePath;
 };
 
@@ -76,13 +83,16 @@ public:
 class DIGIKAM_DATABASE_EXPORT Item
 {
 public:
-    Item();
-    Item(qlonglong id);
 
-    bool isNull() const;
-    uint qHash() const;
+    Item();
+    explicit Item(qlonglong id);
+
+    bool isNull()                      const;
+    uint qHash()                       const;
     bool operator==(const Item& other) const;
 
+public:
+
     qlonglong id;
 };
 
@@ -90,10 +100,12 @@ inline uint qHash(const Album& src)
 {
     return src.qHash();
 }
+
 inline uint qHash(const DstPath& dst)
 {
     return dst.qHash();
 }
+
 inline uint qHash(const Item& item)
 {
     return item.qHash();
@@ -116,17 +128,19 @@ public:
     AlbumCopyMoveHint(int srcAlbumRootId, int srcAlbum,
                       int dstAlbumRootId, const QString& dstRelativePath);
 
-    int albumRootIdSrc() const;
-    int albumIdSrc() const;
+    int albumRootIdSrc()                          const;
+    int albumIdSrc()                              const;
     bool isSrcAlbum(int albumRootId, int albumId) const;
+
     CollectionScannerHints::Album src() const
     {
         return m_src;
     }
 
-    int albumRootIdDst() const;
-    QString relativePathDst() const;
+    int albumRootIdDst()                                          const;
+    QString relativePathDst()                                     const;
     bool isDstAlbum(int albumRootId, const QString& relativePath) const;
+
     CollectionScannerHints::DstPath dst() const
     {
         return m_dst;
@@ -138,6 +152,7 @@ public:
     {
         return src == m_src;
     }
+
     bool operator==(const CollectionScannerHints::DstPath& dst) const
     {
         return dst == m_dst;
@@ -150,6 +165,7 @@ public:
     {
         return m_src;
     }
+
     operator const CollectionScannerHints::DstPath& () const
     {
         return m_dst;
@@ -175,17 +191,18 @@ public:
     ItemCopyMoveHint();
     ItemCopyMoveHint(const QList<qlonglong>& srcIds, int dstAlbumRootId, int albumId, const QStringList& dstNames);
 
-    QList<qlonglong> srcIds() const;
-    bool isSrcId(qlonglong id) const;
-
-    int albumRootIdDst() const;
-    int albumIdDst() const;
+    QList<qlonglong> srcIds()                     const;
+    bool isSrcId(qlonglong id)                    const;
+    int albumRootIdDst()                          const;
+    int albumIdDst()                              const;
     bool isDstAlbum(int albumRootId, int albumId) const;
+
     CollectionScannerHints::Album dst() const
     {
         return m_dst;
     }
-    QStringList dstNames() const;
+
+    QStringList dstNames()        const;
     QString dstName(qlonglong id) const;
 
     bool operator==(const CollectionScannerHints::Album& dst) const
@@ -208,7 +225,6 @@ protected:
     QStringList                   m_dstNames;
 };
 
-
 // ---------------------------------------------------------------------------
 
 class DIGIKAM_DATABASE_EXPORT ItemChangeHint
@@ -225,16 +241,20 @@ public:
         ItemRescan    /// reread metadata
     };
 
+public:
+
     ItemChangeHint();
     explicit ItemChangeHint(QList<qlonglong> srcIds, ChangeType type = ItemModified);
 
-    QList<qlonglong> ids() const;
+    QList<qlonglong> ids()  const;
     bool isId(qlonglong id) const;
     ChangeType changeType() const;
+
     bool isModified() const
     {
         return changeType() == ItemModified;
     }
+
     bool needsRescan() const
     {
         return changeType() == ItemRescan;
@@ -249,6 +269,61 @@ protected:
     ChangeType        m_type;
 };
 
+// ---------------------------------------------------------------------------
+
+class DIGIKAM_DATABASE_EXPORT ItemMetadataAdjustmentHint
+{
+public:
+
+    /** The file's has been edited writing out information from
+      *  the database, i.e., the db is already guaranteed to contain
+      *  all changed information in the file's metadata.
+      *  There is no need for a full rescan, optimizations are possible.
+      */
+
+    enum AdjustmentStatus
+    {
+        AboutToEditMetadata,       /// The file is about to be edited. Suspends scanning. The Finished hint must follow.
+        MetadataEditingFinished,   /// The file's metadata has been edited as described above.
+        MetadataEditingAborted     /// The file's metadata has not been edited, despite sending AboutToEditMedata
+    };
+
+public:
+
+    ItemMetadataAdjustmentHint();
+    explicit ItemMetadataAdjustmentHint(qlonglong id, AdjustmentStatus status,
+                                        const QDateTime& modificationDateOnDisk, qlonglong fileSize);
+
+    qlonglong id()                      const;
+    AdjustmentStatus adjustmentStatus() const;
+    QDateTime modificationDate()        const;
+    qlonglong fileSize()                const;
+
+    bool isAboutToEdit() const
+    {
+        return adjustmentStatus() == AboutToEditMetadata;
+    }
+
+    bool isEditingFinished() const
+    {
+        return adjustmentStatus() == MetadataEditingFinished;
+    }
+
+    bool isEditingFinishedAborted() const
+    {
+        return adjustmentStatus() == MetadataEditingAborted;
+    }
+
+    ItemMetadataAdjustmentHint& operator<<(const QDBusArgument& argument);
+    const ItemMetadataAdjustmentHint& operator>>(QDBusArgument& argument) const;
+
+protected:
+
+    qlonglong         m_id;
+    AdjustmentStatus  m_status;
+    QDateTime         m_modificationDate;
+    qlonglong         m_fileSize;
+};
 
 inline uint qHash(const Digikam::AlbumCopyMoveHint& hint)
 {
