@@ -91,6 +91,11 @@ public:
     DatabaseFace add(qlonglong imageid, int tagId, const TagRegion& region, bool trainFace = true);
     DatabaseFace addManually(const DatabaseFace& face);
 
+    /**
+     * Switches an unknownPersonEntry or unconfirmedEntry to an unconfirmedEntry (with a different suggested name)
+     */
+    DatabaseFace        changeSuggestedName(const DatabaseFace& previousEntry, int unconfirmedNameTagId);
+
     /**
      * Assign the name tag for given face entry.
      * Pass the tagId if it changed or was newly assigned (UnknownName).
