@@ -7,8 +7,9 @@
  * Description : Handling accesss to one image and associated data
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2009-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C)      2013 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -63,6 +64,105 @@
 namespace Digikam
 {
 
+namespace
+{
+
+MetadataInfo::Field DatabaseVideoMetadataFieldsToMetadataInfoField(const DatabaseFields::VideoMetadata videoMetadataField)
+{
+    switch (videoMetadataField)
+    {
+        case DatabaseFields::AspectRatio:
+            return MetadataInfo::AspectRatio;
+
+        case DatabaseFields::AudioBitRate:
+            return MetadataInfo::AudioBitRate;
+
+        case DatabaseFields::AudioChannelType:
+            return MetadataInfo::AudioChannelType;
+
+        case DatabaseFields::AudioCompressor:
+            return MetadataInfo::AudioCompressor;
+
+        case DatabaseFields::Duration:
+            return MetadataInfo::Duration;
+
+        case DatabaseFields::FrameRate:
+            return MetadataInfo::FrameRate;
+
+        case DatabaseFields::VideoCodec:
+            return MetadataInfo::VideoCodec;
+
+        default:
+            break;
+    }
+
+    /// @todo Invalid request...
+    return MetadataInfo::Field();
+}
+
+MetadataInfo::Field DatabaseImageMetadataFieldsToMetadataInfoField(const DatabaseFields::ImageMetadata imageMetadataField)
+{
+    switch (imageMetadataField)
+    {
+        case DatabaseFields::Make:
+            return MetadataInfo::Make;
+
+        case DatabaseFields::Model:
+            return MetadataInfo::Model;
+
+        case DatabaseFields::Lens:
+            return MetadataInfo::Lens;
+
+        case DatabaseFields::Aperture:
+            return MetadataInfo::Aperture;
+
+        case DatabaseFields::FocalLength:
+            return MetadataInfo::FocalLength;
+
+        case DatabaseFields::FocalLength35:
+            return MetadataInfo::FocalLengthIn35mm;
+
+        case DatabaseFields::ExposureTime:
+            return MetadataInfo::ExposureTime;
+
+        case DatabaseFields::ExposureProgram:
+            return MetadataInfo::ExposureProgram;
+
+        case DatabaseFields::ExposureMode:
+            return MetadataInfo::ExposureMode;
+
+        case DatabaseFields::Sensitivity:
+            return MetadataInfo::Sensitivity;
+
+        case DatabaseFields::FlashMode:
+            return MetadataInfo::FlashMode;
+
+        case DatabaseFields::WhiteBalance:
+            return MetadataInfo::WhiteBalance;
+
+        case DatabaseFields::WhiteBalanceColorTemperature:
+            return MetadataInfo::WhiteBalanceColorTemperature;
+
+        case DatabaseFields::MeteringMode:
+            return MetadataInfo::MeteringMode;
+
+        case DatabaseFields::SubjectDistance:
+            return MetadataInfo::SubjectDistance;
+
+        case DatabaseFields::SubjectDistanceCategory:
+            return MetadataInfo::SubjectDistanceCategory;
+
+        default:
+            break;
+    }
+
+    /// @todo Invalid request...
+    return MetadataInfo::Field();
+}
+
+
+}
+
 ImageInfoStatic* ImageInfoStatic::m_instance = 0;
 
 void ImageInfoStatic::create()
@@ -84,6 +184,8 @@ ImageInfoCache* ImageInfoStatic::cache()
     return &m_instance->m_cache;
 }
 
+// ---------------------------------------------------------------
+
 ImageInfoData::ImageInfoData()
 {
     id                     = -1;
@@ -123,12 +225,19 @@ ImageInfoData::ImageInfoData()
     groupImageCached       = false;
 
     invalid                = false;
+
+    videoMetadataCached    = DatabaseFields::VideoMetadataNone;
+    imageMetadataCached    = DatabaseFields::ImageMetadataNone;
+    hasVideoMetadata       = true;
+    hasImageMetadata       = true;
 }
 
 ImageInfoData::~ImageInfoData()
 {
 }
 
+// ---------------------------------------------------------------
+
 ImageInfo::ImageInfo()
     : m_data(0)
 {
@@ -161,6 +270,11 @@ ImageInfo::ImageInfo(const ImageListerRecord& record)
     // field is only signed 32 bit in the protocol. -1 indicates value is larger, reread
     m_data->fileSizeCached         = m_data->fileSize != -1;
     m_data->imageSizeCached        = true;
+    m_data->videoMetadataCached    = DatabaseFields::VideoMetadataNone;
+    m_data->imageMetadataCached    = DatabaseFields::ImageMetadataNone;
+    m_data->hasVideoMetadata       = true;
+    m_data->hasImageMetadata       = true;
+    m_data->databaseFieldsHashRaw.clear();
 
     if (newlyCreated)
     {
@@ -189,7 +303,7 @@ ImageInfo::ImageInfo(qlonglong ID)
         else
         {
             // invalid image id
-            ImageInfoData* olddata = m_data.unassign();
+            ImageInfoData* const olddata = m_data.unassign();
 
             if (olddata)
             {
@@ -208,7 +322,7 @@ ImageInfo::ImageInfo(const KUrl& url)
     if (location.isNull())
     {
         m_data = 0;
-        qWarning() << "No location could be retrieved for url" << url;
+        kWarning() << "No location could be retrieved for url" << url;
         return;
     }
 
@@ -227,7 +341,7 @@ ImageInfo::ImageInfo(const KUrl& url)
         if (!info.id)
         {
             m_data = 0;
-            qWarning() << "No itemShortInfo could be retrieved from the database for image" << name;
+            kWarning() << "No itemShortInfo could be retrieved from the database for image" << name;
             return;
         }
 
@@ -245,7 +359,7 @@ ImageInfo::ImageInfo(const KUrl& url)
 
 ImageInfo::~ImageInfo()
 {
-    ImageInfoData* olddata = m_data.unassign();
+    ImageInfoData* const olddata = m_data.unassign();
 
     if (olddata)
     {
@@ -265,7 +379,7 @@ ImageInfo& ImageInfo::operator=(const ImageInfo& info)
         return *this;
     }
 
-    ImageInfoData* olddata = m_data.assign(info.m_data);
+    ImageInfoData* const olddata = m_data.assign(info.m_data);
 
     if (olddata)
     {
@@ -370,6 +484,16 @@ QString ImageInfo::name() const
         }                         \
     }
 
+#define RETURN_ASPECTRATIO_IF_IMAGESIZE_CACHED()       \
+    if (m_data->imageSizeCached)  \
+    {                             \
+        ImageInfoReadLocker lock; \
+        if (m_data->imageSizeCached)    \
+        {                         \
+    return (double)m_data->imageSize.width()/m_data->imageSize.height();     \
+        }                         \
+    }
+
 #define STORE_IN_CACHE_AND_RETURN(x, retrieveMethod) \
     ImageInfoWriteLocker lock;                       \
     m_data.constCastData()->x##Cached = true;        \
@@ -408,6 +532,7 @@ QString ImageInfo::title() const
         ImageComments comments(access, m_data->id);
         title = comments.defaultComment(DatabaseComment::Title);
     }
+
     ImageInfoWriteLocker lock;
     m_data.constCastData()->defaultTitle       = title;
     m_data.constCastData()->defaultTitleCached = true;
@@ -429,12 +554,25 @@ QString ImageInfo::comment() const
         ImageComments comments(access, m_data->id);
         comment = comments.defaultComment();
     }
+
     ImageInfoWriteLocker lock;
     m_data.constCastData()->defaultComment       = comment;
     m_data.constCastData()->defaultCommentCached = true;
     return m_data->defaultComment;
 }
 
+double ImageInfo::aspectRatio() const
+{
+    if(!m_data)
+    {
+        return 0;
+    }
+
+    RETURN_ASPECTRATIO_IF_IMAGESIZE_CACHED()
+
+    return (double)m_data->imageSize.width() / m_data->imageSize.height();
+}
+
 int ImageInfo::pickLabel() const
 {
     if (!m_data)
@@ -541,10 +679,12 @@ QSize ImageInfo::dimensions() const
     QVariantList values = DatabaseAccess().db()->getImageInformation(m_data->id, DatabaseFields::Width | DatabaseFields::Height);
     ImageInfoWriteLocker lock;
     m_data.constCastData()->imageSizeCached = true;
+
     if (values.size() == 2)
     {
         m_data.constCastData()->imageSize = QSize(values.at(0).toInt(), values.at(1).toInt());
     }
+
     return m_data->imageSize;
 }
 
@@ -569,14 +709,17 @@ void ImageInfoList::loadTagIds() const
     QVector<QList<int> > allTagIds = DatabaseAccess().db()->getItemsTagIDs(toImageIdList());
 
     ImageInfoWriteLocker lock;
+
     for (int i=0; i<size(); i++)
     {
         const ImageInfo& info = at(i);
         const QList<int>& ids = allTagIds.at(i);
+
         if (!info.m_data)
         {
             continue;
         }
+
         info.m_data.constCastData()->tagIds       = ids;
         info.m_data.constCastData()->tagIdsCached = true;
     }
@@ -633,8 +776,8 @@ QString ImageInfo::filePath() const
     }
 
     QString album = ImageInfoStatic::cache()->albumRelativePath(m_data->albumId);
-
     ImageInfoReadLocker lock;
+
     if (album == "/")
     {
         return albumRoot + album + m_data->name;
@@ -752,8 +895,7 @@ int ImageInfo::numberOfGroupedImages() const
 
     RETURN_IF_CACHED(groupedImages)
 
-    int groupedImages = DatabaseAccess().db()->getImagesRelatingTo(m_data->id, DatabaseRelation::Grouped).size();
-
+    int groupedImages                           = DatabaseAccess().db()->getImagesRelatingTo(m_data->id, DatabaseRelation::Grouped).size();
     ImageInfoWriteLocker lock;
     m_data.constCastData()->groupedImages       = groupedImages;
     m_data.constCastData()->groupedImagesCached = true;
@@ -771,7 +913,7 @@ qlonglong ImageInfo::groupImageId() const
 
     QList<qlonglong> ids = DatabaseAccess().db()->getImagesRelatedFrom(m_data->id, DatabaseRelation::Grouped);
     // list size should be 0 or 1
-    int groupImage = ids.isEmpty() ? -1 : ids.first();
+    int groupImage       = ids.isEmpty() ? -1 : ids.first();
 
     ImageInfoWriteLocker lock;
     m_data.constCastData()->groupImage       = groupImage;
@@ -781,18 +923,19 @@ qlonglong ImageInfo::groupImageId() const
 
 void ImageInfoList::loadGroupImageIds() const
 {
-    QVector<QList<qlonglong> > allGroupIds = DatabaseAccess().db()->getImagesRelatedFrom(toImageIdList(),
-                                                                                         DatabaseRelation::Grouped);
+    QVector<QList<qlonglong> > allGroupIds = DatabaseAccess().db()->getImagesRelatedFrom(toImageIdList(), DatabaseRelation::Grouped);
     ImageInfoWriteLocker lock;
 
     for (int i=0; i<size(); i++)
     {
         const ImageInfo& info            = at(i);
         const QList<qlonglong>& groupIds = allGroupIds.at(i);
+
         if (!info.m_data)
         {
             continue;
         }
+
         info.m_data.constCastData()->groupImage       = groupIds.isEmpty() ? -1 : groupIds.first();
         info.m_data.constCastData()->groupImageCached = true;
     }
@@ -806,10 +949,12 @@ bool ImageInfo::isGrouped() const
 ImageInfo ImageInfo::groupImage() const
 {
     qlonglong id = groupImageId();
+
     if (id == -1)
     {
         return ImageInfo();
     }
+
     return ImageInfo(id);
 }
 
@@ -1145,7 +1290,90 @@ ImageMetadataContainer ImageInfo::imageMetadataContainer() const
     }
 
     ImageMetadataContainer container;
-    ImageScanner::fillMetadataContainer(m_data->id, &container);
+    const DatabaseFieldsHashRaw rawVideoMetadata = getDatabaseFieldsRaw(DatabaseFields::ImageMetadataAll);
+    bool allFieldsNull = true;
+    for (DatabaseFields::ImageMetadataIterator it; !it.atEnd(); ++it)
+    {
+        const QVariant fieldValue = rawVideoMetadata.value(*it);
+
+        allFieldsNull&=fieldValue.isNull();
+
+        if (!fieldValue.isNull())
+        {
+            const MetadataInfo::Field mdField = DatabaseImageMetadataFieldsToMetadataInfoField(*it);
+            const QString fieldString = DMetadata::valueToString(fieldValue, mdField);
+
+            switch (*it)
+            {
+                case DatabaseFields::Make:
+                    container.make = fieldString;
+                    break;
+
+                case DatabaseFields::Model:
+                    container.model = fieldString;
+                    break;
+
+                case DatabaseFields::Lens:
+                    container.lens = fieldString;
+                    break;
+
+                case DatabaseFields::Aperture:
+                    container.aperture = fieldString;
+                    break;
+
+                case DatabaseFields::FocalLength:
+                    container.focalLength = fieldString;
+                    break;
+
+                case DatabaseFields::FocalLength35:
+                    container.focalLength35 = fieldString;
+                    break;
+
+                case DatabaseFields::ExposureTime:
+                    container.exposureTime = fieldString;
+                    break;
+
+                case DatabaseFields::ExposureProgram:
+                    container.exposureProgram = fieldString;
+                    break;
+
+                case DatabaseFields::ExposureMode:
+                    container.exposureMode = fieldString;
+                    break;
+
+                case DatabaseFields::Sensitivity:
+                    container.sensitivity = fieldString;
+                    break;
+
+                case DatabaseFields::FlashMode:
+                    container.flashMode = fieldString;
+                    break;
+
+                case DatabaseFields::WhiteBalance:
+                    container.whiteBalance = fieldString;
+                    break;
+
+                case DatabaseFields::WhiteBalanceColorTemperature:
+                    container.whiteBalanceColorTemperature = fieldString;
+                    break;
+
+                case DatabaseFields::SubjectDistance:
+                    container.subjectDistance = fieldString;
+                    break;
+
+                case DatabaseFields::SubjectDistanceCategory:
+                    container.subjectDistanceCategory = fieldString;
+                    break;
+
+                default:
+                    break;
+            }
+        }
+    }
+
+    // store whether we have at least one valid field
+    container.allFieldsNull = allFieldsNull;
+
     return container;
 }
 
@@ -1157,7 +1385,59 @@ VideoMetadataContainer ImageInfo::videoMetadataContainer() const
     }
 
     VideoMetadataContainer container;
-    ImageScanner::fillVideoMetadataContainer(m_data->id, &container);
+    const DatabaseFieldsHashRaw rawVideoMetadata = getDatabaseFieldsRaw(DatabaseFields::VideoMetadataAll);
+
+    bool allFieldsNull = true;
+    for (DatabaseFields::VideoMetadataIterator it; !it.atEnd(); ++it)
+    {
+        const QVariant fieldValue = rawVideoMetadata.value(*it);
+
+        allFieldsNull&=fieldValue.isNull();
+
+        if (!fieldValue.isNull())
+        {
+            const MetadataInfo::Field mdField = DatabaseVideoMetadataFieldsToMetadataInfoField(*it);
+            const QString fieldString = DMetadata::valueToString(fieldValue, mdField);
+
+            switch (*it)
+            {
+                case DatabaseFields::AspectRatio:
+                    container.aspectRatio = fieldString;
+                    break;
+
+                case DatabaseFields::AudioBitRate:
+                    container.audioBitRate = fieldString;
+                    break;
+
+                case DatabaseFields::AudioChannelType:
+                    container.audioChannelType = fieldString;
+                    break;
+
+                case DatabaseFields::AudioCompressor:
+                    container.audioCompressor = fieldString;
+                    break;
+
+                case DatabaseFields::Duration:
+                    container.duration = fieldString;
+                    break;
+
+                case DatabaseFields::FrameRate:
+                    container.frameRate = fieldString;
+                    break;
+
+                case DatabaseFields::VideoCodec:
+                    container.videoCodec = fieldString;
+                    break;
+
+                default:
+                    break;
+            }
+        }
+    }
+
+    // store whether we have at least one valid field
+    container.allFieldsNull = allFieldsNull;
+
     return container;
 }
 
@@ -1198,13 +1478,13 @@ VideoInfoContainer ImageInfo::videoInfoContainer() const
     VideoMetadataContainer meta = videoMetadataContainer();
     VideoInfoContainer videoInfo;
 
-    videoInfo.aspectRatio               = meta.aspectRatio;
-    videoInfo.audioBitRate              = meta.audioBitRate;
-    videoInfo.audioChannelType          = meta.audioChannelType;
-    videoInfo.audioCompressor           = meta.audioCompressor;
-    videoInfo.duration                  = meta.duration;
-    videoInfo.frameRate                 = meta.frameRate;
-    videoInfo.videoCodec                = meta.videoCodec;
+    videoInfo.aspectRatio       = meta.aspectRatio;
+    videoInfo.audioBitRate      = meta.audioBitRate;
+    videoInfo.audioChannelType  = meta.audioChannelType;
+    videoInfo.audioCompressor   = meta.audioCompressor;
+    videoInfo.duration          = meta.duration;
+    videoInfo.frameRate         = meta.frameRate;
+    videoInfo.videoCodec        = meta.videoCodec;
 
     return videoInfo;
 }
@@ -1268,6 +1548,7 @@ void ImageInfo::setPickLabel(int pickId)
     // Perform "switch" operation atomic
     {
         DatabaseAccess access;
+
         foreach(int tagId, currentTagIds)
         {
             if (pickLabelTags.contains(tagId))
@@ -1275,6 +1556,7 @@ void ImageInfo::setPickLabel(int pickId)
                 removeTag(tagId);
             }
         }
+
         setTag(pickLabelTags[pickId]);
     }
 
@@ -1297,6 +1579,7 @@ void ImageInfo::setColorLabel(int colorId)
     // Perform "switch" operation atomic
     {
         DatabaseAccess access;
+
         foreach(int tagId, currentTagIds)
         {
             if (colorLabelTags.contains(tagId))
@@ -1304,6 +1587,7 @@ void ImageInfo::setColorLabel(int colorId)
                 removeTag(tagId);
             }
         }
+
         setTag(colorLabelTags[colorId]);
     }
 
@@ -1425,4 +1709,105 @@ QDebug& operator<<(QDebug& stream, const ImageInfo& info)
                   << info.databaseUrl() << "]";
 }
 
+ImageInfo::DatabaseFieldsHashRaw ImageInfo::getDatabaseFieldsRaw(const DatabaseFields::Set& requestedSet) const
+{
+    if (!m_data)
+    {
+        return DatabaseFieldsHashRaw();
+    }
+
+    // keep the system locked to make sure all fields are taken from the same cache state
+    /// @todo Actually we need a read-write-lock, but we only have a write lock.
+    ImageInfoWriteLocker writeLocker;
+    if (requestedSet.hasFieldsFromVideoMetadata() && m_data->hasVideoMetadata)
+    {
+        const DatabaseFields::VideoMetadata requestedVideoMetadata = requestedSet.getVideoMetadata();
+
+        const DatabaseFields::VideoMetadata missingVideoMetadata = requestedVideoMetadata & ~m_data->videoMetadataCached;
+//         kDebug()<<QString("videometadata: requested: %1 missing: %3").arg(requestedVideoMetadata, 0, 16).arg(missingVideoMetadata, 0, 16);
+        if (missingVideoMetadata)
+        {
+            const QVariantList fieldValues = DatabaseAccess().db()->getVideoMetadata(m_data->id, missingVideoMetadata);
+
+            if (fieldValues.isEmpty())
+            {
+                m_data.constCastData()->hasVideoMetadata = false;
+                m_data.constCastData()->databaseFieldsHashRaw.removeAllFields(DatabaseFields::VideoMetadataAll);
+                m_data.constCastData()->videoMetadataCached = DatabaseFields::VideoMetadataNone;
+            }
+            else
+            {
+                int fieldsIndex = 0;
+                for (DatabaseFields::VideoMetadataIteratorSetOnly it(missingVideoMetadata); !it.atEnd(); ++it)
+                {
+                    const QVariant fieldValue = fieldValues.at(fieldsIndex);
+                    ++fieldsIndex;
+
+                    m_data.constCastData()->databaseFieldsHashRaw.insertField(*it, fieldValue);
+                }
+
+                m_data.constCastData()->videoMetadataCached|=missingVideoMetadata;
+            }
+        }
+    }
+
+    if (requestedSet.hasFieldsFromImageMetadata() && m_data->hasImageMetadata)
+    {
+        const DatabaseFields::ImageMetadata requestedImageMetadata = requestedSet.getImageMetadata();
+
+        const DatabaseFields::ImageMetadata missingImageMetadata = requestedImageMetadata & ~m_data->imageMetadataCached;
+//         kDebug()<<QString("imagemetadata: requested: %1 missing: %3").arg(requestedImageMetadata, 0, 16).arg(missingImageMetadata, 0, 16);
+        if (missingImageMetadata)
+        {
+            const QVariantList fieldValues = DatabaseAccess().db()->getImageMetadata(m_data->id, missingImageMetadata);
+
+            if (fieldValues.isEmpty())
+            {
+                m_data.constCastData()->hasImageMetadata = false;
+                m_data.constCastData()->databaseFieldsHashRaw.removeAllFields(DatabaseFields::ImageMetadataAll);
+                m_data.constCastData()->imageMetadataCached = DatabaseFields::ImageMetadataNone;
+            }
+            else
+            {
+                int fieldsIndex = 0;
+                for (DatabaseFields::ImageMetadataIteratorSetOnly it(missingImageMetadata); !it.atEnd(); ++it)
+                {
+                    const QVariant fieldValue = fieldValues.at(fieldsIndex);
+                    ++fieldsIndex;
+
+                    m_data.constCastData()->databaseFieldsHashRaw.insertField(*it, fieldValue);
+                }
+
+                m_data.constCastData()->imageMetadataCached|=missingImageMetadata;
+            }
+        }
+    }
+
+    // We always return all fields, the caller can just retrieve the ones he needs.
+    return m_data->databaseFieldsHashRaw;
+}
+
+QVariant ImageInfo::getDatabaseFieldRaw(const DatabaseFields::Set& requestedField) const
+{
+    DatabaseFieldsHashRaw rawHash = getDatabaseFieldsRaw(requestedField);
+
+    if (requestedField.hasFieldsFromImageMetadata())
+    {
+        const DatabaseFields::ImageMetadata requestedFieldFlag = requestedField;
+        const QVariant value = rawHash.value(requestedFieldFlag);
+
+        return value;
+    }
+
+    if (requestedField.hasFieldsFromVideoMetadata())
+    {
+        const DatabaseFields::VideoMetadata requestedFieldFlag = requestedField;
+        const QVariant value = rawHash.value(requestedFieldFlag);
+
+        return value;
+    }
+
+    return QVariant();
+}
+
 }  // namespace Digikam
