@@ -6,8 +6,9 @@
  * Date        : 2007-03-20
  * Description : Listing information from database.
  *
- * Copyright (C) 2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2007-2008 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
+ * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2007-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -80,26 +81,48 @@ static inline int toInt32BitSafe(const QList<QVariant>::const_iterator& it)
     return (int)v;
 }
 
-ImageLister::ImageLister()
+// ---------------------------------------------------------------------------------
+
+class ImageLister::Private
 {
-    m_recursive = true;
-    m_listOnlyAvailableImages = true;
-    m_allowExtraValues = false;
+
+public:
+
+    Private()
+    {
+        recursive               = true;
+        listOnlyAvailableImages = true;
+        allowExtraValues        = false;
+    }
+
+    bool recursive;
+    bool listOnlyAvailableImages;
+    bool allowExtraValues;
+};
+
+ImageLister::ImageLister()
+    : d(new Private)
+{
+}
+
+ImageLister::~ImageLister()
+{
+    delete d;
 }
 
 void ImageLister::setRecursive(bool recursive)
 {
-    m_recursive = recursive;
+    d->recursive = recursive;
 }
 
 void ImageLister::setListOnlyAvailable(bool listOnlyAvailable)
 {
-    m_listOnlyAvailableImages = listOnlyAvailable;
+    d->listOnlyAvailableImages = listOnlyAvailable;
 }
 
 void ImageLister::setAllowExtraValues(bool useExtraValue)
 {
-    m_allowExtraValues = useExtraValue;
+    d->allowExtraValues = useExtraValue;
 }
 
 KIO::TransferJob* ImageLister::startListJob(const DatabaseUrl& url, int extraValue)
@@ -116,7 +139,7 @@ KIO::TransferJob* ImageLister::startListJob(const DatabaseUrl& url, int extraVal
     return new KIO::SpecialJob(url, ba);
 }
 
-void ImageLister::list(ImageListerReceiver* receiver, const DatabaseUrl& url)
+void ImageLister::list(ImageListerReceiver* const receiver, const DatabaseUrl& url)
 {
     if (url.isAlbumUrl())
     {
@@ -140,10 +163,9 @@ void ImageLister::list(ImageListerReceiver* receiver, const DatabaseUrl& url)
     }
 }
 
-void ImageLister::listAlbum(ImageListerReceiver* receiver,
-                            int albumRootId, const QString& album)
+void ImageLister::listAlbum(ImageListerReceiver* const receiver, int albumRootId, const QString& album)
 {
-    if (m_listOnlyAvailableImages)
+    if (d->listOnlyAvailableImages)
     {
         if (!CollectionManager::instance()->locationForAlbumRootId(albumRootId).isAvailable())
         {
@@ -153,7 +175,7 @@ void ImageLister::listAlbum(ImageListerReceiver* receiver,
 
     QList<QVariant> albumIds;
 
-    if (m_recursive)
+    if (d->recursive)
     {
         QList<int> intAlbumIds = DatabaseAccess().db()->getAlbumAndSubalbumsForPath(albumRootId, album);
 
@@ -190,18 +212,18 @@ void ImageLister::listAlbum(ImageListerReceiver* receiver,
                     "       INNER JOIN ImageInformation ON Images.id=ImageInformation.imageid "
                     " WHERE Images.status=1 AND ";
 
-    if (m_recursive)
+    if (d->recursive)
     {
         // SQLite allows no more than 999 parameters
         const int maxParams = DatabaseAccess().backend()->maximumBoundValues();
         for (int i=0; i<albumIds.size(); i++)
         {
-            QString q = query;
-            QList<QVariant> ids = (albumIds.size() <= maxParams) ? albumIds : albumIds.mid(i, maxParams);
-            i += ids.count();
-            QList<QVariant> v;
+            QString q           = query;
+            QList<QVariant> ids =  (albumIds.size() <= maxParams) ? albumIds : albumIds.mid(i, maxParams);
+            i                   += ids.count();
 
-            DatabaseAccess access;
+            QList<QVariant> v;
+            DatabaseAccess  access;
             q += "Images.album IN (";
             access.db()->addBoundValuePlaceholders(q, ids.size());
             q += ");";
@@ -255,16 +277,16 @@ void ImageLister::listAlbum(ImageListerReceiver* receiver,
     }
 }
 
-void ImageLister::listTag(ImageListerReceiver* receiver, int tagId)
+void ImageLister::listTag(ImageListerReceiver* const receiver, int tagId)
 {
-    QList<QVariant> values;
+    QList<QVariant>         values;
     QMap<QString, QVariant> parameters;
     parameters.insert(":tagPID", tagId);
     parameters.insert(":tagID",  tagId);
 
     DatabaseAccess access;
 
-    if (m_recursive)
+    if (d->recursive)
     {
         access.backend()->execDBAction(access.backend()->getDBAction(QString("listTagRecursive")), parameters, &values);
     }
@@ -308,7 +330,7 @@ void ImageLister::listTag(ImageListerReceiver* receiver, int tagId)
         height                   = (*it).toInt();
         ++it;
 
-        if (m_listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
+        if (d->listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
         {
             continue;
         }
@@ -319,14 +341,12 @@ void ImageLister::listTag(ImageListerReceiver* receiver, int tagId)
     }
 }
 
-void ImageLister::listFaces(ImageListerReceiver* receiver, int personId)
+void ImageLister::listFaces(ImageListerReceiver* const receiver, int personId)
 {
-
     QList<qlonglong> list;
+    QList<QVariant>  values;
+    DatabaseAccess   access;
 
-    QList<QVariant> values;
-
-    DatabaseAccess access;
     access.backend()->execSql(QString("SELECT Images.id "
                                       " FROM Images "
                                       "       INNER JOIN ImageInformation ON Images.id=ImageInformation.imageid "
@@ -358,8 +378,7 @@ void ImageLister::listFaces(ImageListerReceiver* receiver, int personId)
     listFromIdList(receiver, list);
 }
 
-
-void ImageLister::listDateRange(ImageListerReceiver* receiver, const QDate& startDate, const QDate& endDate)
+void ImageLister::listDateRange(ImageListerReceiver* const receiver, const QDate& startDate, const QDate& endDate)
 {
     QList<QVariant> values;
 
@@ -384,8 +403,7 @@ void ImageLister::listDateRange(ImageListerReceiver* receiver, const QDate& star
     }
 
     QSet<int> albumRoots = albumRootsToList();
-
-    int width, height;
+    int       width, height;
 
     for (QList<QVariant>::const_iterator it = values.constBegin(); it != values.constEnd();)
     {
@@ -418,7 +436,7 @@ void ImageLister::listDateRange(ImageListerReceiver* receiver, const QDate& star
         height                   = (*it).toInt();
         ++it;
 
-        if (m_listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
+        if (d->listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
         {
             continue;
         }
@@ -429,8 +447,7 @@ void ImageLister::listDateRange(ImageListerReceiver* receiver, const QDate& star
     }
 }
 
-void ImageLister::listAreaRange(ImageListerReceiver* receiver,
-                                double lat1, double lat2, double lon1, double lon2)
+void ImageLister::listAreaRange(ImageListerReceiver* const receiver, double lat1, double lat2, double lon1, double lon2)
 {
     QList<QVariant> values;
     QList<QVariant> boundValues;
@@ -455,13 +472,13 @@ void ImageLister::listAreaRange(ImageListerReceiver* receiver,
 
 
     kDebug() << "Results:" << values.size() / 14;
-    QSet<int> albumRoots = albumRootsToList();
 
-    double lat, lon;
+    QSet<int> albumRoots = albumRootsToList();
+    double    lat, lon;
 
     for (QList<QVariant>::const_iterator it = values.constBegin(); it != values.constEnd();)
     {
-        ImageListerRecord record(m_allowExtraValues ? ImageListerRecord::ExtraValueFormat : ImageListerRecord::TraditionalFormat);
+        ImageListerRecord record(d->allowExtraValues ? ImageListerRecord::ExtraValueFormat : ImageListerRecord::TraditionalFormat);
 
         record.imageID           = (*it).toLongLong();
         ++it;
@@ -477,7 +494,7 @@ void ImageLister::listAreaRange(ImageListerReceiver* receiver,
         lon                      = (*it).toDouble();
         ++it;
 
-        if (m_listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
+        if (d->listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
         {
             continue;
         }
@@ -486,14 +503,9 @@ void ImageLister::listAreaRange(ImageListerReceiver* receiver,
 
         receiver->receive(record);
     }
-
-
 }
 
-
-void ImageLister::listSearch(ImageListerReceiver* receiver,
-                             const QString& xml,
-                             int limit)
+void ImageLister::listSearch(ImageListerReceiver* const receiver, const QString& xml, int limit)
 {
     if (xml.isEmpty())
     {
@@ -516,13 +528,15 @@ void ImageLister::listSearch(ImageListerReceiver* receiver,
                " FROM Images "
                "       INNER JOIN ImageInformation ON Images.id=ImageInformation.imageid "
                "       LEFT  JOIN ImageMetadata    ON Images.id=ImageMetadata.imageid "
+               "       LEFT  JOIN VideoMetadata    ON Images.id=VideoMetadata.imageid "
                "       LEFT  JOIN ImagePositions   ON Images.id=ImagePositions.imageid "
                "       INNER JOIN Albums           ON Albums.id=Images.album "
                "WHERE Images.status=1 AND ( ";
 
     // query body
-    ImageQueryBuilder builder;
+    ImageQueryBuilder   builder;
     ImageQueryPostHooks hooks;
+
     sqlQuery += builder.buildQuery(xml, &boundValues, &hooks);
 
     if (limit > 0)
@@ -556,9 +570,8 @@ void ImageLister::listSearch(ImageListerReceiver* receiver,
     kDebug() << "Search result:" << values.size();
 
     QSet<int> albumRoots = albumRootsToList();
-
-    int width, height;
-    double lat,lon;
+    int       width, height;
+    double    lat,lon;
 
     for (QList<QVariant>::const_iterator it = values.constBegin(); it != values.constEnd();)
     {
@@ -595,7 +608,7 @@ void ImageLister::listSearch(ImageListerReceiver* receiver,
         lon                      = (*it).toDouble();
         ++it;
 
-        if (m_listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
+        if (d->listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
         {
             continue;
         }
@@ -611,7 +624,7 @@ void ImageLister::listSearch(ImageListerReceiver* receiver,
     }
 }
 
-void ImageLister::listImageTagPropertySearch(ImageListerReceiver* receiver, const QString& xml)
+void ImageLister::listImageTagPropertySearch(ImageListerReceiver* const receiver, const QString& xml)
 {
     if (xml.isEmpty())
     {
@@ -674,7 +687,7 @@ void ImageLister::listImageTagPropertySearch(ImageListerReceiver* receiver, cons
 
     for (QList<QVariant>::const_iterator it = values.constBegin(); it != values.constEnd();)
     {
-        ImageListerRecord record(m_allowExtraValues ? ImageListerRecord::ExtraValueFormat : ImageListerRecord::TraditionalFormat);
+        ImageListerRecord record(d->allowExtraValues ? ImageListerRecord::ExtraValueFormat : ImageListerRecord::TraditionalFormat);
 
         record.imageID           = (*it).toLongLong();
         ++it;
@@ -710,7 +723,7 @@ void ImageLister::listImageTagPropertySearch(ImageListerReceiver* receiver, cons
         record.extraValues      << (*it); // tag id
         ++it;
 
-        if (m_listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
+        if (d->listOnlyAvailableImages && !albumRoots.contains(record.albumRootID))
         {
             continue;
         }
@@ -721,7 +734,7 @@ void ImageLister::listImageTagPropertySearch(ImageListerReceiver* receiver, cons
     }
 }
 
-void ImageLister::listHaarSearch(ImageListerReceiver* receiver, const QString& xml)
+void ImageLister::listHaarSearch(ImageListerReceiver* const receiver, const QString& xml)
 {
     SearchXmlReader reader(xml);
     reader.readToFirstField();
@@ -737,8 +750,8 @@ void ImageLister::listHaarSearch(ImageListerReceiver* receiver, const QString& x
     QStringRef thresholdString  = reader.attributes().value("threshold");
     QStringRef sketchTypeString = reader.attributes().value("sketchtype");
 
-    double threshold            = 0.9;
-    int numberOfResults         = 20;
+    double threshold                 = 0.9;
+    int numberOfResults              = 20;
     HaarIface::SketchType sketchType = HaarIface::ScannedSketch;
 
     if (!numResultsString.isNull())
@@ -767,7 +780,7 @@ void ImageLister::listHaarSearch(ImageListerReceiver* receiver, const QString& x
         QString sig = reader.value();
         HaarIface iface;
 
-        if (m_listOnlyAvailableImages)
+        if (d->listOnlyAvailableImages)
         {
             iface.setAlbumRootsToSearch(albumRootsToList());
         }
@@ -779,7 +792,7 @@ void ImageLister::listHaarSearch(ImageListerReceiver* receiver, const QString& x
         qlonglong id = reader.valueToLongLong();
         HaarIface iface;
 
-        if (m_listOnlyAvailableImages)
+        if (d->listOnlyAvailableImages)
         {
             iface.setAlbumRootsToSearch(albumRootsToList());
         }
@@ -790,11 +803,11 @@ void ImageLister::listHaarSearch(ImageListerReceiver* receiver, const QString& x
     listFromIdList(receiver, list);
 }
 
-void ImageLister::listFromIdList(ImageListerReceiver* receiver, QList<qlonglong> imageIds)
+void ImageLister::listFromIdList(ImageListerReceiver* const receiver, const QList<qlonglong>& imageIds)
 {
     QList<QVariant> values;
-    QString errMsg;
-    bool executionSuccess = true;
+    QString         errMsg;
+    bool            executionSuccess = true;
 
     {
         /*
@@ -895,23 +908,25 @@ void ImageLister::listFromIdList(ImageListerReceiver* receiver, QList<qlonglong>
     }
 }
 
-QSet<int> ImageLister::albumRootsToList()
+QSet<int> ImageLister::albumRootsToList() const
 {
-    if (!m_listOnlyAvailableImages)
+    if (!d->listOnlyAvailableImages)
     {
         return QSet<int>();    // invalid value, all album roots shall be listed
     }
 
     QList<CollectionLocation> locations = CollectionManager::instance()->allAvailableLocations();
-    QSet<int> ids;
+    QSet<int>                 ids;
+
     foreach(const CollectionLocation& location, locations)
     {
         ids << location.id();
     }
+
     return ids;
 }
 
-QString ImageLister::tagSearchXml(const DatabaseUrl& url, const QString& type, bool includeChildTags)
+QString ImageLister::tagSearchXml(const DatabaseUrl& url, const QString& type, bool includeChildTags) const
 {
     int tagId = url.tagId();
 
