@@ -6,7 +6,7 @@
  * Date        : 2007-03-22
  * Description : Building complex database SQL queries from search descriptions
  *
- * Copyright (C) 2005      by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -223,6 +223,7 @@ void ImageQueryBuilder::buildGroup(QString& sql, SearchXmlCachingReader& reader,
 }
 
 // ---------------------------------------------------------------------------------------
+
 class FieldQueryBuilder
 {
 public:
@@ -541,13 +542,13 @@ public:
                 }
             }
 
-            bool firstCondition = true;
-            sql += " (";
+            bool firstCondition =  true;
+            sql                 += " (";
 
             if (!simpleValues.isEmpty())
             {
-                firstCondition = false;
-                sql += name + " IN (";
+                firstCondition =  false;
+                sql            += name + " IN (";
                 AlbumDB::addBoundValuePlaceholders(sql, simpleValues.size());
 
                 foreach(const QString& value, simpleValues)
@@ -961,7 +962,6 @@ bool ImageQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     {
         fieldQuery.addIntField("Images.fileSize");
     }
-
     else if (name == "rating")
     {
         fieldQuery.addIntField("ImageInformation.rating");
@@ -1026,6 +1026,30 @@ bool ImageQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
         fieldQuery.addIntField("ImageInformation.width");
         sql += " ) ) ";
     }
+    else if (name == "aspectratioimg")
+    {
+        QString query;
+        QString readerString = (reader.valueToStringOrStringList()).at(0);
+        if(readerString.contains(QRegExp("^\\d+:\\d+$")))
+        {
+            QStringList ratioNum = readerString.split(":", QString::SkipEmptyParts);
+            int num = ratioNum.at(0).toInt();
+            int denominator = ratioNum.at(1).toInt();
+            query = "abs((ImageInformation.width/CAST(ImageInformation.height as REAL)) - ?)  < 0.1";
+            sql += " (" + query + ") ";
+            *boundValues << (double)num/denominator;
+        }
+        else if(readerString.contains(QRegExp("^\\d+(.\\d+)?$")))
+        {
+            query = "abs((ImageInformation.width/CAST(ImageInformation.height as REAL)) - ?)  < 0.1";
+            sql += " (" + query + ") ";
+            *boundValues << readerString.toDouble();
+        }
+    }
+    else if (name == "pixelsize")
+    {
+        fieldQuery.addIntField("(ImageInformation.width * ImageInformation.height)");
+    }
     else if (name == "pixels")
     {
         fieldQuery.addIntField("(ImageInformation.width * ImageInformation.height)");
@@ -1042,7 +1066,198 @@ bool ImageQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     {
         fieldQuery.addIntField("ImageInformation.colorModel");
     }
+    else if (name == "videoaspectratio")
+    {
+        if (relation == SearchXml::OneOf)
+        {
+            QStringList values = reader.valueToStringList();
 
+            if (values.isEmpty())
+            {
+                kDebug() << "List for OneOf is empty";
+            }
+
+            QList<double> ratioValues;
+            foreach(const QString& value, values)
+            {
+                 *boundValues << value;
+
+                 if (value.contains(":"))
+                 {
+                     QStringList ratioNum = value.split(":", QString::SkipEmptyParts);
+                     int num = ratioNum.at(0).toInt();
+                     int denominator = ratioNum.at(1).toInt();
+                     ratioValues << (double)num/denominator;
+                 }
+            }
+
+            sql += "(VideoMetadata.aspectRatio IN (";
+            AlbumDB::addBoundValuePlaceholders(sql, values.size());
+            sql += ") ";
+            QString query = "abs((CAST(VideoMetadata.aspectRatio as REAL) - ?)  < 0.1) ";
+
+            foreach(double value, ratioValues)
+            {
+                *boundValues << value;
+                sql +=  "OR " + query;
+            }
+
+            sql += ") ";
+        }
+        else
+        {
+            QString value = reader.value();
+            *boundValues << value;
+
+            if (value.contains(":"))
+            {
+                QStringList ratioNum = value.split(":", QString::SkipEmptyParts);
+                int num = ratioNum.at(0).toInt();
+                int denominator = ratioNum.at(1).toInt();
+                *boundValues << (double)num/denominator;
+            }
+
+            sql += "(VideoMetadata.aspectRatio=? OR abs((CAST(VideoMetadata.aspectRatio as REAL) - ?)  < 0.1 )) ";
+        }
+    }
+    else if (name == "videoaudiobitrate")
+    {
+        //fieldQuery.addIntField("VideoMetadata.audioBitRate");
+        QList<int> values = reader.valueToIntList();
+
+        if (values.size() != 2)
+        {
+            kWarning() << "Relation Interval requires a list of two values";
+        }
+
+        sql += " ( CAST(VideoMetadata.audioBitRate AS INTEGER)";
+        ImageQueryBuilder::addSqlRelation(sql,
+                                          relation == SearchXml::Interval ? SearchXml::GreaterThanOrEqual : SearchXml::GreaterThan);
+        sql += " ? AND CAST(VideoMetadata.audioBitRate AS INTEGER)";
+        ImageQueryBuilder::addSqlRelation(sql,
+                                          relation == SearchXml::Interval ? SearchXml::LessThanOrEqual : SearchXml::LessThan);
+        sql += " ?) ";
+
+        *boundValues << values.first() << values.last();
+    }
+    else if (name == "videoaudiochanneltype")
+    {
+        if (relation == SearchXml::OneOf)
+        {
+            QStringList values = reader.valueToStringList();
+
+            if (values.isEmpty())
+            {
+                kDebug() << "List for OneOf is empty";
+            }
+
+            foreach(const QString& value, values)
+            {
+                 *boundValues << value;
+
+                 if (value=="1")
+                 {
+                     *boundValues << "Mono";
+                 }
+                 else if (value == "2")
+                 {
+                     *boundValues << "Stereo";
+                 }
+            }
+
+            sql += "(VideoMetadata.audioChannelType IN (";
+            AlbumDB::addBoundValuePlaceholders(sql, boundValues->size());
+            sql += ")) ";
+        }
+        else
+        {
+            QString value = reader.value();
+            *boundValues << value;
+
+            if (value=="1")
+            {
+                *boundValues << "Mono";
+            }
+            else if (value == "2")
+            {
+                *boundValues << "Stereo";
+            }
+
+            sql += "(VideoMetadata.audioChannelType IN (";
+            AlbumDB::addBoundValuePlaceholders(sql, boundValues->size());
+            sql += ")) ";
+        }
+    }
+    else if (name == "videoaudiocompressor")
+    {
+        fieldQuery.addChoiceStringField("VideoMetadata.audioCompressor");
+    }
+    else if (name == "videoduration")
+    {
+        QList<int> values = reader.valueToIntList();
+
+        if (values.size() != 2)
+        {
+            kWarning() << "Relation Interval requires a list of two values";
+        }
+
+        sql += " ( CAST(VideoMetadata.duration AS INTEGER)";
+        ImageQueryBuilder::addSqlRelation(sql,
+                                          relation == SearchXml::Interval ? SearchXml::GreaterThanOrEqual : SearchXml::GreaterThan);
+        sql += " ? AND CAST(VideoMetadata.duration AS INTEGER)";
+        ImageQueryBuilder::addSqlRelation(sql,
+                                          relation == SearchXml::Interval ? SearchXml::LessThanOrEqual : SearchXml::LessThan);
+        sql += " ?) ";
+
+        *boundValues << values.first()*1000 << values.last()*1000;
+    }
+    else if (name == "videoframerate")
+    {
+        //fieldQuery.addChoiceStringField("VideoMetadata.frameRate");
+        QList<double> values = reader.valueToDoubleList();
+
+        if (values.size() != 2)
+        {
+            kWarning() << "Relation Interval requires a list of two values";
+        }
+
+        sql += " ( CAST(VideoMetadata.frameRate AS REAL)";
+        ImageQueryBuilder::addSqlRelation(sql,
+                                          relation == SearchXml::Interval ? SearchXml::GreaterThanOrEqual : SearchXml::GreaterThan);
+        sql += " ? AND CAST(VideoMetadata.frameRate AS REAL)";
+        ImageQueryBuilder::addSqlRelation(sql,
+                                          relation == SearchXml::Interval ? SearchXml::LessThanOrEqual : SearchXml::LessThan);
+        sql += " ?) ";
+
+        *boundValues << values.first() << values.last();
+    }
+    else if (name == "videocodec")
+    {
+        if (relation == SearchXml::OneOf)
+        {
+            QStringList values = reader.valueToStringList();
+
+            if (values.isEmpty())
+            {
+                kDebug() << "List for OneOf is empty";
+            }
+
+            foreach(const QString& value, values)
+            {
+                sql += "( Upper(VideoMetadata.videoCodec) LIKE '%" + value.toUpper() + "%' ";
+                if (value!=values.last())
+                {
+                    sql += "OR ";
+                }
+            }
+            sql += ") ";
+        }
+        else
+        {
+            QString value = reader.value();
+            sql += "(Upper(VideoMetadata.videoCodec) LIKE '%" + value.toUpper() + "%') ";
+        }
+    }
     else if (name == "make")
     {
         fieldQuery.addStringField("ImageMetadata.make");
@@ -1103,7 +1318,6 @@ bool ImageQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     {
         fieldQuery.addChoiceIntField("ImageMetadata.subjectDistanceCategory");
     }
-
     else if (name == "position")
     {
         fieldQuery.addPosition();
@@ -1140,7 +1354,6 @@ bool ImageQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     {
         sql += " (ImagePositions.latitudeNumber IS NULL AND ImagePositions.longitudeNumber IS NULL) ";
     }
-
     else if (name == "comment")
     {
         sql += " (Images.id IN "
@@ -1587,7 +1800,7 @@ public:
 
 QString ImageQueryBuilder::buildQueryFromUrl(const KUrl& url, QList<QVariant>* boundValues) const
 {
-    int  count = url.queryItem("count").toInt();
+    int count = url.queryItem("count").toInt();
 
     if (count <= 0)
     {
@@ -1965,10 +2178,9 @@ QString ImageQueryBuilder::possibleDate(const QString& str, bool& exact) const
         return date.toString(Qt::ISODate);
     }
 
-    exact = false;
-
+    exact    = false;
     bool ok;
-    int num = str.toInt(&ok);
+    int  num = str.toInt(&ok);
 
     if (ok)
     {
