@@ -67,7 +67,7 @@ class TagsCache::TagsCachePriv
 {
 public:
 
-    TagsCachePriv(TagsCache* q) :
+    explicit TagsCachePriv(TagsCache* q) :
         initialized(false),
         needUpdateInfos(true),
         needUpdateHash(true),
@@ -236,7 +236,7 @@ class ChangingDB
 {
 public:
 
-    ChangingDB(TagsCache::TagsCachePriv* d)
+    explicit ChangingDB(TagsCache::TagsCachePriv* d)
         : d(d)
     {
         d->changingDB = true;
@@ -411,7 +411,7 @@ QList<int> TagsCache::tagsForName(const QString& tagName, HiddenTagsPolicy hidde
         QList<int> ids;
         QMultiHash<QString, int>::const_iterator it;
 
-        for (it = d->nameHash.find(tagName); it != d->nameHash.end() && it.key() == tagName; ++it)
+        for (it = d->nameHash.constFind(tagName); it != d->nameHash.constEnd() && it.key() == tagName; ++it)
         {
             if (!d->internalTags.contains(it.value()))
             {
@@ -585,7 +585,6 @@ int TagsCache::createTag(const QString& tagPathToCreate)
 
     d->checkNameHash();
 
-    int  parentTagID      = 0;
     int  tagID            = 0;
     bool parentTagExisted = true;
 
@@ -593,6 +592,7 @@ int TagsCache::createTag(const QString& tagPathToCreate)
     int parentTagIDForCreation = 0;
 
     {
+        int  parentTagID = 0;
         QReadLocker locker(&d->lock);
 
         // Traverse hierarchy from top to bottom
@@ -804,7 +804,7 @@ QList<int> TagsCache::tagsWithProperty(const QString& property, const QString& v
     QReadLocker locker(&d->lock);
     QList<int>  ids;
 
-    for (TagPropertiesConstIterator it = d->tagProperties.begin(); it != d->tagProperties.end(); )
+    for (TagPropertiesConstIterator it = d->tagProperties.constBegin(); it != d->tagProperties.constEnd(); )
     {
         // sort out invalid entries, see bug #277169
         if (it->tagId <= 0)
