@@ -6,7 +6,7 @@
  * Date        : 2008-07-11
  * Description : shared libraries list dialog
  *
- * Copyright (C) 2008-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,7 +45,7 @@ class DIGIKAM_EXPORT LibsInfoDlg : public InfoDlg
 
 public:
 
-    LibsInfoDlg(QWidget* parent);
+    explicit LibsInfoDlg(QWidget* const parent);
     ~LibsInfoDlg();
 };
 
