@@ -6,7 +6,7 @@
  * Date        : 2005-24-01
  * Description : normalize image filter.
  *
- * Copyright (C) 2005-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -39,13 +39,13 @@
 namespace Digikam
 {
 
-NormalizeFilter::NormalizeFilter(QObject* parent)
+NormalizeFilter::NormalizeFilter(QObject* const parent)
     : DImgThreadedFilter(parent)
 {
     initFilter();
 }
 
-NormalizeFilter::NormalizeFilter(DImg* orgImage, const DImg* refImage, QObject* parent)
+NormalizeFilter::NormalizeFilter(DImg* const orgImage, const DImg* const refImage, QObject* const parent)
     : DImgThreadedFilter(orgImage, parent, "NormalizeFilter"),
       m_refImage(*refImage)
 {
@@ -72,7 +72,8 @@ void NormalizeFilter::filterImage()
     image so that the darkest point becomes black, and the
     brightest point becomes as bright as possible without
     altering its hue. This is often a magic fix for
-    images that are dim or washed out.*/
+    images that are dim or washed out.
+*/
 void NormalizeFilter::normalizeImage()
 {
     if (m_orgImage.sixteenBit() != m_refImage.sixteenBit())
@@ -270,10 +271,9 @@ FilterAction NormalizeFilter::filterAction()
     return DefaultFilterAction<NormalizeFilter>();
 }
 
-void NormalizeFilter::readParameters(const Digikam::FilterAction& /*action*/)
+void NormalizeFilter::readParameters(const FilterAction& /*action*/)
 {
     return;
 }
 
-
 }  // namespace Digikam
