@@ -3,8 +3,8 @@
  * Date        : 2008-02-10
  * Description : a tool to fix automatically camera lens aberrations
  *
- * Copyright (C) 2008 by Adrian Schroeter <adrian at suse dot de>
- * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008      by Adrian Schroeter <adrian at suse dot de>
+ * Copyright (C) 2008-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -47,11 +47,11 @@ using namespace KDcrawIface;
 namespace Digikam
 {
 
-class LensFunCameraSelector::LensFunCameraSelectorPriv
+class LensFunCameraSelector::Private
 {
 public:
 
-    LensFunCameraSelectorPriv()
+    Private()
         : configUseMetadata("UseMetadata"),
           redStyle("QLabel {color: red;}"),
           orangeStyle("QLabel {color: orange;}"),
@@ -60,6 +60,7 @@ public:
         metadataUsage        = 0;
         make                 = 0;
         model                = 0;
+        lens                 = 0;
         focal                = 0;
         aperture             = 0;
         distance             = 0;
@@ -110,8 +111,8 @@ public:
     LensFunIface*       iface;
 };
 
-LensFunCameraSelector::LensFunCameraSelector(QWidget* parent)
-    : QWidget(parent), d(new LensFunCameraSelectorPriv)
+LensFunCameraSelector::LensFunCameraSelector(QWidget* const parent)
+    : QWidget(parent), d(new Private)
 {
     d->iface            = new LensFunIface();
 
@@ -348,14 +349,17 @@ void LensFunCameraSelector::slotUseMetadata(bool b)
                     d->metadataResult->setText(i18n("(no metadata available)"));
                     d->metadataResult->setStyleSheet(d->redStyle);
                     break;
+
                 case LensFunIface::MetadataNoMatch:
                     d->metadataResult->setText(i18n("(no match found)"));
                     d->metadataResult->setStyleSheet(d->redStyle);
                     break;
+
                 case LensFunIface::MetadataPartialMatch:
                     d->metadataResult->setText(i18n("(partial match found)"));
                     d->metadataResult->setStyleSheet(d->orangeStyle);
                     break;
+
                 default:
                     d->metadataResult->setText(i18n("(exact match found)"));
                     d->metadataResult->setStyleSheet(d->greenStyle);
@@ -571,33 +575,33 @@ void LensFunCameraSelector::populateDeviceCombos()
 
     bool firstRun = false;
 
-    if ( d->make->combo()->count() == 0 )
+    if (d->make->combo()->count() == 0)
     {
         firstRun = true;
     }
 
-    while ( *it )
+    while (*it)
     {
-        if ( firstRun )
+        if (firstRun)
         {
             // Maker DB does not change, so we fill it only once.
-            if ( (*it)->Maker )
+            if ((*it)->Maker)
             {
-                QString t( (*it)->Maker );
+                QString t((*it)->Maker);
 
-                if ( d->make->combo()->findText( t, Qt::MatchExactly ) < 0 )
+                if (d->make->combo()->findText(t, Qt::MatchExactly) < 0)
                 {
-                    d->make->addItem( t );
+                    d->make->addItem(t);
                 }
             }
         }
 
         // Fill models for current selected maker
-        if ( (*it)->Model && (*it)->Maker == d->make->combo()->currentText() )
+        if ((*it)->Model && (*it)->Maker == d->make->combo()->currentText())
         {
             LensFunIface::DevicePtr dev = *it;
             QVariant b                  = qVariantFromValue(dev);
-            d->model->combo()->addItem( dev->Model, b );
+            d->model->combo()->addItem(dev->Model, b);
         }
 
         ++it;
@@ -615,7 +619,7 @@ void LensFunCameraSelector::populateLensCombo()
     d->lens->blockSignals(true);
     d->lens->combo()->clear();
 
-    QVariant v = d->model->combo()->itemData( d->model->currentIndex() );
+    QVariant v = d->model->combo()->itemData(d->model->currentIndex());
 
     if (!v.isValid() || v.isNull())
     {
@@ -633,7 +637,7 @@ void LensFunCameraSelector::populateLensCombo()
         return;
     }
 
-    kDebug() << "dev: " << dev->Maker << " :: " << dev->Model;
+    kDebug() << "dev: " << dev->Maker << " :: " << dev->Model << " :: " << dev->CropFactor;
 
     d->lens->blockSignals(true);
     const lfLens** lenses     = d->iface->lensFunDataBase()->FindLenses(dev, 0, 0);
@@ -665,7 +669,7 @@ void LensFunCameraSelector::slotMakeSelected()
 
 void LensFunCameraSelector::slotModelSelected()
 {
-    QVariant v = d->model->combo()->itemData( d->model->currentIndex() );
+    QVariant v = d->model->combo()->itemData(d->model->currentIndex());
     d->iface->setUsedCamera(d->metadataUsage->isChecked() && d->passiveMetadataUsage ? 0 :
                             v.value<LensFunIface::DevicePtr>());
     emit signalLensSettingsChanged();
@@ -673,7 +677,7 @@ void LensFunCameraSelector::slotModelSelected()
 
 void LensFunCameraSelector::slotLensSelected()
 {
-    QVariant v = d->lens->combo()->itemData( d->lens->currentIndex() );
+    QVariant v = d->lens->combo()->itemData(d->lens->currentIndex());
     d->iface->setUsedLens(d->metadataUsage->isChecked() && d->passiveMetadataUsage ? 0 :
                           v.value<LensFunIface::LensPtr>());
 
@@ -682,12 +686,9 @@ void LensFunCameraSelector::slotLensSelected()
     if (d->iface->usedLens() &&
         settings.cropFactor <= 0.0) // this should not happen
     {
+        kDebug() << "No crop factor is set for camera, using lens calibration data: " << d->iface->usedLens()->CropFactor;
         settings.cropFactor = d->iface->usedLens()->CropFactor;
     }
-    else
-    {
-        settings.cropFactor = -1.0;
-    }
 
     d->iface->setSettings(settings);
     emit signalLensSettingsChanged();
