@@ -11,8 +11,8 @@
  *               See this wiki page for details:
  *               http://community.kde.org/Digikam/SoK2012/AutoNR
  *
- * Copyright (C) 2012 by Sayantan Datta <sayantan dot knz at gmail dot com>
- * Copyright (C) 2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2013 by Sayantan Datta <sayantan dot knz at gmail dot com>
+ * Copyright (C) 2012-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -163,7 +163,7 @@ void NREstimate::startAnalyse()
                   cvTermCriteria(CV_TERMCRIT_EPS + CV_TERMCRIT_ITER, 10, 1.0), 3, 0, 0, centers, 0);
     }
 
-    kDebug() << "cvKmeans2 succesfully run";
+    kDebug() << "cvKmeans2 successfully run";
     postProgress(15);
 
     //-- Divide into cluster->columns, sample->rows, in matrix standard deviation ---------------------------
@@ -520,7 +520,6 @@ void NREstimate::startAnalyse()
     }
 
     postProgress(100);
-
 }
 
 }  // namespace Digikam
