@@ -6,7 +6,7 @@
  * Date        : 2007-16-01
  * Description : white balance color correction.
  *
- * Copyright (C) 2007-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008      by Guillaume Castagnino <casta at xwing dot info>
  * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -58,6 +58,13 @@ public:
         mg      = 1.0;
         mb      = 1.0;
         BP      = 0;
+        WP      = 0;
+        rgbMax  = 0;
+
+        for (int i = 0; i < 65536; ++i)
+        {
+            curve[i] = 0.0;
+        }
     }
 
     bool  clipSat;
@@ -82,7 +89,6 @@ WBFilter::WBFilter(QObject* const parent)
     initFilter();
 }
 
-
 WBFilter::WBFilter(DImg* const orgImage, QObject* const parent, const WBContainer& settings)
     : DImgThreadedFilter(orgImage, parent, "WBFilter"),
       d(new Private)
@@ -239,7 +245,7 @@ void WBFilter::setRGBmult(double& temperature, double& green, float& mr, float&
      */
     const double XYZ_to_RGB[3][3] =
     {
-        { 3.24071,  -0.969258,  0.0556352 },
+        { 3.24071,  -0.969258,   0.0556352 },
         { -1.53726,  1.87599,    -0.203996 },
         { -0.498571, 0.0415557,  1.05707   }
     };
@@ -530,7 +536,7 @@ FilterAction WBFilter::filterAction()
     return action;
 }
 
-void WBFilter::readParameters(const Digikam::FilterAction& action)
+void WBFilter::readParameters(const FilterAction& action)
 {
     m_settings = WBContainer::fromFilterAction(action);
 }
