@@ -6,7 +6,7 @@
  * Date        : 2010-02-26
  * Description : White Balance settings view.
  *
- * Copyright (C) 2010-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,7 +46,7 @@ class DIGIKAM_EXPORT WBSettings : public QWidget
 
 public:
 
-    WBSettings(QWidget* parent);
+    explicit WBSettings(QWidget* const parent);
     ~WBSettings();
 
     WBContainer defaultSettings() const;
@@ -79,8 +79,8 @@ private Q_SLOTS:
 
 private:
 
-    class WBSettingsPriv;
-    WBSettingsPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace Digikam
