@@ -476,6 +476,12 @@ int DMetadata::getImageColorLabel() const
     {
         QString value = getXmpTagString("Xmp.digiKam.ColorLabel", false);
 
+        if (value.isEmpty())
+        {
+            // Nikon NX use this XMP tags to store Color Labels
+            value = getXmpTagString("Xmp.photoshop.Urgency", false);
+        }
+
         if (!value.isEmpty())
         {
             bool ok      = false;
@@ -771,6 +777,12 @@ bool DMetadata::setImageColorLabel(int colorId) const
         {
             return false;
         }
+
+        // Nikon NX use this XMP tags to store Color Labels
+        if (!setXmpTagString("Xmp.photoshop.Urgency", QString::number(colorId)))
+        {
+            return false;
+        }
     }
 
     return true;
@@ -1347,9 +1359,7 @@ bool DMetadata::getImageFacesMap(QMap<QString,QVariant>& faces) const
 
 bool DMetadata::setImageFacesMap(QMap< QString, QVariant >& facesPath, bool write) const
 {
-    qDebug() << "Setting Faces Map";
 #if KEXIV2_VERSION >= 0x020301
-    qDebug() << "Setting Faces Map 2";
     QString qxmpTagName("Xmp.mwg-rs.Regions/mwg-rs:RegionList");
     QString nameTagKey = qxmpTagName + QString("[%1]/mwg-rs:Name");
     QString typeTagKey = qxmpTagName + QString("[%1]/mwg-rs:Type");
@@ -1419,6 +1429,8 @@ bool DMetadata::setImageFacesMap(QMap< QString, QVariant >& facesPath, bool writ
 
     return ok;
 #else
+    Q_UNUSED(facesPath);
+    Q_UNUSED(write);
     return false;
 #endif
 }
@@ -3037,7 +3049,7 @@ QStringList DMetadata::getXmpKeywords() const
 
 bool DMetadata::setXmpKeywords(const QStringList& newKeywords, bool setProgramName) const
 {
-    return addToXmpTagStringBag("Xmp.dc.subject", newKeywords, setProgramName);
+    return setXmpTagStringBag("Xmp.dc.subject", newKeywords, setProgramName);
 }
 
 bool DMetadata::removeXmpKeywords(const QStringList& keywordsToRemove, bool setProgramName)
