@@ -6,7 +6,7 @@
  * Date        : 2010-08-20
  * Description : Metadata Settings Container.
  *
- * Copyright (C) 2010-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -53,7 +53,9 @@ class DIGIKAM_EXPORT MetadataSettingsContainer
 public:
 
     MetadataSettingsContainer();
-    ~MetadataSettingsContainer() {};
+    ~MetadataSettingsContainer()
+    {
+    };
 
     /**
      * Describes the allowed and desired operation when rotating a picture.
@@ -96,6 +98,7 @@ public:
 
     bool                        saveTemplate;
     bool                        saveTags;
+    bool                        saveFaceTags;
 
     bool                        writeRawFiles;
     bool                        updateFileTimeStamp;
