@@ -7,7 +7,7 @@
  * Description : simple image properties side bar (without support
  *               of digiKam database).
  *
- * Copyright (C) 2004-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -40,6 +40,9 @@
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <kdebug.h>
+#include <kglobalsettings.h>
+#include <kaboutdata.h>
+#include <kcomponentdata.h>
 
 // LibKDcraw includes
 
@@ -59,10 +62,10 @@
 namespace Digikam
 {
 
-ImagePropertiesSideBar::ImagePropertiesSideBar(QWidget* parent,
-        SidebarSplitter* splitter,
-        KMultiTabBarPosition side,
-        bool mimimizedDefault)
+ImagePropertiesSideBar::ImagePropertiesSideBar(QWidget* const parent,
+                                               SidebarSplitter* const splitter,
+                                               KMultiTabBarPosition side,
+                                               bool mimimizedDefault)
     : Sidebar(parent, splitter, side, mimimizedDefault)
 {
     m_image              = 0;
@@ -78,10 +81,14 @@ ImagePropertiesSideBar::ImagePropertiesSideBar(QWidget* parent,
     m_colorTab           = new ImagePropertiesColorsTab(parent);
     m_gpsTab             = new ImagePropertiesGPSTab(parent);
 
-    appendTab(m_propertiesTab, SmallIcon("document-properties"), i18n("Properties"));
-    appendTab(m_metadataTab, SmallIcon("exifinfo"), i18n("Metadata"));
-    appendTab(m_colorTab, SmallIcon("format-fill-color"), i18n("Colors"));
-    appendTab(m_gpsTab, SmallIcon("applications-internet"), i18n("Geolocation"));
+    // NOTE: Special case with Showfoto which willonly be able to load image, not video.
+    if (KGlobal::mainComponent().aboutData()->appName() != QString("digikam"))
+        m_propertiesTab->setVideoInfoDisable(true);
+
+    appendTab(m_propertiesTab, SmallIcon("document-properties"),   i18n("Properties"));
+    appendTab(m_metadataTab,   SmallIcon("exifinfo"),              i18n("Metadata"));
+    appendTab(m_colorTab,      SmallIcon("format-fill-color"),     i18n("Colors"));
+    appendTab(m_gpsTab,        SmallIcon("applications-internet"), i18n("Geolocation"));
 
     connect(this, SIGNAL(signalChangedTab(QWidget*)),
             this, SLOT(slotChangedTab(QWidget*)));
@@ -91,7 +98,7 @@ ImagePropertiesSideBar::~ImagePropertiesSideBar()
 {
 }
 
-void ImagePropertiesSideBar::itemChanged(const KUrl& url, const QRect& rect, DImg* img)
+void ImagePropertiesSideBar::itemChanged(const KUrl& url, const QRect& rect, DImg* const img)
 {
     if (!url.isValid())
     {
@@ -144,7 +151,7 @@ void ImagePropertiesSideBar::slotChangedTab(QWidget* tab)
 {
     if (!m_currentURL.isValid())
     {
-        m_gpsTab->setActive(tab==m_gpsTab);
+        m_gpsTab->setActive(tab == m_gpsTab);
 
         return;
     }
@@ -235,7 +242,7 @@ void ImagePropertiesSideBar::setImagePropertiesInformation(const KUrl& url)
     str = (!dims.isValid()) ? i18n("Unknown") : i18n("%1x%2 (%3Mpx)",
             dims.width(), dims.height(), mpixels);
     m_propertiesTab->setImageDimensions(str);
-    m_propertiesTab->setImageBitDepth(bitDepth.isEmpty() ? unavailable : i18n("%1 bpp", bitDepth));
+    m_propertiesTab->setImageBitDepth(bitDepth.isEmpty()   ? unavailable : i18n("%1 bpp", bitDepth));
     m_propertiesTab->setImageColorMode(colorMode.isEmpty() ? unavailable : colorMode);
 
     // -- Photograph information ------------------------------------------
@@ -244,7 +251,7 @@ void ImagePropertiesSideBar::setImagePropertiesInformation(const KUrl& url)
 
     m_propertiesTab->setPhotoInfoDisable(photoInfo.isEmpty());
 
-    m_propertiesTab->setPhotoMake(photoInfo.make.isEmpty() ? unavailable : photoInfo.make);
+    m_propertiesTab->setPhotoMake(photoInfo.make.isEmpty()   ? unavailable : photoInfo.make);
     m_propertiesTab->setPhotoModel(photoInfo.model.isEmpty() ? unavailable : photoInfo.model);
 
     if (photoInfo.dateTime.isValid())
@@ -257,7 +264,7 @@ void ImagePropertiesSideBar::setImagePropertiesInformation(const KUrl& url)
         m_propertiesTab->setPhotoDateTime(unavailable);
     }
 
-    m_propertiesTab->setPhotoLens(photoInfo.lens.isEmpty() ? unavailable : photoInfo.lens);
+    m_propertiesTab->setPhotoLens(photoInfo.lens.isEmpty()         ? unavailable : photoInfo.lens);
     m_propertiesTab->setPhotoAperture(photoInfo.aperture.isEmpty() ? unavailable : photoInfo.aperture);
 
     if (photoInfo.focalLength35mm.isEmpty())
@@ -271,7 +278,7 @@ void ImagePropertiesSideBar::setImagePropertiesInformation(const KUrl& url)
     }
 
     m_propertiesTab->setPhotoExposureTime(photoInfo.exposureTime.isEmpty() ? unavailable : photoInfo.exposureTime);
-    m_propertiesTab->setPhotoSensitivity(photoInfo.sensitivity.isEmpty() ? unavailable : i18n("%1 ISO", photoInfo.sensitivity));
+    m_propertiesTab->setPhotoSensitivity(photoInfo.sensitivity.isEmpty()   ? unavailable : i18n("%1 ISO", photoInfo.sensitivity));
 
     if (photoInfo.exposureMode.isEmpty() && photoInfo.exposureProgram.isEmpty())
     {
@@ -291,17 +298,33 @@ void ImagePropertiesSideBar::setImagePropertiesInformation(const KUrl& url)
         m_propertiesTab->setPhotoExposureMode(str);
     }
 
-    m_propertiesTab->setPhotoFlash(photoInfo.flash.isEmpty() ? unavailable : photoInfo.flash);
+    m_propertiesTab->setPhotoFlash(photoInfo.flash.isEmpty()               ? unavailable : photoInfo.flash);
     m_propertiesTab->setPhotoWhiteBalance(photoInfo.whiteBalance.isEmpty() ? unavailable : photoInfo.whiteBalance);
 
+    // -- Video information ------------------------------------------
+
+    VideoInfoContainer videoInfo = metaData.getVideoInformation();
+
+    m_propertiesTab->setVideoInfoDisable(videoInfo.isEmpty());
+
+    m_propertiesTab->setVideoAspectRatio(videoInfo.aspectRatio.isEmpty()           ? unavailable : videoInfo.aspectRatio);
+    m_propertiesTab->setVideoDuration(videoInfo.duration.isEmpty()                 ? unavailable : videoInfo.duration);
+    m_propertiesTab->setVideoFrameRate(videoInfo.frameRate.isEmpty()               ? unavailable : videoInfo.frameRate);
+    m_propertiesTab->setVideoVideoCodec(videoInfo.videoCodec.isEmpty()             ? unavailable : videoInfo.videoCodec);
+    m_propertiesTab->setVideoAudioBitRate(videoInfo.audioBitRate.isEmpty()         ? unavailable : videoInfo.audioBitRate);
+    m_propertiesTab->setVideoAudioChannelType(videoInfo.audioChannelType.isEmpty() ? unavailable : videoInfo.audioChannelType);
+    m_propertiesTab->setVideoAudioCompressor(videoInfo.audioCompressor.isEmpty()   ? unavailable : videoInfo.audioCompressor);
+
     // -- Caption, ratings, tag information ---------------------
 
     CaptionsMap captions = metaData.getImageComments();
     QString caption;
+
     if (captions.contains("x-default"))
         caption = captions.value("x-default").caption;
     else if (!captions.isEmpty())
         caption = captions.begin().value().caption;
+
     m_propertiesTab->setCaption(caption);
 
     m_propertiesTab->setRating(metaData.getImageRating());
@@ -327,10 +350,10 @@ void ImagePropertiesSideBar::doLoadState()
     m_propertiesTab->readSettings();
 #endif
 
-    const KConfigGroup groupGPSTab = KConfigGroup(&group, entryName("GPS Properties Tab"));
+    const KConfigGroup groupGPSTab      = KConfigGroup(&group, entryName("GPS Properties Tab"));
     m_gpsTab->readSettings(groupGPSTab);
 
-    const KConfigGroup groupColorTab = KConfigGroup(&group, entryName("Color Properties Tab"));
+    const KConfigGroup groupColorTab    = KConfigGroup(&group, entryName("Color Properties Tab"));
     m_colorTab->readSettings(groupColorTab);
 
     const KConfigGroup groupMetadataTab = KConfigGroup(&group, entryName("Metadata Properties Tab"));
@@ -349,10 +372,10 @@ void ImagePropertiesSideBar::doSaveState()
     m_propertiesTab->writeSettings();
 #endif
 
-    KConfigGroup groupGPSTab = KConfigGroup(&group, entryName("GPS Properties Tab"));
+    KConfigGroup groupGPSTab      = KConfigGroup(&group, entryName("GPS Properties Tab"));
     m_gpsTab->writeSettings(groupGPSTab);
 
-    KConfigGroup groupColorTab = KConfigGroup(&group, entryName("Color Properties Tab"));
+    KConfigGroup groupColorTab    = KConfigGroup(&group, entryName("Color Properties Tab"));
     m_colorTab->writeSettings(groupColorTab);
 
     KConfigGroup groupMetadataTab = KConfigGroup(&group, entryName("Metadata Properties Tab"));
