@@ -7,9 +7,9 @@
  * Description : Filter values for use with ImageFilterModel
  *
  * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C)      2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C)      2010 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2011 by Michael G. Hansen <mike at mghansen dot de>
+ * Copyright (C)      2011 by Michael G. Hansen <mike at mghansen dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,6 +24,8 @@
  *
  * ============================================================ */
 
+#include <math.h>
+
 #include "imagefiltersettings.h"
 
 // Qt includes
@@ -297,7 +299,7 @@ bool containsNoneOfExcept(const ContainerA& list, const ContainerB& noneOfList,
     return true;
 }
 
-bool ImageFilterSettings::matches(const ImageInfo& info, bool* foundText) const
+bool ImageFilterSettings::matches(const ImageInfo& info, bool* const foundText) const
 {
     if (foundText)
     {
@@ -374,7 +376,7 @@ bool ImageFilterSettings::matches(const ImageInfo& info, bool* foundText) const
     if (!m_pickLabelTagFilter.isEmpty())
     {
         QList<int> tagIds = info.tagIds();
-        bool matchPL = false;
+        bool matchPL      = false;
 
         if (containsAnyOf(m_pickLabelTagFilter, tagIds))
         {
@@ -383,6 +385,7 @@ bool ImageFilterSettings::matches(const ImageInfo& info, bool* foundText) const
         else if (!matchPL)
         {
             int noPickLabelTagId = TagsCache::instance()->tagForPickLabel(NoPickLabel);
+
             if (m_pickLabelTagFilter.contains(noPickLabelTagId))
             {
                 // Searching for "has no ColorLabel" requires special handling:
@@ -634,6 +637,60 @@ bool ImageFilterSettings::matches(const ImageInfo& info, bool* foundText) const
             textMatch = true;
         }
 
+        // Image Aspect Ratio
+        if (m_textFilterSettings.textFields & SearchTextFilterSettings::ImageAspectRatio)
+        {
+            QRegExp expRatio ("^\\d+:\\d+$");
+            QRegExp expFloat ("^\\d+(.\\d+)?$");
+            if (expRatio.indexIn(m_textFilterSettings.text) > -1 && m_textFilterSettings.text.contains(QRegExp(":\\d+")))
+            {
+                QString trimmedTextFilterSettingsText = m_textFilterSettings.text;
+                QStringList numberStringList = trimmedTextFilterSettingsText.split(":", QString::SkipEmptyParts);
+                if (numberStringList.length() == 2)
+                {
+                    QString numString = (QString)numberStringList.at(0), denomString = (QString)numberStringList.at(1);
+                    bool canConverseNum, canConverseDenom;
+                    int num = numString.toInt(&canConverseNum, 10), denom = denomString.toInt(&canConverseDenom, 10);
+                    if (canConverseNum && canConverseDenom)
+                    {
+                        if (fabs(info.aspectRatio() - (double)num / denom) < 0.1)
+                            textMatch = true;
+                    }
+                }
+            }
+            else if (expFloat.indexIn(m_textFilterSettings.text) > -1)
+            {
+                QString trimmedTextFilterSettingsText = m_textFilterSettings.text;
+                bool canConverse;
+                double ratio = trimmedTextFilterSettingsText.toDouble(&canConverse);
+                if (canConverse)
+                {
+                    if (fabs(info.aspectRatio() - ratio) < 0.1)
+                        textMatch = true;
+                }
+            }
+        }
+
+        // Image Pixel Size
+        if (m_textFilterSettings.textFields & SearchTextFilterSettings::ImagePixelSize)
+        {
+            QSize size = info.dimensions();
+            int pixelSize = size.height()*size.width();
+            QString text = m_textFilterSettings.text;
+            if(text.contains(QRegExp("^>\\d{1,15}$")) && pixelSize > (text.remove(0,1)).toInt())
+            {
+                textMatch = true;
+            }
+            else if(text.contains(QRegExp("^<\\d{1,15}$")) && pixelSize < (text.remove(0,1)).toInt())
+            {
+                textMatch = true;
+            }
+            else if(pixelSize == text.toInt())
+            {
+                textMatch = true;
+            }
+        }
+
         match &= textMatch;
 
         if (foundText)
@@ -684,6 +741,8 @@ bool ImageFilterSettings::matches(const ImageInfo& info, bool* foundText) const
 
 VersionImageFilterSettings::VersionImageFilterSettings()
 {
+    m_includeTagFilter   = 0;
+    m_exceptionTagFilter = 0;
 }
 
 VersionImageFilterSettings::VersionImageFilterSettings(const VersionManagerSettings& settings)
