@@ -6,7 +6,7 @@
  * Date        : 2009-06-23
  * Description : a widget to select metadata template.
  *
- * Copyright (C) 2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -52,11 +52,11 @@ using namespace KDcrawIface;
 namespace Digikam
 {
 
-class TemplateSelector::TemplateSelectorPriv
+class TemplateSelector::Private
 {
 public:
 
-    TemplateSelectorPriv()
+    Private()
     {
         label         = 0;
         setupButton   = 0;
@@ -72,8 +72,8 @@ public:
     Template          metadataTemplate;
 };
 
-TemplateSelector::TemplateSelector(QWidget* parent = 0)
-    : KHBox(parent), d(new TemplateSelectorPriv)
+TemplateSelector::TemplateSelector(QWidget* const parent)
+    : KHBox(parent), d(new Private)
 {
     d->label         = new QLabel(i18n("Template: "), this);
     d->templateCombo = new SqueezedComboBox(this);
@@ -118,7 +118,7 @@ TemplateSelector::~TemplateSelector()
 void TemplateSelector::populateTemplates()
 {
     d->templateCombo->clear();
-    d->templateCombo->insertSqueezedItem(i18n("To remove"),    REMOVETEMPLATE);
+    d->templateCombo->insertSqueezedItem(i18n("To remove"),     REMOVETEMPLATE);
     d->templateCombo->insertSqueezedItem(i18n("Do not change"), DONTCHANGE);
     d->templateCombo->insertSeparator(DONTCHANGE + 1);
 
@@ -172,8 +172,7 @@ Template TemplateSelector::getTemplate() const
 void TemplateSelector::setTemplate(const Template& t)
 {
     d->metadataTemplate = t;
-
-    QString title = d->metadataTemplate.templateTitle();
+    QString title       = d->metadataTemplate.templateTitle();
 
     if (title == Template::removeTemplateTitle())
     {
