@@ -6,7 +6,7 @@
  * Date        : 2006-01-11
  * Description : shared image loading and caching
  *
- * Copyright (C) 2005-2011 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2005-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -49,7 +49,7 @@ class LoadingCache::LoadingCachePriv
 {
 public:
 
-    LoadingCachePriv(LoadingCache* q)
+    explicit LoadingCachePriv(LoadingCache* q)
         : q(q)
     {
         // Note: Don't make the mutex recursive, we need to use a wait condition on it
@@ -239,7 +239,7 @@ void LoadingCache::removeLoadingProcess(LoadingProcess* process)
     d->loadingDict.remove(process->cacheKey());
 }
 
-void LoadingCache::notifyNewLoadingProcess(LoadingProcess* process, LoadingDescription description)
+void LoadingCache::notifyNewLoadingProcess(LoadingProcess* process, const LoadingDescription& description)
 {
     for (QHash<QString, LoadingProcess*>::const_iterator it = d->loadingDict.constBegin();
          it != d->loadingDict.constEnd(); ++it)
@@ -344,8 +344,9 @@ void LoadingCache::notifyFileChanged(const QString& filePath)
     keys = d->thumbnailFilePathHash.values(filePath);
     foreach(const QString& cacheKey, keys)
     {
-        if (d->thumbnailImageCache.remove(cacheKey) ||
-            d->thumbnailPixmapCache.remove(cacheKey))
+        bool removedImage = d->thumbnailImageCache.remove(cacheKey);
+        bool removedPixmap = d->thumbnailPixmapCache.remove(cacheKey);
+        if (removedImage || removedPixmap)
         {
             emit fileChanged(filePath, cacheKey);
         }
