@@ -6,8 +6,8 @@
  * Date        : 2006-01-20
  * Description : image file IO threaded interface.
  *
- * Copyright (C) 2005-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2005-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2005-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -54,10 +54,14 @@ public:
 
 public:
 
-    explicit LoadSaveTask(LoadSaveThread* thread)
+    explicit LoadSaveTask(LoadSaveThread* const thread)
         : m_thread(thread)
-    {};
-    virtual ~LoadSaveTask() {};
+    {
+    };
+
+    virtual ~LoadSaveTask()
+    {
+    };
 
     virtual void execute() = 0;
     virtual TaskType type() = 0;
@@ -69,7 +73,8 @@ protected:
 
 //---------------------------------------------------------------------------------------------------
 
-class LoadingTask : public LoadSaveTask, public DImgLoaderObserver
+class LoadingTask : public LoadSaveTask,
+                    public DImgLoaderObserver
 {
 public:
 
@@ -82,10 +87,13 @@ public:
 
 public:
 
-    LoadingTask(LoadSaveThread* thread, LoadingDescription description,
+    LoadingTask(LoadSaveThread* const thread, const LoadingDescription& description,
                 LoadingTaskStatus loadingTaskStatus = LoadingTaskStatusLoading)
-        : LoadSaveTask(thread), m_loadingDescription(description), m_loadingTaskStatus(loadingTaskStatus)
-    {}
+        : LoadSaveTask(thread),
+          m_loadingDescription(description),
+          m_loadingTaskStatus(loadingTaskStatus)
+    {
+    }
 
     LoadingTaskStatus status() const
     {
@@ -109,8 +117,8 @@ public:
 
     // DImgLoaderObserver
 
-    virtual void progressInfo(const DImg*, float progress);
-    virtual bool continueQuery(const DImg*);
+    virtual void progressInfo(const DImg* const, float progress);
+    virtual bool continueQuery(const DImg* const);
 
     virtual void setStatus(LoadingTaskStatus status);
 
@@ -122,17 +130,19 @@ protected:
 
 //---------------------------------------------------------------------------------------------------
 
-class SharedLoadingTask : public LoadingTask, public LoadingProcess, public LoadingProcessListener
+class SharedLoadingTask : public LoadingTask,
+                          public LoadingProcess,
+                          public LoadingProcessListener
 {
 public:
 
-    SharedLoadingTask(LoadSaveThread* thread, LoadingDescription description,
+    SharedLoadingTask(LoadSaveThread* const thread, const LoadingDescription& description,
                       LoadSaveThread::AccessMode mode = LoadSaveThread::AccessModeReadWrite,
                       LoadingTaskStatus loadingTaskStatus = LoadingTaskStatusLoading);
 
     virtual void execute();
-    virtual void progressInfo(const DImg*, float progress);
-    virtual bool continueQuery(const DImg* img = 0);
+    virtual void progressInfo(const DImg* const, float progress);
+    virtual bool continueQuery(const DImg* const img = 0);
     virtual void setStatus(LoadingTaskStatus status);
 
     virtual bool needsPostProcessing() const;
@@ -145,7 +155,7 @@ public:
     virtual QString cacheKey();
     virtual void addListener(LoadingProcessListener* listener);
     virtual void removeListener(LoadingProcessListener* listener);
-    virtual void notifyNewLoadingProcess(LoadingProcess* process, LoadingDescription description);
+    virtual void notifyNewLoadingProcess(LoadingProcess* process, const LoadingDescription& description);
 
     // LoadingProcessListener
 
@@ -154,6 +164,8 @@ public:
     virtual LoadSaveNotifier* loadSaveNotifier();
     virtual LoadSaveThread::AccessMode accessMode();
 
+    DImg img() { return m_img; }
+
 protected:
 
     bool                           m_completed;
@@ -166,7 +178,8 @@ protected:
 
 //---------------------------------------------------------------------------------------------------
 
-class SavingTask : public LoadSaveTask, public DImgLoaderObserver
+class SavingTask : public LoadSaveTask,
+                   public DImgLoaderObserver
 {
 public:
 
@@ -178,10 +191,14 @@ public:
 
 public:
 
-    SavingTask(LoadSaveThread* thread, DImg& img, const QString& filePath, const QString& format)
+    SavingTask(LoadSaveThread* const thread, DImg& img, const QString& filePath, const QString& format)
         : LoadSaveTask(thread),
-          m_filePath(filePath), m_format(format), m_img(img), m_savingTaskStatus(SavingTaskStatusSaving)
-    {};
+          m_filePath(filePath),
+          m_format(format),
+          m_img(img),
+          m_savingTaskStatus(SavingTaskStatusSaving)
+    {
+    };
 
     SavingTaskStatus status() const
     {
@@ -198,8 +215,8 @@ public:
     virtual void     execute();
     virtual TaskType type();
 
-    virtual void     progressInfo(const DImg*, float progress);
-    virtual bool     continueQuery(const DImg*);
+    virtual void     progressInfo(const DImg* const, float progress);
+    virtual bool     continueQuery(const DImg* const);
 
     virtual void     setStatus(SavingTaskStatus status);
 
