@@ -7,7 +7,7 @@
  * Description : Thumbnail loading
  *
  * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2005-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -88,6 +88,8 @@ public:
         delete provider;
     }
 
+public:
+
     ThumbnailCreator::StorageMethod storageMethod;
     ThumbnailInfoProvider*          provider;
     QWidget*                        displayingWidget;
@@ -99,12 +101,12 @@ K_GLOBAL_STATIC(ThumbnailLoadThreadStaticPriv, static_d)
 
 // -------------------------------------------------------------------
 
-class ThumbnailLoadThread::ThumbnailLoadThreadPriv
+class ThumbnailLoadThread::Private
 {
 
 public:
 
-    ThumbnailLoadThreadPriv()
+    Private()
     {
         size               = ThumbnailSize::Huge;
         wantPixmap         = true;
@@ -133,6 +135,7 @@ public:
 
     QList<LoadingDescription>       lastDescriptions;
     QStringList                     previewPlugins;
+
 public:
 
     LoadingDescription        createLoadingDescription(const QString& filePath, int size, bool setLastDescription = true);
@@ -150,9 +153,9 @@ K_GLOBAL_STATIC(ThumbnailLoadThread, defaultIconViewObject)
 K_GLOBAL_STATIC(ThumbnailLoadThread, defaultObject)
 K_GLOBAL_STATIC(ThumbnailLoadThread, defaultThumbBarObject)
 
-ThumbnailLoadThread::ThumbnailLoadThread(QObject* parent)
+ThumbnailLoadThread::ThumbnailLoadThread(QObject* const parent)
     : ManagedLoadSaveThread(parent),
-      d(new ThumbnailLoadThreadPriv)
+      d(new Private)
 {
     static_d->firstThreadCreated = true;
     d->creator                   = new ThumbnailCreator(static_d->storageMethod);
@@ -198,7 +201,7 @@ void ThumbnailLoadThread::cleanUp()
     defaultThumbBarObject.destroy();
 }
 
-void ThumbnailLoadThread::initializeThumbnailDatabase(const DatabaseParameters& params, ThumbnailInfoProvider* provider)
+void ThumbnailLoadThread::initializeThumbnailDatabase(const DatabaseParameters& params, ThumbnailInfoProvider* const provider)
 {
     if (static_d->firstThreadCreated)
     {
@@ -222,7 +225,7 @@ void ThumbnailLoadThread::initializeThumbnailDatabase(const DatabaseParameters&
     }
 }
 
-void ThumbnailLoadThread::setDisplayingWidget(QWidget* widget)
+void ThumbnailLoadThread::setDisplayingWidget(QWidget* const widget)
 {
     static_d->displayingWidget = widget;
 }
@@ -289,12 +292,12 @@ int ThumbnailLoadThread::thumbnailPixmapSize(bool withHighlight, int size)
     return size;
 }
 
-bool ThumbnailLoadThread::ThumbnailLoadThreadPriv::hasHighlightingBorder() const
+bool ThumbnailLoadThread::Private::hasHighlightingBorder() const
 {
     return highlight && size >= 10;
 }
 
-int ThumbnailLoadThread::ThumbnailLoadThreadPriv::pixmapSizeForThumbnailSize(int thumbnailSize) const
+int ThumbnailLoadThread::Private::pixmapSizeForThumbnailSize(int thumbnailSize) const
 {
     if (hasHighlightingBorder())
     {
@@ -304,7 +307,7 @@ int ThumbnailLoadThread::ThumbnailLoadThreadPriv::pixmapSizeForThumbnailSize(int
     return thumbnailSize;
 }
 
-int ThumbnailLoadThread::ThumbnailLoadThreadPriv::thumbnailSizeForPixmapSize(int pixmapSize) const
+int ThumbnailLoadThread::Private::thumbnailSizeForPixmapSize(int pixmapSize) const
 {
     // bug #206666: Do not cut off one-pixel line for highlighting border
     if (hasHighlightingBorder())
@@ -317,8 +320,8 @@ int ThumbnailLoadThread::ThumbnailLoadThreadPriv::thumbnailSizeForPixmapSize(int
 
 // --- Creating loading descriptions ---
 
-LoadingDescription ThumbnailLoadThread::ThumbnailLoadThreadPriv
-     ::createLoadingDescription(const QString& filePath, int size, bool setLastDescription)
+LoadingDescription ThumbnailLoadThread::Private::createLoadingDescription(const QString& filePath, int size, 
+                                                                          bool setLastDescription)
 {
     size = thumbnailSizeForPixmapSize(size);
 
@@ -341,8 +344,8 @@ LoadingDescription ThumbnailLoadThread::ThumbnailLoadThreadPriv
     return description;
 }
 
-LoadingDescription ThumbnailLoadThread::ThumbnailLoadThreadPriv
-    ::createLoadingDescription(const QString& filePath, int size, const QRect& detailRect, bool setLastDescription)
+LoadingDescription ThumbnailLoadThread::Private::createLoadingDescription(const QString& filePath, int size, 
+                                                                          const QRect& detailRect, bool setLastDescription)
 {
     size = thumbnailSizeForPixmapSize(size);
 
@@ -367,12 +370,12 @@ LoadingDescription ThumbnailLoadThread::ThumbnailLoadThreadPriv
     return description;
 }
 
-bool ThumbnailLoadThread::ThumbnailLoadThreadPriv::checkDescription(const LoadingDescription& description)
+bool ThumbnailLoadThread::Private::checkDescription(const LoadingDescription& description)
 {
     QString cacheKey = description.cacheKey();
 
     {
-        LoadingCache* cache = LoadingCache::cache();
+        LoadingCache* const cache = LoadingCache::cache();
         LoadingCache::CacheLock lock(cache);
 
         if (cache->hasThumbnailPixmap(cacheKey))
@@ -389,14 +392,16 @@ bool ThumbnailLoadThread::ThumbnailLoadThreadPriv::checkDescription(const Loadin
             return false;
         }
     }
+
     return true;
 }
 
-QList<LoadingDescription> ThumbnailLoadThread::ThumbnailLoadThreadPriv::makeDescriptions(const QStringList& filePaths, int size)
+QList<LoadingDescription> ThumbnailLoadThread::Private::makeDescriptions(const QStringList& filePaths, int size)
 {
     QList<LoadingDescription> descriptions;
     {
         LoadingDescription description = createLoadingDescription(QString(), size, false);
+
         foreach(const QString& filePath, filePaths)
         {
             description.filePath = filePath;
@@ -409,16 +414,18 @@ QList<LoadingDescription> ThumbnailLoadThread::ThumbnailLoadThreadPriv::makeDesc
             descriptions << description;
         }
     }
+
     lastDescriptions = descriptions;
     return descriptions;
 }
 
-QList<LoadingDescription> ThumbnailLoadThread::ThumbnailLoadThreadPriv::makeDescriptions(const QList<QPair<QString, QRect> >& filePathsAndRects, int size)
+QList<LoadingDescription> ThumbnailLoadThread::Private::makeDescriptions(const QList<QPair<QString, QRect> >& filePathsAndRects, int size)
 {
     QList<LoadingDescription> descriptions;
     {
         LoadingDescription description = createLoadingDescription(QString(), size, QRect(1,1,1,1), false);
         typedef QPair<QString, QRect> StringRectPair;
+
         foreach(const StringRectPair& pair, filePathsAndRects)
         {
             description.filePath = pair.first;
@@ -432,6 +439,7 @@ QList<LoadingDescription> ThumbnailLoadThread::ThumbnailLoadThreadPriv::makeDesc
             descriptions << description;
         }
     }
+
     lastDescriptions = descriptions;
     return descriptions;
 }
@@ -453,9 +461,9 @@ bool ThumbnailLoadThread::find(const QString& filePath, int size, QPixmap* retPi
     QString cacheKey = description.cacheKey();
 
     {
-        LoadingCache* cache = LoadingCache::cache();
+        LoadingCache* const cache = LoadingCache::cache();
         LoadingCache::CacheLock lock(cache);
-        pix                 = cache->retrieveThumbnailPixmap(cacheKey);
+        pix                       = cache->retrieveThumbnailPixmap(cacheKey);
     }
 
     if (pix)
@@ -741,7 +749,7 @@ void ThumbnailLoadThread::slotThumbnailLoaded(const LoadingDescription& descript
 
     // put into cache
     {
-        LoadingCache* cache = LoadingCache::cache();
+        LoadingCache* const cache = LoadingCache::cache();
         LoadingCache::CacheLock lock(cache);
         cache->putThumbnail(description.cacheKey(), pix, description.filePath);
     }
@@ -766,24 +774,28 @@ void ThumbnailLoadThread::startKdePreviewJob()
 
     d->kdeJobHash.clear();
     KUrl::List list;
+
     foreach(const LoadingDescription& description, d->kdeTodo)
     {
         KUrl url = KUrl::fromPath(description.filePath);
         list << url;
         d->kdeJobHash[url] = description;
     }
+
     d->kdeTodo.clear();
 
 #if KDE_IS_VERSION(4,7,0)
     KFileItemList items;
+
     if (d->previewPlugins.isEmpty())
       d->previewPlugins = KIO::PreviewJob::availablePlugins();
-    
-    for (KUrl::List::ConstIterator it = list.begin() ; it != list.end() ; ++it)
+
+    for (KUrl::List::ConstIterator it = list.constBegin() ; it != list.constEnd() ; ++it)
     {
         if ((*it).isValid())
             items.append(KFileItem(KFileItem::Unknown, KFileItem::Unknown, *it, true));
     }
+
     d->kdeJob = KIO::filePreview(items, QSize(d->creator->storedSize(), d->creator->storedSize()), &d->previewPlugins); // FIXME: do not know if size 0 is allowed
 #else
     d->kdeJob = KIO::filePreview(list, d->creator->storedSize());                                   // FIXME: do not know if size 0 is allowed
@@ -823,7 +835,7 @@ void ThumbnailLoadThread::gotKDEPreview(const KFileItem& item, const QPixmap& kd
 
     // put into cache
     {
-        LoadingCache* cache = LoadingCache::cache();
+        LoadingCache* const cache = LoadingCache::cache();
         LoadingCache::CacheLock lock(cache);
         cache->putThumbnail(description.cacheKey(), pix, description.filePath);
     }
@@ -857,7 +869,7 @@ QPixmap ThumbnailLoadThread::surrogatePixmap(const LoadingDescription& descripti
     No dependency on AlbumSettings here please...
     QString ext = QFileInfo(url.toLocalFile()).suffix();
 
-    AlbumSettings* settings = AlbumSettings::instance();
+    AlbumSettings* const settings = AlbumSettings::instance();
     if (settings)
     {
         if (settings->getImageFileFilter().toUpper().contains(ext.toUpper()) ||
@@ -906,7 +918,8 @@ QPixmap ThumbnailLoadThread::surrogatePixmap(const LoadingDescription& descripti
 
 void ThumbnailLoadThread::storeDetailThumbnail(const QString& filePath, const QRect& detailRect, const QImage& image, bool isFace)
 {
-    d->creator->storeDetailThumbnail(filePath, detailRect, image, isFace);
+    Q_UNUSED(isFace);
+    d->creator->storeDetailThumbnail(filePath, detailRect, image);
 }
 
 int ThumbnailLoadThread::storedSize() const
@@ -917,10 +930,10 @@ int ThumbnailLoadThread::storedSize() const
 void ThumbnailLoadThread::deleteThumbnail(const QString& filePath)
 {
     {
-        LoadingCache* cache = LoadingCache::cache();
+        LoadingCache* const cache = LoadingCache::cache();
         LoadingCache::CacheLock lock(cache);
+        QStringList possibleKeys  = LoadingDescription::possibleThumbnailCacheKeys(filePath);
 
-        QStringList possibleKeys = LoadingDescription::possibleThumbnailCacheKeys(filePath);
         foreach(const QString& cacheKey, possibleKeys)
         {
             cache->removeThumbnail(cacheKey);
@@ -937,67 +950,112 @@ void ThumbnailLoadThread::deleteThumbnail(const QString& filePath)
     creator.deleteThumbnailsFromDisk(filePath);
 }
 
-// --- ThumbnailImageCatcher
+// --- ThumbnailImageCatcher ---------------------------------------------------------
 
-class ThumbnailImageCatcherResult
+class ThumbnailImageCatcher::Private
 {
+
 public:
 
-    ThumbnailImageCatcherResult(const LoadingDescription& d)
-        : description(d), received(false)
+    enum CatcherState
     {
-    }
+        Inactive,
+        Accepting,
+        Waiting,
+        Quitting
+    };
 
-    ThumbnailImageCatcherResult(const LoadingDescription& d, const QImage& image)
-        : image(image), description(d), received(true)
-    {
-    }
-
-    QImage             image;
-    LoadingDescription description;
-    bool               received;
-};
-
-enum ThumbnailImageCatcherState
-{
-    Inactive,
-    Accepting,
-    Waiting,
-    Quitting
-};
-
-class ThumbnailImageCatcher::ThumbnailImageCatcherPriv
-{
 public:
 
-    ThumbnailImageCatcherPriv()
+    class CatcherResult
+    {
+    public:
+
+        CatcherResult(const LoadingDescription& d)
+            : description(d), received(false) {}
+
+        CatcherResult(const LoadingDescription& d, const QImage& image)
+            : image(image), description(d), received(true){}
+
+    public:
+
+        QImage             image;
+        LoadingDescription description;
+        bool               received;
+    };
+
+public:
+
+    Private()
     {
         state   = Inactive;
         thread  = 0;
         active  = true;
     }
 
-    ThumbnailImageCatcherState         state;
-
-    bool                               active;
-    ThumbnailLoadThread*               thread;
-    QList<ThumbnailImageCatcherResult> tasks;
-    QList<ThumbnailImageCatcherResult> intermediate;
-
-    QMutex                             mutex;
-    QWaitCondition                     condVar;
-
     void reset();
     void harvest(const LoadingDescription& description, const QImage& image);
+
+public:
+
+    CatcherState                  state;
+
+    bool                          active;
+    ThumbnailLoadThread*          thread;
+    QList<Private::CatcherResult> tasks;
+    QList<Private::CatcherResult> intermediate;
+
+    QMutex                        mutex;
+    QWaitCondition                condVar;
 };
 
-ThumbnailImageCatcher::ThumbnailImageCatcher(QObject* parent)
-    : QObject(parent), d(new ThumbnailImageCatcherPriv)
+void ThumbnailImageCatcher::Private::reset()
+{
+    intermediate.clear();
+    tasks.clear();
+
+    if (active)
+    {
+        state = Accepting;
+    }
+    else
+    {
+        state = Inactive;
+    }
+}
+
+void ThumbnailImageCatcher::Private::harvest(const LoadingDescription& description, const QImage& image)
+{
+    // called under lock
+    bool finished = true;
+
+    for (int i=0; i<tasks.size(); ++i)
+    {
+        Private::CatcherResult& task = tasks[i];
+
+        if (task.description == description)
+        {
+            task.image    = image;
+            task.received = true;
+        }
+
+        finished = finished && task.received;
+    }
+
+    if (finished)
+    {
+        state = Quitting;
+        condVar.wakeOne();
+    }
+}
+
+ThumbnailImageCatcher::ThumbnailImageCatcher(QObject* const parent)
+    : QObject(parent), d(new Private)
 {
 }
 
-ThumbnailImageCatcher::ThumbnailImageCatcher(ThumbnailLoadThread* thread, QObject* parent)
-    : QObject(parent), d(new ThumbnailImageCatcherPriv)
+ThumbnailImageCatcher::ThumbnailImageCatcher(ThumbnailLoadThread* const thread, QObject* const parent)
+    : QObject(parent), d(new Private)
 {
     setThumbnailLoadThread(thread);
 }
@@ -1012,14 +1070,14 @@ ThumbnailLoadThread* ThumbnailImageCatcher::thread() const
     return d->thread;
 }
 
-void ThumbnailImageCatcher::setThumbnailLoadThread(ThumbnailLoadThread* thread)
+void ThumbnailImageCatcher::setThumbnailLoadThread(ThumbnailLoadThread* const thread)
 {
     if (d->thread == thread)
     {
         return;
     }
 
-    d->state = Inactive;
+    d->state = Private::Inactive;
 
     if (d->thread)
     {
@@ -1038,10 +1096,8 @@ void ThumbnailImageCatcher::setThumbnailLoadThread(ThumbnailLoadThread* thread)
     {
         connect(thread, SIGNAL(signalThumbnailLoaded(LoadingDescription,QImage)),
                 this, SLOT(slotThumbnailLoaded(LoadingDescription,QImage)),
-                Qt::DirectConnection
-               );
+                Qt::DirectConnection);
     }
-
 }
 
 void ThumbnailImageCatcher::setActive(bool active)
@@ -1065,53 +1121,13 @@ void ThumbnailImageCatcher::cancel()
 {
     QMutexLocker lock(&d->mutex);
 
-    if (d->state == Waiting)
+    if (d->state == Private::Waiting)
     {
-        d->state = Quitting;
+        d->state = Private::Quitting;
         d->condVar.wakeOne();
     }
 }
 
-void ThumbnailImageCatcher::ThumbnailImageCatcherPriv::reset()
-{
-    intermediate.clear();
-    tasks.clear();
-
-    if (active)
-    {
-        state = Accepting;
-    }
-    else
-    {
-        state = Inactive;
-    }
-}
-
-void ThumbnailImageCatcher::ThumbnailImageCatcherPriv::harvest(const LoadingDescription& description, const QImage& image)
-{
-    // called under lock
-    bool finished = true;
-
-    for (int i=0; i<tasks.size(); ++i)
-    {
-        ThumbnailImageCatcherResult& task = tasks[i];
-
-        if (task.description == description)
-        {
-            task.image    = image;
-            task.received = true;
-        }
-
-        finished = finished && task.received;
-    }
-
-    if (finished)
-    {
-        state = Quitting;
-        condVar.wakeOne();
-    }
-}
-
 void ThumbnailImageCatcher::slotThumbnailLoaded(const LoadingDescription& description, const QImage& image)
 {
     // We are in the thumbnail thread here, DirectConnection!
@@ -1120,15 +1136,15 @@ void ThumbnailImageCatcher::slotThumbnailLoaded(const LoadingDescription& descri
 
     switch (d->state)
     {
-        case Inactive:
+        case Private::Inactive:
             break;
-        case Accepting:
-            d->intermediate << ThumbnailImageCatcherResult(description, image);
+        case Private::Accepting:
+            d->intermediate << Private::CatcherResult(description, image);
             break;
-        case Waiting:
+        case Private::Waiting:
             d->harvest(description, image);
             break;
-        case Quitting:
+        case Private::Quitting:
             break;
     }
 }
@@ -1138,6 +1154,7 @@ int ThumbnailImageCatcher::enqueue()
     QList<LoadingDescription> descriptions = d->thread->lastDescriptions();
 
     QMutexLocker(&d->mutex);
+
     foreach(const LoadingDescription& description, descriptions)
     {
         d->tasks << description;
@@ -1154,23 +1171,25 @@ QList<QImage> ThumbnailImageCatcher::waitForThumbnails()
     }
 
     QMutexLocker lock(&d->mutex);
-    d->state = Waiting;
+    d->state = Private::Waiting;
 
     // first, handle results received between request and calling this method
-    foreach(const ThumbnailImageCatcherResult& result, d->intermediate)
+    foreach(const Private::CatcherResult& result, d->intermediate)
     {
         d->harvest(result.description, result.image);
     }
+
     d->intermediate.clear();
 
     // Now wait for the rest to arrive. If already finished, state will be Quitting
-    while (d->state == Waiting)
+    while (d->state == Private::Waiting)
     {
         d->condVar.wait(&d->mutex);
     }
 
     QList<QImage> result;
-    foreach(const ThumbnailImageCatcherResult& task, d->tasks)
+
+    foreach(const Private::CatcherResult& task, d->tasks)
     {
         result << task.image;
     }
