@@ -6,7 +6,7 @@
  * Date        : 2008-12-10
  * Description : tool tip widget for iconview, thumbbar, and folderview items
  *
- * Copyright (C) 2008-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -139,11 +139,11 @@ QString DToolTipStyleSheet::elidedText(const QString& str, Qt::TextElideMode eli
 
 // --------------------------------------------------------------------------------------------------
 
-class DItemToolTip::DItemToolTipPriv
+class DItemToolTip::Private
 {
 public:
 
-    DItemToolTipPriv() :
+    Private() :
         tipBorder(5)
     {
         corner = 0;
@@ -154,8 +154,8 @@ public:
     QPixmap     corners[4];
 };
 
-DItemToolTip::DItemToolTip(QWidget* parent)
-    : QLabel(parent, Qt::ToolTip), d(new DItemToolTipPriv)
+DItemToolTip::DItemToolTip(QWidget* const parent)
+    : QLabel(parent, Qt::ToolTip), d(new Private)
 {
     hide();
 
