@@ -6,7 +6,7 @@
  * Date        : 2006-01-10
  * Description : a widget to display CIE tongue from an ICC profile.
  *
- * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Any source code are inspired from lprof project and
  * Copyright (C) 1998-2001 Marti Maria
@@ -154,11 +154,11 @@ static const double spectral_chromaticity[81][3] =
     { 0.7347, 0.2653 }  // 780 nm
 };
 
-class CIETongueWidget::CIETongueWidgetPriv
+class CIETongueWidget::Private
 {
 public:
 
-    CIETongueWidgetPriv() :
+    Private() :
         profileDataAvailable(true),
         loadingImageMode(false),
         loadingImageSucess(false),
@@ -174,7 +174,7 @@ public:
         hMonitorProfile(0),
         hXFORM(0)
     {
-        progressPix         = KPixmapSequence("process-working", KIconLoader::SizeSmallMedium);
+        progressPix = KPixmapSequence("process-working", KIconLoader::SizeSmallMedium);
     }
 
     bool            profileDataAvailable;
@@ -204,8 +204,8 @@ public:
     cmsCIEXYZ       MediaWhite;
 };
 
-CIETongueWidget::CIETongueWidget(int w, int h, QWidget* parent, cmsHPROFILE hMonitor)
-    : QWidget(parent), d(new CIETongueWidgetPriv)
+CIETongueWidget::CIETongueWidget(int w, int h, QWidget* const parent, cmsHPROFILE hMonitor)
+    : QWidget(parent), d(new Private)
 {
     cmsHPROFILE hXYZProfile;
     d->progressTimer = new QTimer(this);
@@ -223,7 +223,9 @@ CIETongueWidget::CIETongueWidget(int w, int h, QWidget* parent, cmsHPROFILE hMon
     }
 
     hXYZProfile = dkCmsCreateXYZProfile();
-    if (hXYZProfile == NULL) return;
+
+    if (hXYZProfile == NULL)
+        return;
 
 
     d->hXFORM = dkCmsCreateTransform(hXYZProfile, TYPE_XYZ_16,
@@ -232,7 +234,8 @@ CIETongueWidget::CIETongueWidget(int w, int h, QWidget* parent, cmsHPROFILE hMon
 
     dkCmsCloseProfile(hXYZProfile);
 
-    if (d->hXFORM == NULL) kDebug() << "Wrong d->hXFORM" ;
+    if (d->hXFORM == NULL)
+        kDebug() << "Wrong d->hXFORM" ;
 
     connect(d->progressTimer, SIGNAL(timeout()),
             this, SLOT(slotProgressTimerDone()));
@@ -331,7 +334,7 @@ void CIETongueWidget::setProfile(cmsHPROFILE hProfile)
 
     // Get the colorant matrix.
 
-    ZeroMemory(&(d->Primaries), sizeof(cmsCIExyYTRIPLE));
+    memset(&(d->Primaries),0,sizeof(cmsCIExyYTRIPLE));
 
     if (dkCmsIsTag(hProfile, icSigRedColorantTag)   &&
         dkCmsIsTag(hProfile, icSigGreenColorantTag) &&
