@@ -6,7 +6,7 @@
  * Date        : 2009-09-03
  * Description : an input widget for the AdvancedRename utility
  *
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at googlemail dot com>
+ * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -47,56 +47,18 @@
 
 namespace
 {
-static const short INVALID = -1;
+static const quint8 INVALID = -1;
+static const QString DUMMY_TEXT("DUMMY_TEXT_y_fjqp|");
 }
 
 namespace Digikam
 {
 
-AdvancedRenameLineEditProxy::AdvancedRenameLineEditProxy(QWidget* parent)
-    : ProxyLineEdit(parent)
-{
-    setClearButtonShown(true);
-}
-
-void AdvancedRenameLineEditProxy::setWidget(QWidget* widget)
-{
-    delete m_widget;
-    delete m_layout;
-
-    m_widget = widget;
-    m_widget->setParent(this);
-
-    QWidget* placeholder = new QWidget(this);
-    placeholder->setFixedHeight(1);
-    placeholder->setFixedWidth(clearButtonUsedSize().width());
-
-    QGridLayout* mainLayout = new QGridLayout(this);
-    mainLayout->addWidget(m_widget,    0, 0, 1, 1);
-    mainLayout->addWidget(placeholder, 0, 1, 1, 1);
-    mainLayout->setSpacing(0);
-    mainLayout->setMargin(0);
-    setLayout(mainLayout);
-    updateGeometry();
-}
-
-void AdvancedRenameLineEditProxy::mousePressEvent(QMouseEvent* event)
-{
-    KLineEdit::mousePressEvent(event);
-}
-
-void AdvancedRenameLineEditProxy::mouseReleaseEvent(QMouseEvent* event)
-{
-    KLineEdit::mouseReleaseEvent(event);
-}
-
-// --------------------------------------------------------
-
-class AdvancedRenameLineEdit::AdvancedRenameLineEditPriv
+class AdvancedRenameLineEdit::Private
 {
 public:
 
-    AdvancedRenameLineEditPriv() :
+    Private() :
         allowDirectoryCreation(false),
         verticalSliderPosition(INVALID),
         parseTimer(0),
@@ -110,9 +72,20 @@ public:
 };
 
 AdvancedRenameLineEdit::AdvancedRenameLineEdit(QWidget* parent)
-    : QTextEdit(parent), d(new AdvancedRenameLineEditPriv)
+    : QPlainTextEdit(parent), d(new Private)
 {
-    setLineWrapMode(QTextEdit::NoWrap);
+    setupWidgets();
+    setupConnections();
+}
+
+AdvancedRenameLineEdit::~AdvancedRenameLineEdit()
+{
+    delete d;
+}
+
+void AdvancedRenameLineEdit::setupWidgets()
+{
+    setLineWrapMode(QPlainTextEdit::NoWrap);
     setWordWrapMode(QTextOption::NoWrap);
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -124,7 +97,8 @@ AdvancedRenameLineEdit::AdvancedRenameLineEdit(QWidget* parent)
     setAutoFillBackground(false);
 
     QFontMetrics fm = fontMetrics();
-    setFixedHeight(fm.height());
+    int widgetHeight = fm.boundingRect(DUMMY_TEXT).height();
+    setMinimumHeight(widgetHeight * 2);
 
     // --------------------------------------------------------
 
@@ -136,13 +110,14 @@ AdvancedRenameLineEdit::AdvancedRenameLineEdit(QWidget* parent)
 
     // layout widget correctly by setting a dummy text and calling ensureCursorVisible().
     // Save the scrollbar position now, to avoid scrolling of the text when selecting with the mouse
-    setPlainText("DUMMY TEXT");
+    setPlainText(DUMMY_TEXT);
     ensureCursorVisible();
     d->verticalSliderPosition = verticalScrollBar()->value();
     clear();
+}
 
-    // --------------------------------------------------------
-
+void AdvancedRenameLineEdit::setupConnections()
+{
     connect(d->parseTimer, SIGNAL(timeout()),
             this, SLOT(slotParseTimer()));
 
@@ -153,11 +128,6 @@ AdvancedRenameLineEdit::AdvancedRenameLineEdit(QWidget* parent)
             this, SLOT(slotCursorPositionChanged()));
 }
 
-AdvancedRenameLineEdit::~AdvancedRenameLineEdit()
-{
-    delete d;
-}
-
 void AdvancedRenameLineEdit::setParseTimerDuration(int milliseconds)
 {
     d->parseTimer->setInterval(milliseconds);
@@ -211,7 +181,7 @@ void AdvancedRenameLineEdit::keyPressEvent(QKeyEvent* e)
 
         default:
         {
-            QTextEdit::keyPressEvent(e);
+            QPlainTextEdit::keyPressEvent(e);
             break;
         }
     }
@@ -256,16 +226,8 @@ void AdvancedRenameLineEdit::slotCursorPositionChanged()
         int start            = INVALID;
         int length           = INVALID;
         int pos              = textCursor().position();
-        found                = d->parser->tokenAtPosition(Parser::OptionToken,
-                                                          settings, pos, start, length);
+        found                = d->parser->tokenAtPosition(settings, pos, start, length);
         found                = found && ((start + length) == pos);
-
-        if (!found)
-        {
-            found = d->parser->tokenAtPosition(Parser::OptionModifiersToken,
-                                               settings, pos, start, length);
-            found = found && ((start + length) == pos);
-        }
     }
 
     emit signalTokenMarked(found);
@@ -283,14 +245,15 @@ void AdvancedRenameLineEdit::slotSetText(const QString& text)
 
 // --------------------------------------------------------
 
-class AdvancedRenameInput::AdvancedRenameInputPriv
+class AdvancedRenameInput::Private
 {
 public:
 
-    AdvancedRenameInputPriv() :
+    Private() :
         maxVisibleItems(10),
         maxHistoryItems(30),
         lineEdit(0),
+        proxy(0),
         highlighter(0)
     {}
 
@@ -300,54 +263,20 @@ public:
     const int               maxVisibleItems;
     const int               maxHistoryItems;
 
-    QStringList             patternHistory;
-
     AdvancedRenameLineEdit* lineEdit;
+    ProxyLineEdit*          proxy;
     Highlighter*            highlighter;
 };
-const QString AdvancedRenameInput::AdvancedRenameInputPriv::configGroupName("AdvancedRename Input");
-const QString AdvancedRenameInput::AdvancedRenameInputPriv::configPatternHistoryListEntry("Pattern History List");
+const QString AdvancedRenameInput::Private::configGroupName("AdvancedRename Input");
+const QString AdvancedRenameInput::Private::configPatternHistoryListEntry("Pattern History List");
 
 // --------------------------------------------------------
 
 AdvancedRenameInput::AdvancedRenameInput(QWidget* parent)
-    : KComboBox(parent), d(new AdvancedRenameInputPriv)
+    : KComboBox(parent), d(new Private)
 {
-    // important: setEditable() has to be called before adding the actual line edit widget, otherwise
-    //            our lineEdit gets removed again.
-    setEditable(true);
-    setMaxVisibleItems(d->maxVisibleItems);
-    setMaxCount(d->maxHistoryItems);
-    setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
-
-    AdvancedRenameLineEditProxy* proxy = new AdvancedRenameLineEditProxy(this);
-    d->lineEdit                        = new AdvancedRenameLineEdit(this);
-    proxy->setWidget(d->lineEdit);
-
-    setLineEdit(proxy);
-    proxy->setAutoFillBackground(false);
-
-    // --------------------------------------------------------
-
-    connect(proxy, SIGNAL(clearButtonClicked()),
-            this, SLOT(slotClearButtonPressed()));
-
-    connect(d->lineEdit, SIGNAL(signalTextChanged(QString)),
-            proxy, SLOT(setText(QString)));
-
-    connect(d->lineEdit, SIGNAL(signalTextChanged(QString)),
-            this, SIGNAL(signalTextChanged(QString)));
-
-    connect(d->lineEdit, SIGNAL(signalTokenMarked(bool)),
-            this, SIGNAL(signalTokenMarked(bool)));
-
-    connect(d->lineEdit, SIGNAL(signalReturnPressed()),
-            this, SIGNAL(signalReturnPressed()));
-
-    connect(this, SIGNAL(activated(QString)),
-            d->lineEdit, SLOT(slotSetText(QString)));
-
-    // --------------------------------------------------------
+    setupWidgets();
+    setupConnections();
 
     readSettings();
 }
@@ -408,10 +337,44 @@ void AdvancedRenameInput::enableHighlighter(bool enable)
 {
     delete d->highlighter;
     d->highlighter = enable
-                     ? new Highlighter(d->lineEdit, d->lineEdit->parser())
+                     ? new Highlighter(d->lineEdit->document(), d->lineEdit->parser())
                      : 0;
 }
 
+void AdvancedRenameInput::setupWidgets()
+{
+    setEditable(true);
+
+    setMaxVisibleItems(d->maxVisibleItems);
+    setMaxCount(d->maxHistoryItems);
+
+    d->lineEdit = new AdvancedRenameLineEdit(this);
+    d->proxy    = new ProxyLineEdit(this);
+    d->proxy->setWidget(d->lineEdit);
+    d->proxy->setClearButtonShown(true);
+    d->proxy->setAutoFillBackground(false);
+
+    setLineEdit(d->proxy);
+}
+
+void AdvancedRenameInput::setupConnections()
+{
+    connect(d->proxy, SIGNAL(clearButtonClicked()),
+            this, SLOT(slotClearButtonPressed()));
+
+    connect(d->lineEdit, SIGNAL(signalTextChanged(QString)),
+            this, SIGNAL(signalTextChanged(QString)));
+
+    connect(d->lineEdit, SIGNAL(signalTokenMarked(bool)),
+            this, SIGNAL(signalTokenMarked(bool)));
+
+    connect(d->lineEdit, SIGNAL(signalReturnPressed()),
+            this, SIGNAL(signalReturnPressed()));
+
+    connect(this, SIGNAL(currentIndexChanged(QString)),
+            d->lineEdit, SLOT(slotSetText(QString)));
+}
+
 void AdvancedRenameInput::changeEvent(QEvent* e)
 {
     KComboBox::changeEvent(e);
@@ -444,9 +407,9 @@ void AdvancedRenameInput::readSettings()
     KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup group        = config->group(d->configGroupName);
 
-    d->patternHistory = group.readEntry(d->configPatternHistoryListEntry, QStringList());
-    d->patternHistory.removeAll(QString(""));
-    addItems(d->patternHistory);
+    QStringList patternHistory = group.readEntry(d->configPatternHistoryListEntry, QStringList());
+    patternHistory.removeAll(QString(""));
+    addItems(patternHistory);
     d->lineEdit->clear();
 }
 
@@ -455,12 +418,14 @@ void AdvancedRenameInput::writeSettings()
     KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup group        = config->group(d->configGroupName);
 
+    QStringList patternHistory = group.readEntry(d->configPatternHistoryListEntry, QStringList());
+
     // remove duplicate entries and save pattern history, omit empty strings
     QString pattern = d->lineEdit->toPlainText();
-    d->patternHistory.removeAll(pattern);
-    d->patternHistory.removeAll(QString(""));
-    d->patternHistory.prepend(pattern);
-    group.writeEntry(d->configPatternHistoryListEntry, d->patternHistory);
+    patternHistory.removeAll(pattern);
+    patternHistory.removeAll(QString(""));
+    patternHistory.prepend(pattern);
+    group.writeEntry(d->configPatternHistoryListEntry, patternHistory);
 }
 
 }  // namespace Digikam
