@@ -6,7 +6,7 @@
  * Date        : 2009-09-14
  * Description : a parse results map for token management
  *
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at googlemail dot com>
+ * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -29,7 +29,7 @@
 
 namespace
 {
-static const short INVALID_KEY_ID = -1;
+static const quint8 INVALID_KEY_ID = -1;
 }
 
 namespace Digikam
@@ -145,7 +145,7 @@ void ParseResults::clear()
     m_results.clear();
 }
 
-void ParseResults::append(ParseResults& results)
+void ParseResults::append(const ParseResults& results)
 {
     m_results.unite(results.m_results);
 }
