@@ -6,7 +6,7 @@
  * Date        : 2009-08-08
  * Description : an option to add a sequence number to the parser
  *
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at googlemail dot com>
+ * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,8 +42,8 @@
 namespace Digikam
 {
 
-SequenceNumberDialog::SequenceNumberDialog(Parseable* parent)
-    : ParseableDialog(parent), ui(new Ui::SequenceNumberOptionDialogWidget())
+SequenceNumberDialog::SequenceNumberDialog(Rule* parent)
+    : RuleDialog(parent), ui(new Ui::SequenceNumberOptionDialogWidget())
 {
     QWidget* mainWidget = new QWidget(this);
     ui->setupUi(mainWidget);
@@ -67,7 +67,7 @@ SequenceNumberOption::SequenceNumberOption()
     addToken("#[||options||,||start||]",          i18n("Sequence number (custom start)"));
     addToken("#[||options||,||start||,||step||]", i18n("Sequence number (custom start + step)"));
 
-    QRegExp reg("(#+)(\\[(e?f?,?)?((\\d+)(,(\\d+))?)?\\])?");
+    QRegExp reg("(#+)(\\[(e?f?,?)?((-?\\d+)(,(-?\\d+))?)?\\])?");
     setRegExp(reg);
 }
 
@@ -137,13 +137,11 @@ QString SequenceNumberOption::parseOperation(ParseSettings& settings)
     int step         = 0;
     int number       = 0;
     int index        = 0;
-    bool extAware    = false;
-    bool folderAware = false;
 
     if (settings.manager)
     {
-        extAware    = !reg.cap(3).isEmpty() && reg.cap(3).contains(QChar('e'));
-        folderAware = !reg.cap(3).isEmpty() && reg.cap(3).contains(QChar('f'));
+        bool extAware    = !reg.cap(3).isEmpty() && reg.cap(3).contains(QChar('e'));
+        bool folderAware = !reg.cap(3).isEmpty() && reg.cap(3).contains(QChar('f'));
 
         index = settings.manager->indexOfFile(settings.fileUrl.toLocalFile());
 
@@ -164,6 +162,16 @@ QString SequenceNumberOption::parseOperation(ParseSettings& settings)
     start   = reg.cap(5).isEmpty() ? settings.startIndex : reg.cap(5).toInt();
     step    = reg.cap(7).isEmpty() ? 1 : reg.cap(7).toInt();
 
+    if (start < 1)
+    {
+        start = settings.startIndex;
+    }
+
+    if (step < 1)
+    {
+        step = 1;
+    }
+
     number  = start + ((index - 1) * step);
     result  = QString("%1").arg(number, slength, 10, QChar('0'));
 
