@@ -21,7 +21,6 @@
  *
  * ============================================================ */
 
-
 #include "facepipeline.moc"
 #include "facepipeline_p.moc"
 
@@ -237,7 +236,7 @@ ScanStateFilter::ScanStateFilter(FacePipeline::FilterMode mode, FacePipeline::Pr
 
 FacePipelineExtendedPackage::Ptr ScanStateFilter::filter(const ImageInfo& info)
 {
-    FaceIface iface;
+    FaceUtils utils;
 
     switch (mode)
     {
@@ -248,7 +247,7 @@ FacePipelineExtendedPackage::Ptr ScanStateFilter::filter(const ImageInfo& info)
 
         case FacePipeline::SkipAlreadyScanned:
         {
-            if (!iface.hasBeenScanned(info))
+            if (!utils.hasBeenScanned(info))
             {
                 return d->buildPackage(info);
             }
@@ -264,21 +263,22 @@ FacePipelineExtendedPackage::Ptr ScanStateFilter::filter(const ImageInfo& info)
 
             if (mode == FacePipeline::ReadUnconfirmedFaces)
             {
-                databaseFaces = iface.unconfirmedDatabaseFaces(info.id());
+                databaseFaces = utils.unconfirmedDatabaseFaces(info.id());
+
             }
             else if (mode == FacePipeline::ReadFacesForTraining)
             {
-                databaseFaces = iface.databaseFacesForTraining(info.id());
+                databaseFaces = utils.databaseFacesForTraining(info.id());
             }
             else
             {
-                databaseFaces = iface.confirmedDatabaseFaces(info.id());
+                databaseFaces = utils.confirmedDatabaseFaces(info.id());
             }
 
             if (!databaseFaces.isEmpty())
             {
                 FacePipelineExtendedPackage::Ptr package = d->buildPackage(info);
-                package->databaseFaces                   = databaseFaces;
+                package->databaseFaces = databaseFaces;
                 //kDebug() << "Prepared package with" << databaseFaces.size();
                 package->databaseFaces.setRole(FacePipelineDatabaseFace::ReadFromDatabase);
 
@@ -287,7 +287,6 @@ FacePipelineExtendedPackage::Ptr ScanStateFilter::filter(const ImageInfo& info)
                     package->databaseFaces.setRole(tasks);
                 }
 
-                package->faces = iface.toFaces(databaseFaces);
                 return package;
             }
 
@@ -459,7 +458,7 @@ void PreviewLoader::slotImageLoaded(const LoadingDescription& loadingDescription
 bool PreviewLoader::sentOutLimitReached()
 {
     int packagesInTheFollowingPipeline = d->packagesOnTheRoad - scheduledPackages.size();
-    return packagesInTheFollowingPipeline > maximumSentOutPackages;
+    return (packagesInTheFollowingPipeline > maximumSentOutPackages);
 }
 
 void PreviewLoader::checkRestart()
@@ -479,83 +478,139 @@ DetectionWorker::DetectionWorker(FacePipeline::Private* const d)
 
 void DetectionWorker::process(FacePipelineExtendedPackage::Ptr package)
 {
-    package->detectionImage = scaleForDetection(package->image);
-    KFaceIface::Image image = FaceIface::toImage(package->detectionImage);
-    image.setOriginalSize(package->image.originalSize());
+    QImage detectionImage  = scaleForDetection(package->image);
+    package->detectedFaces = detector.detectFaces(detectionImage, package->image.originalSize());
 
-    package->faces          = detector.detectFaces(image);
-
-    kDebug() << "Found" << package->faces.size() << "faces in" << package->info.name()
+    kDebug() << "Found" << package->detectedFaces.size() << "faces in" << package->info.name()
              << package->image.size() << package->image.originalSize();
 
-    package->processFlags  |= FacePipelinePackage::ProcessedByDetector;
+    package->processFlags |= FacePipelinePackage::ProcessedByDetector;
 
     emit processed(package);
 }
 
-DImg DetectionWorker::scaleForDetection(const DImg& image) const
+QImage DetectionWorker::scaleForDetection(const DImg& image) const
 {
     int recommendedSize = detector.recommendedImageSize(image.size());
 
     if (qMax(image.width(), image.height()) > (uint)recommendedSize)
     {
-        return image.smoothScale(recommendedSize, recommendedSize, Qt::KeepAspectRatio);
+        return image.smoothScale(recommendedSize, recommendedSize, Qt::KeepAspectRatio).copyQImage();
     }
 
-    return image;
+    return image.copyQImage();
 }
 
 void DetectionWorker::setAccuracy(double accuracy)
 {
-    detector.setAccuracy(accuracy);
+    QVariantMap params;
+    params["accuracy"]    = accuracy;
+    params["specificity"] = 0.8; //TODO: add UI for sensitivity - specificity
+    detector.setParameters(params);
+}
+
+// ----------------------------------------------------------------------------------------
+
+FaceImageRetriever::FaceImageRetriever(FacePipeline::Private* const d)
+    : catcher(new ThumbnailImageCatcher(d->createThumbnailLoadThread(), d))
+{
+}
+
+ThumbnailImageCatcher* FaceImageRetriever::thumbnailCatcher()
+{
+    return catcher;
+}
+
+void FaceImageRetriever::cancel()
+{
+    catcher->cancel();
+}
+
+QList<QImage> FaceImageRetriever::getDetails(const DImg& src, const QList<QRectF>& rects)
+{
+    QList<QImage> images;
+
+    foreach (const QRectF& rect, rects)
+    {
+        images << src.copyQImage(rect);
+    }
+    return images;
+}
+
+QList<QImage> FaceImageRetriever::getDetails(const DImg& src, const QList<DatabaseFace>& faces)
+{
+    QList<QImage> images;
+
+    foreach (const DatabaseFace& face, faces)
+    {
+        QRect rect = TagRegion::mapFromOriginalSize(src, face.region().toRect());
+        images << src.copyQImage(rect);
+    }
+
+    return images;
+}
+
+QList<QImage> FaceImageRetriever::getThumbnails(const QString& filePath, const QList<DatabaseFace>& faces)
+{
+    thumbnailCatcher()->setActive(true);
+
+    foreach (const DatabaseFace& face, faces)
+    {
+        QRect rect = face.region().toRect();
+        catcher->thread()->find(filePath, rect);
+        catcher->enqueue();
+    }
+
+    QList<QImage> images = catcher->waitForThumbnails();
+    thumbnailCatcher()->setActive(false);
+    
+    return images;
 }
 
 // ----------------------------------------------------------------------------------------
 
 RecognitionWorker::RecognitionWorker(FacePipeline::Private* const d)
-    : d(d)
+    : imageRetriever(d),
+      d(d)
 {
-    database             = KFaceIface::RecognitionDatabase::addDatabase();
-    recognitionThreshold = 10000000;
+    database = KFaceIface::RecognitionDatabase::addDatabase();
 }
 
 void RecognitionWorker::process(FacePipelineExtendedPackage::Ptr package)
 {
-/* Disable recognition for stable release. See bug 269720.
+    FaceUtils utils;
+    QList<QImage> images;
 
-    FaceIface iface;
-    QSize size = database.recommendedImageSize(package->image.size());
-    iface.fillImageInFaces(package->image, package->faces, size);
-
-    QList<double> distances = database.recognizeFaces(package->faces);
-
-    for (int i=0; i<distances.size(); ++i)
+    if (package->processFlags & FacePipelinePackage::ProcessedByDetector)
     {
-        kDebug() << "Recognition:"  << package->info.id()     << package->faces[i].toRect()
-                 << "recognized as" << package->faces[i].id() << package->faces[i].name()
-                 << "at distance"   << distances[i]
-                 << ((distances[i] > recognitionThreshold) ? "(discarded)" : "(accepted)");
-
-        if (distances[i] > recognitionThreshold)
-        {
-            package->faces[i].clearRecognition();
-        }
+        // assume we have an image
+        images = imageRetriever.getDetails(package->image, package->detectedFaces);
+    }
+    else if (!package->databaseFaces.isEmpty())
+    {
+        images = imageRetriever.getThumbnails(package->filePath, package->databaseFaces.toDatabaseFaceList());
     }
-*/
 
-    package->processFlags |= FacePipelinePackage::ProcessedByRecognizer;
+    package->recognitionResults  = database.recognizeFaces(images);
+    package->processFlags       |= FacePipelinePackage::ProcessedByRecognizer;
+
     emit processed(package);
 }
 
 void RecognitionWorker::setThreshold(double threshold)
 {
-    recognitionThreshold = threshold;
+    database.setParameter("threshold", threshold);
+}
+
+void RecognitionWorker::aboutToDeactivate()
+{
+    imageRetriever.cancel();
 }
 
 // ----------------------------------------------------------------------------------------
 
 DatabaseWriter::DatabaseWriter(FacePipeline::WriteMode mode, FacePipeline::Private* const d)
-    : mode(mode), d(d)
+    : mode(mode), thumbnailLoadThread(d->createThumbnailLoadThread()), d(d)
 {
 }
 
@@ -564,34 +619,56 @@ void DatabaseWriter::process(FacePipelineExtendedPackage::Ptr package)
     if (package->databaseFaces.isEmpty())
     {
         // Detection / Recognition
+        FaceUtils utils;
 
-        FaceIface iface;
-
-        if (mode == FacePipeline::OverwriteUnconfirmed && package->processFlags & FacePipelinePackage::ProcessedByDetector)
+        // OverwriteUnconfirmed means that a new scan discared unconfirmed results of previous scans
+        // (assuming at least equal or new, better methodology is in use compared to the previous scan)
+        if (mode == FacePipeline::OverwriteUnconfirmed && (package->processFlags & FacePipelinePackage::ProcessedByDetector))
         {
-            QList<DatabaseFace> oldEntries = iface.unconfirmedDatabaseFaces(package->info.id());
+            QList<DatabaseFace> oldEntries = utils.unconfirmedDatabaseFaces(package->info.id());
             kDebug() << "Removing old entries" << oldEntries;
-            iface.removeFaces(oldEntries);
+            utils.removeFaces(oldEntries);
         }
 
-        iface.markAsScanned(package->info);
+        // mark the whole image as scanned-for-faces
+        utils.markAsScanned(package->info);
 
-        if (!package->info.isNull() && !package->faces.isEmpty())
+        if (!package->info.isNull() && !package->detectedFaces.isEmpty())
         {
-            package->databaseFaces = iface.writeUnconfirmedResults(package->detectionImage, package->info.id(), package->faces);
+            package->databaseFaces = utils.writeUnconfirmedResults(package->info.id(),
+                                                                   package->detectedFaces,
+                                                                   package->recognitionResults,
+                                                                   package->image.originalSize());
             package->databaseFaces.setRole(FacePipelineDatabaseFace::DetectedFromImage);
 
             if (!package->image.isNull())
             {
-                iface.storeThumbnails(d->thumbnailLoadThread, package->filePath, package->databaseFaces.toDatabaseFaceList(), package->image);
+                utils.storeThumbnails(thumbnailLoadThread, package->filePath,
+                                      package->databaseFaces.toDatabaseFaceList(), package->image);
             }
         }
     }
+    else if (package->processFlags & FacePipelinePackage::ProcessedByRecognizer)
+    {
+        FaceUtils utils;
+
+        for (int i=0; i<package->databaseFaces.size(); i++)
+        {
+            if ((package->databaseFaces[i].roles & FacePipelineDatabaseFace::ForRecognition)
+                && !package->recognitionResults[i].isNull())
+            {
+                int tagId = FaceTags::getOrCreateTagForIdentity(package->recognitionResults[i].attributes);
+                package->databaseFaces[i] = utils.changeSuggestedName(package->databaseFaces[i], tagId);
+
+                package->databaseFaces[i].roles &= ~FacePipelineDatabaseFace::ForRecognition;
+           }
+        }
+    }
     else
     {
         // Editing database entries
 
-        FaceIface iface;
+        FaceUtils utils;
         FacePipelineDatabaseFaceList add;
         FacePipelineDatabaseFaceList::iterator it;
 
@@ -599,7 +676,7 @@ void DatabaseWriter::process(FacePipelineExtendedPackage::Ptr package)
         {
             if (it->roles & FacePipelineDatabaseFace::ForConfirmation)
             {
-                FacePipelineDatabaseFace confirmed  = iface.confirmName(*it, it->assignedTagId, it->assignedRegion);
+                FacePipelineDatabaseFace confirmed  = utils.confirmName(*it, it->assignedTagId, it->assignedRegion);
                 confirmed.roles                    |= FacePipelineDatabaseFace::Confirmed | FacePipelineDatabaseFace::ForTraining;
                 add << confirmed;
             }
@@ -608,18 +685,18 @@ void DatabaseWriter::process(FacePipelineExtendedPackage::Ptr package)
                 if (it->isNull())
                 {
                     // add Manually
-                    DatabaseFace newFace = iface.unconfirmedEntry(package->info.id(), it->assignedTagId, it->assignedRegion);
-                    iface.addManually(newFace);
+                    DatabaseFace newFace = utils.unconfirmedEntry(package->info.id(), it->assignedTagId, it->assignedRegion);
+                    utils.addManually(newFace);
                     add << newFace;
                 }
                 else if (it->assignedRegion.isValid())
                 {
-                    add << iface.changeRegion(*it, it->assignedRegion);
+                    add << utils.changeRegion(*it, it->assignedRegion);
                     // not implemented: changing tag id
                 }
                 else
                 {
-                    iface.removeFace(*it);
+                    utils.removeFace(*it);
                 }
 
                 it->roles &= ~FacePipelineDatabaseFace::ForEditing;
@@ -631,7 +708,7 @@ void DatabaseWriter::process(FacePipelineExtendedPackage::Ptr package)
 
         if (!package->image.isNull())
         {
-            iface.storeThumbnails(d->thumbnailLoadThread, package->filePath, add.toDatabaseFaceList(), package->image);
+            utils.storeThumbnails(thumbnailLoadThread, package->filePath, add.toDatabaseFaceList(), package->image);
         }
 
         package->databaseFaces << add;
@@ -666,22 +743,24 @@ void Benchmarker::process(FacePipelineExtendedPackage::Ptr package)
         // Detection / Recognition
         kDebug() << "Benchmarking image" << package->info.name();
 
-        FaceIface iface;
-        QList<DatabaseFace> groundTruth = iface.databaseFaces(package->info.id());
-        QList<DatabaseFace> testedFaces = iface.toDatabaseFaces(package->detectionImage, package->info.id(), package->faces);
+        FaceUtils utils;
+        QList<DatabaseFace> groundTruth = utils.databaseFaces(package->info.id());
 
-        QList<DatabaseFace> unmatchedTrueFaces = groundTruth;
+        QList<DatabaseFace> testedFaces = utils.toDatabaseFaces(package->info.id(), package->detectedFaces,
+                                                                package->recognitionResults, package->image.originalSize());
+
+        QList<DatabaseFace> unmatchedTrueFaces   = groundTruth;
         QList<DatabaseFace> unmatchedTestedFaces = testedFaces;
         QList<DatabaseFace> matchedTrueFaces;
 
-        int trueFaces = groundTruth.size();
+        int trueFaces           = groundTruth.size();
         const double minOverlap = 0.75;
 
         kDebug() << "There are" << trueFaces << "faces to be detected. The detector found" << testedFaces.size();
 
         ++totalImages;
-        faces += trueFaces;
-        totalPixels += package->detectionImage.originalSize().width() * package->detectionImage.originalSize().height();
+        faces       += trueFaces;
+        totalPixels += package->image.originalSize().width() * package->image.originalSize().height();
 
         foreach(const DatabaseFace& trueFace, groundTruth)
         {
@@ -699,6 +778,7 @@ void Benchmarker::process(FacePipelineExtendedPackage::Ptr package)
                 }
             }
         }
+
         foreach(const DatabaseFace& testedFace, testedFaces)
         {
             foreach(const DatabaseFace& trueFace, groundTruth)
@@ -750,7 +830,7 @@ QString Benchmarker::result() const
                                      "This means the result is cannot be representative; "
                                      "it can only be used to compare preselected collections, "
                                      "and the specificity and false-positive rate have little meaning. </p>")
-                             .arg(negativeImages).arg(totalImages);
+                .arg(negativeImages).arg(totalImages);
         negativeImages     = qMax(negativeImages, 1);
     }
 
@@ -759,7 +839,7 @@ QString Benchmarker::result() const
         sensitivityWarning = QString("<p><b>Note:</b><br/> "
                                      "No picture in the test collection contained a face. "
                                      "This means that sensitivity and PPV have no meaning and will be zero. </p>");
-        trueFaces = 1;
+        trueFaces          = 1;
     }
 
     // collection properties
@@ -796,30 +876,61 @@ QString Benchmarker::result() const
                    "Given face with no images on it, the detector will with a probability "
                    "of %5% falsely find a face on it. "
                    "</p>")
-           .arg(totalImages).arg(faces).arg(pixelCoverage * 100, 0, 'f', 1)
-           .arg(specificity * 100, 0, 'f', 1).arg(falsePositiveRate * 100, 0, 'f', 1)
-           .arg(sensitivity * 100, 0, 'f', 1).arg(ppv * 100, 0, 'f', 1)
-           .arg(specificityWarning).arg(sensitivityWarning);
+            .arg(totalImages).arg(faces).arg(pixelCoverage * 100, 0, 'f', 1)
+            .arg(specificity * 100, 0, 'f', 1).arg(falsePositiveRate * 100, 0, 'f', 1)
+            .arg(sensitivity * 100, 0, 'f', 1).arg(ppv * 100, 0, 'f', 1)
+            .arg(specificityWarning).arg(sensitivityWarning);
 }
 
 // ----------------------------------------------------------------------------------------
 
+class MapListTrainingDataProvider : public KFaceIface::TrainingDataProvider
+{
+public:
+
+    MapListTrainingDataProvider()
+    {
+    }
+
+    KFaceIface::ImageListProvider* newImages(const KFaceIface::Identity& identity)
+    {
+        if (imagesToTrain.contains(identity.id))
+        {
+            KFaceIface::QListImageListProvider& provider = imagesToTrain[identity.id];
+            provider.reset();
+            return &provider;
+        }
+
+        return &empty;
+    }
+
+    KFaceIface::ImageListProvider* images(const KFaceIface::Identity&)
+    {
+        // Unimplemented. Would be needed if we use a backend with a "holistic" approach that needs all images to train.
+        return &empty;
+    }
+
+    KFaceIface::EmptyImageListProvider            empty;
+    QMap<int, KFaceIface::QListImageListProvider> imagesToTrain;
+};
+
+
 Trainer::Trainer(FacePipeline::Private* const d)
-    : d(d)
+    : imageRetriever(d),
+      d(d)
 {
-    /*
-     * Disable recognition for stable release. See bug 269720 and 255520.
-     *
     database = KFaceIface::RecognitionDatabase::addDatabase();
-    */
-    catcher  = 0;
 }
 
 void Trainer::process(FacePipelineExtendedPackage::Ptr package)
 {
     //kDebug() << "Trainer: processing one package";
     // Get a list of faces with type FaceForTraining (probably type is ConfirmedFace)
+
     QList<DatabaseFace> toTrain;
+    QList<int> identities;
+    QList<KFaceIface::Identity> identitySet;
+    FaceUtils utils;
 
     foreach(const FacePipelineDatabaseFace& face, package->databaseFaces)
     {
@@ -828,57 +939,51 @@ void Trainer::process(FacePipelineExtendedPackage::Ptr package)
             DatabaseFace dbFace = face;
             dbFace.setType(DatabaseFace::FaceForTraining);
             toTrain << dbFace;
+
+            KFaceIface::Identity identity = utils.identityForTag(dbFace.tagId(), database);
+            identities  << identity.id;
+
+            if (!identitySet.contains(identity))
+            {
+                identitySet << identity;
+            }
         }
     }
 
     if (!toTrain.isEmpty())
     {
-        FaceIface iface;
-
-/* Disable recognition for stable release. See bug 269720 and 255520.
-
-        // Get KFaceIface faces
-        package->faces = iface.toFaces(toTrain);
-
-        // Fill images in faces - either from given DImg, or from thumbnails
-        QSize size = database.recommendedImageSize(package->image.size());
+        QList<QImage> images;
 
         if (package->image.isNull())
         {
-            if (!catcher)
-            {
-                catcher = new ThumbnailImageCatcher(d->thumbnailLoadThread, this);
-            }
-
-            catcher->setActive(true);
-            iface.fillImageInFaces(catcher, package->filePath, package->faces, size);
-            catcher->setActive(false);
+            images = imageRetriever.getThumbnails(package->filePath, toTrain);
         }
         else
         {
-            iface.fillImageInFaces(package->image, package->faces, size);
+            images = imageRetriever.getDetails(package->image, toTrain);
         }
 
-        // Train
-        kDebug() << "Training" << package->faces.size() << "faces";
-        database.updateFaces(package->faces);
-*/
+        MapListTrainingDataProvider provider;
 
-        // Remove the "FaceForTraining" entry in database (tagRegion entry remains, of course, untouched)
-        iface.removeFaces(toTrain);
-        package->databaseFaces.replaceRole(FacePipelineDatabaseFace::ForTraining, FacePipelineDatabaseFace::Trained);
+        // Group images by identity
+        for (int i = 0; i<toTrain.size(); ++i)
+        {
+            provider.imagesToTrain[identities[i]].list << images[i];
+        }
+
+        database.train(identitySet, &provider, "digikam");
     }
 
+    utils.removeFaces(toTrain);
+    package->databaseFaces.replaceRole(FacePipelineDatabaseFace::ForTraining, FacePipelineDatabaseFace::Trained);
+
     package->processFlags |= FacePipelinePackage::ProcessedByTrainer;
     emit processed(package);
 }
 
 void Trainer::aboutToDeactivate()
 {
-    if (catcher)
-    {
-        catcher->cancel();
-    }
+    imageRetriever.cancel();
 }
 
 // ----------------------------------------------------------------------------------------
@@ -894,7 +999,6 @@ FacePipeline::Private::Private(FacePipeline* const q)
     databaseWriter       = 0;
     trainer              = 0;
     benchmarker          = 0;
-    thumbnailLoadThread  = 0;
     priority             = QThread::LowPriority;
     started              = false;
     infosForFiltering    = 0;
@@ -1089,7 +1193,7 @@ void FacePipeline::Private::stop()
     ParallelPipes* pipes       = 0;
     DynamicThread* thread      = 0;
 
-    foreach(QObject* const  element, pipeline)
+    foreach(QObject* const element, pipeline)
     {
         if ((workerObject = qobject_cast<WorkerObject*>(element)))
         {
@@ -1160,24 +1264,22 @@ void FacePipeline::Private::applyPriority()
         }
     }
 
-    if (thumbnailLoadThread)
+    foreach (ThumbnailLoadThread* thread, thumbnailLoadThreads)
     {
-        thumbnailLoadThread->setPriority(priority);
+        thread->setPriority(priority);
     }
 }
 
-void FacePipeline::Private::createThumbnailLoadThread()
+ThumbnailLoadThread* FacePipeline::Private::createThumbnailLoadThread()
 {
-    if (!thumbnailLoadThread)
-    {
-        thumbnailLoadThread = new ThumbnailLoadThread;
-        thumbnailLoadThread->setPixmapRequested(false);
-        thumbnailLoadThread->setThumbnailSize(ThumbnailLoadThread::maximumThumbnailSize());
-        // KFaceIface::Image::recommendedSizeForRecognition()
-        thumbnailLoadThread->setPriority(priority);
-    }
+    ThumbnailLoadThread* thumbnailLoadThread = new ThumbnailLoadThread;
+    thumbnailLoadThread->setPixmapRequested(false);
+    thumbnailLoadThread->setThumbnailSize(ThumbnailLoadThread::maximumThumbnailSize());
+    // KFaceIface::Image::recommendedSizeForRecognition()
+    thumbnailLoadThread->setPriority(priority);
 
-    //FaceIface::faceRectDisplayMargin()
+    thumbnailLoadThreads << thumbnailLoadThread;
+    return thumbnailLoadThread;
 }
 
 // ----------------------------------------------------------------------------------------
@@ -1200,7 +1302,7 @@ FacePipeline::~FacePipeline()
     delete d->recognitionWorker;
     delete d->databaseWriter;
     delete d->trainer;
-    delete d->thumbnailLoadThread;
+    qDeleteAll(d->thumbnailLoadThreads);
     delete d->benchmarker;
     delete d;
 }
@@ -1225,6 +1327,12 @@ void FacePipeline::plugDatabaseFilter(FilterMode mode)
     d->databaseFilter = new ScanStateFilter(mode, d);
 }
 
+void FacePipeline::plugRerecognizingDatabaseFilter()
+{
+    plugDatabaseFilter(ReadUnconfirmedFaces);
+    d->databaseFilter->tasks = FacePipelineDatabaseFace::ForRecognition;
+}
+
 void FacePipeline::plugRetrainingDatabaseFilter()
 {
     plugDatabaseFilter(ReadConfirmedFaces);
@@ -1257,7 +1365,7 @@ void FacePipeline::plugParallelFaceDetectors()
 
     for (int i = 0; i < n; ++i)
     {
-        DetectionWorker* worker = new DetectionWorker(d);
+        DetectionWorker* const worker = new DetectionWorker(d);
 
         connect(d, SIGNAL(accuracyChanged(double)),
                 worker, SLOT(setAccuracy(double)));
@@ -1269,8 +1377,9 @@ void FacePipeline::plugParallelFaceDetectors()
 void FacePipeline::plugFaceRecognizer()
 {
     d->recognitionWorker = new RecognitionWorker(d);
+    d->createThumbnailLoadThread();
 
-    connect(d, SIGNAL(thresholdChanged(double)),
+    connect(d, SIGNAL(accuracyChanged(double)),
             d->recognitionWorker, SLOT(setThreshold(double)));
 }
 
