@@ -6,7 +6,7 @@
  * Date        : 2009-28-04
  * Description : first run assistant dialog
  *
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -35,7 +35,7 @@ class WelcomePage : public AssistantDlgPage
 {
 public:
 
-    WelcomePage(KAssistantDialog* dlg);
+    explicit WelcomePage(KAssistantDialog* const dlg);
     ~WelcomePage();
 };
 
