@@ -54,6 +54,7 @@ class EditorTool::Private
 public:
 
     Private() :
+        initPreview(false),
         version(0),
         view(0),
         timer(0),
@@ -62,6 +63,7 @@ public:
     {
     }
 
+    bool                   initPreview;
     QString                helpAnchor;
     QString                name;
     int                    version;
@@ -96,6 +98,11 @@ void EditorTool::init()
     QTimer::singleShot(0, this, SLOT(slotInit()));
 }
 
+void EditorTool::setInitPreview(bool b)
+{
+    d->initPreview = b;
+}
+
 QPixmap EditorTool::toolIcon() const
 {
     return d->icon;
@@ -211,6 +218,9 @@ void EditorTool::slotInit()
     // Unlock signals from preview and settings widgets when init is done.
     d->view->blockSignals(false);
     d->settings->blockSignals(false);
+
+    if (d->initPreview)
+        slotTimer();
 }
 
 void EditorTool::setToolHelp(const QString& anchor)
