@@ -39,7 +39,6 @@
 
 // Local includes
 
-#include "daboutdata.h"
 #include "editorwindow.h"
 #include "versionmanager.h"
 
@@ -70,8 +69,6 @@ class EditorWindow::Private
 public:
 
     Private() :
-        removeFullScreenButton(false),
-        fullScreenHideToolBar(false),
         cmViewIndicator(0),
         underExposureIndicator(0),
         overExposureIndicator(0),
@@ -79,10 +76,10 @@ public:
         imagepluginsActionCollection(0),
         copyAction(0),
         cropAction(0),
+        autoCropAction(0),
         filePrintAction(0),
         flipHorizAction(0),
         flipVertAction(0),
-        libsInfoAction(0),
         rotateLeftAction(0),
         rotateRightAction(0),
         selectAllAction(0),
@@ -109,8 +106,7 @@ public:
         zoomBar(0),
         previewToolBar(0),
         exposureSettings(0),
-        toolIface(0),
-        about(0)
+        toolIface(0)
     {
     }
 
@@ -125,9 +121,6 @@ public:
 
     static const QString       configAutoZoomEntry;
     static const QString       configBackgroundColorEntry;
-    static const QString       configFullScreenEntry;
-    static const QString       configFullScreenHideThumbBarEntry;
-    static const QString       configFullScreenHideToolBarEntry;
     static const QString       configJpeg2000CompressionEntry;
     static const QString       configJpeg2000LossLessEntry;
     static const QString       configJpegCompressionEntry;
@@ -149,9 +142,6 @@ public:
     static const QString       configVerticalSplitterSizesEntry;
     static const QString       configVerticalSplitterStateEntry;
 
-    bool                       removeFullScreenButton;
-    bool                       fullScreenHideToolBar;
-
     QToolButton*               cmViewIndicator;
     QToolButton*               underExposureIndicator;
     QToolButton*               overExposureIndicator;
@@ -163,11 +153,11 @@ public:
     KAction*                   contributeAction;
     KAction*                   copyAction;
     KAction*                   cropAction;
+    KAction*                   autoCropAction;
     KAction*                   donateMoneyAction;
     KAction*                   filePrintAction;
     KAction*                   flipHorizAction;
     KAction*                   flipVertAction;
-    KAction*                   libsInfoAction;
     KAction*                   rawCameraListAction;
     KAction*                   rotateLeftAction;
     KAction*                   rotateRightAction;
@@ -196,8 +186,6 @@ public:
 
     ActionCategorizedView*     selectToolsActionView;
 
-    QList<int>                 fullscreenSizeBackup;
-
     ICCSettingsContainer*      ICCSettings;
 
     DZoomBar*                  zoomBar;
@@ -209,14 +197,11 @@ public:
 
     VersionManager             defaultVersionManager;
 
-    DAboutData*                about;
+    QList<int>                 fullscreenSizeBackup;
 };
 
 const QString EditorWindow::Private::configAutoZoomEntry("AutoZoom");
 const QString EditorWindow::Private::configBackgroundColorEntry("BackgroundColor");
-const QString EditorWindow::Private::configFullScreenEntry("FullScreen");
-const QString EditorWindow::Private::configFullScreenHideThumbBarEntry("FullScreenHideThumbBar");
-const QString EditorWindow::Private::configFullScreenHideToolBarEntry("FullScreen Hide ToolBar");
 const QString EditorWindow::Private::configJpeg2000CompressionEntry("JPEG2000Compression");
 const QString EditorWindow::Private::configJpeg2000LossLessEntry("JPEG2000LossLess");
 const QString EditorWindow::Private::configJpegCompressionEntry("JPEGCompression");
