@@ -426,12 +426,6 @@ void ImageWindow::setupActions()
 {
     setupStandardActions();
 
-    // Provides a menu entry that allows showing/hiding the toolbar(s)
-    setStandardToolBarMenuEnabled(true);
-
-    // Provides a menu entry that allows showing/hiding the statusbar
-    createStandardStatusBarAction();
-
     d->toMainWindowAction = new KAction(KIcon("view-list-icons"),
                                         i18nc("@action Finish editing, close editor, back to main window", "Close Editor"), this);
     connect(d->toMainWindowAction, SIGNAL(triggered()), this, SLOT(slotToMainWindow()));
@@ -465,9 +459,7 @@ void ImageWindow::setupActions()
 
     // ---------------------------------------------------------------------------------
 
-    d->dbStatAction = new KAction(KIcon("network-server-database"), i18n("Database Statistics"), this);
-    connect(d->dbStatAction, SIGNAL(triggered()), this, SLOT(slotDBStat()));
-    actionCollection()->addAction("editorwindow_dbstat", d->dbStatAction);
+    createHelpActions(); 
 
     // ---------------------------------------------------------------------------------
 
@@ -478,13 +470,9 @@ void ImageWindow::slotSetupChanged()
 {
     applyStandardSettings();
 
-    MetadataSettingsContainer writeSettings = MetadataSettings::instance()->settings();
-    m_setExifOrientationTag                 = writeSettings.exifSetOrientation;
-    m_canvas->setExifOrient(writeSettings.exifRotate);
-
     VersionManagerSettings versionSettings = AlbumSettings::instance()->getVersionManagerSettings();
     d->versionManager.setSettings(versionSettings);
-    m_nonDestructive = versionSettings.enabled;
+    m_nonDestructive                       = versionSettings.enabled;
     toggleNonDestructiveActions();
 
     d->rightSideBar->setStyle(AlbumSettings::instance()->getSidebarTitleStyle());
@@ -597,12 +585,33 @@ void ImageWindow::slotThumbBarImageSelected(const ImageInfo& info)
 
 void ImageWindow::slotDroppedOnThumbbar(const QList<ImageInfo>& infos)
 {
+    // Check whether dropped image list is empty
+
     if (infos.isEmpty())
     {
         return;
     }
 
-    loadImageInfos(infos, infos.first(), QString());
+    // Create new list and images that are not present currently in the thumbbar
+
+    QList<ImageInfo> toAdd;
+
+    foreach(ImageInfo it, infos)
+    {
+        QModelIndex index(d->imageFilterModel->indexForImageInfo(it));
+
+        if( !index.isValid() )
+        {
+            toAdd.append(it);
+        }
+    }
+
+    // Loading images if new images are dropped
+
+    if(!toAdd.isEmpty())
+    {
+        loadImageInfos(toAdd, toAdd.first(), QString());
+    }
 }
 
 void ImageWindow::slotFileOriginChanged(const QString& filePath)
@@ -1335,8 +1344,6 @@ void ImageWindow::slotFilePrint()
 
 void ImageWindow::slideShow(SlideShowSettings& settings)
 {
-    float cnt;
-    int i               = 0;
     m_cancelSlideShow   = false;
     settings.exifRotate = MetadataSettings::instance()->settings().exifRotate;
 
@@ -1347,8 +1354,8 @@ void ImageWindow::slideShow(SlideShowSettings& settings)
         m_nameLabel->progressBarMode(StatusProgressBar::CancelProgressBarMode,
                                      i18n("Preparing slideshow. Please wait..."));
 
-        cnt = (float)d->imageInfoModel->rowCount();
-
+        float cnt = (float)d->imageInfoModel->rowCount();
+        int i = 0;
         foreach(const ImageInfo& info, d->imageInfoModel->imageInfos())
         {
             SlidePictureInfo pictInfo;
