@@ -6,7 +6,7 @@
  * Date        : 2008-08-20
  * Description : Raw import tool
  *
- * Copyright (C) 2008-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -51,11 +51,11 @@
 namespace Digikam
 {
 
-class RawImport::RawImportPriv
+class RawImport::Private
 {
 public:
 
-    RawImportPriv() :
+    Private() :
         settingsBox(0),
         previewWidget(0)
     {
@@ -67,8 +67,8 @@ public:
     DImg            postProcessedImage;
 };
 
-RawImport::RawImport(const KUrl& url, QObject* parent)
-    : EditorToolThreaded(parent), d(new RawImportPriv)
+RawImport::RawImport(const KUrl& url, QObject* const parent)
+    : EditorToolThreaded(parent), d(new Private)
 {
     d->previewWidget = new RawPreview(url, 0);
     d->settingsBox   = new RawSettingsBox(url, 0);
@@ -78,7 +78,6 @@ RawImport::RawImport(const KUrl& url, QObject* parent)
     setProgressMessage(i18n("Post Processing"));
     setToolView(d->previewWidget);
     setToolSettings(d->settingsBox);
-    init();
 }
 
 RawImport::~RawImport()
@@ -188,20 +187,20 @@ void RawImport::slotLoadingStarted()
 void RawImport::slotDemosaicedImage()
 {
     d->settingsBox->setDemosaicedImage(d->previewWidget->demosaicedImage());
-    slotEffect();
+    slotPreview();
 }
 
-void RawImport::prepareEffect()
+void RawImport::preparePreview()
 {
     DImg postImg = d->previewWidget->demosaicedImage();
     setFilter(dynamic_cast<DImgThreadedFilter*>(new RawProcessingFilter(&postImg, this, rawDecodingSettings())));
 }
 
-void RawImport::putPreviewData()
+void RawImport::setPreviewImage()
 {
     // Preserve metadata from loaded image, and take post-processed image data
     d->postProcessedImage = d->previewWidget->demosaicedImage().copyMetaData();
-    DImg data = filter()->getTargetImage();
+    DImg data             = filter()->getTargetImage();
     d->postProcessedImage.putImageData(data.width(), data.height(), data.sixteenBit(), data.hasAlpha(),
                                        data.stripImageData(), false);
     d->previewWidget->setPostProcessedImage(d->postProcessedImage);
@@ -232,7 +231,7 @@ void RawImport::slotOk()
     // NOTE: work around B.K.O #211810
     if (d->settingsBox->curvesWidget()->isSixteenBits() != d->settingsBox->settings().rawPrm.sixteenBitsImage)
     {
-        d->settingsBox->curvesWidget()->updateData(0, 0, 0, d->settingsBox->settings().rawPrm.sixteenBitsImage);
+        d->settingsBox->curvesWidget()->updateData(DImg(0, 0, d->settingsBox->settings().rawPrm.sixteenBitsImage));
     }
 
     EditorTool::slotOk();
