@@ -66,7 +66,6 @@
 #include "digikamapp.h"
 #include "thememanager.h"
 #include "dimg.h"
-#include "dlogoaction.h"
 #include "dmetadata.h"
 #include "metadatasettings.h"
 #include "albumsettings.h"
@@ -538,8 +537,8 @@ void LightTableWindow::setupActions()
     d->clearOnCloseAction->setWhatsThis(i18n("Remove all images from the light table when it is closed"));
     actionCollection()->addAction("lighttable_clearonclose", d->clearOnCloseAction);
 
-    d->showThumbBarAction = d->barViewDock->getToggleAction(this);
-    actionCollection()->addAction("lighttable_showthumbbar", d->showThumbBarAction);
+    d->showBarAction = d->barViewDock->getToggleAction(this);
+    actionCollection()->addAction("lighttable_showthumbbar", d->showBarAction);
 
     createFullScreenAction("lighttable_fullscreen");
 
@@ -617,16 +616,7 @@ void LightTableWindow::setupActions()
 
     // -- Standard 'Help' menu actions ---------------------------------------------
 
-    d->about = new DAboutData(this);
-    d->about->registerHelpActions();
-
-    d->libsInfoAction = new KAction(KIcon("help-about"), i18n("Components Information"), this);
-    connect(d->libsInfoAction, SIGNAL(triggered()), this, SLOT(slotComponentsInfo()));
-    actionCollection()->addAction("lighttable_librariesinfo", d->libsInfoAction);
-
-    d->dbStatAction = new KAction(KIcon("network-server-database"), i18n("Database Statistics"), this);
-    connect(d->dbStatAction, SIGNAL(triggered()), this, SLOT(slotDBStat()));
-    actionCollection()->addAction("lighttable_dbstat", d->dbStatAction);
+    createHelpActions();
 
     // Provides a menu entry that allows showing/hiding the toolbar(s)
     setStandardToolBarMenuEnabled(true);
@@ -643,8 +633,6 @@ void LightTableWindow::setupActions()
 
     // ---------------------------------------------------------------------------------
 
-    actionCollection()->addAction("logo_action", new DLogoAction(this));
-
     createGUI(xmlFile());
 
     d->showMenuBarAction->setChecked(!menuBar()->isHidden());  // NOTE: workaround for B.K.O #171080
@@ -1623,4 +1611,12 @@ void LightTableWindow::showSideBars(bool visible)
     }
 }
 
+void LightTableWindow::customizedFullScreenMode(bool set)
+{
+    statusBarMenuAction()->setEnabled(!set);
+    toolBarMenuAction()->setEnabled(!set);
+    d->showMenuBarAction->setEnabled(!set);
+    d->showBarAction->setEnabled(!set);
+}
+
 }  // namespace Digikam
