@@ -30,6 +30,7 @@
 
 // Local includes
 
+#include "album.h"
 #include "facescansettings.h"
 #include "metadatasynchronizer.h"
 
@@ -46,7 +47,16 @@ public:
 
 public:
 
-    /// Find new items on whole collection
+    bool             wholeAlbums;
+    bool             wholeTags;
+
+    AlbumList        albums;
+    AlbumList        tags;
+
+    /// Use Multi-core CPU to process items.
+    bool             useMutiCoreCPU;
+
+    /// Find new items on whole collection.
     bool             newItems;
 
     /// Generate thumbnails
@@ -64,14 +74,14 @@ public:
     /// Similarity between items to compare, in percents.
     int              similarity;
 
-    /// Scan for faces
+    /// Scan for faces.
     bool             faceManagement;
-    /// Face detection settings
+    /// Face detection settings.
     FaceScanSettings faceSettings;
 
-    /// Sync metadata and DB
+    /// Sync metadata and DB.
     bool             metadataSync;
-    /// Sync direction (image metadata <-> DB)
+    /// Sync direction (image metadata <-> DB).
     int              syncDirection;
 };
 
