@@ -6,8 +6,8 @@
  * Date        : 2012-02-02
  * Description : maintenance tool
  *
- * Copyright (C) 2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2012 by Andi Clemens <andi dot clemens at gmail dot com>
+ * Copyright (C) 2012-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,7 +42,7 @@ class MaintenanceTool : public ProgressItem
 
 public:
 
-    MaintenanceTool(const QString& id, ProgressItem* parent = 0);
+    explicit MaintenanceTool(const QString& id, ProgressItem* const parent = 0);
     virtual ~MaintenanceTool();
 
     /** If true, show a notification message on desktop notification manager
@@ -52,6 +52,10 @@ public:
 
     void start();
 
+    /** Re-implement this method if your tool is able to use multi-core CPU to process item in parallel
+     */
+    virtual void setUseMultiCoreCPU(bool) {};
+
 Q_SIGNALS:
 
     /** Emit when process is done (not canceled).
@@ -66,8 +70,8 @@ protected Q_SLOTS:
 
 private:
 
-    class MaintenanceToolPriv;
-    MaintenanceToolPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 } // namespace Digikam
