@@ -6,7 +6,7 @@
  * Date        : 2010-03-16
  * Description : 8 to 16 bits color depth converter batch tool.
  *
- * Copyright (C) 2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,24 +25,24 @@
 
 // KDE includes
 
-#include <kiconloader.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
+#include <kglobal.h>
 
 // Local includes
 
 #include "dimg.h"
+#include "dimgbuiltinfilter.h"
 
 namespace Digikam
 {
 
-Convert8to16::Convert8to16(QObject* parent)
+Convert8to16::Convert8to16(QObject* const parent)
     : BatchTool("Convert8to16", ColorTool, parent)
 {
     setToolTitle(i18n("Convert to 16 bits"));
     setToolDescription(i18n("Convert color depth from 8 to 16 bits."));
-    setToolIcon(KIcon(SmallIcon("depth8to16")));
-    setNoSettingsWidget();
+    setToolIconName("depth8to16");
 }
 
 Convert8to16::~Convert8to16()
@@ -56,7 +56,8 @@ bool Convert8to16::toolOperations()
         return false;
     }
 
-    image().convertDepth(64);
+    DImgBuiltinFilter filter(DImgBuiltinFilter::ConvertTo16Bit);
+    applyFilter(&filter);
 
     return (savefromDImg());
 }
