@@ -6,7 +6,7 @@
  * Date        : 2010-03-15
  * Description : Anti-vignetting batch tool.
  *
- * Copyright (C) 2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -39,15 +39,18 @@ class AntiVignetting : public BatchTool
 
 public:
 
-    AntiVignetting(QObject* parent=0);
+    explicit AntiVignetting(QObject* const parent = 0);
     ~AntiVignetting();
 
     BatchToolSettings defaultSettings();
 
+    BatchTool* clone(QObject* const parent=0) const { return new AntiVignetting(parent); };
+
+    void registerSettingsWidget();
+
 private:
 
     bool toolOperations();
-    QWidget* createSettingsWidget();
 
 private Q_SLOTS:
 
