@@ -6,7 +6,7 @@
  * Date        : 2010-05-03
  * Description : blur image batch tool.
  *
- * Copyright (C) 2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -41,15 +41,18 @@ class Blur : public BatchTool
 
 public:
 
-    Blur(QObject* parent = 0);
+    explicit Blur(QObject* const parent = 0);
     ~Blur();
 
     BatchToolSettings defaultSettings();
 
+    BatchTool* clone(QObject* const parent=0) const { return new Blur(parent); };
+
+    void registerSettingsWidget();
+
 private:
 
     bool toolOperations();
-    QWidget* createSettingsWidget();
 
 private Q_SLOTS:
 
