@@ -6,8 +6,8 @@
  * Date        : 2009-05-02
  * Description : sharpen image batch tool.
  *
- * Copyright (C) 2009 by Matthias Welwarsky <matze at welwarsky dot de>
- * Copyright (C) 2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009      by Matthias Welwarsky <matze at welwarsky dot de>
+ * Copyright (C) 2010-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,15 +38,18 @@ class Sharpen : public BatchTool
 
 public:
 
-    Sharpen(QObject* parent=0);
+    explicit Sharpen(QObject* const parent = 0);
     ~Sharpen();
 
     BatchToolSettings defaultSettings();
 
+    BatchTool* clone(QObject* const parent=0) const { return new Sharpen(parent); };
+
+    void registerSettingsWidget();
+
 private:
 
     bool toolOperations();
-    QWidget* createSettingsWidget();
 
 private Q_SLOTS:
 
