@@ -39,11 +39,15 @@ class Flip : public BatchTool
 
 public:
 
-    Flip(QObject* parent = 0);
+    explicit Flip(QObject* parent = 0);
     ~Flip();
 
     BatchToolSettings defaultSettings();
 
+    BatchTool* clone(QObject* const parent=0) const { return new Flip(parent); };
+
+    void registerSettingsWidget();
+
 private:
 
     bool toolOperations();
