@@ -6,7 +6,7 @@
  * Date        : 2008-11-24
  * Description : Batch Tool Container.
  *
- * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,7 +30,6 @@
 #include <QFileInfo>
 #include <QPolygon>
 #include <QTemporaryFile>
-
 #include <QWidget>
 #include <QLabel>
 
@@ -70,6 +69,7 @@ public:
         cancel(false),
         last(false),
         observer(0),
+        toolGroup(BaseTool),
         rawLoadingRule(QueueSettings::DEMOSAICING)
     {
     }
@@ -116,9 +116,9 @@ public:
     {
     }
 
-    bool continueQuery(const DImg*)
+    bool continueQuery(const DImg* const)
     {
-        return !d->cancel;
+        return (!d->cancel);
     }
 
 private:
@@ -341,7 +341,7 @@ void BatchTool::setOutputUrlFromInputUrl()
 
 bool BatchTool::isRawFile(const KUrl& url) const
 {
-    QString rawFilesExt(KDcraw::rawFiles());
+    QString   rawFilesExt(KDcraw::rawFiles());
     QFileInfo fileInfo(url.toLocalFile());
     return (rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper()));
 }
@@ -356,8 +356,8 @@ bool BatchTool::loadToDImg() const
     if (d->rawLoadingRule == QueueSettings::USEEMBEDEDJPEG && isRawFile(inputUrl()))
     {
         QImage img;
-        bool ret = KDcraw::loadRawPreview(img, inputUrl().toLocalFile());
-        d->image = DImg(img);
+        bool   ret = KDcraw::loadRawPreview(img, inputUrl().toLocalFile());
+        d->image   = DImg(img);
         return ret;
     }
 
@@ -385,9 +385,9 @@ bool BatchTool::savefromDImg() const
     if (frm.isEmpty())
     {
         // In case of output support is not set for ex. with all tool which do not convert to new format.
-        d->image.prepareMetadataToSave(outputUrl().toLocalFile(), DImg::formatToMimeType(detectedFormat),
-                                       resetOrientation);
-        return(d->image.save(outputUrl().toLocalFile(), detectedFormat, d->observer));
+        d->image.prepareMetadataToSave(outputUrl().toLocalFile(), DImg::formatToMimeType(detectedFormat), resetOrientation);
+        bool b = d->image.save(outputUrl().toLocalFile(), detectedFormat, d->observer);
+        return b;
     }
 
     d->image.prepareMetadataToSave(outputUrl().toLocalFile(), frm, resetOrientation);
@@ -417,7 +417,7 @@ bool BatchTool::apply()
         if (it.value().canConvert<QPolygon>())
         {
             QPolygon pol = it.value().value<QPolygon>();
-            int size     = pol.size() > 20 ? 20 : pol.size();
+            int     size = (pol.size() > 20) ? 20 : pol.size();
             QString tmp;
             tmp.append(QString("[%1 items] : ").arg(pol.size()));
 
