@@ -213,7 +213,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setText(i18n("Width"), i18n("Find pictures with a width between"));
         field->setBetweenText(i18nc("Find pictures with a width between...and...", "and"));
         field->setNumberPrefixAndSuffix(QString(), i18nc("Pixels", "px"));
-        field->setBoundary(1, 100000, 250);
+        field->setBoundary(1, 1000000, 250);
         field->setSuggestedValues(QList<int>()
                                   << 50 << 100 << 200 << 300 << 400 << 500 << 600 << 700 << 800 << 900
                                   << 1000 << 1250 << 1500 << 1750 << 2000 << 3000 << 4000
@@ -230,7 +230,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setText(i18n("Height"), i18n("Find pictures with a height between"));
         field->setBetweenText(i18nc("Find pictures with a height between...and...", "and"));
         field->setNumberPrefixAndSuffix(QString(), i18nc("Pixels", "px"));
-        field->setBoundary(1, 100000, 250);
+        field->setBoundary(1, 1000000, 250);
         field->setSuggestedValues(QList<int>()
                                   << 50 << 100 << 200 << 300 << 400 << 500 << 600 << 700 << 800 << 900
                                   << 1000 << 1250 << 1500 << 1750 << 2000 << 3000 << 4000
@@ -317,7 +317,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setBetweenText("-");
         field->setNoValueText("f/#");
         field->setNumberPrefixAndSuffix("f/", QString());
-        field->setBoundary(0.3, 128, 1, 0.1);
+        field->setBoundary(0.3, 65536, 1, 0.1);
         field->setSuggestedValues(QList<double>()
                                   << 0.5 << 0.7 << 1.0 << 1.4 << 2 << 2.8 << 4 << 5.6
                                   << 8 << 11 << 16 << 22 << 32 << 45 << 64 << 90 << 128
@@ -334,7 +334,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setText(i18n("Focal length"), i18n("Focal length of the lens"));
         field->setBetweenText("-");
         field->setNumberPrefixAndSuffix(QString(), "mm");
-        field->setBoundary(0, 20000, 10);
+        field->setBoundary(0, 200000, 10);
         field->setSuggestedValues(QList<int>()
                                   << 10 << 15 << 20 << 25 << 30 << 40 << 50 << 60 << 70 << 80 << 90
                                   << 100 << 150 << 200 << 250 << 300 << 400 << 500 << 750 << 1000
@@ -351,7 +351,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setText(i18n("Focal length"), i18n("35mm equivalent focal length"));
         field->setBetweenText("-");
         field->setNumberPrefixAndSuffix(QString(), "mm");
-        field->setBoundary(0, 10000, 10);
+        field->setBoundary(0, 200000, 10);
         field->setSuggestedValues(QList<int>()
                                   << 8 << 10 << 15 << 16 << 20 << 28 << 30 << 40 << 50 << 60 << 70 << 80
                                   << 90 << 100 << 150 << 200 << 250 << 300 << 400 << 500 << 750 << 1000
@@ -369,11 +369,11 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setBetweenText("-");
         field->setNumberPrefixAndSuffix(QString(), "s");
         field->enableFractionMagic("1/"); // it's 1/250, not 250 as in the spin box
-        field->setBoundary(120, -10000, 10); // negative is 1/
+        field->setBoundary(86400, -1024000, 10); // negative is 1/
         field->setSuggestedValues(QList<int>()
                                   << 30 << 15 << 8 << 4 << 2 << 1 << -2 << -4 << -8 << -15
                                   << -30 << -50 << -60 << -100 << -125 << -150 << -200
-                                  << -250 << -500 << -750 << -1000 << -2000 << -4000 << -8000
+                                  << -250 << -500 << -750 << -1000 << -2000 << -4000 << -8000 << -16000
                                  );
         field->setSuggestedInitialValue(-200);
         field->setSingleSteps(2000, 5);
@@ -406,7 +406,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setFieldName(name);
         field->setText(i18n("Sensitivity"), i18n("ISO film speed (linear scale, ASA)"));
         field->setBetweenText("-");
-        field->setBoundary(5, 6400, 50);
+        field->setBoundary(0, 2000000, 50);
         field->setSuggestedValues(QList<int>()
                                   << 6 << 8 << 10 << 12 << 16 << 20 << 25 << 32 << 40 << 50 << 64
                                   << 80 << 100 << 125 << 160 << 200 << 250 << 320 << 400 << 500
@@ -448,7 +448,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setText(i18n("White balance"), i18n("Color temperature used for white balance"));
         field->setBetweenText("-");
         field->setNumberPrefixAndSuffix(QString(), "K");
-        field->setBoundary(1, 1000, 100);
+        field->setBoundary(1, 100000, 100);
         return field;
     }
     else if (name == "meteringmode")
@@ -469,7 +469,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setText(i18n("Subject Distance"), i18n("Distance of the subject from the lens"));
         field->setBetweenText("-");
         field->setNumberPrefixAndSuffix(QString(), "m");
-        field->setBoundary(0.5, 128, 1, 0.1);
+        field->setBoundary(0, 50000, 1, 0.1);
         return field;
     }
     else if (name == "subjectdistancecategory")
@@ -543,6 +543,137 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         field->setText(QString(), i18n("Find pictures that have associated all these words:"));
         return field;
     }
+    else if (name == "aspectratioimg")
+    {
+        SearchFieldText* const field = new SearchFieldText(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Aspect Ratio"), i18n("Return pictures with the aspect ratio"));
+        return field;
+    }
+    else if (name == "pixelsize")
+    {
+        SearchFieldRangeInt* const field = new SearchFieldRangeInt(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Pixel Size"), i18n("Value of (Width * Height) between"));
+        field->setBetweenText("and");
+        field->setNumberPrefixAndSuffix(QString(), "px");
+        field->setBoundary(1, 2000000000, 100);
+        return field;
+    }
+
+
+    else if (name == "videoaspectratio")
+    {
+        SearchFieldChoice* field = new SearchFieldChoice(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Aspect Ratio"), i18n("Return video with the frame aspect ratio"));
+        QStringList ratio;
+        ratio << "4:3"<< "4:3";
+        ratio << "3:2"<< "3:2";
+        ratio << "16:9" << "16:9";
+        ratio << "2:1" << "2:1";
+        // TODO: add more possible aspect ratio
+        field->setChoice(ratio);
+        return field;
+    }
+    else if (name == "videoduration")
+    {
+        SearchFieldRangeInt* field = new SearchFieldRangeInt(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Duration"), i18n("Length of the video"));
+        field->setBetweenText(i18nc("Find video with a lenght between...and...", "and"));
+        field->setNumberPrefixAndSuffix(QString(), i18nc("Seconds", "s"));
+        field->setBoundary(1, 10000, 100);
+        field->setSuggestedValues(QList<int>()
+                                  << 10 << 30 << 60 << 90 << 120 << 240 << 360 << 500 << 1000 << 2000
+                                  << 3000 << 4000 << 5000 << 6000 << 7000 << 8000 << 9000 << 10000
+                                  // TODO : adjust default values
+                                 );
+        field->setSuggestedInitialValue(10);
+        field->setSingleSteps(10, 100);
+        return field;
+    }
+    else if (name == "videoframerate")
+    {
+        SearchFieldRangeInt* field = new SearchFieldRangeInt(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Frame Rate"), i18n("Return video with the frame rate"));
+        field->setBetweenText(i18nc("Find video with frame rate between...and...", "and"));
+        field->setNumberPrefixAndSuffix(QString(), i18nc("Frames per Second", "fps"));
+        field->setBoundary(10, 60, 5);
+        field->setSuggestedValues(QList<int>()
+                                  << 10 << 15 << 20 << 25 << 30 << 35 << 40 << 45 << 55 << 60
+                                  // TODO : adjust default values
+                                 );
+        field->setSuggestedInitialValue(10);
+        field->setSingleSteps(5, 60);
+        return field;
+    }
+    else if (name == "videocodec")
+    {
+        SearchFieldChoice* field = new SearchFieldChoice(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Codec"), i18n("Return video codec"));
+        QStringList codec;
+        codec << "avi"  << "Audio Video Interleave";
+        codec << "mov"  << "QuickTime";
+        codec << "mp4"  << "MPEG Layer 4";
+        codec << "3gp"  << "3GPP";
+        codec << "divx" << "DivX";
+        codec << "wma"  << "Windows Media Video";
+        codec << "mkv"  << "Matroska";
+        codec << "s263" << "H.263";
+        codec << "mjpg" << "Motion JPEG";
+        // TODO: add more possible codec
+        field->setChoice(codec);
+        return field;
+    }
+    else if (name == "videoaudiobitrate")
+    {
+        SearchFieldRangeInt* field = new SearchFieldRangeInt(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Audio Bit Rate"), i18n("Return video audio bits rate"));
+        field->setBetweenText(i18nc("Find video with audio bit rate between...and...", "and"));
+        field->setNumberPrefixAndSuffix(QString(), i18nc("Bits per Second", "bps"));
+        field->setBoundary(1000, 100000, 1000);
+        field->setSuggestedValues(QList<int>()
+                                  << 1000 << 4000 << 8000 << 12000 << 16000 << 20000 << 30000 << 40000 << 50000
+                                  << 60000 << 700000 << 800000 << 900000 << 100000
+                                  // TODO : adjust default values
+                                 );
+        field->setSuggestedInitialValue(1000);
+        field->setSingleSteps(1000, 1000);
+        return field;
+    }
+    else if (name == "videoaudiochanneltype")
+    {
+        SearchFieldChoice* field = new SearchFieldChoice(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Audio Channel Type"), i18n("Return video audio Channel Type"));
+        QStringList type;
+        type << "1" << i18n("Mono");
+        type << "2" << i18n("Stereo");
+        // TODO: add more possible audio channel type
+        field->setChoice(type);
+        return field;
+    }
+    else if (name == "videoaudiocompressor")
+    {
+        SearchFieldChoice* field = new SearchFieldChoice(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Audio Compressor"), i18n("Return video audio Compressor"));
+        QStringList type;
+        type << "raw" << "RAW";
+        type << "mp3" << "MPEG Layer 3";
+        type << "mp4a" << "MPEG4 Audio";
+        type << "samr" << "Adaptive Multi-rate Audio";
+        type << "sowt" << "Apple QuickTime SWOT Little Endian PCM Audio";
+        type << "Microsoft PCM" << "Microsoft PCM";
+        // TODO: add more possible audio compressor
+        field->setChoice(type);
+        return field;
+    }
+
     else
     {
         kWarning() << "SearchField::createField: cannot create SearchField for" << name;
@@ -2127,7 +2258,7 @@ void SearchFieldAlbum::read(SearchXmlCachingReader& reader)
 
 void SearchFieldAlbum::write(SearchXmlWriter& writer)
 {
-    QList<Album*> checkedAlbums = m_model->checkedAlbums();
+    AlbumList checkedAlbums = m_model->checkedAlbums();
 
     if (checkedAlbums.isEmpty())
     {
@@ -2136,7 +2267,7 @@ void SearchFieldAlbum::write(SearchXmlWriter& writer)
 
     QList<int> albumIds;
 
-    foreach(Album* album, checkedAlbums)
+    foreach(Album* const album, checkedAlbums)
     {
         albumIds << album->id();
     }
