@@ -529,7 +529,7 @@ void Setup::okClicked()
             return;
         }
 
-        new ThumbsGenerator();
+        new ThumbsGenerator(true, -1);
     }
 
     accept();
