@@ -6,8 +6,8 @@
  * Date        : 2003-02-10
  * Description : camera setup tab.
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * Copyright (C) 2006-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -62,6 +62,10 @@
 #include "gpcamera.h"
 #include "filtercombo.h"
 #include "importfilters.h"
+#include "dfontselect.h"
+#include "importsettings.h"
+#include "fullscreensettings.h"
+#include "dxmlguiwindow.h"
 
 namespace Digikam
 {
@@ -109,11 +113,11 @@ private:
 
 // -------------------------------------------------------------------
 
-class CameraAutoDetectThread::CameraAutoDetectThreadPriv
+class CameraAutoDetectThread::Private
 {
 public:
 
-    CameraAutoDetectThreadPriv()
+    Private()
     {
         result = 0;
     }
@@ -125,7 +129,7 @@ public:
 };
 
 CameraAutoDetectThread::CameraAutoDetectThread(QObject* const parent)
-    : DBusyThread(parent), d(new CameraAutoDetectThreadPriv)
+    : DBusyThread(parent), d(new Private)
 {
     d->result = -1;
 }
@@ -158,11 +162,11 @@ QString CameraAutoDetectThread::port() const
 
 // -------------------------------------------------------------------
 
-class SetupCamera::SetupCameraPriv
+class SetupCamera::Private
 {
 public:
 
-    SetupCameraPriv() :
+    Private() :
         addButton(0),
         removeButton(0),
         editButton(0),
@@ -170,20 +174,34 @@ public:
         importAddButton(0),
         importRemoveButton(0),
         importEditButton(0),
-        useDateFromMetadata(0),
+        useFileMetadata(0),
         turnHighQualityThumbs(0),
         useDefaultTargetAlbum(0),
+        iconShowNameBox(0),
+        iconShowSizeBox(0),
+        iconShowDateBox(0),
+        iconShowResolutionBox(0),
+        iconShowTagsBox(0),
+        iconShowOverlaysBox(0),
+        iconShowRatingBox(0),
+        iconShowFormatBox(0),
+        previewLoadFullImageSize(0),
+        previewItemsWhileDownload(0),
+        previewShowIcons(0),
+        leftClickActionComboBox(0),
+        iconViewFontSelect(0),
         target1AlbumSelector(0),
         listView(0),
         importListView(0),
         tab(0),
         ignoreNamesEdit(0),
-        ignoreExtensionsEdit(0)
+        ignoreExtensionsEdit(0),
+        fullScreenSettings(0)
     {
     }
 
     static const QString configGroupName;
-    static const QString configUseMetadataDateEntry;
+    static const QString configUseFileMetadata;
     static const QString configTrunHighQualityThumbs;
     static const QString configUseDefaultTargetAlbum;
     static const QString configDefaultTargetAlbumId;
@@ -197,10 +215,27 @@ public:
     QPushButton*         importRemoveButton;
     QPushButton*         importEditButton;
 
-    QCheckBox*           useDateFromMetadata;
+    QCheckBox*           useFileMetadata;
     QCheckBox*           turnHighQualityThumbs;
     QCheckBox*           useDefaultTargetAlbum;
 
+    QCheckBox*           iconShowNameBox;
+    QCheckBox*           iconShowSizeBox;
+    QCheckBox*           iconShowDateBox;
+    QCheckBox*           iconShowResolutionBox;
+    QCheckBox*           iconShowTagsBox;
+    QCheckBox*           iconShowOverlaysBox;
+    QCheckBox*           iconShowRatingBox;
+    QCheckBox*           iconShowFormatBox;
+    QCheckBox*           previewLoadFullImageSize;
+    QCheckBox*           previewItemsWhileDownload;
+    QCheckBox*           previewShowIcons;
+
+    KComboBox*           leftClickActionComboBox;
+
+    DFontSelect*         iconViewFontSelect;
+
+
     AlbumSelectWidget*   target1AlbumSelector;
 
     QTreeWidget*         listView;
@@ -212,27 +247,29 @@ public:
     QLineEdit*           ignoreExtensionsEdit;
 
     FilterList           filters;
+
+    FullScreenSettings*  fullScreenSettings;
 };
 
-const QString SetupCamera::SetupCameraPriv::configGroupName("Camera Settings");
-const QString SetupCamera::SetupCameraPriv::configUseMetadataDateEntry("UseThemeBackgroundColor");
-const QString SetupCamera::SetupCameraPriv::configTrunHighQualityThumbs("TurnHighQualityThumbs");
-const QString SetupCamera::SetupCameraPriv::configUseDefaultTargetAlbum("UseDefaultTargetAlbum");
-const QString SetupCamera::SetupCameraPriv::configDefaultTargetAlbumId("DefaultTargetAlbumId");
-const QString SetupCamera::SetupCameraPriv::importFiltersConfigGroupName("Import Filters");
+const QString SetupCamera::Private::configGroupName("Camera Settings");
+const QString SetupCamera::Private::configUseFileMetadata("UseFileMetadata");
+const QString SetupCamera::Private::configTrunHighQualityThumbs("TurnHighQualityThumbs");
+const QString SetupCamera::Private::configUseDefaultTargetAlbum("UseDefaultTargetAlbum");
+const QString SetupCamera::Private::configDefaultTargetAlbumId("DefaultTargetAlbumId");
+const QString SetupCamera::Private::importFiltersConfigGroupName("Import Filters");
 
 SetupCamera::SetupCamera(QWidget* const parent)
-    : QScrollArea(parent), d(new SetupCameraPriv)
+    : QScrollArea(parent), d(new Private)
 {
-    d->tab            = new KTabWidget(viewport());
+    d->tab               = new KTabWidget(viewport());
     setWidget(d->tab);
     setWidgetResizable(true);
 
-    QWidget* panel    = new QWidget(d->tab);
+    QWidget* const panel = new QWidget(d->tab);
     panel->setAutoFillBackground(false);
 
-    QGridLayout* grid = new QGridLayout(panel);
-    d->listView       = new QTreeWidget(panel);
+    QGridLayout* const grid = new QGridLayout(panel);
+    d->listView             = new QTreeWidget(panel);
     d->listView->setColumnCount(4);
     d->listView->setRootIsDecorated(false);
     d->listView->setSelectionMode(QAbstractItemView::SingleSelection);
@@ -272,9 +309,8 @@ SetupCamera::SetupCamera(QWidget* const parent)
 
     // -------------------------------------------------------------
 
-    QSpacerItem* spacer = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);
-
-    KUrlLabel* gphotoLogoLabel = new KUrlLabel(panel);
+    QSpacerItem* const spacer        = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);
+    KUrlLabel* const gphotoLogoLabel = new KUrlLabel(panel);
     gphotoLogoLabel->setText(QString());
     gphotoLogoLabel->setUrl("http://www.gphoto.org");
     gphotoLogoLabel->setPixmap(QPixmap(KStandardDirs::locate("data", "digikam/data/logo-gphoto.png")));
@@ -303,20 +339,20 @@ SetupCamera::SetupCamera(QWidget* const parent)
 
     // -------------------------------------------------------------
 
-    QWidget* panel2          = new QWidget(d->tab);
+    QWidget* const panel2     = new QWidget(d->tab);
     panel2->setAutoFillBackground(false);
 
-    QVBoxLayout* layout      = new QVBoxLayout(panel2);
-    d->useDateFromMetadata   = new QCheckBox(i18n("Use date from metadata to sort items instead file-system date (makes connection slower)"), panel2);
-    d->turnHighQualityThumbs = new QCheckBox(i18n("Turn on high quality thumbnail loading (slower loading)"), panel2);
-    d->useDefaultTargetAlbum = new QCheckBox(i18n("Use a default target album to download from camera"), panel2);
-    d->target1AlbumSelector  = new AlbumSelectWidget(panel2);
+    QVBoxLayout* const layout = new QVBoxLayout(panel2);
+    d->useFileMetadata        = new QCheckBox(i18n("Use file metadata (makes connection slower)"), panel2);
+    d->turnHighQualityThumbs  = new QCheckBox(i18n("Turn on high quality thumbnail loading (slower loading)"), panel2);
+    d->useDefaultTargetAlbum  = new QCheckBox(i18n("Use a default target album to download from camera"), panel2);
+    d->target1AlbumSelector   = new AlbumSelectWidget(panel2);
 
     d->tab->insertTab(1, panel2, i18n("Behavior"));
 
     layout->setMargin(KDialog::spacingHint());
     layout->setSpacing(KDialog::spacingHint());
-    layout->addWidget(d->useDateFromMetadata);
+    layout->addWidget(d->useFileMetadata);
     layout->addWidget(d->turnHighQualityThumbs);
     layout->addWidget(d->useDefaultTargetAlbum);
     layout->addWidget(d->target1AlbumSelector);
@@ -324,30 +360,30 @@ SetupCamera::SetupCamera(QWidget* const parent)
 
     // -------------------------------------------------------------
 
-    QWidget* panel3 = new QWidget(d->tab);
+    QWidget* const panel3         = new QWidget(d->tab);
     panel3->setAutoFillBackground(false);
 
-    QGridLayout* importGrid = new QGridLayout(panel3);
-    d->importListView       = new QListWidget(panel3);
+    QGridLayout* const importGrid = new QGridLayout(panel3);
+    d->importListView             = new QListWidget(panel3);
     d->importListView->setSelectionMode(QAbstractItemView::SingleSelection);
     d->importListView->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     d->importListView->setWhatsThis(i18n("Here you can see filters that can be used to filter "
                                          "files in import dialog."));
 
-    d->importAddButton    = new QPushButton(panel3);
-    d->importRemoveButton = new QPushButton(panel3);
-    d->importEditButton   = new QPushButton(panel3);
-    QSpacerItem* spacer2  = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);
+    d->importAddButton         = new QPushButton(panel3);
+    d->importRemoveButton      = new QPushButton(panel3);
+    d->importEditButton        = new QPushButton(panel3);
+    QSpacerItem* const spacer2 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);
 
-    QGroupBox* groupBox         = new QGroupBox(panel3);
-    QVBoxLayout* verticalLayout = new QVBoxLayout(groupBox);
-    QLabel* label               = new QLabel(groupBox);
+    QGroupBox* const groupBox         = new QGroupBox(panel3);
+    QVBoxLayout* const verticalLayout = new QVBoxLayout(groupBox);
+    QLabel* const label               = new QLabel(groupBox);
     verticalLayout->addWidget(label);
-    d->ignoreNamesEdit          = new QLineEdit(groupBox);
+    d->ignoreNamesEdit                = new QLineEdit(groupBox);
     verticalLayout->addWidget(d->ignoreNamesEdit);
-    QLabel* label2              = new QLabel(groupBox);
+    QLabel* const label2              = new QLabel(groupBox);
     verticalLayout->addWidget(label2);
-    d->ignoreExtensionsEdit     = new QLineEdit(groupBox);
+    d->ignoreExtensionsEdit           = new QLineEdit(groupBox);
     verticalLayout->addWidget(d->ignoreExtensionsEdit);
 
     groupBox->setTitle(i18n("Always ignore"));
@@ -374,6 +410,109 @@ SetupCamera::SetupCamera(QWidget* const parent)
 
     d->tab->insertTab(2, panel3, i18n("Import Filters"));
 
+    // -- Import Icon View ----------------------------------------------------------
+
+    QWidget* const panel4      = new QWidget(d->tab);
+    panel4->setAutoFillBackground(false);
+
+    QVBoxLayout* const layout2 = new QVBoxLayout(panel4);
+
+    QGroupBox* const iconViewGroup = new QGroupBox(i18n("Icon-View Options"), panel4);
+    QGridLayout* const grid2       = new QGridLayout(iconViewGroup);
+
+    d->iconShowNameBox       = new QCheckBox(i18n("Show file&name"), iconViewGroup);
+    d->iconShowNameBox->setWhatsThis(i18n("Set this option to show the filename below the image thumbnail."));
+
+    d->iconShowSizeBox       = new QCheckBox(i18n("Show file si&ze"), iconViewGroup);
+    d->iconShowSizeBox->setWhatsThis(i18n("Set this option to show the file size below the image thumbnail."));
+
+    d->iconShowDateBox    = new QCheckBox(i18n("Show camera creation &date"), iconViewGroup);
+    d->iconShowDateBox->setWhatsThis(i18n("Set this option to show the camera creation date "
+                                             "below the image thumbnail"));
+
+/*
+    d->iconShowResolutionBox = new QCheckBox(i18n("Show ima&ge dimensions"), iconViewGroup);
+    d->iconShowResolutionBox->setWhatsThis(i18n("Set this option to show the image size in pixels "
+                                                "below the image thumbnail."));
+*/
+
+    d->iconShowFormatBox     = new QCheckBox(i18n("Show image Format"), iconViewGroup);
+    d->iconShowFormatBox->setWhatsThis(i18n("Set this option to show image format over image thumbnail."));
+
+    d->iconShowTagsBox       = new QCheckBox(i18n("Show digiKam &tags"), iconViewGroup);
+    d->iconShowTagsBox->setWhatsThis(i18n("Set this option to show the digiKam tags "
+                                          "below the image thumbnail."));
+
+    d->iconShowRatingBox     = new QCheckBox(i18n("Show item &rating"), iconViewGroup);
+    d->iconShowRatingBox->setWhatsThis(i18n("Set this option to show the item rating "
+                                            "below the image thumbnail."));
+
+    d->iconShowOverlaysBox   = new QCheckBox(i18n("Show rotation overlay buttons"), iconViewGroup);
+    d->iconShowOverlaysBox->setWhatsThis(i18n("Set this option to show overlay buttons on "
+                                              "the image thumbnail for image rotation."));
+
+    QLabel* const leftClickLabel = new QLabel(i18n("Thumbnail click action:"), iconViewGroup);
+    d->leftClickActionComboBox   = new KComboBox(iconViewGroup);
+    d->leftClickActionComboBox->addItem(i18n("Show embedded preview"), ImportSettings::ShowPreview);
+    d->leftClickActionComboBox->addItem(i18n("Start image editor"), ImportSettings::StartEditor);
+    d->leftClickActionComboBox->setToolTip(i18n("Choose what should happen when you click on a thumbnail."));
+
+    d->iconViewFontSelect = new DFontSelect(i18n("Icon View font:"), panel);
+    d->iconViewFontSelect->setToolTip(i18n("Select here the font used to display text in Icon Views."));
+
+    grid2->addWidget(d->iconShowNameBox,          0, 0, 1, 1);
+    grid2->addWidget(d->iconShowSizeBox,          1, 0, 1, 1);
+    grid2->addWidget(d->iconShowDateBox,          2, 0, 1, 1);
+//  grid2->addWidget(d->iconShowResolutionBox,    3, 0, 1, 1);              TODO
+    grid2->addWidget(d->iconShowFormatBox,        3, 0, 1, 1);
+
+    grid2->addWidget(d->iconShowTagsBox,          0, 1, 1, 1);
+    grid2->addWidget(d->iconShowRatingBox,        1, 1, 1, 1);
+    grid2->addWidget(d->iconShowOverlaysBox,      2, 1, 1, 1);
+    grid2->addWidget(leftClickLabel,              5, 0, 1, 1);
+    grid2->addWidget(d->leftClickActionComboBox,  5, 1, 1, 1);
+    grid2->addWidget(d->iconViewFontSelect,       6, 0, 1, 2);
+    grid2->setSpacing(KDialog::spacingHint());
+    grid2->setMargin(KDialog::spacingHint());
+
+    // --------------------------------------------------------
+
+    QGroupBox* const interfaceOptionsGroup = new QGroupBox(i18n("Preview Options"), panel4);
+    QGridLayout* const grid3               = new QGridLayout(interfaceOptionsGroup);
+
+    d->previewLoadFullImageSize  = new QCheckBox(i18n("Embedded preview loads full-sized images"), interfaceOptionsGroup);
+    d->previewLoadFullImageSize->setWhatsThis(i18n("<p>Set this option to load images at their full size "
+                                                   "for preview, rather than at a reduced size. As this option "
+                                                   "will make it take longer to load images, only use it if you have "
+                                                   "a fast computer.</p>"
+                                                   "<p><b>Note:</b> for Raw images, a half size version of the Raw data "
+                                                   "is used instead of the embedded JPEG preview.</p>"));
+
+    d->previewItemsWhileDownload = new QCheckBox(i18n("Preview each item while downloading it"), interfaceOptionsGroup);
+    d->previewItemsWhileDownload->setWhatsThis(i18n("<p>Set this option to preview each item while downloading.</p>"));
+
+    d->previewShowIcons          = new QCheckBox(i18n("Show icons and text over preview"), interfaceOptionsGroup);
+    d->previewShowIcons->setWhatsThis(i18n("Uncheck this if you don't want to see icons and text in the image preview."));
+
+    grid3->setMargin(KDialog::spacingHint());
+    grid3->setSpacing(KDialog::spacingHint());
+    grid3->addWidget(d->previewLoadFullImageSize,  0, 0, 1, 2);
+    grid3->addWidget(d->previewItemsWhileDownload, 1, 0, 1, 2);
+    grid3->addWidget(d->previewShowIcons,          2, 0, 1, 2);
+
+    // --------------------------------------------------------
+
+    d->fullScreenSettings = new FullScreenSettings(FS_IMPORTUI, panel4);
+
+    layout2->setMargin(0);
+    layout2->setSpacing(KDialog::spacingHint());
+    layout2->addWidget(iconViewGroup);
+    layout2->addWidget(interfaceOptionsGroup);
+    layout2->addWidget(d->fullScreenSettings);
+    layout2->addStretch();
+
+    d->tab->insertTab(3, panel4, i18n("Import Window"));
+
     // -------------------------------------------------------------
 
     setAutoFillBackground(false);
@@ -404,6 +543,12 @@ SetupCamera::SetupCamera(QWidget* const parent)
     connect(d->useDefaultTargetAlbum, SIGNAL(toggled(bool)),
             d->target1AlbumSelector, SLOT(setEnabled(bool)));
 
+    connect(d->previewItemsWhileDownload, SIGNAL(clicked()),
+            this, SLOT(slotPreviewItemsClicked()));
+
+    connect(d->previewLoadFullImageSize, SIGNAL(clicked()),
+            this, SLOT(slotPreviewFullImageSizeClicked()));
+
     // -------------------------------------------------------------
 
     connect(d->importListView, SIGNAL(itemSelectionChanged()),
@@ -420,6 +565,11 @@ SetupCamera::SetupCamera(QWidget* const parent)
 
     // -------------------------------------------------------------
 
+    connect(d->useFileMetadata, SIGNAL(toggled(bool)),
+            this, SIGNAL(signalUseFileMetadataChanged(bool)));
+
+    // -------------------------------------------------------------
+
     readSettings();
 }
 
@@ -428,17 +578,25 @@ SetupCamera::~SetupCamera()
     delete d;
 }
 
+bool SetupCamera::useFileMetadata()
+{
+    KSharedConfig::Ptr config = KGlobal::config();
+    KConfigGroup group        = config->group(d->configGroupName);
+
+    return (group.readEntry(d->configUseFileMetadata, false));
+}
+
 void SetupCamera::readSettings()
 {
     // Populate cameras --------------------------------------
 
-    CameraList* clist = CameraList::defaultList();
+    CameraList* const clist = CameraList::defaultList();
 
     if (clist)
     {
-        QList<CameraType*>* cl = clist->cameraList();
+        QList<CameraType*>* const cl = clist->cameraList();
 
-        foreach(CameraType* ctype, *cl)
+        foreach(CameraType* const ctype, *cl)
         {
             new SetupCameraItem(d->listView, ctype);
         }
@@ -449,13 +607,15 @@ void SetupCamera::readSettings()
     KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup group        = config->group(d->configGroupName);
 
-    d->useDateFromMetadata->setChecked(group.readEntry(d->configUseMetadataDateEntry, false));
+    d->useFileMetadata->setChecked(useFileMetadata());
     d->turnHighQualityThumbs->setChecked(group.readEntry(d->configTrunHighQualityThumbs, false));
     d->useDefaultTargetAlbum->setChecked(group.readEntry(d->configUseDefaultTargetAlbum, false));
-    PAlbum* album = AlbumManager::instance()->findPAlbum(group.readEntry(d->configDefaultTargetAlbumId, 0));
+    PAlbum* const album = AlbumManager::instance()->findPAlbum(group.readEntry(d->configDefaultTargetAlbumId, 0));
     d->target1AlbumSelector->setCurrentAlbum(album);
     d->target1AlbumSelector->setEnabled(d->useDefaultTargetAlbum->isChecked());
 
+    d->fullScreenSettings->readSettings(group);
+
     // -------------------------------------------------------
 
     KConfigGroup importGroup = config->group(d->importFiltersConfigGroupName);
@@ -469,25 +629,50 @@ void SetupCamera::readSettings()
             break;
         }
 
-        Filter* f = new Filter;
+        Filter* const f = new Filter;
         f->fromString(filter);
         d->filters.append(f);
     }
 
     FilterComboBox::defaultFilters(&d->filters);
-    foreach(Filter* f, d->filters)
+
+    foreach(Filter* const f, d->filters)
     {
         new QListWidgetItem(f->name, d->importListView);
     }
+
     d->ignoreNamesEdit->setText(importGroup.readEntry("IgnoreNames", FilterComboBox::defaultIgnoreNames));
     d->ignoreExtensionsEdit->setText(importGroup.readEntry("IgnoreExtensions", FilterComboBox::defaultIgnoreExtensions));
+
+    ImportSettings* const settings = ImportSettings::instance();
+
+    if (!settings)
+    {
+        return;
+    }
+
+    d->iconShowNameBox->setChecked(settings->getIconShowName());
+    d->iconShowTagsBox->setChecked(settings->getIconShowTags());
+    d->iconShowSizeBox->setChecked(settings->getIconShowSize());
+    d->iconShowDateBox->setChecked(settings->getIconShowDate());
+    //TODO: d->iconShowResolutionBox->setChecked(settings->getIconShowResolution());
+    d->iconShowOverlaysBox->setChecked(settings->getIconShowOverlays());
+    d->iconShowRatingBox->setChecked(settings->getIconShowRating());
+    d->iconShowFormatBox->setChecked(settings->getIconShowImageFormat());
+    d->iconViewFontSelect->setFont(settings->getIconViewFont());
+
+    d->leftClickActionComboBox->setCurrentIndex((int)settings->getItemLeftClickAction());
+
+    d->previewLoadFullImageSize->setChecked(settings->getPreviewLoadFullImageSize());
+    d->previewItemsWhileDownload->setChecked(settings->getPreviewItemsWhileDownload());
+    d->previewShowIcons->setChecked(settings->getPreviewShowIcons());
 }
 
 void SetupCamera::applySettings()
 {
     // Save camera devices -----------------------------------
 
-    CameraList* clist = CameraList::defaultList();
+    CameraList* const clist = CameraList::defaultList();
 
     if (clist)
     {
@@ -497,11 +682,11 @@ void SetupCamera::applySettings()
 
         while (*it)
         {
-            SetupCameraItem* item = dynamic_cast<SetupCameraItem*>(*it);
+            SetupCameraItem* const item = dynamic_cast<SetupCameraItem*>(*it);
 
             if (item)
             {
-                CameraType* ctype = item->cameraType();
+                CameraType* const ctype = item->cameraType();
 
                 if (ctype)
                 {
@@ -520,11 +705,14 @@ void SetupCamera::applySettings()
     KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup group        = config->group(d->configGroupName);
 
-    group.writeEntry(d->configUseMetadataDateEntry, d->useDateFromMetadata->isChecked());
+    group.writeEntry(d->configUseFileMetadata,  d->useFileMetadata->isChecked());
     group.writeEntry(d->configTrunHighQualityThumbs, d->turnHighQualityThumbs->isChecked());
     group.writeEntry(d->configUseDefaultTargetAlbum, d->useDefaultTargetAlbum->isChecked());
-    PAlbum* album = d->target1AlbumSelector->currentAlbum();
+    PAlbum* const album = d->target1AlbumSelector->currentAlbum();
     group.writeEntry(d->configDefaultTargetAlbumId, album ? album->id() : 0);
+
+    d->fullScreenSettings->saveSettings(group);
+
     group.sync();
 
     // -------------------------------------------------------
@@ -541,6 +729,31 @@ void SetupCamera::applySettings()
     importGroup.writeEntry("IgnoreNames", d->ignoreNamesEdit->text());
     importGroup.writeEntry("IgnoreExtensions", d->ignoreExtensionsEdit->text());
     importGroup.sync();
+
+    ImportSettings* const settings = ImportSettings::instance();
+
+    if (!settings)
+    {
+        return;
+    }
+
+    settings->setIconShowName(d->iconShowNameBox->isChecked());
+    settings->setIconShowTags(d->iconShowTagsBox->isChecked());
+    settings->setIconShowSize(d->iconShowSizeBox->isChecked());
+    settings->setIconShowDate(d->iconShowDateBox->isChecked());
+    //TODO: settings->setIconShowResolution(d->iconShowResolutionBox->isChecked());
+    settings->setIconShowOverlays(d->iconShowOverlaysBox->isChecked());
+    settings->setIconShowRating(d->iconShowRatingBox->isChecked());
+    settings->setIconShowImageFormat(d->iconShowFormatBox->isChecked());
+    settings->setIconViewFont(d->iconViewFontSelect->font());
+
+    settings->setItemLeftClickAction((ImportSettings::ItemLeftClickAction)
+                                     d->leftClickActionComboBox->currentIndex());
+
+    settings->setPreviewLoadFullImageSize(d->previewLoadFullImageSize->isChecked());
+    settings->setPreviewItemsWhileDownload(d->previewItemsWhileDownload->isChecked());
+    settings->setPreviewShowIcons(d->previewShowIcons->isChecked());
+    settings->saveSettings();
 }
 
 bool SetupCamera::checkSettings()
@@ -578,7 +791,7 @@ void SetupCamera::slotSelectionChanged()
 
 void SetupCamera::slotAddCamera()
 {
-    CameraSelection* select = new CameraSelection;
+    CameraSelection* const select = new CameraSelection;
 
     connect(select, SIGNAL(signalOkClicked(const QString&, const QString&,
                                            const QString&, const QString&)),
@@ -597,14 +810,14 @@ void SetupCamera::slotAddedCamera(const QString& title, const QString& model,
 
 void SetupCamera::slotRemoveCamera()
 {
-    SetupCameraItem* item = dynamic_cast<SetupCameraItem*>(d->listView->currentItem());
+    SetupCameraItem* const item = dynamic_cast<SetupCameraItem*>(d->listView->currentItem());
 
     delete item;
 }
 
 void SetupCamera::slotEditCamera()
 {
-    SetupCameraItem* item = dynamic_cast<SetupCameraItem*>(d->listView->currentItem());
+    SetupCameraItem* const item = dynamic_cast<SetupCameraItem*>(d->listView->currentItem());
 
     if (!item)
     {
@@ -618,7 +831,7 @@ void SetupCamera::slotEditCamera()
         return;
     }
 
-    CameraSelection* select = new CameraSelection;
+    CameraSelection* const select = new CameraSelection;
     select->setCamera(ctype->title(), ctype->model(), ctype->port(), ctype->path());
 
     connect(select, SIGNAL(signalOkClicked(const QString&, const QString&,
@@ -632,7 +845,7 @@ void SetupCamera::slotEditCamera()
 void SetupCamera::slotEditedCamera(const QString& title, const QString& model,
                                    const QString& port, const QString& path)
 {
-    SetupCameraItem* item = dynamic_cast<SetupCameraItem*>(d->listView->currentItem());
+    SetupCameraItem* const item = dynamic_cast<SetupCameraItem*>(d->listView->currentItem());
 
     if (!item)
     {
@@ -645,8 +858,8 @@ void SetupCamera::slotEditedCamera(const QString& title, const QString& model,
 
 void SetupCamera::slotAutoDetectCamera()
 {
-    DBusyDlg* dlg                  = new DBusyDlg(i18n("Device detection under progress, please wait..."), this);
-    CameraAutoDetectThread* thread = new CameraAutoDetectThread(this);
+    DBusyDlg* const dlg                  = new DBusyDlg(i18n("Device detection under progress, please wait..."), this);
+    CameraAutoDetectThread* const thread = new CameraAutoDetectThread(this);
     dlg->setBusyThread(thread);
     dlg->exec();
 
@@ -681,7 +894,7 @@ void SetupCamera::slotAutoDetectCamera()
 
 void SetupCamera::slotImportSelectionChanged()
 {
-    QListWidgetItem* item = d->importListView->currentItem();
+    QListWidgetItem* const item = d->importListView->currentItem();
 
     d->importRemoveButton->setEnabled(item);
     d->importEditButton->setEnabled(item);
@@ -696,7 +909,7 @@ void SetupCamera::slotAddFilter()
 
     if (dlg.exec() == QDialog::Accepted)
     {
-        Filter* f = new Filter;
+        Filter* const f = new Filter;
         dlg.getData(f);
         d->filters.append(f);
         new QListWidgetItem(f->name, d->importListView);
@@ -722,10 +935,29 @@ void SetupCamera::slotEditFilter()
 
     if (dlg.exec() == QDialog::Accepted)
     {
-        Filter* f = d->filters.at(i);
+        Filter* const f = d->filters.at(i);
         dlg.getData(f);
         d->importListView->currentItem()->setText(f->name);
     }
 }
 
+void SetupCamera::slotPreviewItemsClicked()
+{
+    if (d->previewItemsWhileDownload->isChecked() && d->previewLoadFullImageSize->isChecked())
+    {
+        KMessageBox::information(this, i18n("In order to enable this feature, the full-sized preview will be disabled."));
+
+        d->previewLoadFullImageSize->setChecked(false);
+    }
+}
+
+void SetupCamera::slotPreviewFullImageSizeClicked()
+{
+    if (d->previewItemsWhileDownload->isChecked() && d->previewLoadFullImageSize)
+    {
+        KMessageBox::information(this, i18n("If the full-sized preview is enabled it will affect the speed of previewing each item while download."));
+        d->previewItemsWhileDownload->setChecked(false);
+    }
+}
+
 }  // namespace Digikam
