@@ -6,7 +6,7 @@
  * Date        : 2004-01-02
  * Description : album category setup tab.
  *
- * Copyright (C) 2004-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,7 +37,7 @@ class SetupCategory : public QScrollArea
 
 public:
 
-    SetupCategory(QWidget* parent = 0);
+    explicit SetupCategory(QWidget* const parent = 0);
     ~SetupCategory();
 
     void applySettings();
@@ -55,8 +55,8 @@ private Q_SLOTS:
 
 private:
 
-    class SetupCategoryPriv;
-    SetupCategoryPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace Digikam
