@@ -6,7 +6,7 @@
  * Date        : 2007-05-11
  * Description : setup Light Table tab.
  *
- * Copyright (C) 2007-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,7 +37,7 @@ class SetupLightTable : public QScrollArea
 
 public:
 
-    SetupLightTable(QWidget* parent = 0);
+    explicit SetupLightTable(QWidget* const parent = 0);
     ~SetupLightTable();
 
     void applySettings();
@@ -48,8 +48,8 @@ private:
 
 private:
 
-    class SetupLightTablePriv;
-    SetupLightTablePriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace Digikam
