@@ -6,8 +6,8 @@
  * Date        : 2004-08-23
  * Description : mics configuration setup tab
  *
- * Copyright (C) 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2005-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004      by Renchi Raju <renchi dot raju at gmail dot com>
+ * Copyright (C) 2005-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,7 +37,7 @@ class SetupMisc : public QScrollArea
 
 public:
 
-    SetupMisc(QWidget* parent = 0);
+    explicit SetupMisc(QWidget* const parent = 0);
     ~SetupMisc();
 
     void applySettings();
@@ -48,8 +48,8 @@ private:
 
 private:
 
-    class SetupMiscPriv;
-    SetupMiscPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace Digikam
