@@ -6,7 +6,7 @@
  * Date        : 2005-05-21
  * Description : setup tab for slideshow options.
  *
- * Copyright (C) 2005-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -46,11 +46,11 @@
 namespace Digikam
 {
 
-class SetupSlideShow::SetupSlideShowPriv
+class SetupSlideShow::Private
 {
 public:
 
-    SetupSlideShowPriv() :
+    Private() :
         startWithCurrent(0),
         loopMode(0),
         showName(0),
@@ -82,8 +82,8 @@ public:
 
 // --------------------------------------------------------
 
-SetupSlideShow::SetupSlideShow(QWidget* parent)
-    : QScrollArea(parent), d(new SetupSlideShowPriv)
+SetupSlideShow::SetupSlideShow(QWidget* const parent)
+    : QScrollArea(parent), d(new Private)
 {
     QWidget* panel = new QWidget(viewport());
     setWidget(panel);
