@@ -6,7 +6,7 @@
  * Date        : 2006-07-09
  * Description : item tool tip configuration setup tab
  *
- * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,19 +37,28 @@ class SetupToolTip : public QScrollArea
 
 public:
 
-    SetupToolTip(QWidget* parent = 0);
+    explicit SetupToolTip(QWidget* const parent = 0);
     ~SetupToolTip();
 
     void applySettings();
 
+public Q_SLOTS:
+
+    void slotUseFileMetadataChanged(bool);
+
+private Q_SLOTS:
+
+    void slotImportToolTipsChanged();
+
 private:
 
     void readSettings();
+    void refreshCameraOptions();
 
 private:
 
-    class SetupToolTipPriv;
-    SetupToolTipPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace Digikam
