@@ -6,7 +6,7 @@
  * Date        : 2003-05-16
  * Description : a plugin to acquire image using flat scanner.
  *
- * Copyright (C) 2003-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -36,22 +36,19 @@ class QWidget;
 
 class KAction;
 
-namespace KIPI
-{
-    class Interface;
-}
-
 namespace KSaneIface
 {
     class KSaneWidget;
 }
 
+using namespace KIPI;
+
 namespace KIPIAcquireImagesPlugin
 {
 
 class ScanDialog;
 
-class Plugin_AcquireImages : public KIPI::Plugin
+class Plugin_AcquireImages : public Plugin
 {
     Q_OBJECT
 
@@ -60,13 +57,16 @@ public:
     Plugin_AcquireImages(QObject* const parent, const QVariantList& args);
     virtual ~Plugin_AcquireImages();
 
-    KIPI::Category category(KAction* action) const;
-    void setup(QWidget*);
+    void setup(QWidget* const);
 
 public Q_SLOTS:
 
     void slotActivate();
 
+private:
+
+    void setupActions();
+
 private:
 
     QWidget*                 m_parentWidget;
@@ -75,8 +75,6 @@ private:
 
     KSaneIface::KSaneWidget* m_saneWidget;
 
-    KIPI::Interface*         m_interface;
-
     QPointer <ScanDialog>    m_scanDlg;
 };
 
