@@ -1,12 +1,13 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2009-11-13
  * Description : a plugin to blend bracketed images.
  *
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012      by Benjamin Girault <benjamin dot girault at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -31,11 +32,11 @@
 // KDE includes
 
 #include <kurl.h>
-#include <kassistantdialog.h>
 
 // Local includes
 
 #include "actions.h"
+#include "kptooldialog.h"
 
 class KPageWidgetItem;
 
@@ -45,21 +46,20 @@ namespace KIPI
 }
 
 using namespace KIPI;
+using namespace KIPIPlugins;
 
 namespace KIPIExpoBlendingPlugin
 {
 
 class Manager;
-class ExpoBlendingAboutData;
-class ImportWizardDlgPriv;
 
-class ImportWizardDlg : public KAssistantDialog
+class ImportWizardDlg : public KPWizardDialog
 {
     Q_OBJECT
 
 public:
 
-    explicit ImportWizardDlg(Manager* mngr, QWidget* parent=0);
+    explicit ImportWizardDlg(Manager* const mngr, QWidget* const parent = 0);
     ~ImportWizardDlg();
 
     KUrl::List itemUrls() const;
@@ -71,9 +71,9 @@ private Q_SLOTS:
     void next();
     void back();
 
+    void slotIntroPageIsValid(bool);
     void slotItemsPageIsValid(bool);
     void slotPreProcessed(const ItemUrlsMap&);
-    void slotHelp();
 
 private:
 
