@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2009-11-13
  * Description : a plugin to blend bracketed images.
  *
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,19 +25,20 @@
 
 // Local includes
 
-#include "wizardpage.h"
+#include "kpwizardpage.h"
+
+using namespace KIPIPlugins;
 
 namespace KIPIExpoBlendingPlugin
 {
 
 class Manager;
-class LastPagePriv;
 
-class LastPage : public KIPIPlugins::WizardPage
+class LastPage : public KPWizardPage
 {
 public:
 
-    LastPage(Manager* mngr, KAssistantDialog* dlg);
+    LastPage(Manager* const mngr, KAssistantDialog* const dlg);
     ~LastPage();
 
 private:
