@@ -1,12 +1,13 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2009-12-23
  * Description : Autodetect enfuse binary program and version
  *
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012 by Benjamin Girault <benjamin dot girault at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,27 +26,50 @@
 
 // Local includes
 
-#include "binaryiface.h"
+#include "kpbinaryiface.h"
 
 using namespace KIPIPlugins;
 
 namespace KIPIExpoBlendingPlugin
 {
 
-class EnfuseBinary : public BinaryIface
+class EnfuseBinary : public KPBinaryIface
 {
+    Q_OBJECT
 
 public:
 
-    EnfuseBinary();
-    ~EnfuseBinary();
+    EnfuseBinary()
+    : KPBinaryIface(QString("enfuse"), 
+                    QString("3.2"), 
+                    QString("enfuse "),
+                    0, 
+                    QString("Enblend"), 
+                    QString("http://enblend.sourceforge.net"),
+                    QString("ExpoBlending"), 
+                    QStringList("-V")),
+      versionDouble(0)
+        {
+            setup();
+        }
 
-    QString path()           const;
-    QString minimalVersion() const;
-    KUrl    url()            const;
-    QString projectName()    const;
+    ~EnfuseBinary()
+    {
+    }
+    
+    double getVersion() const;
 
-    void    checkSystem();
+Q_SIGNALS:
+
+    void signalEnfuseVersion(double version);
+
+protected:
+
+    bool parseHeader(const QString& output);
+    
+private:
+    
+    double versionDouble;
 };
 
 } // namespace KIPIExpoBlendingPlugin
