@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2011-09-13
  * Description : a plugin to export to flash
@@ -34,22 +34,43 @@
 
 // Local includes
 
-#include "wizardpage.h"
+#include "kpwizardpage.h"
+#include "simpleviewersettingscontainer.h"
+
+using namespace KIPIPlugins;
 
 namespace KIPIFlashExportPlugin
 {
 
 class FlashManager; 
 
-class SelectionPage: public KIPIPlugins::WizardPage
+class SelectionPage: public KPWizardPage
 {
-	Q_OBJECT
+    Q_OBJECT
+
 public:
 
-	SelectionPage(FlashManager *mngr, KAssistantDialog* dlg);
+    SelectionPage(FlashManager* const mngr, KAssistantDialog* const dlg);
     ~SelectionPage();
-    
-    QList<KIPI::ImageCollection> selection() const;
+
+    /**
+     * Set a collection selector or a image dialog according to user choice on the intropage
+     * @param choice - 0 -collection, 1 - image dialog
+     */
+    void setPageContent(int choice);
+
+    /**
+     * Set settings intro SimpleViewerSettingsContainer
+     */
+    void settings(SimpleViewerSettingsContainer* const container);
+
+    /**
+     * Check if at least one collection or one image is selected
+     * User won't be allowed to start export with no images selected
+     * @param imageGetOption 0 - collection 1 - iamgeDialog
+     * to know where to check for selected images
+     */
+    bool isSelectionEmpty(int imageGetOption);
 
 private:
 
