@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2008-10-01
  * Description : a plugin to export to a remote Gallery server.
@@ -27,15 +27,15 @@
 namespace KIPIGalleryExportPlugin
 {
 
-AlbumDlg::AlbumDlg(QWidget *parent)
-        : QDialog(parent)
+AlbumDlg::AlbumDlg(QWidget* const parent)
+    : QDialog(parent)
 {
     setupUi(this);
 
-    connect(buttonOk, SIGNAL(clicked()), 
+    connect(buttonOk, SIGNAL(clicked()),
             this, SLOT(accept()));
 
-    connect(buttonCancel, SIGNAL(clicked()), 
+    connect(buttonCancel, SIGNAL(clicked()),
             this, SLOT(reject()));
 }
 
