@@ -7,7 +7,7 @@
  * @date   2009-05-07
  * @brief  Context menu for GPS list view.
  *
- * @author Copyright (C) 2009,2010,2011 by Michael G. Hansen
+ * @author Copyright (C) 2009-2011 by Michael G. Hansen
  *         <a href="mailto:mike at mghansen dot de">mike at mghansen dot de</a>
  *
  * This program is free software; you can redistribute it
@@ -63,19 +63,23 @@ class GPSListViewContextMenu::Private
 public:
 
     Private()
+      : enabled(true),
+        actionCopy(0),
+        actionPaste(0),
+        actionBookmark(0),
+        actionRemoveCoordinates(0),
+        actionRemoveAltitude(0),
+        actionRemoveUncertainty(0),
+        actionRemoveSpeed(0),
+        actionLookupMissingAltitudes(0),
+        bookmarkOwner(0),
+        imagesList(0),
+        altitudeLookup(),
+        altitudeUndoCommand(0),
+        altitudeRequestedCount(0),
+        altitudeReceivedCount(0)
     {
-        enabled                      = true;
-        actionCopy                   = 0;
-        actionPaste                  = 0;
-        actionBookmark               = 0;
-        actionRemoveCoordinates      = 0;
-        actionRemoveAltitude         = 0;
-        actionRemoveUncertainty      = 0;
-        actionRemoveSpeed            = 0;
-        actionLookupMissingAltitudes = 0;
-        bookmarkOwner                = 0;
-        imagesList                   = 0;
-        altitudeUndoCommand          = 0;
+
     }
 
     bool                              enabled;
@@ -100,19 +104,19 @@ public:
     int                               altitudeReceivedCount;
 };
 
-GPSListViewContextMenu::GPSListViewContextMenu(KipiImageList *imagesList, GPSBookmarkOwner* const bookmarkOwner)
+GPSListViewContextMenu::GPSListViewContextMenu(KipiImageList* const imagesList, GPSBookmarkOwner* const bookmarkOwner)
     : QObject(imagesList), d(new Private)
 {
-    d->imagesList  = imagesList;
+    d->imagesList                   = imagesList;
 
-    d->actionCopy  = new KAction(i18n("Copy coordinates"), this);
+    d->actionCopy                   = new KAction(i18n("Copy coordinates"),                this);
     d->actionCopy->setIcon(SmallIcon("edit-copy"));
-    d->actionPaste = new KAction(i18n("Paste coordinates"), this);
+    d->actionPaste                  = new KAction(i18n("Paste coordinates"),               this);
     d->actionPaste->setIcon(SmallIcon("edit-paste"));
-    d->actionRemoveCoordinates = new KAction(i18n("Remove coordinates"), this);
-    d->actionRemoveAltitude    = new KAction(i18n("Remove altitude"), this);
-    d->actionRemoveUncertainty = new KAction(i18n("Remove uncertainty"), this);
-    d->actionRemoveSpeed       = new KAction(i18n("Remove speed"), this);
+    d->actionRemoveCoordinates      = new KAction(i18n("Remove coordinates"),              this);
+    d->actionRemoveAltitude         = new KAction(i18n("Remove altitude"),                 this);
+    d->actionRemoveUncertainty      = new KAction(i18n("Remove uncertainty"),              this);
+    d->actionRemoveSpeed            = new KAction(i18n("Remove speed"),                    this);
     d->actionLookupMissingAltitudes = new KAction(i18n("Look up missing altitude values"), this);
 
     connect(d->actionCopy, SIGNAL(triggered()),
@@ -202,8 +206,10 @@ bool GPSListViewContextMenu::eventFilter(QObject *watched, QEvent *event)
         {
             d->bookmarkOwner->changeAddBookmark(copyAvailable);
             GPSDataContainer position;
-            getCurrentItemPositionAndUrl(&position, 0);
-            d->bookmarkOwner->setPositionAndTitle(position.getCoordinates(), QString());
+            KUrl             itemUrl;
+            getCurrentItemPositionAndUrl(&position, &itemUrl);
+            const QString itemFileName = itemUrl.fileName();
+            d->bookmarkOwner->setPositionAndTitle(position.getCoordinates(), itemFileName);
         }
 
         // "paste" is only available if there is geo data in the clipboard
