@@ -49,11 +49,11 @@ namespace KIPIImgurExportPlugin
 K_PLUGIN_FACTORY( ImgurExportFactory, registerPlugin<Plugin_ImgurExport>(); )
 K_EXPORT_PLUGIN ( ImgurExportFactory("kipiplugin_imgurexport") )
 
-class Plugin_ImgurExport::Plugin_ImgurExportPriv
+class Plugin_ImgurExport::Private
 {
 public:
 
-    Plugin_ImgurExportPriv()
+    Private()
     {
         actionExport = 0;
         winExport    = 0;
@@ -65,7 +65,7 @@ public:
 
 Plugin_ImgurExport::Plugin_ImgurExport(QObject* const parent, const QVariantList& args)
     : Plugin(ImgurExportFactory::componentData(), parent, "ImgurExport"),
-      d(new Plugin_ImgurExportPriv)
+      d(new Private)
 {
     kDebug(AREA_CODE_LOADING) << "ImgurExport plugin loaded";
     kDebug(AREA_CODE_LOADING) << args;
@@ -102,7 +102,7 @@ void Plugin_ImgurExport::setupActions()
 
     d->actionExport = new KAction(this);
     d->actionExport->setText(i18n("Export to &Imgur..."));
-    d->actionExport->setIcon(KIcon("imgur"));
+    d->actionExport->setIcon(KIcon("kipi-imgur"));
     d->actionExport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_I));
 
     connect(d->actionExport, SIGNAL(triggered(bool)),
@@ -133,9 +133,4 @@ void Plugin_ImgurExport::slotActivate()
     kDebug() << "We have activated the imgur exporter!";
 }
 
-Category Plugin_ImgurExport::category(KAction* action) const
-{
-    return ExportPlugin;
-}
-
 } // namespace KIPIImgurExportPlugin
