@@ -21,8 +21,8 @@
  *
  * ============================================================ */
 
-#ifndef IPOD_EXPORTDIALOG_H
-#define IPOD_EXPORTDIALOG_H
+#ifndef UPLOADDIALOG_H
+#define UPLOADDIALOG_H
 
 #define KIPI_PLUGIN 1
 
@@ -77,7 +77,7 @@ class UploadDialog : public KPToolDialog
 
 public:
 
-    UploadDialog(const QString& caption, QWidget* const parent=0);
+    explicit UploadDialog(const QString& caption, QWidget* const parent=0);
     ~UploadDialog();
 
     QString ipodModel()  const;
@@ -164,4 +164,4 @@ private:
 
 } // namespace KIPIIpodExportPlugin
 
-#endif // IPOD_EXPORTDIALOG_H
+#endif // UPLOADDIALOG_H
