@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2003-10-14
  * Description : batch image rotation
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2004-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -69,7 +69,7 @@ namespace KIPIJPEGLossLessPlugin
 {
 
 ImageRotate::ImageRotate()
-           : QObject()
+    : QObject()
 {
     m_tmpFile.setSuffix("kipiplugin-rotate");
     m_tmpFile.setAutoRemove(true);
@@ -79,7 +79,7 @@ ImageRotate::~ImageRotate()
 {
 }
 
-bool ImageRotate::rotate(const QString& src, RotateAction angle, QString& err, bool updateFileTimeStamp)
+bool ImageRotate::rotate(const QString& src, RotateAction angle, QString& err)
 {
     QFileInfo fi(src);
 
@@ -104,14 +104,14 @@ bool ImageRotate::rotate(const QString& src, RotateAction angle, QString& err, b
     static_cast<QFSFileEngine*>(m_tmpFile.fileEngine())->rename(tmp);
 #endif
 
-    if (Utils::isRAW(src))
+    if (KPMetadata::isRawFile(src))
     {
         err = i18n("Cannot rotate RAW file");
         return false;
     }
     else if (Utils::isJPEG(src))
     {
-        if (!rotateJPEG(src, tmp, angle, err, updateFileTimeStamp))
+        if (!rotateJPEG(src, tmp, angle, err))
         {
             if (err == "nothing to do") { err.clear(); return true; }
             return false;
@@ -126,6 +126,7 @@ bool ImageRotate::rotate(const QString& src, RotateAction angle, QString& err, b
 
         // We update metadata on new image.
         Utils tools(this);
+
         if (!tools.updateMetadataImageMagick(tmp, err))
             return false;
     }
@@ -140,8 +141,7 @@ bool ImageRotate::rotate(const QString& src, RotateAction angle, QString& err, b
     return true;
 }
 
-bool ImageRotate::rotateJPEG(const QString& src, const QString& dest, RotateAction angle,
-                             QString& err, bool updateFileTimeStamp)
+bool ImageRotate::rotateJPEG(const QString& src, const QString& dest, RotateAction angle, QString& err)
 {
     Matrix transform = Matrix::none;
 
@@ -175,7 +175,7 @@ bool ImageRotate::rotateJPEG(const QString& src, const QString& dest, RotateActi
         }
     }
 
-    return transformJPEG(src, dest, transform, err, updateFileTimeStamp);
+    return transformJPEG(src, dest, transform, err);
 }
 
 bool ImageRotate::rotateImageMagick(const QString& src, const QString& dest, 
