@@ -7,7 +7,7 @@
  * Description : a tool to export GPS data to KML file.
  *
  * Copyright (C) 2006-2007 by Stephane Pontier <shadow dot walker at free dot fr>
- * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -63,9 +63,20 @@ namespace KIPIKMLExportPlugin
 
 KmlExport::KmlExport(Interface* const interface)
 {
-    m_kmlDocument    = 0;
-    m_interface      = interface;
-    m_progressDialog = new KPBatchProgressDialog(kapp->activeWindow(), i18n("Generating KML file..."));
+    m_localTarget        = true;
+    m_optimize_googlemap = false;
+    m_GPXtracks          = false;
+    m_iconSize           = 33;
+    m_googlemapSize      = 32;
+    m_size               = 320;
+    m_altitudeMode       = 0;
+    m_TimeZone           = 12;
+    m_LineWidth          = 4;
+    m_GPXOpacity         = 64;
+    m_GPXAltitudeMode    = 0;
+    m_kmlDocument        = 0;
+    m_interface          = interface;
+    m_progressDialog     = new KPBatchProgressDialog(kapp->activeWindow(), i18n("Generating KML file..."));
 }
 
 KmlExport::~KmlExport()
@@ -74,7 +85,7 @@ KmlExport::~KmlExport()
 }
 
 /*!
-	\fn KmlExport::createDir(QDir dir)
+    \fn KmlExport::createDir(QDir dir)
  */
 bool KmlExport::createDir(const QDir& dir) const
 {
@@ -83,11 +94,13 @@ bool KmlExport::createDir(const QDir& dir) const
     QDir parent = dir;
     parent.cdUp();
     bool ok     = createDir(parent);
+
     if (!ok)
     {
         logError(i18n("Could not create '%1'", parent.path()));
         return false;
     }
+
     return parent.mkdir(dir.dirName());
 }
 
@@ -115,10 +128,12 @@ QImage KmlExport::generateSquareThumbnail(const QImage& fullImage, int size) con
     {
         return image;
     }
+
     QPixmap croppedPix(size, size);
     QPainter painter(&croppedPix);
 
     int sx=0, sy=0;
+
     if (image.width()>size)
     {
         sx = (image.width() - size)/2;
@@ -127,6 +142,7 @@ QImage KmlExport::generateSquareThumbnail(const QImage& fullImage, int size) con
     {
         sy = (image.height() - size)/2;
     }
+
     painter.drawImage(0, 0, image, sx, sy, size, size);
     painter.end();
 
@@ -166,6 +182,7 @@ void KmlExport::generateImagesthumb(const KUrl& imageURL, QDomElement& kmlAlbum
     // Load image
     QString path = imageURL.path();
     QFile imageFile(path);
+
     if (!imageFile.open(QIODevice::ReadOnly))
     {
         logWarning(i18n("Could not read image '%1'",path));
@@ -174,16 +191,19 @@ void KmlExport::generateImagesthumb(const KUrl& imageURL, QDomElement& kmlAlbum
 
     QImageReader reader(&imageFile);
     QString imageFormat = reader.format();
+
     if (imageFormat.isEmpty())
     {
         logWarning(i18n("Format of image '%1' is unknown",path));
         return;
     }
+
     imageFile.close();
     imageFile.open(QIODevice::ReadOnly);
 
     QByteArray imageData = imageFile.readAll();
     QImage image;
+
     if (!image.loadFromData(imageData) )
     {
         logWarning(i18n("Error loading image '%1'",path));
@@ -197,16 +217,17 @@ void KmlExport::generateImagesthumb(const KUrl& imageURL, QDomElement& kmlAlbum
         QMatrix matrix = RotationMatrix::toMatrix(info.orientation());
         image          = image.transformed( matrix );
     }
-    image = image.scaled(m_size, m_size, Qt::KeepAspectRatioByExpanding);
 
+    image = image.scaled(m_size, m_size, Qt::KeepAspectRatioByExpanding);
     QImage icon;
+
     if (m_optimize_googlemap)
     {
         icon = generateSquareThumbnail(image,m_googlemapSize);
     }
     else
     {
-    //	icon = image.smoothScale(m_iconSize, m_iconSize, QImage::ScaleMax);
+    //    icon = image.smoothScale(m_iconSize, m_iconSize, QImage::ScaleMax);
         icon = generateBorderedThumbnail(image, m_iconSize);
     }
 
@@ -276,6 +297,7 @@ void KmlExport::generateImagesthumb(const KUrl& imageURL, QDomElement& kmlAlbum
         {
             addKmlTextElement(kmlGeometry, "altitudeMode", "clampToGround");
         }
+
         addKmlTextElement(kmlGeometry, "extrude", "1");
 
         // we try to load exif value if any otherwise, try the application db
@@ -288,7 +310,7 @@ void KmlExport::generateImagesthumb(const KUrl& imageURL, QDomElement& kmlAlbum
           * So for:
           * - a DSC: the right time is the DateTimeDigitized which is also DateTimeOriginal
           *          if the picture has been modified the (standard)DateTime should change.
-          * - a scanned picture, the right time is the DateTimeOriginal which should also be the the DateTime
+          * - a scanned picture, the right time is the DateTimeOriginal which should also be the DateTime
           *          the (standard)DateTime should be the same except if the picture is modified
           * - a panorama created from several pictures, the right time is the DateTimeOriginal (average of DateTimeOriginal actually)
           *          The (standard)DateTime is the creation date of the panorama.
@@ -331,6 +353,7 @@ void KmlExport::generateImagesthumb(const KUrl& imageURL, QDomElement& kmlAlbum
         // Save icon
         QString iconFileName = "thumb_" + baseFileName + '.' + imageFormat.toLower();
         QString destPath     = m_tempDestDir + m_imageDir + iconFileName;
+
         if (!icon.save(destPath, imageFormat.toAscii(), 85))
         {
             logWarning(i18n("Could not save icon for image '%1' to '%2'",path,destPath));
@@ -342,6 +365,7 @@ void KmlExport::generateImagesthumb(const KUrl& imageURL, QDomElement& kmlAlbum
             QDomElement kmlStyle     = addKmlElement(kmlPlacemark, "Style");
             QDomElement kmlIconStyle = addKmlElement(kmlStyle,     "IconStyle");
             QDomElement kmlIcon      = addKmlElement(kmlIconStyle, "Icon");
+
             if (m_optimize_googlemap)
             {
                 addKmlTextElement(kmlIcon, "href", m_UrlDestDir + m_imageDir + iconFileName);
@@ -350,6 +374,7 @@ void KmlExport::generateImagesthumb(const KUrl& imageURL, QDomElement& kmlAlbum
             {
                 addKmlTextElement(kmlIcon, "href", m_imageDir + iconFileName);
             }
+
             QDomElement kmlBallonStyle = addKmlElement(kmlStyle, "BalloonStyle");
             addKmlTextElement(kmlBallonStyle, "text", "$[description]");
         }
@@ -483,6 +508,7 @@ void KmlExport::generate()
             logWarning(i18n("No position data for '%1'", info.name()));
             defectImage++;
         }
+
         m_progressDialog->progressWidget()->setProgress(pos, count);
         kapp->processEvents();
     }
@@ -522,7 +548,7 @@ int KmlExport::getConfig()
     m_localTarget        = group.readEntry("localTarget", true);
     m_optimize_googlemap = group.readEntry("optimize_googlemap", false);
     m_iconSize           = group.readEntry("iconSize", 33);
-    //	googlemapSize    = group.readNumEntry("googlemapSize");
+    //    googlemapSize    = group.readNumEntry("googlemapSize");
     m_size               = group.readEntry("size", 320);
 
     // UrlDestDir have to have the trailing
