@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2006-10-18
  * Description : EXIF light settings page.
  *
- * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,7 +37,7 @@ class EXIFLight : public QWidget
 
 public:
 
-    EXIFLight(QWidget* parent);
+    explicit EXIFLight(QWidget* const parent);
     ~EXIFLight();
 
     void applyMetadata(QByteArray& exifData);
@@ -49,8 +49,8 @@ Q_SIGNALS:
 
 private:
 
-    class EXIFLightPriv;
-    EXIFLightPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace KIPIMetadataEditPlugin
