@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2007-11-10
  * Description : IPTC workflow status properties settings page.
  *
- * Copyright (C) 2007-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,26 +44,23 @@
 #include <klocale.h>
 #include <kseparator.h>
 
-// LibKExiv2 includes
-
-#include <libkexiv2/kexiv2.h>
-
 // Local includes
 
 #include "metadatacheckbox.h"
 #include "objectattributesedit.h"
-#include "pluginsversion.h"
+#include "kpversion.h"
+#include "kpmetadata.h"
 
-using namespace KExiv2Iface;
+using namespace KIPIPlugins;
 
 namespace KIPIMetadataEditPlugin
 {
 
-class IPTCProperties::IPTCPropertiesPriv
+class IPTCProperties::Private
 {
 public:
 
-    IPTCPropertiesPriv()
+    Private()
     {
         dateReleasedSel     = 0;
         dateExpiredSel      = 0;
@@ -86,7 +83,7 @@ public:
         languageCheck       = 0;
         originalTransCheck  = 0;
         originalTransEdit   = 0;
-
+        objectTypeDescEdit  = 0;
     }
 
     QCheckBox*                     dateReleasedCheck;
@@ -121,14 +118,14 @@ public:
     ObjectAttributesEdit*          objectAttribute;
 };
 
-IPTCProperties::IPTCProperties(QWidget* parent)
-    : QWidget(parent), d(new IPTCPropertiesPriv)
+IPTCProperties::IPTCProperties(QWidget* const parent)
+    : QWidget(parent), d(new Private)
 {
-    QGridLayout* grid = new QGridLayout(this);
+    QGridLayout* const grid = new QGridLayout(this);
 
     // IPTC only accept printable Ascii char.
     QRegExp asciiRx("[\x20-\x7F]+$");
-    QValidator* asciiValidator = new QRegExpValidator(asciiRx, this);
+    QValidator* const asciiValidator = new QRegExpValidator(asciiRx, this);
 
     // --------------------------------------------------------
 
@@ -171,6 +168,7 @@ IPTCProperties::IPTCProperties(QWidget* parent)
     d->languageBtn   = new KLanguageButton(this);
 
     QStringList list = KGlobal::locale()->allLanguagesList();
+
     for (QStringList::Iterator it = list.begin(); it != list.end(); ++it)
     {
         // Only get all ISO 639 language code based on 2 characters
@@ -194,6 +192,7 @@ IPTCProperties::IPTCProperties(QWidget* parent)
     d->priorityCB->insertItem(6, "6");
     d->priorityCB->insertItem(7, "7");
     d->priorityCB->insertItem(8, i18nc("editorial urgency of content", "8: Low"));
+    d->priorityCB->insertItem(9, i18nc("editorial urgency of content", "9: User-defined"));
     d->priorityCB->setWhatsThis(i18n("Select here the editorial urgency of content."));
 
     // --------------------------------------------------------
@@ -236,7 +235,7 @@ IPTCProperties::IPTCProperties(QWidget* parent)
 
     // --------------------------------------------------------
 
-    QLabel* note = new QLabel(i18n("<b>Note: "
+    QLabel* const note = new QLabel(i18n("<b>Note: "
                  "<b><a href='http://en.wikipedia.org/wiki/IPTC_Information_Interchange_Model'>IPTC</a></b> "
                  "text tags only support the printable "
                  "<b><a href='http://en.wikipedia.org/wiki/Ascii'>ASCII</a></b> "
@@ -406,76 +405,88 @@ void IPTCProperties::slotSetTodayExpired()
 void IPTCProperties::readMetadata(QByteArray& iptcData)
 {
     blockSignals(true);
-    KExiv2 exiv2Iface;
-    exiv2Iface.setIptc(iptcData);
+    KPMetadata meta;
+    meta.setIptc(iptcData);
 
-    int         val;
     QString     data;
     QStringList list;
     QDate       date;
     QTime       time;
     QString     dateStr, timeStr;
 
-    dateStr = exiv2Iface.getIptcTagString("Iptc.Application2.ReleaseDate", false);
-    timeStr = exiv2Iface.getIptcTagString("Iptc.Application2.ReleaseTime", false);
+    dateStr = meta.getIptcTagString("Iptc.Application2.ReleaseDate", false);
+    timeStr = meta.getIptcTagString("Iptc.Application2.ReleaseTime", false);
 
     d->dateReleasedSel->setDate(QDate::currentDate());
     d->dateReleasedCheck->setChecked(false);
+
     if (!dateStr.isEmpty())
     {
         date = QDate::fromString(dateStr, Qt::ISODate);
+
         if (date.isValid())
         {
             d->dateReleasedSel->setDate(date);
             d->dateReleasedCheck->setChecked(true);
         }
     }
+
     d->dateReleasedSel->setEnabled(d->dateReleasedCheck->isChecked());
 
     d->timeReleasedSel->setTime(QTime::currentTime());
     d->timeReleasedCheck->setChecked(false);
+
     if (!timeStr.isEmpty())
     {
         time = QTime::fromString(timeStr, Qt::ISODate);
+
         if (time.isValid())
         {
             d->timeReleasedSel->setTime(time);
             d->timeReleasedCheck->setChecked(true);
         }
     }
+
     d->timeReleasedSel->setEnabled(d->timeReleasedCheck->isChecked());
 
-    dateStr = exiv2Iface.getIptcTagString("Iptc.Application2.ExpirationDate", false);
-    timeStr = exiv2Iface.getIptcTagString("Iptc.Application2.ExpirationTime", false);
+    dateStr = meta.getIptcTagString("Iptc.Application2.ExpirationDate", false);
+    timeStr = meta.getIptcTagString("Iptc.Application2.ExpirationTime", false);
 
     d->dateExpiredSel->setDate(QDate::currentDate());
     d->dateExpiredCheck->setChecked(false);
+
     if (!dateStr.isEmpty())
     {
         date = QDate::fromString(dateStr, Qt::ISODate);
+
         if (date.isValid())
         {
             d->dateExpiredSel->setDate(date);
             d->dateExpiredCheck->setChecked(true);
         }
     }
+
     d->dateExpiredSel->setEnabled(d->dateExpiredCheck->isChecked());
 
     d->timeExpiredSel->setTime(QTime::currentTime());
     d->timeExpiredCheck->setChecked(false);
+
     if (!timeStr.isEmpty())
     {
         time = QTime::fromString(timeStr, Qt::ISODate);
+
         if (time.isValid())
         {
             d->timeExpiredSel->setTime(time);
             d->timeExpiredCheck->setChecked(true);
         }
     }
+
     d->timeExpiredSel->setEnabled(d->timeExpiredCheck->isChecked());
 
     d->languageCheck->setChecked(false);
-    data = exiv2Iface.getIptcTagString("Iptc.Application2.Language", false);
+    data = meta.getIptcTagString("Iptc.Application2.Language", false);
+
     if (!data.isNull())
     {
         if (d->languageBtn->contains(data))
@@ -484,29 +495,36 @@ void IPTCProperties::readMetadata(QByteArray& iptcData)
             d->languageCheck->setChecked(true);
         }
         else
+        {
             d->languageCheck->setValid(false);
+        }
     }
+
     d->languageBtn->setEnabled(d->languageCheck->isChecked());
 
     d->priorityCB->setCurrentIndex(0);
     d->priorityCheck->setChecked(false);
-    data = exiv2Iface.getIptcTagString("Iptc.Application2.Urgency", false);
+    data = meta.getIptcTagString("Iptc.Application2.Urgency", false);
+
     if (!data.isNull())
     {
-        val = data.toInt();
-        if (val >= 0 && val <= 8)
+        const int val = data.toInt();
+        if (val >= 0 && val <= 9)
         {
             d->priorityCB->setCurrentIndex(val);
             d->priorityCheck->setChecked(true);
         }
         else
+        {
             d->priorityCheck->setValid(false);
+        }
     }
     d->priorityCB->setEnabled(d->priorityCheck->isChecked());
 
     d->objectCycleCB->setCurrentIndex(0);
     d->objectCycleCheck->setChecked(false);
-    data = exiv2Iface.getIptcTagString("Iptc.Application2.ObjectCycle", false);
+    data = meta.getIptcTagString("Iptc.Application2.ObjectCycle", false);
+
     if (!data.isNull())
     {
         if (data == QString("a"))
@@ -527,18 +545,22 @@ void IPTCProperties::readMetadata(QByteArray& iptcData)
         else
             d->objectCycleCheck->setValid(false);
     }
+
     d->objectCycleCB->setEnabled(d->objectCycleCheck->isChecked());
 
     d->objectTypeCB->setCurrentIndex(0);
     d->objectTypeDescEdit->clear();
     d->objectTypeCheck->setChecked(false);
-    data = exiv2Iface.getIptcTagString("Iptc.Application2.ObjectType", false);
+    data = meta.getIptcTagString("Iptc.Application2.ObjectType", false);
+
     if (!data.isNull())
     {
         QString typeSec = data.section(':', 0, 0);
+
         if (!typeSec.isEmpty())
         {
             int type = typeSec.toInt()-1;
+
             if (type >= 0 && type < 3)
             {
                 d->objectTypeCB->setCurrentIndex(type);
@@ -546,23 +568,28 @@ void IPTCProperties::readMetadata(QByteArray& iptcData)
                 d->objectTypeCheck->setChecked(true);
             }
             else
+            {
                 d->objectTypeCheck->setValid(false);
+            }
         }
     }
+
     d->objectTypeCB->setEnabled(d->objectTypeCheck->isChecked());
     d->objectTypeDescEdit->setEnabled(d->objectTypeCheck->isChecked());
 
-    list = exiv2Iface.getIptcTagsStringList("Iptc.Application2.ObjectAttribute", false);
+    list = meta.getIptcTagsStringList("Iptc.Application2.ObjectAttribute", false);
     d->objectAttribute->setValues(list);
 
     d->originalTransEdit->clear();
     d->originalTransCheck->setChecked(false);
-    data = exiv2Iface.getIptcTagString("Iptc.Application2.TransmissionReference", false);
+    data = meta.getIptcTagString("Iptc.Application2.TransmissionReference", false);
+
     if (!data.isNull())
     {
         d->originalTransEdit->setText(data);
         d->originalTransCheck->setChecked(true);
     }
+
     d->originalTransEdit->setEnabled(d->originalTransCheck->isChecked());
 
     blockSignals(false);
@@ -570,87 +597,92 @@ void IPTCProperties::readMetadata(QByteArray& iptcData)
 
 void IPTCProperties::applyMetadata(QByteArray& iptcData)
 {
-    KExiv2 exiv2Iface;
-    exiv2Iface.setIptc(iptcData);
+    KPMetadata meta;
+    meta.setIptc(iptcData);
 
     if (d->dateReleasedCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.ReleaseDate",
+        meta.setIptcTagString("Iptc.Application2.ReleaseDate",
                                     d->dateReleasedSel->date().toString(Qt::ISODate));
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.ReleaseDate");
+        meta.removeIptcTag("Iptc.Application2.ReleaseDate");
 
     if (d->dateExpiredCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.ExpirationDate",
+        meta.setIptcTagString("Iptc.Application2.ExpirationDate",
                                     d->dateExpiredSel->date().toString(Qt::ISODate));
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.ExpirationDate");
+        meta.removeIptcTag("Iptc.Application2.ExpirationDate");
 
     if (d->timeReleasedCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.ReleaseTime",
+        meta.setIptcTagString("Iptc.Application2.ReleaseTime",
                                     d->timeReleasedSel->time().toString(Qt::ISODate));
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.ReleaseTime");
+        meta.removeIptcTag("Iptc.Application2.ReleaseTime");
 
     if (d->timeExpiredCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.ExpirationTime",
+        meta.setIptcTagString("Iptc.Application2.ExpirationTime",
                                     d->timeExpiredSel->time().toString(Qt::ISODate));
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.ExpirationTime");
+        meta.removeIptcTag("Iptc.Application2.ExpirationTime");
 
     if (d->languageCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.Language", d->languageBtn->current());
+        meta.setIptcTagString("Iptc.Application2.Language", d->languageBtn->current());
     else if (d->languageCheck->isValid())
-        exiv2Iface.removeIptcTag("Iptc.Application2.Language");
+        meta.removeIptcTag("Iptc.Application2.Language");
 
     if (d->priorityCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.Urgency", QString::number(d->priorityCB->currentIndex()));
+        meta.setIptcTagString("Iptc.Application2.Urgency", QString::number(d->priorityCB->currentIndex()));
     else if (d->priorityCheck->isValid())
-        exiv2Iface.removeIptcTag("Iptc.Application2.Urgency");
+        meta.removeIptcTag("Iptc.Application2.Urgency");
 
     if (d->objectCycleCheck->isChecked())
     {
         switch (d->objectCycleCB->currentIndex())
         {
             case(0):
-                exiv2Iface.setIptcTagString("Iptc.Application2.ObjectCycle", QString("a"));
+                meta.setIptcTagString("Iptc.Application2.ObjectCycle", QString("a"));
                 break;
 
             case(1):
-                exiv2Iface.setIptcTagString("Iptc.Application2.ObjectCycle", QString("b"));
+                meta.setIptcTagString("Iptc.Application2.ObjectCycle", QString("b"));
                 break;
 
             case(2):
-                exiv2Iface.setIptcTagString("Iptc.Application2.ObjectCycle", QString("c"));
+                meta.setIptcTagString("Iptc.Application2.ObjectCycle", QString("c"));
                 break;
         }
     }
     else if (d->objectCycleCheck->isValid())
-        exiv2Iface.removeIptcTag("Iptc.Application2.ObjectCycle");
+    {
+        meta.removeIptcTag("Iptc.Application2.ObjectCycle");
+    }
 
     if (d->objectTypeCheck->isChecked())
     {
         QString objectType;
         objectType.sprintf("%2d", d->objectTypeCB->currentIndex()+1);
         objectType.append(QString(":%1").arg(d->objectTypeDescEdit->text()));
-        exiv2Iface.setIptcTagString("Iptc.Application2.ObjectType", objectType);
+        meta.setIptcTagString("Iptc.Application2.ObjectType", objectType);
     }
     else if (d->objectTypeCheck->isValid())
-        exiv2Iface.removeIptcTag("Iptc.Application2.ObjectType");
+    {
+        meta.removeIptcTag("Iptc.Application2.ObjectType");
+    }
 
     QStringList oldList, newList;
+
     if (d->objectAttribute->getValues(oldList, newList))
-        exiv2Iface.setIptcTagsStringList("Iptc.Application2.ObjectAttribute", 64, oldList, newList);
+        meta.setIptcTagsStringList("Iptc.Application2.ObjectAttribute", 64, oldList, newList);
     else if (d->objectAttribute->isValid())
-        exiv2Iface.removeIptcTag("Iptc.Application2.ObjectAttribute");
+        meta.removeIptcTag("Iptc.Application2.ObjectAttribute");
 
     if (d->originalTransCheck->isChecked())
-        exiv2Iface.setIptcTagString("Iptc.Application2.TransmissionReference", d->originalTransEdit->text());
+        meta.setIptcTagString("Iptc.Application2.TransmissionReference", d->originalTransEdit->text());
     else
-        exiv2Iface.removeIptcTag("Iptc.Application2.TransmissionReference");
+        meta.removeIptcTag("Iptc.Application2.TransmissionReference");
 
-    exiv2Iface.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
+    meta.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
 
-    iptcData = exiv2Iface.getIptc();
+    iptcData = meta.getIptc();
 }
 
 }  // namespace KIPIMetadataEditPlugin
