@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2011-05-23
  * Description : a plugin to create panorama by fusion of several images.
  * Acknowledge : based on the expoblending plugin
  *
- * Copyright (C) 2011 by Benjamin Girault <benjamin dot girault at gmail dot com>
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2012 by Benjamin Girault <benjamin dot girault at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -27,7 +27,7 @@
 
 // Local includes
 
-#include "wizardpage.h"
+#include "kpwizardpage.h"
 
 // KDE includes
 
@@ -44,22 +44,22 @@ namespace KIPIPanoramaPlugin
 
 class Manager;
 
-class PreProcessingPage : public WizardPage
+class PreProcessingPage : public KPWizardPage
 {
     Q_OBJECT
 
 public:
 
-    PreProcessingPage(Manager* mngr, KAssistantDialog* dlg);
+    PreProcessingPage(Manager* const mngr, KAssistantDialog* const dlg);
     ~PreProcessingPage();
 
     void process();
-    void cancel();
+    bool cancel();
     void resetPage();
 
 Q_SIGNALS:
 
-    void signalPreProcessed(const ItemUrlsMap&);
+    void signalPreProcessed(bool);
 
 private Q_SLOTS:
 
