@@ -38,6 +38,7 @@
 #include <ktempdir.h>
 #include <threadweaver/ThreadWeaver.h>
 #include <threadweaver/JobCollection.h>
+#include <threadweaver/JobSequence.h>
 #include <threadweaver/DependencyPolicy.h>
 
 // Local includes
@@ -86,7 +87,7 @@ ActionThread::~ActionThread()
 
 void ActionThread::preProcessFiles(const KUrl::List& urlList, ItemUrlsMap& preProcessedMap,
                                    KUrl& baseUrl, KUrl& cpFindPtoUrl, KUrl& cpCleanPtoUrl,
-                                   bool celeste, bool hdr, PanoramaFileType fileType,
+                                   bool celeste, PanoramaFileType fileType, bool gPano,
                                    const RawDecodingSettings& rawSettings,
                                    const QString& cpCleanPath, const QString& cpFindPath)
 {
@@ -123,10 +124,10 @@ void ActionThread::preProcessFiles(const KUrl::List& urlList, ItemUrlsMap& prePr
 
     CreatePtoTask *pto = new CreatePtoTask(d->preprocessingTmpDir->name(),
                                            fileType,
-                                           hdr,
                                            baseUrl,
                                            urlList,
-                                           preProcessedMap);
+                                           preProcessedMap,
+                                           gPano);
 
     connect(pto, SIGNAL(started(ThreadWeaver::Job*)),
             this, SLOT(slotStarting(ThreadWeaver::Job*)));
@@ -169,24 +170,38 @@ void ActionThread::preProcessFiles(const KUrl::List& urlList, ItemUrlsMap& prePr
     appendJob(jobs);
 }
 
-void ActionThread::optimizeProject(KUrl& ptoUrl, KUrl& optimizePtoUrl, bool levelHorizon,
-                                   bool optimizeProjectionAndSize, const QString& autooptimiserPath)
+void ActionThread::optimizeProject(KUrl& ptoUrl, KUrl& optimizePtoUrl, KUrl& viewCropPtoUrl,
+                                   bool levelHorizon, bool buildGPano,
+                                   const QString& autooptimiserPath, const QString& panoModifyPath)
 {
-    JobCollection       *jobs                       = new JobCollection();
+    JobSequence       *jobs                       = new JobSequence();
 
-    OptimisationTask *t = new OptimisationTask(d->preprocessingTmpDir->name(),
+    OptimisationTask *ot = new OptimisationTask(d->preprocessingTmpDir->name(),
                                                ptoUrl,
                                                optimizePtoUrl,
                                                levelHorizon,
-                                               optimizeProjectionAndSize,
+//                                                buildGPano,
                                                autooptimiserPath);
 
-    connect(t, SIGNAL(started(ThreadWeaver::Job*)),
+    connect(ot, SIGNAL(started(ThreadWeaver::Job*)),
             this, SLOT(slotStarting(ThreadWeaver::Job*)));
-    connect(t, SIGNAL(done(ThreadWeaver::Job*)),
+    connect(ot, SIGNAL(done(ThreadWeaver::Job*)),
+            this, SLOT(slotStepDone(ThreadWeaver::Job*)));
+
+    jobs->addJob(ot);
+
+    AutoCropTask *act = new AutoCropTask(d->preprocessingTmpDir->name(),
+                                         optimizePtoUrl,
+                                         viewCropPtoUrl,
+                                         buildGPano,
+                                         panoModifyPath);
+
+    connect(act, SIGNAL(started(ThreadWeaver::Job*)),
+            this, SLOT(slotStarting(ThreadWeaver::Job*)));
+    connect(act, SIGNAL(done(ThreadWeaver::Job*)),
             this, SLOT(slotDone(ThreadWeaver::Job*)));
 
-    jobs->addJob(t);
+    jobs->addJob(act);
 
     appendJob(jobs);
 }
@@ -263,7 +278,7 @@ void ActionThread::compileProject(const PTOType& basePtoData, KUrl& panoPtoUrl,
 }
 
 void ActionThread::copyFiles(const KUrl& ptoUrl, const KUrl& panoUrl, const KUrl& finalPanoUrl,
-                             const ItemUrlsMap& preProcessedUrlsMap, bool savePTO)
+                             const ItemUrlsMap& preProcessedUrlsMap, bool savePTO, bool addGPlusMetadata)
 {
     JobCollection   *jobs           = new JobCollection();
 
@@ -272,7 +287,8 @@ void ActionThread::copyFiles(const KUrl& ptoUrl, const KUrl& panoUrl, const KUrl
                                          finalPanoUrl,
                                          ptoUrl,
                                          preProcessedUrlsMap,
-                                         savePTO);
+                                         savePTO,
+                                         addGPlusMetadata);
 
     connect(t, SIGNAL(started(ThreadWeaver::Job*)),
             this, SLOT(slotStarting(ThreadWeaver::Job*)));
