@@ -7,8 +7,8 @@
  * Description : a plugin to create panorama by fusion of several images.
  * Acknowledge : based on the expoblending plugin
  *
- * Copyright (C) 2011-2012 by Benjamin Girault <benjamin dot girault at gmail dot com>
- * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011-2013 by Benjamin Girault <benjamin dot girault at gmail dot com>
+ * Copyright (C) 2009-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -73,6 +73,7 @@ Plugin_Panorama::~Plugin_Panorama()
 {
     if (m_action != 0)
         delete m_action;
+
     if (m_manager != 0)
         delete m_manager;
 }
@@ -85,6 +86,7 @@ void Plugin_Panorama::setup(QWidget* const widget)
     setupActions();
 
     m_interface = interface();
+
     if (!m_interface)
     {
        kError() << "Kipi interface is null!";
@@ -100,7 +102,7 @@ void Plugin_Panorama::setupActions()
 
     m_action = new KAction(this);
     m_action->setText(i18n("Stitch images into a panorama..."));
-    m_action->setIcon(KIcon("layer-visible-on"));
+    m_action->setIcon(KIcon("kipi-panorama"));
     m_action->setEnabled(false);
 
     connect(m_action, SIGNAL(triggered(bool)),
