@@ -47,6 +47,11 @@ PLEConfigDialog::PLEConfigDialog(QWidget * parent) :
     this->addPage( d->confVWdg, i18n("View") )->setIcon(KIcon(QIcon(":/view.png")));
 }
 
+PLEConfigDialog::~PLEConfigDialog()
+{
+   delete d;
+}
+
 void PLEConfigDialog::updateSettings()
 {
     d->confVWdg->updateSettings();
