@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2011-09-01
  * Description : a plugin to create photo layouts by fusion of several images.
@@ -42,11 +42,12 @@ PhotoItemLoader::PhotoItemLoader(PhotoItem * item, QDomElement & element, QObjec
 
 void PhotoItemLoader::run()
 {
-    QDomElement e = this->element();
     PhotoItem * item = (PhotoItem*) this->item();
     ProgressObserver * observer = this->observer();
     AbstractPhotoItemLoader::run();
 
+    QDomElement e = this->element();
+
     // Gets data field
     QDomElement defs = e.firstChildElement("defs");
     while (!defs.isNull() && defs.attribute("class") != "data")
@@ -70,6 +71,32 @@ void PhotoItemLoader::run()
     if (item->m_image_path.isEmpty())
         this->exit(1);
 
+    // transform
+    QDomElement transform = path.nextSiblingElement("transform");
+    if (!transform.isNull())
+    {
+        item->d->m_brush_transform = QTransform();
+        QRegExp rot("matrix\\([-0-9.]+,[-0-9.]+,[-0-9.]+,[-0-9.]+,[-0-9.]+,[-0-9.]+\\)");
+        if (rot.indexIn(transform.attribute("matrix")) >= 0)
+        {
+            QStringList list = rot.capturedTexts();
+            QString matrix = list.at(0);
+            matrix.remove(matrix.length()-1,1).remove(0,7);
+            list = matrix.split(',');
+            QString m11 = list.at(0);
+            QString m12 = list.at(1);
+            QString m21 = list.at(2);
+            QString m22 = list.at(3);
+            QString m31 = list.at(4);
+            QString m32 = list.at(5);
+            item->d->m_brush_transform *= QTransform(m11.toDouble(), m12.toDouble(), 0,
+                                                     m21.toDouble(), m22.toDouble(), 0,
+                                                     m31.toDouble(), m32.toDouble(), 1);
+        }
+        qDebug() << item->d->m_brush_transform;
+    }
+    qDebug() << item->d->m_brush_transform;
+
     // m_pixmap_original
     if (observer)
     {
@@ -82,8 +109,8 @@ void PhotoItemLoader::run()
     if (!(imageAttribute = imageElement.text()).isEmpty())
     {
         item->d->m_image = QImage::fromData( QByteArray::fromBase64(imageAttribute.toAscii()) );
-        if (item->d->m_image.isNull())
-            this->exit(1);
+        //if (item->d->m_image.isNull())
+        //    this->exit(1);
     }
     // Try to find file from path attribute
     else if ( !(imageAttribute = PhotoItem::PhotoItemPrivate::locateFile( imageElement.attribute("xlink:href") )).isEmpty() )
