@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2011-09-01
  * Description : a plugin to create photo layouts by fusion of several images.
@@ -26,6 +26,15 @@
 #include "Canvas.moc"
 #include "Canvas_p.h"
 
+#include <QPrinter>
+#include <QPaintDevice>
+#include <QPaintEngine>
+#include <QVBoxLayout>
+
+#include <kapplication.h>
+#include <kmessagebox.h>
+#include <klocalizedstring.h>
+
 #include "Scene.h"
 #include "LayersModel.h"
 #include "LayersModelItem.h"
@@ -41,15 +50,6 @@
 #include "CanvasSavingThread.h"
 #include "PLEStatusBar.h"
 
-#include <QPrinter>
-#include <QPaintDevice>
-#include <QPaintEngine>
-#include <QVBoxLayout>
-
-#include <kapplication.h>
-#include <kmessagebox.h>
-#include <klocalizedstring.h>
-
 #define MAX_SCALE_LIMIT 4
 #define MIN_SCALE_LIMIT 0.5
 
@@ -846,13 +846,14 @@ Canvas * Canvas::fromSvg(QDomDocument & document)
             QString xResolution = pageElement.attribute("width");
             QString yResolution = pageElement.attribute("height");
             QString resUnit = pageElement.attribute("unit");
+            qDebug() << pageElement.namespaceURI() << KIPIPhotoLayoutsEditor::templateUri();
+
             // Canvas size validation
             QRegExp sizeRegExp("[0-9.]+((cm)|(mm)|(in)|(pc)|(pt)|(px))");
             QRegExp resRegExp("[0-9.]+");
             if (sizeRegExp.exactMatch(width) &&
                     sizeRegExp.exactMatch(height) &&
                     width.right(2) == height.right(2) &&
-                    pageElement.namespaceURI() == KIPIPhotoLayoutsEditor::uri() &&
                     resRegExp.exactMatch(xResolution) &&
                     resRegExp.exactMatch(yResolution) &&
                     CanvasSize::resolutionUnit(resUnit) != CanvasSize::UnknownResolutionUnit)
@@ -877,6 +878,7 @@ Canvas * Canvas::fromSvg(QDomDocument & document)
                         result = new Canvas(scene);
                         result->setEnabled(false);
                         result->d->m_size = size;
+                        result->d->m_template = (pageElement.namespaceURI() == KIPIPhotoLayoutsEditor::templateUri());
                     }
                 }
             }
@@ -893,7 +895,7 @@ Canvas * Canvas::fromSvg(QDomDocument & document)
 void Canvas::scale(qreal factor, const QPoint & center)
 {
     // Scaling limitation
-    if (factor <= 0 || !scene() || (m_scale_factor*factor <= 0.1 && factor < 1 && m_scale_factor*factor > 7))
+    if (factor <= 0 || !scene() || ((m_scale_factor*factor <= 0.1 && factor < 1) || (m_scale_factor*factor > 7)))
         return;
 
     QGraphicsView::scale(factor, factor);
@@ -973,6 +975,24 @@ void Canvas::save(const KUrl & fileUrl, bool setAsDefault)
     thread->save(this, m_file);
 }
 
+/** ###########################################################################################################################
+ * Save canvas as a template
+ #############################################################################################################################*/
+void Canvas::saveTemplate(const KUrl & fileUrl)
+{
+    if (fileUrl.isEmpty() || !fileUrl.isValid())
+    {
+        KMessageBox::detailedError(0,
+                                   i18n("Can't save canvas!"),
+                                   i18n("Invalid file path."));
+        return;
+    }
+
+    CanvasSavingThread * thread = new CanvasSavingThread(this);
+    connect(thread, SIGNAL(saved()), this, SLOT(savingFinished()));
+    thread->saveAsTemplate(this, fileUrl);
+}
+
 /** ###########################################################################################################################
  * Check if canvas is saved
  #############################################################################################################################*/
@@ -1002,6 +1022,14 @@ void Canvas::isSavedChanged(bool /*isStackClean*/)
     emit savedStateChanged();
 }
 
+/** ###########################################################################################################################
+ * Controls changes on cavnas (based on QUndoStack state)
+ #############################################################################################################################*/
+bool Canvas::isTemplate() const
+{
+    return d->m_template;
+}
+
 /** ###########################################################################################################################
  * Saving finished slot
  #############################################################################################################################*/
