@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2011-09-01
  * Description : a plugin to create photo layouts by fusion of several images.
@@ -23,11 +23,9 @@
  *
  * ============================================================ */
 
-#ifndef DOCUMENT_H
-#define DOCUMENT_H
+#ifndef CANVAS_H
+#define CANVAS_H
 
-#include "global.h"
-#include "CanvasSize.h"
 
 // Qt
 #include <QObject>
@@ -46,6 +44,9 @@
 #include <klocalizedstring.h>
 #include <kurl.h>
 
+#include "global.h"
+#include "CanvasSize.h"
+
 namespace KIPIPhotoLayoutsEditor
 {
     class CanvasPrivate;
@@ -94,9 +95,15 @@ namespace KIPIPhotoLayoutsEditor
             /// Saves canvas state to SVG format file
             void save(const KUrl& file, bool setAsDefault = true);
 
+            /// Saves canvas state to SVG format file as a template file
+            void saveTemplate(const KUrl& file);
+
             /// Check if canvas is saved
             bool isSaved();
 
+            /// Check if canvas is loaded from template (read only)
+            bool isTemplate() const;
+
             /// Set selection mode
             void setSelectionMode(SelectionMode mode);
 
@@ -273,4 +280,4 @@ namespace KIPIPhotoLayoutsEditor
     };
 }
 
-#endif // DOCUMENT_H
+#endif // CANVAS_H
