@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2011-09-01
  * Description : a plugin to create photo layouts by fusion of several images.
  * Acknowledge : based on the expoblending plugin
  *
- * Copyright (C) 2011 by Łukasz Spas <lukasz dot spas at gmail dot com>
+ * Copyright (C) 2011      by Łukasz Spas <lukasz dot spas at gmail dot com>
  * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -37,6 +37,10 @@
 #include "ImageLoadingThread.h"
 #include "ProgressEvent.h"
 #include "CanvasLoadingThread.h"
+#include "PhotoItem.h"
+#include "SceneBorder.h"
+
+#include "kpimagedialog.h"
 
 #include "LayersModel.h"
 #include "LayersModelItem.h"
@@ -64,6 +68,7 @@
 #include <QUndoCommand>
 #include <QImageReader>
 #include <QtAlgorithms>
+#include <QBuffer>
 
 // KDE
 #include <kapplication.h>
@@ -88,12 +93,15 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         m_rot_item(0),
         m_scale_item(0),
         m_crop_item(0),
+        m_blend_active(false),
         m_readSceneMousePress_listener(0),
         m_readSceneMousePress_enabled(false),
         m_hovered_photo(0)
     {
         // Background of the scene
         m_background = new SceneBackground(m_scene);
+        // Border of the scene
+        m_border = new SceneBorder(m_scene);
     }
 
     QList<QGraphicsItem*> itemsAtPosition(const QPointF & scenePos, QWidget * widget)
@@ -107,11 +115,13 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         const QTransform viewTransform = view->viewportTransform();
         return m_scene->items(pointRect, Qt::IntersectsItemShape, Qt::DescendingOrder, viewTransform);
     }
+
     AbstractItemInterface * itemAt(const QPointF & scenePos, QWidget * widget)
     {
         QList<QGraphicsItem*> items = itemsAtPosition(scenePos, widget);
         return items.count() ? dynamic_cast<AbstractItemInterface*>(items.first()) : 0;
     }
+
     QList<AbstractItemInterface*> itemsAt(const QPointF & scenePos, QWidget * widget)
     {
         QList<QGraphicsItem*> items = itemsAtPosition(scenePos, widget);
@@ -124,6 +134,7 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         }
         return r;
     }
+
     void sendPressEventToItem(AbstractItemInterface * item, QGraphicsSceneMouseEvent * event)
     {
         if (!item)
@@ -136,6 +147,7 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         event->setLastPos(item->mapFromScene(event->lastScenePos()));
         item->mousePressEvent(event);
     }
+
     void sendMoveEventToItem(AbstractItemInterface * item, QGraphicsSceneMouseEvent * event)
     {
         if (!item)
@@ -148,6 +160,7 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         event->setLastPos(item->mapFromScene(event->lastScenePos()));
         item->mouseMoveEvent(event);
     }
+
     void sendReleaseEventToItem(AbstractItemInterface * item, QGraphicsSceneMouseEvent * event)
     {
         if (!item)
@@ -160,6 +173,7 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         event->setLastPos(item->mapFromScene(event->lastScenePos()));
         item->mouseReleaseEvent(event);
     }
+
     void sendDoubleClickEventToItem(AbstractItemInterface * item, QGraphicsSceneMouseEvent * event)
     {
         if (!item)
@@ -173,14 +187,6 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         item->mouseDoubleClickEvent(event);
     }
 
-    // Parent scene
-    QGraphicsScene * m_scene;
-    // Scene's model
-    LayersModel * model;
-    LayersSelectionModel * selection_model;
-    // Background item
-    SceneBackground * m_background;
-
     // Used for selecting items
     void deselectSelected()
     {
@@ -194,6 +200,7 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         m_selected_items.clear();
         m_selected_items_path = QPainterPath();
     }
+
     bool selectPressed()
     {
         if (m_pressed_item)
@@ -202,8 +209,8 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
             if (!m_pressed_item->isSelected())
             {
                 m_selected_items.insert(m_pressed_item, m_pressed_item->pos());
-                m_selected_items_path = m_selected_items_path.united(m_pressed_item->mapToScene(m_pressed_item->shape()));
-                m_selected_items_all_movable &= m_pressed_item->flags() & QGraphicsItem::ItemIsMovable;
+                m_selected_items_path        = m_selected_items_path.united(m_pressed_item->mapToScene(m_pressed_item->shape()));
+                m_selected_items_all_movable = ((m_pressed_item->flags() & QGraphicsItem::ItemIsMovable) != 0) && m_selected_items_all_movable;
                 m_pressed_item->setSelected(true);
                 setSelectionInitialPosition();
             }
@@ -211,6 +218,7 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         }
         return false;
     }
+
     void focusPressed()
     {
         if (!m_pressed_item)
@@ -219,6 +227,7 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         if (m_pressed_item->flags() & QGraphicsItem::ItemIsFocusable)
             m_pressed_item->setFocus(Qt::MouseFocusReason);
     }
+
     void setSelectionInitialPosition()
     {
         QMap<AbstractPhoto*,QPointF>::iterator it = m_selected_items.begin();
@@ -229,6 +238,7 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         }
         m_selected_items_path_initial_pos = m_selected_items_path.boundingRect().topLeft();
     }
+
     bool wasMoved()
     {
         QMap<AbstractPhoto*,QPointF>::iterator it = m_selected_items.begin();
@@ -240,32 +250,43 @@ class KIPIPhotoLayoutsEditor::ScenePrivate
         }
         return false;
     }
+
+    // Parent scene
+    QGraphicsScene*              m_scene;
+    // Scene's model
+    LayersModel*                 model;
+    LayersSelectionModel*        selection_model;
+    // Background item
+    SceneBackground*             m_background;
+    // Border item
+    SceneBorder*                 m_border;
+
     QMap<AbstractPhoto*,QPointF> m_selected_items;
-    AbstractItemInterface * m_pressed_object;
-    AbstractPhoto * m_pressed_item;
-    QPainterPath m_selected_items_path;
-    QPointF m_selected_items_path_initial_pos;
-    bool m_selected_items_all_movable;
-    bool m_selection_visible;
-    QList<const char *> m_selection_filters;
-    QPointF paste_scene_pos;
+    AbstractItemInterface*       m_pressed_object;
+    AbstractPhoto*               m_pressed_item;
+    QPainterPath                 m_selected_items_path;
+    QPointF                      m_selected_items_path_initial_pos;
+    bool                         m_selected_items_all_movable;
+    bool                         m_selection_visible;
+    QList<const char*>           m_selection_filters;
+    QPointF                      paste_scene_pos;
 
     // Used for rotating items
-    RotationWidgetItem * m_rot_item;
+    RotationWidgetItem*          m_rot_item;
 
     // Used for scaling item
-    ScalingWidgetItem * m_scale_item;
+    ScalingWidgetItem*           m_scale_item;
 
     // Used for cropping items
-    CropWidgetItem * m_crop_item;
-    bool m_blend_active;
+    CropWidgetItem*              m_crop_item;
+    bool                         m_blend_active;
 
     // For reading mouse press
-    MousePressListener * m_readSceneMousePress_listener;
-    bool m_readSceneMousePress_enabled;
+    MousePressListener*          m_readSceneMousePress_listener;
+    bool                         m_readSceneMousePress_enabled;
 
     // Used for drag&drop images
-    PhotoItem * m_hovered_photo;
+    PhotoItem*                   m_hovered_photo;
 
     friend class Scene;
 };
@@ -286,7 +307,7 @@ class KIPIPhotoLayoutsEditor::AddItemsCommand : public QUndoCommand
             items << item;
         }
         AddItemsCommand(const QList<AbstractPhoto*> & items, int position, Scene * scene, QUndoCommand * parent = 0) :
-            QUndoCommand(i18n("Add item(s)"), parent),
+            QUndoCommand(i18np("Add item", "Add items", items.count()), parent),
             items(items),
             position(position),
             scene(scene),
@@ -329,7 +350,7 @@ class KIPIPhotoLayoutsEditor::MoveItemsCommand : public QUndoCommand
         bool done;
     public:
         MoveItemsCommand(QMap<AbstractPhoto*,QPointF> items, Scene * scene, QUndoCommand * parent = 0) :
-            QUndoCommand(i18n("Move item(s)"), parent),
+            QUndoCommand(i18np("Move item", "Move items", items.count()), parent),
             m_items(items),
             m_scene(scene),
             done(true)
@@ -369,20 +390,24 @@ class KIPIPhotoLayoutsEditor::MoveItemsCommand : public QUndoCommand
 };
 class KIPIPhotoLayoutsEditor::RemoveItemsCommand : public QUndoCommand
 {
-        AbstractPhoto * item;
-        int item_row;
-        AbstractPhoto * item_parent;
-        Scene * m_scene;
-        bool done;
+        AbstractPhoto* item;
+        int            item_row;
+        AbstractPhoto* item_parent;
+        Scene*         m_scene;
+        bool           done;
+
     public:
+
         RemoveItemsCommand(AbstractPhoto * item, Scene * scene, QUndoCommand * parent = 0) :
             QUndoCommand(QString("Remove item"), parent),
             item(item),
+            item_row(0),
             m_scene(scene),
             done(false)
         {
             item_parent = dynamic_cast<AbstractPhoto*>(item->parentItem());
         }
+
         ~RemoveItemsCommand()
         {
             if (done)
@@ -391,6 +416,7 @@ class KIPIPhotoLayoutsEditor::RemoveItemsCommand : public QUndoCommand
                     delete item;
             }
         }
+
         virtual void redo()
         {
             QPersistentModelIndex parentIndex = QPersistentModelIndex(m_scene->model()->findIndex( item_parent ));
@@ -408,6 +434,7 @@ class KIPIPhotoLayoutsEditor::RemoveItemsCommand : public QUndoCommand
                 m_scene->QGraphicsScene::removeItem(item);
             done = true;
         }
+
         virtual void undo()
         {
             if (!done)
@@ -432,13 +459,16 @@ class KIPIPhotoLayoutsEditor::RemoveItemsCommand : public QUndoCommand
             }
             done = false;
         }
+
     private:
+
         static bool compareGraphicsItems(QGraphicsItem * i1, QGraphicsItem * i2)
         {
             if ((i1 && i2) && (i1->zValue() < i2->zValue()))
                 return true;
             return false;
         }
+
         void appendChild(AbstractPhoto * item, const QModelIndex & parent)
         {
             QList<QGraphicsItem*> items = item->childItems();
@@ -468,7 +498,7 @@ class KIPIPhotoLayoutsEditor::CropItemsCommand : public QUndoCommand
     QMap<AbstractPhoto*,QPainterPath> data;
 public:
     CropItemsCommand(const QPainterPath & path, const QList<AbstractPhoto*> & items, QUndoCommand * parent = 0) :
-        QUndoCommand(i18n("Crop item(s)"), parent)
+        QUndoCommand(i18np("Crop item", "Crop items", items.count()), parent)
     {
         qDebug() << "scene crop shape" << path.boundingRect();
         foreach(AbstractPhoto* item, items)
@@ -541,6 +571,12 @@ SceneBackground * Scene::background()
     return d->m_background;
 }
 
+//#####################################################################################################
+SceneBorder * Scene::border()
+{
+    return d->m_border;
+}
+
 //#####################################################################################################
 LayersModel * Scene::model() const
 {
@@ -607,7 +643,7 @@ void Scene::addItems(const QList<AbstractPhoto*> & items)
     QUndoCommand * parent = 0;
     QUndoCommand * command = 0;
     if (items.count() > 1)
-        parent = new QUndoCommand(i18n("Add item(s)"));
+        parent = new QUndoCommand( i18np("Add item", "Add items", items.count()) );
 
     foreach(AbstractPhoto* item, tempItems)
         command = new AddItemsCommand(item, insertionRow++, this, parent);
@@ -635,8 +671,8 @@ void Scene::removeItems(const QList<AbstractPhoto *> & items)
     QUndoCommand * command = 0;
     QUndoCommand * parent = 0;
     if (items.count() > 1)
-        parent = new QUndoCommand("Remove item(s)");
-    foreach(AbstractPhoto* item, items)
+        parent = new QUndoCommand( i18np("Remove item", "Remove items", items.count()) );
+    foreach (AbstractPhoto * item, items)
         command = new RemoveItemsCommand(item, this, parent);
     if (parent)
         PLE_PostUndoCommand(parent);
@@ -650,6 +686,27 @@ void Scene::removeSelectedItems()
     removeItems(selectedItems());
 }
 
+//#####################################################################################################
+void Scene::changeSelectedImage()
+{
+    QList<AbstractPhoto*> items = selectedItems();
+    if (items.count() != 1)
+        return;
+    PhotoItem * item = dynamic_cast<PhotoItem*>(items.first());
+    if (!item)
+        return;
+
+    KUrl::List urls = KIPIPlugins::KPImageDialog::getImageUrl(PhotoLayoutsEditor::instance());
+    if (urls.count() != 1)
+        return;
+
+    ImageLoadingThread * ilt = new ImageLoadingThread(this);
+    ilt->setImageUrl(urls.first());
+    ilt->setMaximumProgress(1);
+    connect(ilt, SIGNAL(imageLoaded(KUrl,QImage)), item, SLOT(imageLoaded(KUrl,QImage)));
+    ilt->start();
+}
+
 //#####################################################################################################
 void Scene::contextMenuEvent(QGraphicsSceneMouseEvent * event)
 {
@@ -659,7 +716,17 @@ void Scene::contextMenuEvent(QGraphicsSceneMouseEvent * event)
     QList<AbstractPhoto*> items = this->selectedItems();
     if (items.count())
     {
-        QAction * removeAction = menu.addAction( i18n("Delete selected item(s)") );
+        if (items.count() == 1)
+        {
+            PhotoItem * item = dynamic_cast<PhotoItem*>(items.first());
+            if (item)
+            {
+                QAction * removeAction = menu.addAction( i18n("Change item's image") );
+                connect(removeAction, SIGNAL(triggered()), this, SLOT(changeSelectedImage()));
+            }
+        }
+
+        QAction * removeAction = menu.addAction( i18np("Delete selected item", "Delete selected items", items.count()) );
         connect(removeAction, SIGNAL(triggered()), this, SLOT(removeSelectedItems()));
         menu.addSeparator();
     }
@@ -815,7 +882,7 @@ void Scene::mouseMoveEvent(QGraphicsSceneMouseEvent * event)
         if (d->m_pressed_object)
             d->sendMoveEventToItem(d->m_pressed_object, event);
 
-        if (m_interaction_mode & Moving)
+        if (m_interaction_mode & Moving && !event->isAccepted())
         {
             // Selecting pressed item
             event->setAccepted(d->selectPressed());
@@ -1283,6 +1350,18 @@ qreal Scene::gridVerticalDistance() const
 
 //#####################################################################################################
 QDomDocument Scene::toSvg(ProgressObserver * observer)
+{
+    return toSvg(observer, false);
+}
+
+//#####################################################################################################
+QDomDocument Scene::toTemplateSvg(ProgressObserver * observer)
+{
+    return toSvg(observer, true);
+}
+
+//#####################################################################################################
+QDomDocument Scene::toSvg(ProgressObserver * observer, bool asTemplate)
 {
     QDomDocument document;
 
@@ -1292,16 +1371,53 @@ QDomDocument Scene::toSvg(ProgressObserver * observer)
     sceneElement.setAttribute("height", QString::number(this->height()));
     document.appendChild(sceneElement);
 
+    if (asTemplate)
+    {
+        QDomElement previewImage = document.createElement("defs");
+        previewImage.setAttribute("id", "Preview");
+        QDomElement image = document.createElement("image");
+
+        QSizeF sceneSize = this->sceneRect().size();
+        double imgw = 200, imgh = 200;
+        if ((imgw / sceneSize.width()) < (imgh / sceneSize.height()))
+            imgh = qRound(sceneSize.height() * imgw / sceneSize.width());
+        else
+            imgw = qRound(sceneSize.width() * imgh / sceneSize.height());
+
+        QByteArray byteArray;
+        QBuffer buffer(&byteArray);
+        QImage img(QSize(imgw, imgh), QImage::Format_ARGB32_Premultiplied);
+        img.fill(Qt::white);
+        QPainter p(&img);
+        this->render(&p, QRectF(0, 0, imgw, imgh), this->sceneRect(), Qt::KeepAspectRatio);
+        p.end();
+        img.save(QString("/home/coder89/pliczek.png"));
+        img.save(&buffer, "PNG");
+        image.appendChild( document.createTextNode( QString(byteArray.toBase64()) ) );
+        image.setAttribute("width",QString::number((int)imgw));
+        image.setAttribute("height",QString::number((int)imgh));
+
+        previewImage.appendChild(image);
+        sceneElement.appendChild(previewImage);
+    }
+
     QList<QGraphicsItem*> itemsList = this->items(Qt::AscendingOrder);
-    observer->progresChanged(0);
+
+    if (observer)
+        observer->progresChanged(0);
+
     //--------------------------------------------------------
 
-    if (observer) observer->progresName( i18n("Saving background...") );
+    if (observer)
+        observer->progresName( i18n("Saving background...") );
+
     QDomElement background = document.createElement("g");
     background.setAttribute("class", "background");
     background.appendChild(d->m_background->toSvg(document));
     sceneElement.appendChild(background);
-    if (observer) observer->progresChanged(1.0 / (double)(itemsList.count()+1.0));
+
+    if (observer)
+        observer->progresChanged(1.0 / (double)(itemsList.count()+1.0));
 
     //--------------------------------------------------------
 
@@ -1309,14 +1425,33 @@ QDomDocument Scene::toSvg(ProgressObserver * observer)
     foreach(QGraphicsItem* item, itemsList)
     {
         AbstractPhoto * photo = dynamic_cast<AbstractPhoto*>(item);
+
         if (photo)
         {
-            if (observer) observer->progresName( i18n("Saving %1...", photo->name()) );
-            QDomDocument photoItemDocument = photo->toSvg();
+            if (observer) 
+                observer->progresName( i18n("Saving %1...", photo->name()) );
+
+            QDomDocument photoItemDocument = asTemplate ? photo->toTemplateSvg() : photo->toSvg();
             sceneElement.appendChild( photoItemDocument.documentElement() );
         }
-        if (observer) observer->progresChanged((double)i++ / (double)(itemsList.count()+1.0));
+
+        if (observer)
+            observer->progresChanged((double)i++ / (double)(itemsList.count()+1.0));
     }
+
+    //--------------------------------------------------------
+
+    if (observer)
+        observer->progresName( i18n("Saving border...") );
+
+    QDomElement border = document.createElement("g");
+    border.setAttribute("class", "border");
+    border.appendChild(d->m_border->toSvg(document));
+    sceneElement.appendChild(border);
+
+    if (observer)
+        observer->progresChanged(1.0 / (double)(itemsList.count()+1.0));
+
     return document;
 }
 
@@ -1362,6 +1497,11 @@ Scene * Scene::fromSvg(QDomElement & sceneElement)
             thread->addBackground(result->d->m_background, element);
             continue;
         }
+        else if (itemClass == "border")
+        {
+            thread->addBorder(result->d->m_border, element);
+            continue;
+        }
         else
             continue;
 
@@ -1382,7 +1522,7 @@ Scene * Scene::fromSvg(QDomElement & sceneElement)
     if (errorsCount)
     {
         KMessageBox::error(0,
-                           i18n("Unable to create %1 element(s)!", errorsCount));
+                           i18np("Unable to create one element!", "Unable to create %1 elements!", errorsCount));
     }
 
     return result;
@@ -1488,7 +1628,7 @@ bool Scene::askAboutRemoving(int count)
 {
     if (count)
     {
-        int result = KMessageBox::questionYesNo(KApplication::activeWindow(), i18n("Are you sure you want to delete %1 selected item(s)?", count), i18n("Items deleting"));
+        int result = KMessageBox::questionYesNo(KApplication::activeWindow(), i18np("Are you sure you want to delete selected item?", "Are you sure you want to delete %1 selected items?", count), i18n("Items deleting"));
         if (result == KMessageBox::Yes)
             return true;
     }
