@@ -102,7 +102,7 @@ void Plugin_PicasawebExport::setupActions()
 
     m_actionExport = new KAction(this);
     m_actionExport->setText(i18n("Export to &PicasaWeb..."));
-    m_actionExport->setIcon(KIcon("picasa"));
+    m_actionExport->setIcon(KIcon("kipi-picasa"));
     m_actionExport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_P));
     m_actionExport->setEnabled(false);
 
@@ -113,7 +113,7 @@ void Plugin_PicasawebExport::setupActions()
 
     m_actionImport = new KAction(this);
     m_actionImport->setText(i18n("Import from &PicasaWeb..."));
-    m_actionImport->setIcon(KIcon("picasa"));
+    m_actionImport->setIcon(KIcon("kipi-picasa"));
     m_actionImport->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::CTRL+Qt::Key_P));
     m_actionImport->setEnabled(false);
 
