@@ -1,13 +1,13 @@
 /* ===============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2010-10-01
  * Description : Dialog to allow a custom page layout for
  *               printimages plugin.
  *
- * Copyright (C) 2010 by Angelo Naselli <anaselli at linux dot it>
+ * Copyright (C) 2010-2012 by Angelo Naselli <anaselli at linux dot it>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,12 +30,12 @@ namespace KIPIPrintImagesPlugin
 
 enum CustomChoice
 {
-    PHOTO_GRID=1,
-    FIT_AS_MANY_AS_POSSIBLE=2,
-    PHOTOS_PER_PAGE = 3
+    PHOTO_GRID              = 1,
+    FIT_AS_MANY_AS_POSSIBLE = 2,
+    PHOTOS_PER_PAGE         = 3
 };
 
-CustomLayoutDlg::CustomLayoutDlg ( QWidget* parent )
+CustomLayoutDlg::CustomLayoutDlg(QWidget* const parent)
     : QDialog ( parent )
 {
     setupUi ( this );
@@ -77,13 +77,14 @@ void CustomLayoutDlg::readSettings()
     m_photoHeight->setValue(photoSize.height());
     m_photoWidth->setValue(photoSize.width());
 
-    int index = group.readEntry  ( "Custom-photoUnits", 0);
+    int index       = group.readEntry  ( "Custom-photoUnits", 0);
     m_photoUnits->setCurrentIndex(index);
 
     bool autorotate = group.readEntry ( "Custom-autorotate", 0 ) == 1;
     m_autorotate->setChecked(autorotate);
 
-    int choice = group.readEntry  ( "Custom-choice", (int)PHOTO_GRID);
+    int choice      = group.readEntry  ( "Custom-choice", (int)PHOTO_GRID);
+
     if (choice == PHOTOS_PER_PAGE)
     {
       m_photosXPageCheck->setChecked(true);
@@ -104,10 +105,12 @@ void CustomLayoutDlg::saveSettings()
     KConfigGroup group = config.group ( QString ( "PrintAssistant" ) );
 
     int choice = PHOTO_GRID;
+
     if (m_fitAsManyCheck->isChecked())
       choice = FIT_AS_MANY_AS_POSSIBLE;
     else if (m_photosXPageCheck->isChecked())
       choice = PHOTOS_PER_PAGE;
+
     group.writeEntry("Custom-choice", choice);
     group.writeEntry ("Custom-gridSize",  QSize(m_gridRows->value(), m_gridColumns->value()));
     group.writeEntry ("Custom-photoSize", QSize(m_photoWidth->value(), m_photoHeight->value()));
