@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2008-10-31
  * Description : a widget to display simple settings
@@ -47,7 +47,7 @@ public:
 
 public:
 
-    HaarSettingsWidget(QWidget* parent = 0);
+    HaarSettingsWidget(QWidget* const parent = 0);
     ~HaarSettingsWidget();
 
     void         loadSettings(HaarSettings&);
@@ -65,8 +65,8 @@ private:
 
 private:
 
-    struct SettingsTabPriv;
-    SettingsTabPriv* const d;
+    struct Private;
+    Private* const d;
 };
 
 } // namespace KIPIRemoveRedEyesPlugin
