@@ -6,7 +6,7 @@
  * Date        : 2003-10-01
  * Description : a kipi plugin to e-mailing images
  *
- * Copyright (C) 2003-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,11 +50,11 @@ namespace KIPISendimagesPlugin
 K_PLUGIN_FACTORY( SendImagesFactory, registerPlugin<Plugin_SendImages>(); )
 K_EXPORT_PLUGIN ( SendImagesFactory("kipiplugin_sendimages") )
 
-class Plugin_SendImages::Plugin_SendImagesPriv
+class Plugin_SendImages::Private
 {
 public:
 
-    Plugin_SendImagesPriv()
+    Private()
     {
         dialog              = 0;
         action_sendimages   = 0;
@@ -70,9 +70,12 @@ public:
 
 Plugin_SendImages::Plugin_SendImages(QObject* const parent, const QVariantList&)
     : Plugin(SendImagesFactory::componentData(), parent, "SendImages"), 
-      d(new Plugin_SendImagesPriv)
+      d(new Private)
 {
     kDebug(AREA_CODE_LOADING) << "Plugin_SendImages plugin loaded";
+
+    setUiBaseName("kipiplugin_sendimagesui.rc");
+    setupXML();
 }
 
 Plugin_SendImages::~Plugin_SendImages()
@@ -80,43 +83,52 @@ Plugin_SendImages::~Plugin_SendImages()
     delete d;
 }
 
-void Plugin_SendImages::setup(QWidget* widget)
+void Plugin_SendImages::setup(QWidget* const widget)
 {
     Plugin::setup(widget);
 
-    d->action_sendimages = actionCollection()->addAction("sendimages");
+    setupActions();
+
+    Interface* const iface = interface();
+
+    if (!iface)
+    {
+        kError() << "Kipi interface is null!";
+        return;
+    }
+
+    ImageCollection selection = iface->currentSelection();
+    d->action_sendimages->setEnabled(selection.isValid() && !selection.images().isEmpty() );
+
+    connect(iface, SIGNAL(selectionChanged(bool)),
+            d->action_sendimages, SLOT(setEnabled(bool)));
+}
+
+void Plugin_SendImages::setupActions()
+{
+    setDefaultCategory(ExportPlugin);
+
+    d->action_sendimages = new KAction(this);
     d->action_sendimages->setText(i18n("Email Images..."));
     d->action_sendimages->setIcon(KIcon("mail-send"));
 
     connect(d->action_sendimages, SIGNAL(triggered(bool)),
             this, SLOT(slotActivate()));
 
-    addAction(d->action_sendimages);
-
-    Interface* interface = dynamic_cast<Interface*>(parent());
-    if (!interface)
-    {
-        kError() << "Kipi interface is null!";
-        return;
-    }
-
-    ImageCollection selection = interface->currentSelection();
-    d->action_sendimages->setEnabled(selection.isValid() && !selection.images().isEmpty() );
-
-    connect(interface, SIGNAL(selectionChanged(bool)),
-            d->action_sendimages, SLOT(setEnabled(bool)));
+    addAction("sendimages", d->action_sendimages);
 }
 
 void Plugin_SendImages::slotActivate()
 {
-    Interface* interface = dynamic_cast<Interface*>(parent());
-    if (!interface)
+    Interface* const iface = interface();
+
+    if (!iface)
     {
        kError() << "Kipi interface is null!";
        return;
     }
 
-    ImageCollection images = interface->currentSelection();
+    ImageCollection images = iface->currentSelection();
 
     if ( !images.isValid() || images.images().isEmpty() )
         return;
@@ -132,7 +144,8 @@ void Plugin_SendImages::slotActivate()
 
 void Plugin_SendImages::slotPrepareEmail()
 {
-    Interface* interface = dynamic_cast<Interface*>(parent());
+    Interface* const interface = dynamic_cast<Interface*>(parent());
+
     if (!interface)
     {
        kError() << "Kipi interface is null!";
@@ -144,13 +157,4 @@ void Plugin_SendImages::slotPrepareEmail()
     d->sendImagesOperation->firstStage();
 }
 
-Category Plugin_SendImages::category(KAction* action) const
-{
-    if (action == d->action_sendimages)
-       return ExportPlugin;
-
-    kWarning() << "Unrecognized action for plugin category identification";
-    return ExportPlugin; // no warning from compiler, please
-}
-
 } // namespace KIPISendimagesPlugin
