@@ -84,7 +84,7 @@ SmugWindow::SmugWindow(const QString& tmpFolder, bool import, QWidget* const /*p
     m_widget      = new SmugWidget(this, iface(), import);
 
     setMainWidget(m_widget);
-    setWindowIcon(KIcon("smugmug"));
+    setWindowIcon(KIcon("kipi-smugmug"));
     setButtons(Help|User1|Close);
     setDefaultButton(Close);
     setModal(false);
@@ -694,7 +694,7 @@ bool SmugWindow::prepareImageForUpload(const QString& imgPath, bool isRAW)
     if (isRAW)
     {
         kDebug() << "Get RAW preview " << imgPath;
-        KDcrawIface::KDcraw::loadDcrawPreview(image, imgPath);
+        KDcrawIface::KDcraw::loadRawPreview(image, imgPath);
     }
     else
     {
