@@ -51,12 +51,13 @@
 namespace KExiv2Iface
 {
 
-class AltLangStrEdit::AltLangStrEditPriv
+class AltLangStrEdit::Private
 {
 public:
 
-    AltLangStrEditPriv()
+    Private()
     {
+        valueEdit       = 0;
         titleLabel      = 0;
         delValueButton  = 0;
         languageCB      = 0;
@@ -265,7 +266,7 @@ public:
 };
 
 AltLangStrEdit::AltLangStrEdit(QWidget* parent)
-              : QWidget(parent), d(new AltLangStrEditPriv)
+              : QWidget(parent), d(new Private)
 {
     QGridLayout* grid = new QGridLayout(this);
     d->titleLabel     = new QLabel(this);
@@ -419,7 +420,7 @@ void AltLangStrEdit::loadLangAltListEntries()
 
     // ...and now, all the rest...
 
-    for (AltLangStrEditPriv::LanguageCodeMap::Iterator it = d->languageCodeMap.begin();
+    for (Private::LanguageCodeMap::Iterator it = d->languageCodeMap.begin();
          it != d->languageCodeMap.end(); ++it)
     {
         if (!list.contains(it.key()))
