@@ -7,9 +7,9 @@
  * @date   2006-09-15
  * @brief  Common metadata image information manipulation methods
  *
- * @author Copyright (C) 2006-2011 by Gilles Caulier
+ * @author Copyright (C) 2006-2012 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2011 by Marcel Wiesweg
+ * @author Copyright (C) 2006-2012 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
  *
  * This program is free software; you can redistribute it
@@ -45,9 +45,7 @@ bool KExiv2::setImageProgramId(const QString& program, const QString& version) c
 
         // Set program info into Exif.Image.ProcessingSoftware tag (only available with Exiv2 >= 0.14.0).
 
-#if (EXIV2_TEST_VERSION(0,14,0))
         d->exifMetadata()["Exif.Image.ProcessingSoftware"] = std::string(software.toAscii().constData());
-#endif
 
         // See B.K.O #142564: Check if Exif.Image.Software already exist. If yes, do not touch this tag.
 
@@ -226,6 +224,24 @@ KExiv2::ImageOrientation KExiv2::getImageOrientation() const
         long orientation;
         ImageOrientation imageOrient = ORIENTATION_NORMAL;
 
+        // -- Standard Xmp tag --------------------------------
+
+#ifdef _XMP_SUPPORT_
+
+        bool ok = false;
+        QString str = getXmpTagString("Xmp.tiff.Orientation");
+        if (!str.isEmpty())
+        {
+            orientation = str.toLong(&ok);
+            if (ok)
+            {
+                kDebug() << "Orientation => Xmp.tiff.Orientation => " << (int)orientation;
+                return (ImageOrientation)orientation;
+            }
+        }
+
+#endif // _XMP_SUPPORT_
+
         // Because some camera set a wrong standard exif orientation tag,
         // We need to check makernote tags in first!
 
@@ -281,24 +297,6 @@ KExiv2::ImageOrientation KExiv2::getImageOrientation() const
             return (ImageOrientation)orientation;
         }
 
-        // -- Standard Xmp tag --------------------------------
-
-#ifdef _XMP_SUPPORT_
-
-        bool ok = false;
-        QString str = getXmpTagString("Xmp.tiff.Orientation");
-        if (!str.isEmpty())
-        {
-            orientation = str.toLong(&ok);
-            if (ok)
-            {
-                kDebug() << "Orientation => Xmp.tiff.Orientation => " << (int)orientation;
-                return (ImageOrientation)orientation;
-            }
-        }
-
-#endif // _XMP_SUPPORT_
-
     }
     catch( Exiv2::Error& e )
     {
