@@ -7,9 +7,9 @@
  * @date   2006-09-15
  * @brief  Iptc manipulation methods
  *
- * @author Copyright (C) 2006-2011 by Gilles Caulier
+ * @author Copyright (C) 2006-2012 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2011 by Marcel Wiesweg
+ * @author Copyright (C) 2006-2012 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
  *
  * This program is free software; you can redistribute it
@@ -82,20 +82,11 @@ QByteArray KExiv2::getIptc(bool addIrbHeader) const
 
             if (addIrbHeader)
             {
-#if (EXIV2_TEST_VERSION(0,10,0))
                 c2 = Exiv2::Photoshop::setIptcIrb(0, 0, iptc);
-#else
-                kDebug() << "Exiv2 version is to old. Cannot add Irb header to Iptc metadata";
-                return QByteArray();
-#endif
             }
             else
             {
-#if (EXIV2_TEST_VERSION(0,17,91))
                 c2 = Exiv2::IptcParser::encode(d->iptcMetadata());
-#else
-                c2 = iptc.copy();
-#endif
             }
 
             QByteArray data((const char*)c2.pData_, c2.size_);
@@ -120,15 +111,8 @@ bool KExiv2::setIptc(const QByteArray& data) const
     {
         if (!data.isEmpty())
         {
-#if (EXIV2_TEST_VERSION(0,17,91))
             Exiv2::IptcParser::decode(d->iptcMetadata(), (const Exiv2::byte*)data.data(), data.size());
             return (!d->iptcMetadata().empty());
-#else
-            if (d->iptcMetadata().load((const Exiv2::byte*)data.data(), data.size()) != 0)
-                return false;
-            else
-                return true;
-#endif
         }
     }
     catch( Exiv2::Error& e )
