@@ -46,6 +46,8 @@ MarkerModelHelper::~MarkerModelHelper()
 
 void MarkerModelHelper::slotDataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight)
 {
+    Q_UNUSED(topLeft)
+    Q_UNUSED(bottomRight)
     emit(signalModelChangedDrastically());
 }
 
@@ -614,6 +616,7 @@ void TestItemMarkerTiler::testSelectionState1()
 void TestItemMarkerTiler::benchmarkIteratorWholeWorld()
 {
     return;
+#if 0
 //     QBENCHMARK
     {
         QScopedPointer<QStandardItemModel> itemModel(new QStandardItemModel());
@@ -647,6 +650,7 @@ void TestItemMarkerTiler::benchmarkIteratorWholeWorld()
             }
         }
     }
+#endif
 }
 
 QTEST_MAIN(TestItemMarkerTiler)
