@@ -7,7 +7,7 @@
  * @date   2008-02-22
  * @brief  image collection selector template
  *
- * @author Copyright (C) 2008-2010 by Gilles Caulier
+ * @author Copyright (C) 2008-2012 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  *
  * This program is free software; you can redistribute it
@@ -23,15 +23,18 @@
  *
  * ============================================================ */
 
+#include "imagecollectionselector.moc"
+
 // Local includes
 
-#include "imagecollectionselector.moc"
+#include "imagecollection.h"
+#include <kdebug.h>
 
 namespace KIPI 
 {
 
-ImageCollectionSelector::ImageCollectionSelector(QWidget* parent)
-                       : QWidget(parent)
+ImageCollectionSelector::ImageCollectionSelector(QWidget* const parent)
+    : QWidget(parent)
 {
 }
 
@@ -44,4 +47,8 @@ QList<ImageCollection> ImageCollectionSelector::selectedImageCollections() const
     return QList<ImageCollection>();
 }
 
+void ImageCollectionSelector::enableVirtualCollections(bool /*flag*/)
+{
+}
+
 } // namespace KIPI
