@@ -109,7 +109,8 @@ bool KSaneOption::needsPolling()
 {
     if (!m_optDesc) return false;
 
-    if ((m_optDesc->cap & SANE_CAP_AUTOMATIC) || !(m_optDesc->cap & SANE_CAP_SOFT_SELECT)) {
+    if ((m_optDesc->cap & SANE_CAP_SOFT_DETECT) && !(m_optDesc->cap & SANE_CAP_SOFT_SELECT)) {
+        kDebug() << name() << "optDesc->cap =" << m_optDesc->cap;
         return true;
     }
 
@@ -161,19 +162,35 @@ void KSaneOption::readValue() {}
 SANE_Word KSaneOption::toSANE_Word(unsigned char *data)
 {
     SANE_Word tmp;
+    // if __BYTE_ORDER is not defined we get #if 0 == 0
+    #if __BYTE_ORDER == __LITTLE_ENDIAN
     tmp  = (data[0]&0xff);
     tmp += ((SANE_Word)(data[1]&0xff))<<8;
     tmp += ((SANE_Word)(data[2]&0xff))<<16;
     tmp += ((SANE_Word)(data[3]&0xff))<<24;
+    #else
+    tmp  = (data[3]&0xff);
+    tmp += ((SANE_Word)(data[2]&0xff))<<8;
+    tmp += ((SANE_Word)(data[1]&0xff))<<16;
+    tmp += ((SANE_Word)(data[0]&0xff))<<24;
+    #endif
     return tmp;
 }
 
 void KSaneOption::fromSANE_Word(unsigned char *data, SANE_Word from)
 {
+    // if __BYTE_ORDER is not defined we get #if 0 == 0
+    #if __BYTE_ORDER == __LITTLE_ENDIAN
     data[0] = (from & 0x000000FF);
     data[1] = (from & 0x0000FF00)>>8;
     data[2] = (from & 0x00FF0000)>>16;
     data[3] = (from & 0xFF000000)>>24;
+    #else
+    data[3] = (from & 0x000000FF);
+    data[2] = (from & 0x0000FF00)>>8;
+    data[1] = (from & 0x00FF0000)>>16;
+    data[0] = (from & 0xFF000000)>>24;
+    #endif
 }
 
 bool KSaneOption::getMinValue(float &) {return false;}
