@@ -16,7 +16,7 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#include "allmessageslistjob.h"
+#include "allmessageslistjob.moc"
 #include "messageslistjob.h"
 
 #include <KDebug>
@@ -83,7 +83,10 @@ void AllMessagesListJob::jobFinished(KJob *kjob)
 {
     MessagesListJob *job = dynamic_cast<MessagesListJob *>(kjob);
     Q_ASSERT(job);
+
+    if (!job) return;
     m_jobs.removeAll(job);
+
     if (job->error()) {
         setError(job->error());
         setErrorText(job->errorText());
