@@ -16,7 +16,7 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#include "messageinfo.h"
+#include "messageinfo.moc"
 #include "util.h"
 
 #include <QtCore/QRegExp>
