@@ -38,7 +38,7 @@ QString QIntList::join() const
     for (int i = 0; i < size(); i ++)
     {
         if (i)
-            res += ",";
+            res += ',';
         res += QString::number(at(i));
     }
 
