@@ -2,12 +2,12 @@
  * @file
  *
  * This file is a part of KDE project
- * <a href="https://projects.kde.org/projects/kdereview/libmediawiki">libmediawiki</a>
+ * <a href="https://projects.kde.org/projects/extragear/libs/libmediawiki">libmediawiki</a>
  *
  * @date   2011-03-22
  * @brief  a MediaWiki C++ interface for KDE
  *
- * @author Copyright (C) 2011 by Gilles Caulier
+ * @author Copyright (C) 2011-2012 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2010 by Ludovic Delfau
  *         <a href="mailto:ludovicdelfau at gmail dot com">ludovicdelfau at gmail dot com</a>
@@ -58,7 +58,7 @@ public:
     QString imcontinue;
 };
 
-QueryImages::QueryImages(MediaWiki& mediawiki, QObject* parent)
+QueryImages::QueryImages(MediaWiki& mediawiki, QObject* const parent)
     : Job(*new QueryImagesPrivate(mediawiki, "10"), parent)
 {
 }
@@ -90,10 +90,10 @@ void QueryImages::doWorkSendRequest()
 
     // Set the url
     QUrl url = d->mediawiki.url();
-    url.addQueryItem("format", "xml");
-    url.addQueryItem("action", "query");
-    url.addQueryItem("titles", d->title);
-    url.addQueryItem("prop", "images");
+    url.addQueryItem("format",  "xml");
+    url.addQueryItem("action",  "query");
+    url.addQueryItem("titles",  d->title);
+    url.addQueryItem("prop",    "images");
     url.addQueryItem("imlimit", d->limit);
     if (!d->imcontinue.isNull())
     {
