@@ -5,10 +5,12 @@
 # Redistribution and use is allowed according to the terms of the BSD license.
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
 #
-# Copy this script on root folder where are source code
+# before to run this script you must set these sheel variable :
+# $DKCoverityToken with token of digiKam project given by Coverity SCAN.
+# $DKCoverityEmail with email adress to send SCAN result.
 #
 # See this url to see how to prepare your computer with Coverity SCAN tool:
-# http://scan.coverity.com/self-build/
+# http://scan.coverity.com/projects/285/upload_form
 
 cd ../..
 
@@ -35,16 +37,15 @@ echo "-----------------------------"
 echo "Coverity Scan tarball 'myproject.tgz' uploading in progress..."
 
 nslookup scan5.coverity.com
+SECONDS=0
 
-curl -v \
-     --progress-bar \
+curl --form project=digiKam \
+     --form token=$DKCoverityToken \
+     --form email=$DKCoverityEmail \
      --form file=@myproject.tgz \
-     --form project=digiKam \
-     --form password=$digiKamCoverityPassword \
-     --form email=caulier.gilles@gmail.com \
      --form version=git-master \
      --form description="$desc" \
      http://scan5.coverity.com/cgi-bin/upload.py
 
 echo "Done. Coverity Scan tarball 'myproject.tgz' is uploaded and ready for analyse."
-
+echo "That took approximately $SECONDS seconds to upload."
